@@ -18,7 +18,11 @@ password		=
 dbname			= 
 tables_prefix	= 
 port			= 3306
-adapter			= PDO_MYSQL ; PDO_MYSQL or MYSQLI
+adapter			= PDO_MYSQL
+; if charset is set to utf8, Piwik will ensure that it is storing its data using UTF8 charset.
+; it will add a sql query SET at each page view.
+; Piwik should work correctly without this setting.  
+;charset		= utf8
 
 [database_tests]
 host 			= localhost
@@ -39,6 +43,10 @@ always_archive_data_day = 0;
 ; and a profiling summary will be printed at the end of the request
 enable_sql_profiler = 0
 
+; if set to 1, a Piwik tag will be included in the Piwik UI footer and will track visits, pages, etc. to idsite = 1
+; this is useful for Piwik developers as an easy way to create data in their local Piwik
+track_visits_inside_piwik_ui = 0
+
 [General]
 ; Time in seconds after which an archive will be computed again. 
 ; This setting is used only for today's statistics.
@@ -68,8 +76,17 @@ enable_browser_archiving_triggering = 1
 ; the page first-post in the subcategory development which belongs to the blog category
 action_category_delimiter = /
 
+; this action name is used when the URL ends with a slash / 
+; it is useful to have an actual string to write in the UI
+action_default_name 		= index
+
+; this action name is used when the URL has no page title or page URL defined
+action_default_name_when_not_defined = "page title not defined"
+action_default_url_when_not_defined = "page url not defined"
+
 ; currency used by default when reporting money in Piwik
-default_currency = "$"
+; the trailing space is required for php 5.2.x vs 5.3 compatibility
+default_currency = "$ "
 
 ; if you want all your users to use Piwik in only one language, disable the LanguagesManager
 ; plugin, and set this default_language (users won't see the language drop down) 
@@ -90,8 +107,12 @@ show_website_selector_in_user_interface = 1
 minimum_php_version = 5.1.3
 
 ; MySQL minimum required version
+; note: timezone support added in 4.1.3
 minimum_mysql_version = 4.1
 
+; PostgreSQL minimum required version
+minimum_pgsql_version = 8.3
+
 ; Minimum adviced memory limit in php.ini file (see memory_limit value)
 minimum_memory_limit = 128
 
@@ -119,13 +140,27 @@ datatable_archiving_maximum_rows_actions = 500
 ; maximum number of rows for pages in categories (sub pages, when clicking on the + for a page category)
 datatable_archiving_maximum_rows_subtable_actions = 100
 
+; by default, Piwik uses self-hosted AJAX libraries.
+; If set to 1, Piwik uses a Content Distribution Network
+use_ajax_cdn = 0
+
+; required AJAX library versions
+jquery_version = 1.3.2
+jqueryui_version = 1.7.2
+swfobject_version = 2.2
+
+; If set to 0, Flash widgets require separate HTTP requests
+; (i.e., one request to load the JavaScript which instantiates Open Flash Chart; the other request is made by OFC to download the JSON data for the chart)
+; If set to 1, Piwik uses a single HTTP request per Flash widget to serve both the widget and data
+serve_widget_and_data = 1
+
+; If set to 1, Piwik adds a response header to workaround the IE+Flash+HTTPS bug.
+reverse_proxy = 0
+
 [Tracker]
 ; set to 0 if you want to stop tracking the visitors. Useful if you need to stop all the connections on the DB.
 record_statistics			= 1
 
-; this action name is used when the javascript variable piwik_action_name is not specified in the piwik javascript code, and when the URL has no path.
-default_action_name 		= index
-
 ; length of a visit in seconds. If a visitor comes back on the website visit_standard_length seconds after his last page view, it will be recorded as a new visit  
 visit_standard_length       = 1800
 
@@ -161,24 +196,8 @@ campaign_var_name			= piwik_campaign
 ; Example: If a visitor first visits 'index.php?piwik_campaign=Adwords-CPC&piwik_kwd=My killer keyword' then it will be counted as a campaign referer named 'Adwords-CPC' with the keyword 'My killer keyword'
 campaign_keyword_var_name	= piwik_kwd
 
-; variable name used to specify a download link
-; Example: '/piwik.php?idsite=1&download=http://piwik.org/piwik.zip' will redirect to 'http://piwik.org/piwik.zip'
-download_url_var_name 		= download
-
-; variable name used to specify a link to an external website
-; Example: '/piwik.php?idsite=1&link=http://piwik.org/' will redirect to 'http://piwik.org/'
-outlink_url_var_name		= link
-
-; variable name used to specify that the user should be redirected to the clicked linked, or the downloaded file
-; eg. http://yourwebsite.org/piwik/piwik.php?idsite=1&link=http://example.org&redirect=1
-;     will count the outlink in piwik and redirect the user to http://example.org
-; eg. http://yourwebsite.org/piwik/piwik.php?idsite=1&download=http://yourwebsite.org/download.pdf&redirect=1
-;     will count the download in piwik and redirect the user to http://yourwebsite.org/download.pdf
-; NOTE: it is recommended to rely on the automatic outlink and download tracking (more information on http://piwik.org/docs/javascript-tracking/). 
-;       rather than adding a depending on Piwik for your website to function properly. 
-;       However this feature is useful to some users as it gives a simple and reliable way of counting clicks, that you can then query using the Piwik API.
-outlink_redirect_var_name	= redirect
-download_redirect_var_name	= redirect
+; maximum length of a Page Title or a Page URL recorded in the log_action.name table
+page_maximum_length = 1024;
 
 [log]
 ;possible values for log: screen, database, file
@@ -187,9 +206,9 @@ logger_message[]		= screen
 logger_error[]			= screen
 logger_exception[]		= screen
 
-; if configured to log in files, log files will be created in this relative path
-; eg. if the value is tmp/logs files will be created in /path/to/piwik/tmp/logs/ 
-logger_file_path		= tmp/logs/
+; if configured to log in files, log files will be created in this path
+; eg. if the value is tmp/logs files will be created in /path/to/piwik/tmp/logs/
+logger_file_path		= tmp/logs
 
 ; all calls to the API (method name, parameters, execution time, caller IP, etc.)
 ; disabled by default as it can cause serious overhead and should only be used wisely
@@ -222,6 +241,7 @@ Plugins[] 		= Widgetize
 Plugins[] 		= LanguagesManager
 Plugins[] 		= Actions
 Plugins[] 		= Dashboard
+Plugins[] 		= MultiSites
 Plugins[] 		= Referers
 Plugins[] 		= UserSettings
 
