@@ -4,11 +4,16 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: Proxy.php 581 2008-07-27 23:07:52Z matt $
+ * @version $Id: Proxy.php 1530 2009-10-22 22:40:18Z matt $
  * 
- * @package Piwik_API
+ * @category Piwik
+ * @package Piwik
  */
 
+/**
+ * To differentiate between "no value" and default value of null
+ */
+class Piwik_API_Proxy_NoDefaultValue {}
 
 /**
  * Proxy is a singleton that has the knowledge of every method available, their parameters 
@@ -18,7 +23,8 @@
  * 
  * It will also log the performance of API calls (time spent, parameter values, etc.) if logger available
  * 
- * @package Piwik_API
+ * @package Piwik
+ * @subpackage Piwik_API
  */
 class Piwik_API_Proxy
 {
@@ -27,11 +33,14 @@ class Piwik_API_Proxy
 	
 	private $metadataArray = array();
 	
-	// when a parameter doesn't have a default value we use this constant
-	const NO_DEFAULT_VALUE = null;
+	// when a parameter doesn't have a default value we use this
+	private $noDefaultValue;
 
 	static private $instance = null;
-	protected function __construct() {}
+	protected function __construct()
+	{
+		$this->noDefaultValue = new Piwik_API_Proxy_NoDefaultValue();
+	}
 	
 	/**
 	 * Singleton, returns instance
@@ -127,21 +136,18 @@ class Piwik_API_Proxy
 			
 			// get the list of parameters required by the method
 			$parameterNamesDefaultValues = $this->getParametersList($className, $methodName);
-			
+
 			// load parameters in the right order, etc.
 			$finalParameters = $this->getRequestParametersArray( $parameterNamesDefaultValues, $parametersRequest );
 
-			// all parameters to the function call must be non null
-			$this->checkParametersAreNotNull($className, $methodName, $finalParameters);
-
 			// start the timer
-			$timer = new Piwik_Timer;
+			$timer = new Piwik_Timer();
 			
 			// call the method
 			$returnedValue = call_user_func_array(array($object, $methodName), $finalParameters);
 			
 			// log the API Call
-			Zend_Registry::get('logger_api_call')->log(
+			Zend_Registry::get('logger_api_call')->logEvent(
 								$className,
 								$methodName,
 								$parameterNamesDefaultValues,
@@ -149,8 +155,7 @@ class Piwik_API_Proxy
 								$timer->getTimeMs(),
 								$returnedValue
 							);
-		}
-		catch( Piwik_Access_NoAccessException $e) {
+		} catch(Piwik_Access_NoAccessException $e) {
 			throw $e;
 		}
 
@@ -197,17 +202,17 @@ class Piwik_API_Proxy
 		foreach($requiredParameters as $name => $defaultValue)
 		{
 			try{
-				if($defaultValue === Piwik_API_Proxy::NO_DEFAULT_VALUE)
+				if($defaultValue instanceof Piwik_API_Proxy_NoDefaultValue)
 				{
-					try {
-						$requestValue = Piwik_Common::getRequestVar($name, null, null, $parametersRequest);
-					} catch(Exception $e) {
-						$requestValue = null;
-					}
+					$requestValue = Piwik_Common::getRequestVar($name, null, null, $parametersRequest);
 				}
 				else
 				{
-					$requestValue = Piwik_Common::getRequestVar($name, $defaultValue, null, $parametersRequest);
+					try{
+						$requestValue = Piwik_Common::getRequestVar($name, $defaultValue, null, $parametersRequest);
+					} catch(Exception $e) {
+						$requestValue = $defaultValue;
+					}
 				}
 			} catch(Exception $e) {
 				throw new Exception("The required variable '$name' is not correct or has not been found in the API Request. Add the parameter '&$name=' (with a value) in the URL.");
@@ -225,20 +230,13 @@ class Piwik_API_Proxy
 	private function includeApiFile($fileName)
 	{
 		$module = self::getModuleNameFromClassName($fileName);
-		$potentialPaths = array( $module ."/API.php", );
-		
-		$found = false;
-		foreach($potentialPaths as $path)
+		$path = PIWIK_INCLUDE_PATH . '/plugins/' . $module . '/API.php';
+
+		if(Zend_Loader::isReadable($path))
 		{
-			if(Zend_Loader::isReadable($path))
-			{
-				require_once $path;
-				$found = true;
-				break;
-			}
+			require_once $path; // prefixed by PIWIK_INCLUDE_PATH
 		}
-		
-		if(!$found)
+		else
 		{
 			throw new Exception("API module $module not found.");
 		}
@@ -248,7 +246,9 @@ class Piwik_API_Proxy
 	{
 		if($method->isPublic() 
 			&& !$method->isConstructor()
-			&& $method->getName() != 'getInstance' )
+			&& $method->getName() != 'getInstance'
+			&& false === strstr($method->getDocComment(), '@deprecated')
+			 )
 		{
 			$name = $method->getName();
 			$parameters = $method->getParameters();
@@ -258,7 +258,7 @@ class Piwik_API_Proxy
 			{
 				$nameVariable = $parameter->getName();
 				
-				$defaultValue = self::NO_DEFAULT_VALUE;
+				$defaultValue = $this->noDefaultValue;
 				if($parameter->isDefaultValueAvailable())
 				{
 					$defaultValue = $parameter->getDefaultValue();
@@ -310,21 +310,6 @@ class Piwik_API_Proxy
 		return isset($this->metadataArray[$className][$methodName]);
 	}
 		
-	/**
-	 * @throws exception If any parameter value is null
-	 */
-	private function checkParametersAreNotNull($className, $methodName, $parametersValues)
-	{
-		foreach($parametersValues as $value)
-		{
-			if(is_null($value))
-			{
-				$nbParamsRequired = $this->getNumberOfRequiredParameters($className, $methodName);
-				throw new Exception("The parameters are not valid. The method called requires $nbParamsRequired parameters. Please check your URL and the method API.");
-			}
-		}
-	}
-	
 	/**
 	 * Checks that the class is a Singleton (presence of the getInstance() method)
 	 * 
