@@ -4,15 +4,12 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: Request.php 506 2008-06-06 01:18:47Z matt $
+ * @version $Id: Request.php 1420 2009-08-22 13:23:16Z vipsoft $
  * 
- * 
- * @package Piwik_API
+ * @category Piwik
+ * @package Piwik
  */
 
-require_once "API/ResponseBuilder.php";
-require_once "API/DataTableGenericFilter.php";
-
 /**
  * An API request is the object used to make a call to the API and get the result.
  * The request has the format of a normal GET request, ie. parameter_1=X&parameter_2=Y
@@ -36,7 +33,8 @@ require_once "API/DataTableGenericFilter.php";
  *  echo $result;
  * 
  * @see http://dev.piwik.org/trac/wiki/API
- * @package Piwik_API
+ * @package Piwik
+ * @subpackage Piwik_API
  */
 class Piwik_API_Request
 {	
@@ -60,13 +58,7 @@ class Piwik_API_Request
 			$request = trim($request);
 			$request = str_replace(array("\n","\t"),'', $request);
 			parse_str($request, $requestArray);
-
-			// if a token_auth is specified in the API request, we load the right permissions
-			if(isset($requestArray['token_auth']))
-			{
-				Piwik_PostEvent('API.Request.authenticate', $requestArray['token_auth']);
-				Zend_Registry::get('access')->reloadAccess();
-			}
+		
 			$requestArray = $requestArray + $defaultRequest;
 		}
 		
@@ -105,12 +97,20 @@ class Piwik_API_Request
 			
 			if(!Piwik_PluginsManager::getInstance()->isPluginActivated($module))
 			{
-				throw new Exception_PluginDeactivated($module);
+				throw new Piwik_FrontController_PluginDeactivatedException($module);
 			}
 			$module = "Piwik_" . $module . "_API";
 
+			// if a token_auth is specified in the API request, we load the right permissions
+			$token_auth = Piwik_Common::getRequestVar('token_auth', '', 'string', $this->request);
+			if($token_auth)
+			{
+				Piwik_PostEvent('API.Request.authenticate', $token_auth);
+				Zend_Registry::get('access')->reloadAccess();
+			}
+			
 			// call the method 
-			$returnedValue = Piwik_Api_Proxy::getInstance()->call($module, $method, $this->request);
+			$returnedValue = Piwik_API_Proxy::getInstance()->call($module, $method, $this->request);
 			
 			$toReturn = $response->getResponse($returnedValue);
 		} catch(Exception $e ) {
@@ -134,5 +134,4 @@ class Piwik_API_Request
 		}
 		return $a;
 	}
-
 }
