@@ -1,5 +1,19 @@
 <?php
+/**
+ * Piwik - Open source web analytics
+ * 
+ * @link http://piwik.org
+ * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
+ * @version $Id: ResponseBuilder.php 1420 2009-08-22 13:23:16Z vipsoft $
+ * 
+ * @category Piwik
+ * @package Piwik
+ */
 
+/**
+ * @package Piwik
+ * @subpackage Piwik_API
+ */
 class Piwik_API_ResponseBuilder
 {
 	private $request = null;
@@ -184,6 +198,10 @@ class Piwik_API_ResponseBuilder
 			$renderer->setSerialize( $this->caseRendererPHPSerialize());
 			$renderer->setPrettyDisplay(Piwik_Common::getRequestVar('prettyDisplay', false, 'int', $this->request));
 		}
+		else if($format == 'html')
+		{
+			$renderer->setTableId($this->request['method']);
+		}
 		
 		return $renderer->render();
 	}
@@ -234,7 +252,6 @@ class Piwik_API_ResponseBuilder
 
 	protected function handleScalar($scalar)
 	{
-		require_once "DataTable/Simple.php";
 		$dataTable = new Piwik_DataTable_Simple();
 		$dataTable->addRowsFromArray( array($scalar) );
 		return $this->getRenderedDataTable($dataTable);
@@ -279,6 +296,5 @@ class Piwik_API_ResponseBuilder
 			$dataTable->addRowsFromSimpleArray($array);
 			return $this->getRenderedDataTable($dataTable);
 		}
-	}
-	
+	}	
 }
