@@ -4,14 +4,12 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: Access.php 581 2008-07-27 23:07:52Z matt $
+ * @version $Id: Access.php 1420 2009-08-22 13:23:16Z vipsoft $
  *
+ * @category Piwik
  * @package Piwik
- *
  */
 
-require_once 'SitesManager/API.php';
-
 /**
  * Class to handle User Access:
  * - loads user access from the Piwik_Auth_Result object 
@@ -35,8 +33,8 @@ require_once 'SitesManager/API.php';
  * and he only can change the main configuration settings.
  *
  * @package Piwik
+ * @subpackage Piwik_Access
  */
-
 class Piwik_Access
 {	
 	/**
@@ -158,7 +156,12 @@ class Piwik_Access
 		}
 		return true;
 	}
-	
+
+	/**
+	 * Reload super user access
+	 *
+	 * @return bool
+	 */	
 	protected function reloadAccessSuperUser()
 	{
 		$this->isSuperUser = true;
@@ -169,8 +172,6 @@ class Piwik_Access
 	/**
 	 * We bypass the normal auth method and give the current user Super User rights.
 	 * This should be very carefully used.
-	 * 
-	 * @return void
 	 */
 	public function setSuperUser()
 	{
@@ -189,6 +190,7 @@ class Piwik_Access
 	
 	/**
 	 * Returns the current user login
+	 *
 	 * @return string|null
 	 */
 	public function getLogin()
@@ -198,6 +200,7 @@ class Piwik_Access
 
 	/**
 	 * Returns the token_auth used to authenticate this user in the API
+	 *
 	 * @return string|null
 	 */
 	public function getTokenAuth()
@@ -264,6 +267,7 @@ class Piwik_Access
 
 	/**
 	 * If the user doesn't have an ADMIN access for at least one website, throws an exception
+	 *
 	 * @throws Exception
 	 */
 	public function checkUserHasSomeAdminAccess()
@@ -277,6 +281,7 @@ class Piwik_Access
 	
 	/**
 	 * If the user doesn't have any view permission, throw exception
+	 *
 	 * @throws Exception
 	 */
 	public function checkUserHasSomeViewAccess()
@@ -350,6 +355,7 @@ class Piwik_Access
  * Exception thrown when a user doesn't  have sufficient access.
  * 
  * @package Piwik
+ * @subpackage Piwik_Access
  */
 class Piwik_Access_NoAccessException extends Exception
 {}
