@@ -1,6 +1,19 @@
 <?php
-require_once "Archive/Array.php";
+/**
+ * Piwik - Open source web analytics
+ * 
+ * @link http://piwik.org
+ * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
+ * @version $Id: IndexedByDate.php 1420 2009-08-22 13:23:16Z vipsoft $
+ * 
+ * @category Piwik
+ * @package Piwik
+ */
 
+/**
+ * @package Piwik
+ * @subpackage Piwik_Archive
+ */
 class Piwik_Archive_Array_IndexedByDate extends Piwik_Archive_Array 
 {
 	/**
@@ -79,6 +92,12 @@ class Piwik_Archive_Array_IndexedByDate extends Piwik_Archive_Array
 		foreach($queries as $table => $aIds)
 		{
 			$inIds = implode(', ', $aIds);
+			if(empty($inIds))
+			{
+				// Probable timezone configuration error, i.e., mismatch between PHP and MySQL server.
+				continue;
+			}
+
 			$sql = "SELECT value, name, UNIX_TIMESTAMP(date1) as timestamp
 									FROM $table
 									WHERE idarchive IN ( $inIds )
