@@ -4,12 +4,12 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: Day.php 504 2008-06-01 20:19:28Z matt $
+ * @version $Id: Day.php 1547 2009-10-28 06:08:49Z vipsoft $
  * 
- * @package Piwik_ArchiveProcessing
+ * @category Piwik
+ * @package Piwik
  */
 
-
 /**
  * Handles the archiving process for a day. 
  * The class provides generic helper methods to manipulate data from the DB, 
@@ -17,8 +17,8 @@
  * 
  * All the logic of the archiving is done inside the plugins listening to the event 'ArchiveProcessing_Day.compute'
  * 
- * @package Piwik_ArchiveProcessing
- * 
+ * @package Piwik
+ * @subpackage Piwik_ArchiveProcessing
  */
 class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 {
@@ -28,13 +28,11 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 		$this->db = Zend_Registry::get('db');
 		$this->debugAlwaysArchive = Zend_Registry::get('config')->Debug->always_archive_data_day;
 	}
-	
+
 	/**
 	 * Main method to process logs for a day. The only logic done here is computing the number of visits, actions, etc.
 	 * All the other reports are computed inside plugins listening to the event 'ArchiveProcessing_Day.compute'.
 	 * See some of the plugins for an example eg. 'Provider'
-	 * 
-	 * @return void
 	 */
 	protected function compute()
 	{
@@ -49,20 +47,20 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 					WHERE visit_server_date = ?
 						AND idsite = ?
 					GROUP BY visit_server_date
-					ORDER BY NULL
-				 ";
+					ORDER BY NULL";
 		$row = $this->db->fetchRow($query, array($this->strDateStart,$this->idsite ) );
-		
-		if($row === false)
+		if($row === false || $row === null)
 		{
 			return;
 		}
+
 		$this->isThereSomeVisits = true;
 	
 		foreach($row as $name => $value)
 		{
 			$this->insertNumericRecord($name, $value);
 		}
+
 		$this->setNumberOfVisits($row['nb_visits']);
 		$this->setNumberOfVisitsConverted($row['nb_visits_converted']);
 		Piwik_PostEvent('ArchiveProcessing_Day.compute', $this);
@@ -97,14 +95,14 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 		{
 			$count = array($labelCount => $count);
 		}
-		$table = new Piwik_DataTable;
+		$table = new Piwik_DataTable();
 		$table->addRowsFromArrayWithIndexLabel($data);
 		return $table;
 	}
 	
 	public function getDataTableFromArray( $array )
 	{
-		$table = new Piwik_DataTable;
+		$table = new Piwik_DataTable();
 		$table->addRowsFromArrayWithIndexLabel($array);
 		return $table;
 	}
@@ -156,7 +154,8 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 				FROM ".$this->logTable."
 				WHERE visit_server_date = ?
 					AND idsite = ?
-				GROUP BY label";
+				GROUP BY label
+				ORDER BY NULL";
 		$query = $this->db->query($query, array( $this->strDateStart, $this->idsite ) );
 
 		$interest = array();
@@ -178,7 +177,7 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 	 */
 	static public function generateDataTable( $table )
 	{
-		$dataTableToReturn = new Piwik_DataTable;
+		$dataTableToReturn = new Piwik_DataTable();
 		foreach($table as $label => $maybeDatatableRow)
 		{
 			// case the aInfo is a subtable-like array
@@ -216,7 +215,7 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 	 */
 	public function getDataTableSerialized( $array )
 	{
-		$table = new Piwik_DataTable;
+		$table = new Piwik_DataTable();
 		$table->addRowsFromArrayWithIndexLabel($array );
 		$toReturn = $table->getSerialized();
 		return $toReturn;
@@ -253,11 +252,11 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 		$tablesByLabel = array();
 		foreach($arrayLevel0 as $label => $aAllRowsForThisLabel)
 		{
-			$table = new Piwik_DataTable;
+			$table = new Piwik_DataTable();
 			$table->addRowsFromArrayWithIndexLabel($aAllRowsForThisLabel);
 			$tablesByLabel[$label] = $table;
 		}
-		$parentTableLevel0 = new Piwik_DataTable;
+		$parentTableLevel0 = new Piwik_DataTable();
 		$parentTableLevel0->addRowsFromArrayWithIndexLabel($subArrayLevel1ByKey, $tablesByLabel);
 
 		return $parentTableLevel0;
@@ -330,7 +329,8 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 			 	FROM ".$this->logConversionTable."
 			 	WHERE visit_server_date = ?
 			 		AND idsite = ?
-			 	GROUP BY idgoal $segments";
+			 	GROUP BY idgoal $segments
+				ORDER BY NULL";
 		$query = $this->db->query($query, array( $this->strDateStart, $this->idsite ));
 		return $query;
 	}
@@ -344,7 +344,8 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 			 	FROM ".$this->logConversionTable."
 			 	WHERE visit_server_date = ?
 			 		AND idsite = ?
-			 	GROUP BY idgoal, label";
+			 	GROUP BY idgoal, label
+				ORDER BY NULL";
 		$query = $this->db->query($query, array( $this->strDateStart, $this->idsite ));
 		return $query;
 	}
@@ -373,8 +374,8 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 	 * 			LABEL2 => array( Piwik_Archive::INDEX_NB_VISITS => Y, [...] )
 	 * 			);
 	 * 		)
-	 * @param array by reference, will be modified
-	 * @return void (array by reference is modified)
+	 *
+	 * @param array $interestByLabel Passed by reference, will be modified
 	 */
 	function enrichConversionsByLabelArray(&$interestByLabel)
 	{
@@ -395,8 +396,7 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 	}
 
 	/**
-	 * @param array $interestByLabelAndSubLabel
-	 * @return void (array by reference is modified)
+	 * @param array $interestByLabelAndSubLabel Passed by reference, will be modified
 	 */
 	function enrichConversionsByLabelArrayHasTwoLevels(&$interestByLabelAndSubLabel)
 	{
@@ -426,5 +426,3 @@ class Piwik_ArchiveProcessing_Day extends Piwik_ArchiveProcessing
 					);
 	}
 }
-
-
