@@ -4,9 +4,10 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: Common.php 581 2008-07-27 23:07:52Z matt $
+ * @version $Id: Common.php 1682 2009-12-13 21:25:01Z vipsoft $
  *
- * @package Piwik_Helper
+ * @category Piwik
+ * @package Piwik
  */
 
 /**
@@ -16,13 +17,12 @@
  * This class should contain only the functions that are used in
  * both the CORE and the piwik.php statistics logging engine.
  *
- * @package Piwik_Helper
+ * @package Piwik
  */
 class Piwik_Common
 {
 	/**
 	 * Const used to map the referer type to an integer in the log_visit table
-	 *
 	 */
 	const REFERER_TYPE_DIRECT_ENTRY		= 1;
 	const REFERER_TYPE_SEARCH_ENGINE	= 2;
@@ -32,15 +32,13 @@ class Piwik_Common
 	/**
 	 * Flag used with htmlspecialchar
 	 * See php.net/htmlspecialchars
-	 *
 	 */
 	const HTML_ENCODING_QUOTE_STYLE		= ENT_COMPAT;
 
-	
 	/**
 	 * Returns the table name prefixed by the table prefix.
 	 * Works in both Tracker and UI mode.
-	 * 
+	 *
 	 * @param string The table name to prefix, ie "log_visit"
 	 * @return string The table name prefixed, ie "piwik-production_log_visit"
 	 */
@@ -64,7 +62,7 @@ class Piwik_Common
 		}
 		return $prefixTable . $table;
 	}
-	
+
 	/**
 	 * Returns array containing data about the website: goals, URLs, etc.
 	 *
@@ -73,10 +71,11 @@ class Piwik_Common
 	 */
 	static function getCacheWebsiteAttributes( $idSite )
 	{
+		require_once PIWIK_INCLUDE_PATH . '/core/Loader.php';
+
 		static $cache = null;
 		if(is_null($cache))
 		{
-			require_once "CacheFile.php";
 			$cache = new Piwik_CacheFile('tracker');
 		}
 		$filename = $idSite;
@@ -85,30 +84,13 @@ class Piwik_Common
 		{
 			return $cacheContent;
 		}
-		if(defined('PIWIK_TRACKER_MODE') 
-			&& PIWIK_TRACKER_MODE) 
+		if(defined('PIWIK_TRACKER_MODE')
+			&& PIWIK_TRACKER_MODE)
 		{
-			//TODO we can remove these includes when #620 is done
-			require_once "Zend/Exception.php";
-			require_once "Zend/Loader.php"; 
-			require_once "Zend/Auth.php";
-			require_once "Timer.php";
-			require_once "PluginsManager.php";
-			require_once "Piwik.php";
-			require_once "Access.php";
-			require_once "Auth.php";
-			require_once "API/Proxy.php";
-			require_once "Archive.php";
-			require_once "Site.php";
-			require_once "Date.php";
-			require_once "DataTable.php";
-			require_once "Translate.php";
-			require_once "Mail.php";
-			require_once "Url.php";
-			require_once "Controller.php";
-			require_once "Option.php";
-			require_once "View.php";
-			require_once "UpdateCheck.php";
+			require_once PIWIK_INCLUDE_PATH . '/core/PluginsManager.php';
+			require_once PIWIK_INCLUDE_PATH . '/core/Translate.php';
+			require_once PIWIK_INCLUDE_PATH . '/core/Option.php';
+
 			Zend_Registry::set('db', Piwik_Tracker::getDatabase());
 			Piwik::createAccessObject();
 			Piwik::createConfigObject();
@@ -127,12 +109,11 @@ class Piwik_Common
 		}
 		return $content;
 	}
-	
+
 	/**
-	 * Delete existing Tracker cache files and regenerate them
-	 * 
+	 * Regenerate Tracker cache files
+	 *
 	 * @param array $idSites array of idSites to clear cache for
-	 * @return void
 	 */
 	static public function regenerateCacheWebsiteAttributes($idSites = array())
 	{
@@ -145,10 +126,14 @@ class Piwik_Common
 			self::getCacheWebsiteAttributes($idSite);
 		}
 	}
-	
+
+	/**
+	 * Delete existing Tracker cache
+	 *
+	 * @param string $idSite (website ID of the site to clear cache for
+	 */
 	static public function deleteCacheWebsiteAttributes( $idSite )
 	{
-		require_once "CacheFile.php";
 		$cache = new Piwik_CacheFile('tracker');
 		$filename = $idSite;
 		$cache->delete($filename);
@@ -175,16 +160,15 @@ class Piwik_Common
 		}
 		return $result;
 	}
-	
+
 	/**
 	 * ending WITHOUT slash
-	 * @return string 
+	 * @return string
 	 */
 	static public function getPathToPiwikRoot()
 	{
-		return realpath( dirname(__FILE__). "/../" );
+		return realpath( dirname(__FILE__). "/.." );
 	}
-	
 
 	/**
 	 * Returns the value of a GET parameter $parameter in an URL query $urlQuery
@@ -238,7 +222,7 @@ class Piwik_Common
 			{
 				$exploded = explode('=',$value);
 				$name = $exploded[0];
-				
+
 				// if array without indexes
 				if( substr($name,-2,2) == '[]' )
 				{
@@ -258,17 +242,24 @@ class Piwik_Common
 		return $nameToValue;
 	}
 
+	/**
+	 * Create directory if permitted
+	 *
+	 * @param string $path
+	 * @param int $mode (in octal)
+	 * @param bool $denyAccess
+	 */
 	static public function mkdir( $path, $mode = 0755, $denyAccess = true )
 	{
 		if(!is_dir($path))
 		{
-			$directoryParent = Piwik_Common::realpath(dirname($path));
+			$directoryParent = self::realpath(dirname($path));
 			if( is_writable($directoryParent) )
 			{
 				mkdir($path, $mode, true);
 			}
 		}
-		
+
 		if($denyAccess)
 		{
 			self::createHtAccess($path);
@@ -276,22 +267,33 @@ class Piwik_Common
 	}
 
 	/**
-	 * path without trailing slash
+	 * Create .htaccess file in specified directory
+	 *
+	 * Apache-specific; for IIS @see web.config
+	 *
+	 * @param string $path without trailing slash
 	 */
 	static public function createHtAccess( $path )
 	{
-		@file_put_contents($path . "/.htaccess", "Deny from all");
+		@file_put_contents($path . '/.htaccess', 'Deny from all');
 	}
-	
+
+	/**
+	 * Get canonicalized absolute path
+	 * See http://php.net/realpath
+	 *
+	 * @param string $path
+	 * @return string canonicalized absolute path
+	 */
 	static public function realpath($path)
 	{
-		if (file_exists($path)) 
+		if (file_exists($path))
 		{
 		    return realpath($path);
-		} 
+		}
 	    return $path;
 	}
-	
+
 	/**
 	 * Returns true if the string is a valid filename
 	 * File names that start with a-Z or 0-9 and contain a-Z, 0-9, underscore(_), dash(-), and dot(.) will be accepted.
@@ -304,9 +306,9 @@ class Piwik_Common
 	 */
 	static public function isValidFilename($filename)
 	{
-		return (0 !== preg_match("/(^[a-zA-Z0-9]+([a-zA-Z\_0-9\.-]*))$/" , $filename));
+		return (0 !== preg_match('/(^[a-zA-Z0-9]+([a-zA-Z_0-9.-]*))$/', $filename));
 	}
-	
+
 	/**
 	 * Returns true if the string passed may be a URL.
 	 * We don't need a precise test here because the value comes from the website
@@ -317,7 +319,7 @@ class Piwik_Common
 	 */
 	static function isLookLikeUrl( $url )
 	{
-		return preg_match('/^(ftp|news|http|https)?:\/\/(.*)$/', $url, $matches) !== 0
+		return preg_match('~^(ftp|news|http|https)?://(.*)$~', $url, $matches) !== 0
 				&& strlen($matches[2]) > 0;
 	}
 
@@ -354,7 +356,7 @@ class Piwik_Common
 			$value = self::sanitizeInputValue($value);
 
 			// Undo the damage caused by magic_quotes -- only before php 5.3 as it is now deprecated
-			if ( version_compare(phpversion(), '5.3') === -1 
+			if ( version_compare(phpversion(), '5.3') === -1
 				&& get_magic_quotes_gpc())
 			{
 				$value = stripslashes($value);
@@ -365,14 +367,14 @@ class Piwik_Common
 			foreach (array_keys($value) as $key)
 			{
 				$newKey = $key;
-				$newKey = Piwik_Common::sanitizeInputValues($newKey);
+				$newKey = self::sanitizeInputValues($newKey);
 				if ($key != $newKey)
 				{
 					$value[$newKey] = $value[$key];
 					unset($value[$key]);
 				}
 
-				$value[$newKey] = Piwik_Common::sanitizeInputValues($value[$newKey]);
+				$value[$newKey] = self::sanitizeInputValues($value[$newKey]);
 			}
 		}
 		elseif( !is_null($value)
@@ -383,26 +385,38 @@ class Piwik_Common
 		return $value;
 	}
 
+	/**
+	 * Sanitize a single input value
+	 *
+	 * @param string $value
+	 * @return string sanitized input
+	 */
 	static public function sanitizeInputValue($value)
 	{
-		return htmlspecialchars($value, Piwik_Common::HTML_ENCODING_QUOTE_STYLE, 'UTF-8');
+		return htmlspecialchars($value, self::HTML_ENCODING_QUOTE_STYLE, 'UTF-8');
 	}
-	
+
+	/**
+	 * Unsanitize a single input value
+	 *
+	 * @param string $value
+	 * @return string unsanitized input
+	 */
 	static public function unsanitizeInputValue($value)
 	{
-		return htmlspecialchars_decode($value, Piwik_Common::HTML_ENCODING_QUOTE_STYLE);
+		return htmlspecialchars_decode($value, self::HTML_ENCODING_QUOTE_STYLE);
 	}
-	
+
 	/**
 	 * Returns a sanitized variable value from the $_GET and $_POST superglobal.
 	 * If the variable doesn't have a value or an empty value, returns the defaultValue if specified.
 	 * If the variable doesn't have neither a value nor a default value provided, an exception is raised.
 	 *
 	 * @see sanitizeInputValues() for the applied sanitization
-	 *  
+	 *
 	 * @param string $varName name of the variable
 	 * @param string $varDefault default value. If '', and if the type doesn't match, exit() !
-	 * @param string $varType Expected type, the value must be one of the following: array, numeric, int, integer, string
+	 * @param string $varType Expected type, the value must be one of the following: array, int, integer, string
 	 *
 	 * @exception if the variable type is not known
 	 * @exception if the variable we want to read doesn't have neither a value nor a default value specified
@@ -446,29 +460,25 @@ class Piwik_Common
 				return $varDefault;
 			}
 		}
-	
+
 		// Normal case, there is a value available in REQUEST for the requested varName
 		$value = self::sanitizeInputValues( $requestArrayToUse[$varName] );
 
 		if( !is_null($varType))
 		{
 			$ok = false;
-				
+
 			if($varType == 'string')
 			{
 				if(is_string($value)) $ok = true;
 			}
-			elseif($varType == 'numeric')
-			{
-				if(is_numeric($value) || $value==(int)$value || $value==(float)$value) $ok = true;
-			}
 			elseif($varType == 'integer')
 			{
-				if(is_int($value) || $value==(int)$value) $ok = true;
+				if($value == (string)(int)$value) $ok = true;
 			}
 			elseif($varType == 'float')
 			{
-				if(is_float($value) || $value==(float)$value) $ok = true;
+				if($value == (string)(float)$value) $ok = true;
 			}
 			elseif($varType == 'array')
 			{
@@ -476,9 +486,9 @@ class Piwik_Common
 			}
 			else
 			{
-				throw new Exception("\$varType specified is not known. It should be one of the following: array, numeric, int, integer, float, string");
+				throw new Exception("\$varType specified is not known. It should be one of the following: array, int, integer, float, string");
 			}
-				
+
 			// The type is not correct
 			if($ok === false)
 			{
@@ -497,6 +507,30 @@ class Piwik_Common
 		return $value;
 	}
 
+	/**
+	 * Unserialize (serialized) array
+	 *
+	 * @param string
+	 * @return array or original string if not unserializable
+	 */
+	public static function unserialize_array( $str )
+	{
+		// we set the unserialized version only for arrays as you can have set a serialized string on purpose
+		if (preg_match('/^a:[0-9]+:{/', $str)
+			&& !preg_match('/(^|;|{|})O:[0-9]+:"/', $str)
+			&& strpos($str, "\0") === false)
+		{
+			if( ($arrayValue = @unserialize($str)) !== false
+				&& is_array($arrayValue) )
+			{
+				return $arrayValue;
+			}
+		}
+
+		// return original string
+		return $str;
+	}
+
 	/**
 	 * Returns a 32 characters long uniq ID
 	 *
@@ -507,6 +541,32 @@ class Piwik_Common
 		return md5(uniqid(rand(), true));
 	}
 
+	/**
+	 * Get salt from [superuser] section
+	 *
+	 * @return string
+	 */
+	static public function getSalt()
+	{
+		static $salt = null;
+		if(is_null($salt))
+		{
+			if(defined('PIWIK_TRACKER_MODE') && PIWIK_TRACKER_MODE)
+			{
+				$salt = Piwik_Tracker_Config::getInstance()->superuser['salt'];
+			}
+			else
+			{
+				$config = Zend_Registry::get('config');
+				if($config !== false)
+				{
+					$salt = $config->superuser->salt;
+				}
+			}
+		}
+		return $salt;
+	}
+
 	/**
 	 * Convert dotted IP to a stringified integer representation
 	 *
@@ -525,13 +585,13 @@ class Piwik_Common
 	static public function getIpString()
 	{
 		if(isset($_SERVER['HTTP_CLIENT_IP'])
-		&& ($ip = Piwik_Common::getFirstIpFromList($_SERVER['HTTP_CLIENT_IP']))
+		&& ($ip = self::getFirstIpFromList($_SERVER['HTTP_CLIENT_IP']))
 		&& strpos($ip, "unknown") === false)
 		{
 			return $ip;
 		}
 		elseif(isset($_SERVER['HTTP_X_FORWARDED_FOR'])
-		&& $ip = Piwik_Common::getFirstIpFromList($_SERVER['HTTP_X_FORWARDED_FOR'])
+		&& $ip = self::getFirstIpFromList($_SERVER['HTTP_X_FORWARDED_FOR'])
 		&& isset($ip)
 		&& !empty($ip)
 		&& strpos($ip, "unknown")===false )
@@ -539,26 +599,25 @@ class Piwik_Common
 			return $ip;
 		}
 		elseif( isset($_SERVER['HTTP_CLIENT_IP'])
-		&& strlen( Piwik_Common::getFirstIpFromList($_SERVER['HTTP_CLIENT_IP']) ) != 0 )
+		&& strlen( self::getFirstIpFromList($_SERVER['HTTP_CLIENT_IP']) ) != 0 )
 		{
-			return Piwik_Common::getFirstIpFromList($_SERVER['HTTP_CLIENT_IP']);
+			return self::getFirstIpFromList($_SERVER['HTTP_CLIENT_IP']);
 		}
 		else if( isset($_SERVER['HTTP_X_FORWARDED_FOR'])
-		&& strlen ($ip = Piwik_Common::getFirstIpFromList($_SERVER['HTTP_X_FORWARDED_FOR'])) != 0)
+		&& strlen ($ip = self::getFirstIpFromList($_SERVER['HTTP_X_FORWARDED_FOR'])) != 0)
 		{
 			return $ip;
 		}
 		elseif(isset($_SERVER['REMOTE_ADDR']))
 		{
-			return Piwik_Common::getFirstIpFromList($_SERVER['REMOTE_ADDR']);	
+			return self::getFirstIpFromList($_SERVER['REMOTE_ADDR']);
 		}
 		else
 		{
-			return '0.0.0.0';	
+			return '0.0.0.0';
 		}
 	}
 
-
 	/**
 	 * Returns the first element of a comma separated list of IPs
 	 *
@@ -571,12 +630,11 @@ class Piwik_Common
 		$p = strpos($ip, ',');
 		if($p!==false)
 		{
-			return trim(Piwik_Common::sanitizeInputValues(substr($ip, 0, $p)));
+			return trim(self::sanitizeInputValues(substr($ip, 0, $p)));
 		}
-		return trim(Piwik_Common::sanitizeInputValues($ip));
+		return trim(self::sanitizeInputValues($ip));
 	}
 
-
 	/**
 	 * Returns the continent of a given country
 	 *
@@ -586,11 +644,11 @@ class Piwik_Common
 	 */
 	static public function getContinent($country)
 	{
-		require_once "DataFiles/Countries.php";
+		require_once PIWIK_INCLUDE_PATH . '/core/DataFiles/Countries.php';
 		$countryList = $GLOBALS['Piwik_CountryList'];
-		if(isset($countryList[$country][0]))
+		if(isset($countryList[$country]))
 		{
-			return $countryList[$country][0];
+			return $countryList[$country];
 		}
 		return 'unk';
 	}
@@ -598,20 +656,30 @@ class Piwik_Common
 	/**
 	 * Returns the browser language code, eg. "en-gb,en;q=0.5"
 	 *
+	 * @param string $browerLang (optional browser language)
 	 * @return string
 	 */
 	static public function getBrowserLanguage($browserLang = NULL)
 	{
 		static $replacementPatterns = array(
-				'/(\\\\.)/',     // quoted-pairs (RFC 3282)
-				'/(\s+)/',       // CFWS white space
-				'/(\([^)]*\))/', // CFWS comments
-				'/(;q=[0-9.]+)/' // quality
+				// extraneous bits of RFC 3282 that we ignore
+				'/(\\\\.)/',		// quoted-pairs
+				'/(\s+)/',			// CFWS white space
+				'/(\([^)]*\))/',	// CFWS comments
+				'/(;q=[0-9.]+)/',	// quality
+
+				// found in the LANG environment variable
+				'/\.(.*)/',			// charset (e.g., en_CA.UTF-8)
+				'/^C$/',			// POSIX 'C' locale
 			);
 
 		if(is_null($browserLang))
 		{
-			$browserLang = Piwik_Common::sanitizeInputValues(@$_SERVER['HTTP_ACCEPT_LANGUAGE']);
+			$browserLang = self::sanitizeInputValues(@$_SERVER['HTTP_ACCEPT_LANGUAGE']);
+			if(empty($browserLang) && self::isPhpCliMode())
+			{
+				$browserLang = @$_ENV['LANG'];
+			}
 		}
 
 		if(is_null($browserLang))
@@ -630,7 +698,7 @@ class Piwik_Common
 			$browserLang = preg_replace($replacementPatterns, '', $browserLang);
 
 			$browserLang = preg_replace('/((^|,)chrome:.*)/', '', $browserLang, 1); // Firefox bug
-			$browserLang = preg_replace('/(,)(?:en-securid,)|(?:(^|,)en-securid(,|$))/', '\\1',	$browserLang, 1); // unregistered language tag
+			$browserLang = preg_replace('/(,)(?:en-securid,)|(?:(^|,)en-securid(,|$))/', '$1',	$browserLang, 1); // unregistered language tag
 
 			$browserLang = str_replace('sr-sp', 'sr-rs', $browserLang); // unofficial (proposed) code in the wild
 		}
@@ -643,7 +711,7 @@ class Piwik_Common
 	 *
 	 * @param string $lang browser lang
 	 * @param bool If set to true, some assumption will be made and detection guessed more often, but accuracy could be affected
-	 * @return string 2 letter ISO code 
+	 * @return string 2 letter ISO code
 	 */
 	static public function getCountry( $lang, $enableLanguageToCountryGuess )
 	{
@@ -655,7 +723,7 @@ class Piwik_Common
 		$validCountries = self::getCountriesList();
 		return self::extractCountryCodeFromBrowserLanguage($lang, $validCountries, $enableLanguageToCountryGuess);
 	}
-	
+
 	/**
 	 * Returns list of valid country codes
 	 *
@@ -666,14 +734,18 @@ class Piwik_Common
 		static $countriesList = null;
 		if(is_null($countriesList))
 		{
-			require_once "DataFiles/Countries.php";
+			require_once PIWIK_INCLUDE_PATH . '/core/DataFiles/Countries.php';
 			$countriesList = array_keys($GLOBALS['Piwik_CountryList']);
 		}
 		return $countriesList;
 	}
+
 	/**
 	 * Returns list of valid country codes
 	 *
+	 * @param string $browserLanguage
+	 * @param array of string $validCountries
+	 * @param bool $enableLanguageToCountryGuess (if true, will guess country based on language that lacks region information)
 	 * @return array of 2 letter ISO codes
 	 */
 	static public function extractCountryCodeFromBrowserLanguage($browserLanguage, $validCountries, $enableLanguageToCountryGuess)
@@ -681,10 +753,10 @@ class Piwik_Common
 		static $langToCountry = null;
 		if(is_null($langToCountry))
  		{
-			require_once "DataFiles/LanguageToCountry.php";
+			require_once PIWIK_INCLUDE_PATH . '/core/DataFiles/LanguageToCountry.php';
 			$langToCountry = array_keys($GLOBALS['Piwik_LanguageToCountry']);
  		}
- 
+
  		if($enableLanguageToCountryGuess)
  		{
 			if(preg_match('/^([a-z]{2,3})(?:,|;|$)/', $browserLanguage, $matches))
@@ -696,8 +768,8 @@ class Piwik_Common
 				}
  			}
  		}
- 
-		if(!empty($validCountries) && preg_match_all("/[-]([a-z]{2})/", $browserLanguage, $matches, PREG_SET_ORDER))
+
+		if(!empty($validCountries) && preg_match_all('/[-]([a-z]{2})/', $browserLanguage, $matches, PREG_SET_ORDER))
  		{
 			foreach($matches as $parts)
  			{
@@ -707,23 +779,21 @@ class Piwik_Common
 					return $parts[1];
 				}
  			}
- 		}	
+ 		}
 		return 'xx';
 	}
-	
-	
+
  	/**
 	 * Returns the visitor language based only on the Browser 'accepted language' information
 	 *
 	 * @param string $lang browser lang
-	 *
 	 * @return string 2 letter ISO 639 code
 	 */
 	static public function extractLanguageCodeFromBrowserLanguage($browserLanguage, $validLanguages)
 	{
 		// assumes language preference is sorted;
 		// does not handle language-script-region tags or language range (*)
-		if(!empty($validLanguages) && preg_match_all("/(?:^|,)([a-z]{2,3})([-][a-z]{2})?/", $browserLanguage, $matches, PREG_SET_ORDER))
+		if(!empty($validLanguages) && preg_match_all('/(?:^|,)([a-z]{2,3})([-][a-z]{2})?/', $browserLanguage, $matches, PREG_SET_ORDER))
  		{
 			foreach($matches as $parts)
  			{
@@ -744,27 +814,26 @@ class Piwik_Common
  		}
 		return 'xx';
  	}
-	
 
 	/**
-	 * Extracts a keyword from a raw not encoded URL. 
+	 * Extracts a keyword from a raw not encoded URL.
 	 * Will only extract keyword if a known search engine has been detected.
-	 * Returns the keyword: 
-	 * - in UTF8: automatically converted from other charsets when applicable 
+	 * Returns the keyword:
+	 * - in UTF8: automatically converted from other charsets when applicable
 	 * - strtolowered: "QUErY test!" will return "query test!"
 	 * - trimmed: extra spaces before and after are removed
-	 * 
+	 *
 	 * Lists of supported search engines can be found in /core/DataFiles/SearchEngines.php
 	 * The function returns false when a keyword couldn't be found.
-	 * 	 eg. if the url is "http://www.google.com/partners.html" this will return false, 
-	 *       as the google keyword parameter couldn't be found. 
-	 * 
+	 * 	 eg. if the url is "http://www.google.com/partners.html" this will return false,
+	 *       as the google keyword parameter couldn't be found.
+	 *
 	 * @see unit tests in /tests/core/Common.test.php
 	 * @param string URL referer URL, eg. $_SERVER['HTTP_REFERER']
 	 * @return array|false false if a keyword couldn't be extracted,
 	 * 						or array(
-	 * 							'name' => 'Google', 
-	 * 							'keywords' => 'my searched keywords') 
+	 * 							'name' => 'Google',
+	 * 							'keywords' => 'my searched keywords')
 	 */
 	static public function extractSearchEngineInformationFromUrl($refererUrl)
 	{
@@ -782,14 +851,23 @@ class Piwik_Common
 		{
 			return false;
 		}
-		require_once "DataFiles/SearchEngines.php";
-		
+		require_once PIWIK_INCLUDE_PATH . '/core/DataFiles/SearchEngines.php';
+
 		if(!array_key_exists($refererHost, $GLOBALS['Piwik_SearchEngines']))
 		{
 			return false;
 		}
 		$searchEngineName = $GLOBALS['Piwik_SearchEngines'][$refererHost][0];
-		$variableNames = $GLOBALS['Piwik_SearchEngines'][$refererHost][1];
+		$variableNames = null;
+		if(isset($GLOBALS['Piwik_SearchEngines'][$refererHost][1]))
+		{
+			$variableNames = $GLOBALS['Piwik_SearchEngines'][$refererHost][1];
+		}
+		if(!$variableNames)
+		{
+			$url = $GLOBALS['Piwik_SearchEngines_NameToUrl'][$searchEngineName];
+			$variableNames = $GLOBALS['Piwik_SearchEngines'][$url][1];
+		}
 		if(!is_array($variableNames))
 		{
 			$variableNames = array($variableNames);
@@ -798,14 +876,14 @@ class Piwik_Common
 
 		if($searchEngineName == 'Google Images')
 		{
-			$query = urldecode(trim(strtolower(Piwik_Common::getParameterFromQueryString($query, 'prev'))));
+			$query = urldecode(trim(strtolower(self::getParameterFromQueryString($query, 'prev'))));
 			$query = str_replace('&', '&amp;', strstr($query, '?'));
 		}
-		
+
 		foreach($variableNames as $variableName)
 		{
 			// search for keywords now &vname=keyword
-			$key = strtolower(Piwik_Common::getParameterFromQueryString($query, $variableName));
+			$key = strtolower(self::getParameterFromQueryString($query, $variableName));
 			$key = trim(urldecode($key));
 			if(!empty($key))
 			{
@@ -816,12 +894,12 @@ class Piwik_Common
 		{
 			return false;
 		}
-		
-		if(function_exists('iconv') 
+
+		if(function_exists('iconv')
 			&& isset($GLOBALS['Piwik_SearchEngines'][$refererHost][3]))
 		{
 			$charset = trim($GLOBALS['Piwik_SearchEngines'][$refererHost][3]);
-			if(!empty($charset)) 
+			if(!empty($charset))
 			{
 				$key = @iconv($charset, 'utf-8//IGNORE', $key);
 			}
@@ -831,15 +909,14 @@ class Piwik_Common
 			'keywords' => $key,
 		);
 	}
-	
+
 	/**
-	 * Generate random string 
+	 * Generate random string
 	 *
 	 * @param string $length string length
 	 * @param string $alphabet characters allowed in random string
-	 *
 	 * @return string random string with given length
-	 */	
+	 */
 	public static function getRandomString($length = 16, $alphabet = "abcdefghijklmnoprstuvwxyz0123456789")
 	{
 		$chars = $alphabet;
@@ -848,7 +925,7 @@ class Piwik_Common
 		list($usec, $sec) = explode(" ", microtime());
 		$seed = ((float)$sec+(float)$usec)*100000;
 		mt_srand($seed);
-		
+
 		for($i = 0; $i < $length; $i++)
 		{
 			$rand_key = mt_rand(0, strlen($chars)-1);
@@ -856,6 +933,16 @@ class Piwik_Common
 		}
 		return str_shuffle($str);
 	}
+
+	/**
+	 * Returns true if PHP was invoked from command-line interface (shell)
+	 *
+	 * @since added in 0.4.4
+	 * @return bool true if PHP invoked as a CGI or from CLI
+	 */
+	static public function isPhpCliMode()
+	{
+		return	PHP_SAPI == 'cli' ||
+				(substr(PHP_SAPI, 0, 3) == 'cgi' && @$_SERVER['REMOTE_ADDR'] == '');
+	}
 }
-
-
