@@ -4,14 +4,12 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: Config.php 546 2008-07-02 07:13:16Z matt $
+ * @version $Id: Config.php 1420 2009-08-22 13:23:16Z vipsoft $
  * 
- * @package Piwik_Helper
+ * @category Piwik
+ * @package Piwik
  */
 
-require_once "Zend/Config/Ini.php";
-require_once "Zend/Registry.php";
-
 /**
  * This class is used to access configuration files values.
  * You can also set these values, the updated configuration files will be written at the end of the script execution.
@@ -21,7 +19,7 @@ require_once "Zend/Registry.php";
  * 
  * will read the value minimumMemoryLimit under the [General] section of the config file
  * 
- * @package Piwik_Helper
+ * @package Piwik
  */
 class Piwik_Config
 {
@@ -50,18 +48,23 @@ class Piwik_Config
 	protected $correctCwd;
 	
 	/**
-	 * Returns default relative path for configuration file
+	 * Returns default relative path for user configuration file
 	 *
 	 * @return string
 	 */
 	static public function getDefaultUserConfigPath()
 	{
-		return Piwik_Common::getPathToPiwikRoot() . '/config/config.ini.php';
+		return PIWIK_USER_PATH .'/config/config.ini.php';
 	}
 
+	/**
+	 * Returns default relative path for global configuration file
+	 *
+	 * @return string
+	 */
 	static public function getDefaultDefaultConfigPath()
 	{
-		return Piwik_Common::getPathToPiwikRoot() . '/config/global.ini.php';
+		return PIWIK_USER_PATH .'/config/global.ini.php';
 	}
 	
 	/**
@@ -93,8 +96,6 @@ class Piwik_Config
 	 * $config->database = array(...)
 	 * Piwik will automatically save the updated config file in __destruct()
 	 * This can be disabled (when setting partial configuration values during the installation process for example)
-	 *  
-	 * @return void
 	 */
 	public function disableSavingConfigurationFileUpdates()
 	{
@@ -159,7 +160,6 @@ class Piwik_Config
 	
 	/**
 	 * If called, we use the database_tests credentials
-	 * @return void
 	 */
 	public function setTestEnvironment()
 	{
@@ -168,7 +168,7 @@ class Piwik_Config
 	
 	/**
 	 * Called when setting configuration values eg. 
-	 * 	Zend_Registry::get('config')->superuser = $_SESSION['superuser_infos'];
+	 * 	Zend_Registry::get('config')->MyConfigSection = 'foobar';
 	 *
 	 * The values will be saved in the configuration file at the end of the script @see __destruct()
 	 * 
@@ -241,7 +241,6 @@ class Piwik_Config
 	/**
 	 * Loop through the Default and the User configuration objects and cache them in arrays.
 	 * This slightly helps reducing the Zend overhead when accessing config entries hundreds of times.
-	 * @return void
 	 */
 	protected function cacheConfigArray()
 	{
@@ -279,7 +278,7 @@ class Piwik_Config
 	}
 	
 	/**
-	 * Called when getting a configuration value, eg. 	Zend_Registry::get('config')->superuser->login
+	 * Called when getting a configuration value, eg. Zend_Registry::get('config')->superuser->login
 	 *
 	 * @param string $name
 	 * @return mixed value 
