@@ -4,12 +4,12 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: Controller.php 561 2008-07-21 00:00:35Z matt $
+ * @version $Id: Controller.php 1625 2009-12-05 16:46:22Z vipsoft $
  * 
+ * @category Piwik
  * @package Piwik
  */
 
-require_once "ViewDataTable.php";
 /**
  * Parent class of all plugins Controllers (located in /plugins/PluginName/Controller.php
  * It defines some helper functions controllers can use.
@@ -40,7 +40,6 @@ abstract class Piwik_Controller
 	
 	/**
 	 * Builds the controller object, reads the date from the request, extracts plugin name from 
-	 *
 	 */
 	function __construct()
 	{
@@ -126,7 +125,6 @@ abstract class Piwik_Controller
 	 */
 	protected function getLastUnitGraph($currentModuleName, $currentControllerAction, $apiMethod)
 	{
-		require_once "ViewDataTable/GenerateGraphHTML.php";
 		$view = Piwik_ViewDataTable::factory('graphEvolution');
 		$view->init( $currentModuleName, $currentControllerAction, $apiMethod );
 		
@@ -142,8 +140,7 @@ abstract class Piwik_Controller
 		
 		return $view;
 	}
-	
-	
+
 	/**
 	 * Returns the array of new processed parameters once the parameters are applied.
 	 * For example: if you set range=last30 and date=2008-03-10, 
@@ -249,7 +246,15 @@ abstract class Piwik_Controller
 			$view->minDateYear = $minDate->toString('Y');
 			$view->minDateMonth = $minDate->toString('m');
 			$view->minDateDay = $minDate->toString('d');
-			
+
+			$maxDate = Piwik_Date::factory('today');
+			$view->maxDateYear = $maxDate->toString('Y');
+			$view->maxDateMonth = $maxDate->toString('m');
+			$view->maxDateDay = $maxDate->toString('d');
+
+			$view->debugTrackVisitsInsidePiwikUI = Zend_Registry::get('config')->Debug->track_visits_inside_piwik_ui;
+
+			$view->isSuperUser = Zend_Registry::get('access')->isSuperUser();
 		} catch(Exception $e) {
 			self::redirectToIndex(Piwik::getModule(), Piwik::getAction());
 		}
@@ -272,7 +277,7 @@ abstract class Piwik_Controller
 			'week' => array('singular' => Piwik_Translate('CoreHome_PeriodWeek'), 'plural' => Piwik_Translate('CoreHome_PeriodWeeks')),
 			'month' => array('singular' => Piwik_Translate('CoreHome_PeriodMonth'), 'plural' => Piwik_Translate('CoreHome_PeriodMonths')),
 			'year' => array('singular' => Piwik_Translate('CoreHome_PeriodYear'), 'plural' => Piwik_Translate('CoreHome_PeriodYears')),
-			);
+		);
 		
 		$found = array_search($currentPeriod,$availablePeriods);
 		if($found !== false)
@@ -314,7 +319,7 @@ abstract class Piwik_Controller
 				&& $currentLogin != 'anonymous')
 			{
 				$errorMessage = sprintf(Piwik_Translate('CoreHome_NoPrivileges'),$currentLogin);
-				$errorMessage .= "<br /><br />&nbsp;&nbsp;&nbsp;<b><a href='?module=". Zend_Registry::get('auth')->getName() ."&amp;action=logout'>&rsaquo; ". Piwik_Translate('General_Logout'). "</a></b><br />";
+				$errorMessage .= "<br /><br />&nbsp;&nbsp;&nbsp;<b><a href='index.php?module=". Zend_Registry::get('auth')->getName() ."&amp;action=logout'>&rsaquo; ". Piwik_Translate('General_Logout'). "</a></b><br />";
 				Piwik_ExitWithMessage($errorMessage, false, true);
 			}
 			else
