@@ -4,19 +4,19 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: Cookie.php 444 2008-04-11 13:38:22Z johmathe $
+ * @version $Id: Cookie.php 1682 2009-12-13 21:25:01Z vipsoft $
  * 
- * @package Piwik_Helper
+ * @category Piwik
+ * @package Piwik
  */
 
-
 /**
  * Simple class to handle the cookies:
  * - read a cookie values
  * - edit an existing cookie and save it
  * - create a new cookie, set values, expiration date, etc. and save it
  * 
- * @package Piwik_Helper
+ * @package Piwik
  */
 class Piwik_Cookie
 {
@@ -67,6 +67,7 @@ class Piwik_Cookie
 	
 	/**
 	 * Returns true if the visitor already has the cookie.
+	 *
 	 * @return bool 
 	 */
 	public function isCookieFound()
@@ -76,6 +77,7 @@ class Piwik_Cookie
 	
 	/**
 	 * Returns the default expiry time, 2 years
+	 *
 	 * @return int Timestamp in 2 years
 	 */
 	protected function getDefaultExpire()
@@ -114,8 +116,6 @@ class Piwik_Cookie
 	
 	/**
 	 * We set the privacy policy header
-	 * 
-	 * @return void
 	 */
 	protected function setP3PHeader()
 	{
@@ -124,8 +124,6 @@ class Piwik_Cookie
 	
 	/**
 	 * Delete the cookie
-	 * 
-	 * @return void
 	 */
 	public function delete()
 	{
@@ -149,8 +147,6 @@ class Piwik_Cookie
 	 * Parses the cookie string to extract the different variables.
 	 * Unserialize the array when necessary.
 	 * Decode the non numeric values that were base64 encoded.
-	 * 
-	 * @return void
 	 */
 	protected function loadContentFromCookie()
 	{
@@ -168,13 +164,7 @@ class Piwik_Cookie
 				$varValue = base64_decode($varValue);
 
 				// some of the values may be serialized array so we try to unserialize it
-				if( ($arrayValue = @unserialize($varValue)) !== false
-					// we set the unserialized version only for arrays as you can have set a serialized string on purpose
-					&& is_array($arrayValue)
-					)
-				{
-					$varValue = $arrayValue;
-				}
+				$varValue = Piwik_Common::unserialize_array($varValue);
 			}
 			
 			$this->set($varName, $varValue);
@@ -184,6 +174,7 @@ class Piwik_Cookie
 	/**
 	 * Returns the string to save in the cookie from the $this->value array of values.
 	 * It goes through the array and generates the cookie content string.
+	 *
 	 * @return string Cookie content
 	 */
 	protected function generateContentString()
@@ -215,12 +206,18 @@ class Piwik_Cookie
 	 * 
 	 * @param string Name of the value to save; the name will be used to retrieve this value
 	 * @param string|array|numeric Value to save
-	 * 
- 	 */
+	 */
 	public function set( $name, $value )
 	{
 		$name = self::escapeValue($name);
-		$this->value[$name] = $value;
+		if(is_null($value))
+		{
+			unset($this->value[$name]);
+		}
+		else
+		{
+			$this->value[$name] = $value;
+		}
 	}
 	
 	/**
