@@ -4,17 +4,12 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: DataTable.php 578 2008-07-27 00:15:21Z matt $
+ * @version $Id: DataTable.php 1613 2009-11-27 20:57:13Z vipsoft $
  * 
- * @package Piwik_DataTable
+ * @category Piwik
+ * @package Piwik
  */
 
-require_once "DataTable/Renderer.php";
-require_once "DataTable/Renderer/Console.php";
-require_once "DataTable/Filter.php";
-require_once "DataTable/Row.php";
-require_once "DataTable/Manager.php";
-
 /**
  * 
  * ---- DataTable
@@ -90,7 +85,7 @@ require_once "DataTable/Manager.php";
  * 	
  * ---- Code example
  * 
- * $table = new DataTable;
+ * $table = new DataTable();
  * $table->addRowsFromArray( array(...) );
  * 
  * # sort the table by visits asc
@@ -135,9 +130,7 @@ require_once "DataTable/Manager.php";
  * 
  * @package Piwik
  * @subpackage Piwik_DataTable
- * 
  */
-
 class Piwik_DataTable
 {	
 	/**
@@ -285,8 +278,6 @@ class Piwik_DataTable
 	/**
 	 * Enables the recursive sort. Means that when using $table->sort() 
 	 * it will also sort all subtables using the same callback
-	 * 
-	 * @return void
 	 */
 	public function enableRecursiveSort()
 	{
@@ -310,9 +301,6 @@ class Piwik_DataTable
 
 	/**
 	 * Saves the current number of rows
-	 * 
-	 * @return void
-	 *
 	 */
 	function setRowsCountBeforeLimitFilter()
 	{
@@ -327,7 +315,7 @@ class Piwik_DataTable
 	 */
 	public function filter( $className, $parameters = array() )
 	{
-		if(!class_exists($className))
+		if(!class_exists($className, false))
 		{
 			$className = "Piwik_DataTable_Filter_" . $className;
 		}
@@ -359,7 +347,6 @@ class Piwik_DataTable
 	/**
 	 * Apply all filters that were previously queued to this table
 	 * @see queueFilter()
-	 * @return void
 	 */
 	public function applyQueuedFilters()
 	{
@@ -384,7 +371,7 @@ class Piwik_DataTable
 	 * 
 	 * A common row to 2 DataTable is defined by the same label
 	 * 	
-	 * @example @see tests/plugins/DataTable.test.php
+	 * @example tests/core/DataTable.test.php
 	 */
 	public function addDataTable( Piwik_DataTable $tableToSum )
 	{
@@ -449,8 +436,6 @@ class Piwik_DataTable
 
 	/**
 	 * Rebuilds the index used to lookup a row by label
-	 *
-	 * @return void
 	 */
 	private function rebuildIndex()
 	{
@@ -603,14 +588,13 @@ class Piwik_DataTable
 	 */
 	public function getRowsCount()
 	{
-		$count = count($this->rows);
 		if(is_null($this->summaryRow))
 		{
-			return $count;
+			return count($this->rows);
 		}
 		else
 		{
-			return $count + 1;
+			return count($this->rows) + 1;
 		}
 	}
 
@@ -688,6 +672,7 @@ class Piwik_DataTable
 
 	/**
 	 * Rename a column in all rows
+	 *
 	 * @param $oldName
 	 * @param $newName
 	 */
@@ -834,10 +819,7 @@ class Piwik_DataTable
 		$table1->rebuildIndex();
 		$table2->rebuildIndex();
 		
-		$countrows1 = $table1->getRowsCount();
-		$countrows2 = $table2->getRowsCount();
-		
-		if($countrows1 != $countrows2)
+		if($table1->getRowsCount() != $table2->getRowsCount())
 		{
 			return false;
 		}
@@ -845,11 +827,8 @@ class Piwik_DataTable
 		foreach($rows1 as $row1)
 		{
 			$row2 = $table2->getRowFromLabel($row1->getColumn('label'));
-			if($row2 === false)
-			{
-				return false;
-			}
-			if( !Piwik_DataTable_Row::isEqual($row1,$row2) )
+			if($row2 === false
+				|| !Piwik_DataTable_Row::isEqual($row1,$row2))
 			{
 				return false;
 			}
@@ -891,7 +870,6 @@ class Piwik_DataTable
 	 * 					//first Datatable level3 (child of second Datatable level1 for example)
  	 *					3 => 'eghuighahgaueytae78yaet7yaetaeGRQWUBGUIQGH&QE',
 	 * 					);
-	 * 
 	 */
 	public function getSerialized(	$maximumRowsInDataTable = null, 
 									$maximumRowsInSubDataTable = null,
@@ -951,7 +929,6 @@ class Piwik_DataTable
 	  * The function creates all the necessary DataTable_Row
 	  * 
 	  * @param string string of serialized datatable
-	  * @return void
 	  */
 	public function addRowsFromSerializedArray( $stringSerialized )
 	{
@@ -979,7 +956,6 @@ class Piwik_DataTable
 	 * 				array( ... ), 
 	 * 				
 	 * 			)
-	 * @return void
 	 */
 	public function addRowsFromArray( $array )
 	{
@@ -1081,7 +1057,7 @@ class Piwik_DataTable
 				{
 					if(is_array($subRow))
 					{
-						throw $e;						
+						throw $e;
 					}
 				}
 				$row = new Piwik_DataTable_Row( array( Piwik_DataTable_Row::COLUMNS => $row ) );		
@@ -1137,8 +1113,6 @@ class Piwik_DataTable
 	 * 
 	 * @param array $array See method description
 	 * @param array|null $subtablePerLabel see method description
-	 * 
-	 * @return void
 	 */
 	public function addRowsFromArrayWithIndexLabel( $array, $subtablePerLabel = null)
 	{
@@ -1163,6 +1137,4 @@ class Piwik_DataTable
 			$this->addRow( new Piwik_DataTable_Row($cleanRow) );
 		}
 	}
-
 }
-
