@@ -4,9 +4,10 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: Pattern.php 444 2008-04-11 13:38:22Z johmathe $
+ * @version $Id: Pattern.php 1420 2009-08-22 13:23:16Z vipsoft $
  * 
- * @package Piwik_DataTable
+ * @category Piwik
+ * @package Piwik
  */
 
 /**
@@ -14,8 +15,8 @@
  * This filter is to be used on columns containing strings. 
  * Exemple: fron the keyword report, keep only the rows for which the label contains "piwik"
  * 
- * @package Piwik_DataTable
- * @subpackage Piwik_DataTable_Filter 
+ * @package Piwik
+ * @subpackage Piwik_DataTable
  */
 class Piwik_DataTable_Filter_Pattern extends Piwik_DataTable_Filter
 {
@@ -34,7 +35,7 @@ class Piwik_DataTable_Filter_Pattern extends Piwik_DataTable_Filter
 	
 	static public function getPatternQuoted( $pattern )
 	{
-		return "/". str_replace('/','\/', $pattern) ."/";
+		return '/'. str_replace('/', '\/', $pattern) .'/';
 	}
 	
 	/*
@@ -60,4 +61,3 @@ class Piwik_DataTable_Filter_Pattern extends Piwik_DataTable_Filter
 		}
 	}
 }
-
