@@ -4,12 +4,12 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: Csv.php 558 2008-07-20 23:10:38Z matt $
+ * @version $Id: Csv.php 1420 2009-08-22 13:23:16Z vipsoft $
  * 
- * @package Piwik_DataTable
+ * @category Piwik
+ * @package Piwik
  */
 
-require_once "DataTable/Renderer/Php.php";
 /**
  * CSV export
  * 
@@ -21,11 +21,9 @@ require_once "DataTable/Renderer/Php.php";
  * 
  * Note that CSV output doesn't handle recursive dataTable. It will output only the first parent level of the tables.
  * 
- * @package Piwik_DataTable
- * @subpackage Piwik_DataTable_Renderer
- * 
+ * @package Piwik
+ * @subpackage Piwik_DataTable
  */
-
 class Piwik_DataTable_Renderer_Csv extends Piwik_DataTable_Renderer
 {
 	/**
@@ -154,7 +152,7 @@ class Piwik_DataTable_Renderer_Csv extends Piwik_DataTable_Renderer
 					$csvRow[$name] = $value;
 				}
 			}
-			
+
 			if($this->exportMetadata)
 			{
 				$metadata = $row->getMetadata();
