@@ -4,18 +4,18 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: Json.php 516 2008-06-08 20:06:43Z matt $
+ * @version $Id: Json.php 1420 2009-08-22 13:23:16Z vipsoft $
  * 
- * @package Piwik_DataTable
+ * @category Piwik
+ * @package Piwik
  */
 
-require_once "DataTable/Renderer/Php.php";
 /**
  * JSON export. Using the php 5.2 feature json_encode.
  * Works with recursive DataTable (when a row can be associated with a subDataTable).
  * 
- * @package Piwik_DataTable
- * @subpackage Piwik_DataTable_Renderer
+ * @package Piwik
+ * @subpackage Piwik_DataTable
  */
 class Piwik_DataTable_Renderer_Json extends Piwik_DataTable_Renderer
 {
