@@ -4,12 +4,12 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: Xml.php 558 2008-07-20 23:10:38Z matt $
+ * @version $Id: Xml.php 1420 2009-08-22 13:23:16Z vipsoft $
  * 
- * @package Piwik_DataTable
+ * @category Piwik
+ * @package Piwik
  */
 
-require_once "DataTable/Renderer/Php.php";
 /**
  * XML export of a given DataTable.
  * See the tests cases for more information about the XML format (/tests/core/DataTable/Renderer.test.php)
@@ -17,8 +17,8 @@ require_once "DataTable/Renderer/Php.php";
  * 
  * Works with recursive DataTable (when a row can be associated with a subDataTable).
  * 
- * @package Piwik_DataTable
- * @subpackage Piwik_DataTable_Renderer
+ * @package Piwik
+ * @subpackage Piwik_DataTable
  */
 class Piwik_DataTable_Renderer_Xml extends Piwik_DataTable_Renderer
 {
