@@ -4,35 +4,32 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: ExceptionHandler.php 444 2008-04-11 13:38:22Z johmathe $
+ * @version $Id: ExceptionHandler.php 1420 2009-08-22 13:23:16Z vipsoft $
  * 
- * @package Piwik_Helper
+ * @category Piwik
+ * @package Piwik
  */
 
-require_once "Piwik.php";
-
 /**
  * Exception handler used to display nicely exceptions in Piwik
  * 
- * @package Piwik_Helper
+ * @param Exception $exception
  */
 function Piwik_ExceptionHandler(Exception $exception) 
 {
 	try	{
-		Zend_Registry::get('logger_exception')->log($exception);
+		Zend_Registry::get('logger_exception')->logEvent($exception);
 	} catch(Exception $e) {
 		// case when the exception is raised before the logger being ready
 		// we handle the exception a la mano, but using the Logger formatting properties
-		require_once "Log/Exception.php";
-		
 		$event = array();
 		$event['errno'] 	= $exception->getCode();
 		$event['message'] 	= $exception->getMessage();
 		$event['errfile'] 	= $exception->getFile();
 		$event['errline'] 	= $exception->getLine();
 		$event['backtrace'] = $exception->getTraceAsString();
-		
-		$formatter = new Piwik_Log_Formatter_Exception_ScreenFormatter;
+
+		$formatter = new Piwik_Log_Exception_Formatter_ScreenFormatter();
 		
 		$message = $formatter->format($event);
 		$message .= "<br><br>And this exception raised another exception \"". $e->getMessage()."\"";
@@ -40,4 +37,3 @@ function Piwik_ExceptionHandler(Exception $exception)
 		Piwik::exitWithErrorMessage( $message );
 	}
 }
-
