@@ -4,21 +4,20 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: Form.php 444 2008-04-11 13:38:22Z johmathe $
+ * @version $Id: Form.php 1434 2009-08-23 15:55:35Z vipsoft $
  * 
- * @package Piwik_Helper
+ * @category Piwik
+ * @package Piwik
  */
 
-
-require_once "HTML/QuickForm.php";
-require_once "HTML/QuickForm/Renderer/ArraySmarty.php";
-
 /**
  * Parent class for forms to be included in Smarty
  * 
  * For an example, @see Piwik_Login_Form
  * 
- * @package Piwik_Helper
+ * @package Piwik
+ * @see HTML_QuickForm, libs/HTML/QuickForm.php
+ * @link http://pear.php.net/package/HTML_QuickForm/
  */
 abstract class Piwik_Form extends HTML_QuickForm
 {
