@@ -4,41 +4,23 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: FrontController.php 583 2008-07-28 00:37:19Z matt $
+ * @version $Id: FrontController.php 1522 2009-10-21 22:49:44Z vipsoft $
  * 
+ * @category Piwik
  * @package Piwik
  */
 
+// no direct access
+defined('PIWIK_INCLUDE_PATH') or die;
 
 /**
- * Zend classes
+ * @see core/PluginsManager.php
+ * @see core/Translate.php
+ * @see core/Option.php
  */
-require_once "Zend/Exception.php";
-require_once "Zend/Loader.php"; 
-require_once "Zend/Auth.php";
-
-/**
- * Piwik classes
- */
-require_once "Timer.php";
-require_once "PluginsManager.php";
-require_once "Piwik.php";
-require_once "Access.php";
-require_once "Auth.php";
-require_once "API/Proxy.php";
-require_once "Archive.php";
-require_once "Site.php";
-require_once "Date.php";
-require_once "DataTable.php";
-require_once "Translate.php";
-require_once "Mail.php";
-require_once "Url.php";
-require_once "Controller.php";
-require_once "Option.php";
-require_once "View.php";
-require_once "Version.php";
-require_once "UpdateCheck.php";
-
+require_once PIWIK_INCLUDE_PATH . '/core/PluginsManager.php';
+require_once PIWIK_INCLUDE_PATH . '/core/Translate.php';
+require_once PIWIK_INCLUDE_PATH . '/core/Option.php';
 
 /**
  * Front controller.
@@ -48,6 +30,7 @@ require_once "UpdateCheck.php";
  * For a detailed explanation, see the documentation on http://dev.piwik.org/trac/wiki/MainSequenceDiagram
  * 
  * @package Piwik
+ * @subpackage Piwik_FrontController
  */
 class Piwik_FrontController
 {
@@ -92,7 +75,7 @@ class Piwik_FrontController
 		{
 			return;
 		}
-		
+
 		if(is_null($module))
 		{
 			$defaultModule = 'CoreHome';
@@ -116,21 +99,23 @@ class Piwik_FrontController
 		
 		if( ! Piwik_PluginsManager::getInstance()->isPluginActivated( $module )) 
 		{
-			throw new Exception_PluginDeactivated($module);
+			throw new Piwik_FrontController_PluginDeactivatedException($module);
 		}
 				
-		$controllerClassName = "Piwik_".$module."_Controller";
-		if(!class_exists($controllerClassName))
+		$controllerClassName = 'Piwik_'.$module.'_Controller';
+
+		// FrontController's autoloader
+		if(!class_exists($controllerClassName, false))
 		{
-			$moduleController = $module . "/Controller.php";
+			$moduleController = PIWIK_INCLUDE_PATH . '/plugins/' . $module . '/Controller.php';
 			if( !Zend_Loader::isReadable($moduleController))
 			{
 				throw new Exception("Module controller $moduleController not found!");
 			}
-			require_once $moduleController;
+			require_once $moduleController; // prefixed by PIWIK_INCLUDE_PATH
 		}
 		
-		$controller = new $controllerClassName;
+		$controller = new $controllerClassName();
 		if($action === false)
 		{
 			$action = $controller->getDefaultAction();
@@ -149,7 +134,7 @@ class Piwik_FrontController
 	
 	/**
 	 * Often plugins controller display stuff using echo/print.
-	 * Using this function instead of dispath() returns the output string form the actions calls.
+	 * Using this function instead of dispatch() returns the output string form the actions calls.
 	 *
 	 * @param string $controllerName
 	 * @param string $actionName
@@ -165,8 +150,8 @@ class Piwik_FrontController
 		{
 			$output = ob_get_contents();
 		}
-	    ob_end_clean();
-	    return $output;
+		ob_end_clean();
+		return $output;
 	}
 	
 	/**
@@ -194,8 +179,6 @@ class Piwik_FrontController
 	 * - loads the plugin, 
 	 * - inits the DB connection,
 	 * - etc.
-	 * 
-	 * @return void 
 	 */
 	function init()
 	{
@@ -210,34 +193,38 @@ class Piwik_FrontController
 			
 			Piwik::checkDirectoriesWritableOrDie($directoriesToCheck);
 			self::assignCliParametersToRequest();
-			
+
+			Piwik_Translate::getInstance()->loadEnglishTranslation();
+
 			$exceptionToThrow = false;
-			
+
 			try {
 				Piwik::createConfigObject();
 			} catch(Exception $e) {
 				Piwik_PostEvent('FrontController.NoConfigurationFile', $e);
 				$exceptionToThrow = $e;
 			}
-			Piwik_Translate::getInstance()->loadEnglishTranslation();
-			
+
 			$pluginsManager = Piwik_PluginsManager::getInstance();
 			$pluginsManager->setPluginsToLoad( Zend_Registry::get('config')->Plugins->Plugins->toArray() );
-			
+
 			if($exceptionToThrow)
 			{
 				throw $exceptionToThrow;
 			}
+
+			Piwik_Translate::getInstance()->loadUserTranslation();
+
 			Piwik::createDatabaseObject();
 			Piwik::createLogObject();
 			
 			// creating the access object, so that core/Updates/* can enforce Super User and use some APIs
 			Piwik::createAccessObject();
-			Piwik::displayScreenForCoreAndPluginsUpdatesIfNecessary();
-			
+			Piwik_PostEvent('FrontController.dispatchCoreAndPluginUpdatesScreen');
+
 			Piwik_PluginsManager::getInstance()->installLoadedPlugins();
 			Piwik::install();
-			
+
 			Piwik_PostEvent('FrontController.initAuthenticationObject');
 			try {
 				$authAdapter = Zend_Registry::get('auth');
@@ -251,12 +238,11 @@ class Piwik_FrontController
 			Zend_Registry::get('access')->reloadAccess($authAdapter);
 			
 			Piwik::raiseMemoryLimitIfNecessary();
-			
-			Piwik_Translate::getInstance()->loadUserTranslation();
+
 			$pluginsManager->setLanguageToLoad( Piwik_Translate::getInstance()->getLanguageToLoad() );
 			$pluginsManager->postLoadPlugins();
 			
-			Piwik_UpdateCheck::check();
+			Piwik_PostEvent('FrontController.checkForUpdates');
 		} catch(Exception $e) {
 			Piwik_ExitWithMessage($e->getMessage(), $e->getTraceAsString(), true);
 		}
@@ -266,8 +252,6 @@ class Piwik_FrontController
 	 * Assign CLI parameters as if they were REQUEST or GET parameters.
 	 * You can trigger Piwik from the command line by
 	 * # /usr/bin/php5 /path/to/piwik/index.php -- "module=API&method=Actions.getActions&idSite=1&period=day&date=previous8&format=php"
-	 *
-	 * @return void
 	 */
 	static protected function assignCliParametersToRequest()
 	{
@@ -287,8 +271,9 @@ class Piwik_FrontController
  * Exception thrown when the requested plugin is not activated in the config file
  *
  * @package Piwik
+ * @subpackage Piwik_FrontController
  */
-class Exception_PluginDeactivated extends Exception
+class Piwik_FrontController_PluginDeactivatedException extends Exception
 {
 	function __construct($module)
 	{
@@ -296,8 +281,9 @@ class Exception_PluginDeactivated extends Exception
 	}
 }
 
-
-// for more information see http://dev.piwik.org/trac/ticket/374
+/**
+ * For more information: @link http://dev.piwik.org/trac/ticket/374
+ */
 function destroy(&$var) 
 {
 	if (is_object($var)) $var->__destruct();
