@@ -4,21 +4,18 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: Log.php 558 2008-07-20 23:10:38Z matt $
+ * @version $Id: Log.php 1716 2009-12-15 20:13:50Z vipsoft $
  * 
- * @package Piwik_Log
+ * @category Piwik
+ * @package Piwik
  */
 
-require_once "Zend/Log.php";
-require_once "Zend/Log/Formatter/Interface.php";
-require_once "Zend/Log/Writer/Stream.php";
-require_once "Zend/Log/Writer/Db.php";
-
-require_once "Common.php";
-
 /**
  * 
- * @package Piwik_Log
+ * @package Piwik
+ * @subpackage Piwik_Log
+ * @see Zend_Log, libs/Zend/Log.php
+ * @link http://framework.zend.com/manual/en/zend.log.html 
  */
 abstract class Piwik_Log extends Zend_Log
 {
@@ -35,9 +32,14 @@ abstract class Piwik_Log extends Zend_Log
 							$logToDatabaseColumnMapping )
 	{
 		parent::__construct();
-		
-		
-		$this->logToFileFilename = Zend_Registry::get('config')->path->log . $logToFileFilename;
+
+		$log_dir = Zend_Registry::get('config')->log->logger_file_path;
+		if($log_dir[0] != '/' && $log_dir[0] != DIRECTORY_SEPARATOR)
+		{
+			$log_dir = PIWIK_USER_PATH . '/' . $log_dir;
+		}
+		$this->logToFileFilename = $log_dir . '/' . $logToFileFilename;
+
 		$this->fileFormatter = $fileFormatter;
 		$this->screenFormatter = $screenFormatter;
 		$this->logToDatabaseTableName = Piwik::prefixTable($logToDatabaseTableName);
@@ -46,13 +48,13 @@ abstract class Piwik_Log extends Zend_Log
 	
 	static public function dump($var)
 	{
-		Zend_Registry::get('logger_message')->log(var_export($var, true), Piwik_Log::DEBUG);
+		Zend_Registry::get('logger_message')->logEvent(var_export($var, true));
 	}
 	
 	function addWriteToFile()
 	{
+		Piwik_Common::mkdir(dirname($this->logToFileFilename));
 		$writerFile = new Zend_Log_Writer_Stream($this->logToFileFilename);
-		Piwik_Common::mkdir(Zend_Registry::get('config')->path->log);
 		$writerFile->setFormatter( $this->fileFormatter );
 		$this->addWriter($writerFile);
 	}
@@ -87,9 +89,8 @@ abstract class Piwik_Log extends Zend_Log
 
 	/**
 	 * Log an event
-	 * Overload Zend_log::log
 	 */
-	public function log($event)
+	public function log($event, $priority)
 	{
 		// sanity checks
 		if (empty($this->_writers)) {
@@ -118,11 +119,11 @@ abstract class Piwik_Log extends Zend_Log
 
 /**
  * 
- * 
- * @package Piwik_Log
+ * @package Piwik
+ * @subpackage Piwik_Log
  */
 class Piwik_Log_Formatter_FileFormatter implements Zend_Log_Formatter_Interface
-{
+{	
 	/**
 	 * Formats data into a single line to be written by the writer.
 	 *
@@ -136,27 +137,47 @@ class Piwik_Log_Formatter_FileFormatter implements Zend_Log_Formatter_Interface
 			$value = str_replace("\n", '\n', $value);
 			$value = '"'.$value.'"';
 		}
-		$str = implode(" ", $event) . "\n";
-		return $str;
+		$ts = $event['timestamp'];
+		unset($event['timestamp']);
+		return $ts . ' ' . implode(" ", $event) . "\n";
 	}
 }
 
+/**
+ * 
+ * @package Piwik
+ * @subpackage Piwik_Log
+ */
 class Piwik_Log_Formatter_ScreenFormatter implements Zend_Log_Formatter_Interface
 {
+	function formatEvent($event)
+	{
+		// no injection in error messages, backtrace when displayed on screen
+		return array_map('htmlspecialchars', $event);
+	}
+
 	function format($string)
 	{
-		$string = self::getFormattedString($string);
-		return $string;
+		return self::getFormattedString($string);
 	}
 	
 	static public function getFormattedString($string)
 	{
-		if(Piwik::isPhpCliMode())
+		if(Piwik_Common::isPhpCliMode())
 		{
 			$string = str_replace(array('<br>','<br />','<br/>'), "\n", $string);
-			$string = strip_tags($string);
+			if(is_array($string))
+			{
+				for($i=0; $i< count($string); $i++)
+				{
+					$string[i] = strip_tags($string[i]);
+				}
+			}
+			else
+			{
+				$string = strip_tags($string);
+			}
 		}
 		return $string;
 	}
 }
-
