@@ -4,17 +4,17 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: Error.php 485 2008-05-19 22:29:55Z matt $
+ * @version $Id: Error.php 1420 2009-08-22 13:23:16Z vipsoft $
  * 
- * @package Piwik_Log
- * @subpackage Piwik_Log_Error
+ * @category Piwik
+ * @package Piwik
  */
 
 /**
  * Class used to log an error event.
  * 
- * @package Piwik_Log
- * @subpackage Piwik_Log_Error
+ * @package Piwik
+ * @subpackage Piwik_Log
  */
 class Piwik_Log_Error extends Piwik_Log
 {
@@ -24,8 +24,8 @@ class Piwik_Log_Error extends Piwik_Log
 		$logToFileFilename = self::ID;
 		$logToDatabaseTableName = self::ID;
 		$logToDatabaseColumnMapping = null;
-		$screenFormatter = new Piwik_Log_Formatter_Error_ScreenFormatter;
-		$fileFormatter = new Piwik_Log_Formatter_FileFormatter;
+		$screenFormatter = new Piwik_Log_Error_Formatter_ScreenFormatter();
+		$fileFormatter = new Piwik_Log_Formatter_FileFormatter();
 		
 		parent::__construct($logToFileFilename, 
 							$fileFormatter,
@@ -42,7 +42,7 @@ class Piwik_Log_Error extends Piwik_Log
 		$this->addWriter($writerScreen);
 	}
 	
-	public function log($errno, $errstr, $errfile, $errline, $backtrace)
+	public function logEvent($errno, $errstr, $errfile, $errline, $backtrace)
 	{
 		$event = array();
 		$event['errno'] = $errno;
@@ -51,19 +51,17 @@ class Piwik_Log_Error extends Piwik_Log
 		$event['errline'] = $errline;
 		$event['backtrace'] = $backtrace;
 		
-		parent::log($event);
+		parent::log($event, Piwik_Log::ERR);
 	}
 }
 
-
-
 /**
  * Format an error event to be displayed on the screen.
  * 
- * @package Piwik_Log
- * @subpackage Piwik_Log_Error
+ * @package Piwik
+ * @subpackage Piwik_Log
  */
-class Piwik_Log_Formatter_Error_ScreenFormatter extends Piwik_Log_Formatter_ScreenFormatter
+class Piwik_Log_Error_Formatter_ScreenFormatter extends Piwik_Log_Formatter_ScreenFormatter
 {
 	/**
      * Formats data into a single line to be written by the writer.
@@ -116,5 +114,3 @@ class Piwik_Log_Formatter_Error_ScreenFormatter extends Piwik_Log_Formatter_Scre
 	    return parent::format($strReturned);
     }
 }
-
-
