@@ -4,17 +4,17 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: Message.php 492 2008-05-23 01:08:12Z matt $
+ * @version $Id: Message.php 1420 2009-08-22 13:23:16Z vipsoft $
  * 
- * @package Piwik_Log
- * @subpackage Piwik_Log_Message
+ * @category Piwik
+ * @package Piwik
  */
 
 /**
  * Class used to log a standard message event.
  * 
- * @package Piwik_Log
- * @subpackage Piwik_Log_Message
+ * @package Piwik
+ * @subpackage Piwik_Log
  */
 class Piwik_Log_Message extends Piwik_Log
 {
@@ -24,8 +24,8 @@ class Piwik_Log_Message extends Piwik_Log
 		$logToFileFilename = self::ID;
 		$logToDatabaseTableName = self::ID;
 		$logToDatabaseColumnMapping = null;
-		$screenFormatter = new Piwik_Log_Formatter_Message_ScreenFormatter;
-		$fileFormatter = new Piwik_Log_Formatter_FileFormatter;
+		$screenFormatter = new Piwik_Log_Message_Formatter_ScreenFormatter();
+		$fileFormatter = new Piwik_Log_Formatter_FileFormatter();
 		
 		parent::__construct($logToFileFilename, 
 							$fileFormatter,
@@ -34,23 +34,22 @@ class Piwik_Log_Message extends Piwik_Log
 							$logToDatabaseColumnMapping );
 	}
 	
-	public function log( $message )
+	public function logEvent($message)
 	{
 		$event = array();
 		$event['message'] = $message;
-		parent::log($event);
+		parent::log($event, Piwik_Log::INFO);
 	}
 }
 
-
 /**
  * Format a standard message event to be displayed on the screen.
  * The message can be a PHP array or a string.
  * 
- * @package Piwik_Log
- * @subpackage Piwik_Log_Message
+ * @package Piwik
+ * @subpackage Piwik_Log
  */
-class Piwik_Log_Formatter_Message_ScreenFormatter extends Piwik_Log_Formatter_ScreenFormatter 
+class Piwik_Log_Message_Formatter_ScreenFormatter extends Piwik_Log_Formatter_ScreenFormatter 
 {
 	/**
      * Formats data into a single line to be written by the writer.
@@ -72,4 +71,3 @@ class Piwik_Log_Formatter_Message_ScreenFormatter extends Piwik_Log_Formatter_Sc
     	return parent::format($message);
     }
 }
-
