@@ -1,21 +1,21 @@
 <?php
 /**
  * Piwik - Open source web analytics
- * 
+ *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id$
+ * @version $Id: Mail.php 1434 2009-08-23 15:55:35Z vipsoft $
  * 
+ * @category Piwik
  * @package Piwik
  */
 
-require_once "Zend/Mail.php";
-
 /**
  * Class for sending mails, for more information see: 
- * http://framework.zend.com/manual/en/zend.mail.html 
  *
  * @package Piwik
+ * @see Zend_Mail, libs/Zend/Mail.php
+ * @link http://framework.zend.com/manual/en/zend.mail.html 
  */
 class Piwik_Mail extends Zend_Mail
 {
