@@ -4,13 +4,12 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: Period.php 540 2008-06-29 22:44:13Z matt $
+ * @version $Id: Period.php 1613 2009-11-27 20:57:13Z vipsoft $
  * 
- * @package Piwik_Helper
+ * @category Piwik
+ * @package Piwik
  */
 
-require_once "Period/Day.php";
-require_once "Period/Range.php";
 /**
  * Creating a new Piwik_Period subclass: 
  * 
@@ -22,8 +21,8 @@ require_once "Period/Range.php";
  *	that checks whether the subperiods have already been computed.
  *	This is for performance improvements, computing the subperiods is done a per demand basis.
  *
- * 
- * @package Piwik_Helper
+ * @package Piwik
+ * @subpackage Piwik_Period
  */
 abstract class Piwik_Period
 {
@@ -53,17 +52,14 @@ abstract class Piwik_Period
 				break;
 		
 			case 'week':
-				require_once "Period/Week.php";
 				return new Piwik_Period_Week($date); 
 				break;
 				
 			case 'month':
-				require_once "Period/Month.php";
 				return new Piwik_Period_Month($date); 
 				break;
 				
 			case 'year':
-				require_once "Period/Year.php";
 				return new Piwik_Period_Year($date); 
 				break;
 				
@@ -225,8 +221,7 @@ abstract class Piwik_Period
 	
 	public function __toString()
 	{
-		$elements = $this->toString();
-		return implode(",", $elements);
+		return implode(",", $this->toString());
 	}
 	
 	public function get( $part= null )
@@ -242,5 +237,3 @@ abstract class Piwik_Period
 	abstract public function getLocalizedShortString();
 	abstract public function getLocalizedLongString();
 }
-
-	
