@@ -1,8 +1,20 @@
 <?php
+/**
+ * Piwik - Open source web analytics
+ * 
+ * @link http://piwik.org
+ * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
+ * @version $Id: Range.php 1420 2009-08-22 13:23:16Z vipsoft $
+ * 
+ * @category Piwik
+ * @package Piwik
+ */
 
 /**
  * from a starting date to an ending date
  *
+ * @package Piwik
+ * @subpackage Piwik_Period
  */
 class Piwik_Period_Range extends Piwik_Period
 {
@@ -103,7 +115,7 @@ class Piwik_Period_Range extends Piwik_Period
 		}
 		parent::generate();
 		
-		if(ereg('(last|previous)([0-9]*)', $this->strDate, $regs))
+		if(preg_match('/(last|previous)([0-9]*)/', $this->strDate, $regs))
 		{
 			$lastN = $regs[2];
 			$lastOrPrevious = $regs[1];
@@ -132,7 +144,7 @@ class Piwik_Period_Range extends Piwik_Period
 			
 			$startDate = $this->removePeriod($endDate, $lastN);
 		}
-		elseif(ereg('([0-9]{4}-[0-9]{1,2}-[0-9]{1,2}),([0-9]{4}-[0-9]{1,2}-[0-9]{1,2})', $this->strDate, $regs))
+		elseif(preg_match('/([0-9]{4}-[0-9]{1,2}-[0-9]{1,2}),([0-9]{4}-[0-9]{1,2}-[0-9]{1,2})/', $this->strDate, $regs))
 		{
 			$strDateStart = $regs[1];
 			$strDateEnd = $regs[2];
