@@ -1,9 +1,18 @@
 <?php
-
-require_once "Period/Month.php";
 /**
+ * Piwik - Open source web analytics
  * 
- * @package Piwik_Period
+ * @link http://piwik.org
+ * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
+ * @version $Id: Year.php 1420 2009-08-22 13:23:16Z vipsoft $
+ * 
+ * @category Piwik
+ * @package Piwik
+ */
+
+/**
+ * @package Piwik
+ * @subpackage Piwik_Period
  */
 class Piwik_Period_Year extends Piwik_Period
 {	
