@@ -1,19 +1,22 @@
 <?php
 /**
  * Piwik - Open source web analytics
- * 
+ *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: Piwik.php 581 2008-07-27 23:07:52Z matt $
- * 
+ * @version $Id: Piwik.php 1609 2009-11-26 09:45:59Z vipsoft $
+ *
+ * @category Piwik
  * @package Piwik
  */
 
-require_once "Config.php";
-require_once "Zend/Db.php";
-require_once "Zend/Db/Table.php";
-require_once "Log.php";
-require_once "Translate.php";
+// no direct access
+defined('PIWIK_INCLUDE_PATH') or die;
+
+/**
+ * @see core/Translate.php
+ */
+require_once PIWIK_INCLUDE_PATH . '/core/Translate.php';
 
 /**
  * Main piwik helper class.
@@ -35,8 +38,6 @@ class Piwik
 	/**
 	 * Checks that the directories Piwik needs write access are actually writable
 	 * Displays a nice error page if permissions are missing on some directories
-	 * 
-	 * @return void
 	 */
 	static public function checkDirectoriesWritableOrDie( $directoriesToCheck = null )
 	{
@@ -78,16 +79,16 @@ class Piwik
 				'/tmp',
 				'/tmp/templates_c',
 				'/tmp/cache',
-				'/tmp/latest/',
+				'/tmp/latest',
 			); 
 		}
 		
 		$resultCheck = array();
 		foreach($directoriesToCheck as $directoryToCheck)
 		{
-			if( !ereg('^'.preg_quote(PIWIK_INCLUDE_PATH), $directoryToCheck) )
+			if( !preg_match('/^'.preg_quote(PIWIK_USER_PATH, '/').'/', $directoryToCheck) )
 			{
-				$directoryToCheck = PIWIK_INCLUDE_PATH . $directoryToCheck;
+				$directoryToCheck = PIWIK_USER_PATH . $directoryToCheck;
 			}
 			
 			if(!file_exists($directoryToCheck))
@@ -118,7 +119,7 @@ class Piwik
 	{	
 		$jsTag = file_get_contents( PIWIK_INCLUDE_PATH . "/core/Tracker/javascriptTag.tpl");
 		$jsTag = nl2br(htmlentities($jsTag));
-		$piwikUrl = preg_match('/^(http|https):\/\/(.*)$/', $piwikUrl, $matches);
+		$piwikUrl = preg_match('~^(http|https)://(.*)$~', $piwikUrl, $matches);
 		$piwikUrl = $matches[2];
 		$jsTag = str_replace('{$actionName}', $actionName, $jsTag);
 		$jsTag = str_replace('{$idSite}', $idSite, $jsTag);
@@ -126,7 +127,19 @@ class Piwik
 		$jsTag = str_replace('{$hrefTitle}', Piwik::getRandomTitle(), $jsTag);
 		return $jsTag;
 	}
-	
+
+	/**
+	 * Set maximum script execution time.
+	 *
+	 * @param int max execution time in seconds (0 = no limit)
+	 */
+	static public function setMaxExecutionTime($executionTime)
+	{
+		// in the event one or the other is disabled...
+		@ini_set('max_execution_time', $executionTime);
+		@set_time_limit($executionTime);
+	}
+
 	static public function getMemoryLimitValue()
 	{
 		if($memory = ini_get('memory_limit'))
@@ -163,8 +176,8 @@ class Piwik
 	
 	static public function log($message = '')
 	{
-		Zend_Registry::get('logger_message')->log($message);
-		Zend_Registry::get('logger_message')->log( "<br>" . PHP_EOL);
+		Zend_Registry::get('logger_message')->logEvent($message);
+		Zend_Registry::get('logger_message')->logEvent( "<br>" . PHP_EOL);
 	}
 	
 	
@@ -223,24 +236,26 @@ class Piwik
 	
 	static public function printSqlProfilingReportTracker( $db = null )
 	{
-		function maxSumMsFirst($a,$b)
+		if(!function_exists('maxSumMsFirst'))
 		{
-			return $a['sum_time_ms'] < $b['sum_time_ms'];
+			function maxSumMsFirst($a,$b)
+			{
+				return $a['sum_time_ms'] < $b['sum_time_ms'];
+			}
 		}
 		
 		if(is_null($db))
 		{
-			$db = Zend_Registry::get('db');
+			$db = Piwik_Tracker::getDatabase();
 		}
 		$tableName = Piwik_Common::prefixTable('log_profiling');
 		
-		$all = $db->fetchAll('SELECT *, sum_time_ms / count as avg_time_ms 
-								FROM '.$tableName );
+		$all = $db->fetchAll('SELECT * FROM '.$tableName );
 		if($all === false) 
 		{
 			return;
 		}
-		usort($all, 'maxSumMsFirst');
+		uasort($all, 'maxSumMsFirst');
 		
 		$infoIndexedByQuery = array();
 		foreach($all as $infoQuery)
@@ -282,9 +297,13 @@ class Piwik
 							'sumTimeMs' =>  $existing['count'] + $query->getElapsedSecs() * 1000);
 			$infoIndexedByQuery[$query->getQuery()] = $new;
 		}
-		function sortTimeDesc($a,$b)
+
+		if(!function_exists('sortTimeDesc'))
 		{
-			return $a['sumTimeMs'] < $b['sumTimeMs'];
+			function sortTimeDesc($a,$b)
+			{
+				return $a['sumTimeMs'] < $b['sumTimeMs'];
+			}
 		}
 		uasort( $infoIndexedByQuery, 'sortTimeDesc');
 		
@@ -322,9 +341,7 @@ class Piwik
 				$avgTimeMs = $timeMs / $count;
 				$avgTimeString = " (average = <b>". round($avgTimeMs,1) . "ms</b>)"; 
 			}
-			$query = str_replace(array("\t","\n","\r\n","\r"), "_toberemoved_", $query);
-			$query = str_replace('_toberemoved__toberemoved_','',$query);
-			$query = str_replace('_toberemoved_', ' ',$query);
+			$query = preg_replace('/([\t\n\r ]+)/', ' ', $query);
 			$output .= "Executed <b>$count</b> time". ($count==1?'':'s') ." in <b>".$timeMs."ms</b> $avgTimeString <pre>\t$query</pre>";
 		}
 		Piwik::log($output);
@@ -385,10 +402,17 @@ class Piwik
 		}
 		return round($size, 1)." ".$val;
 	}
-	
+
+	/**
+	 * Returns true if PHP was invoked as CGI or command-line interface (shell)
+	 *
+	 * @deprecated deprecated in 0.4.4
+	 * @see Piwik_Common::isPhpCliMode()
+	 * @return bool true if PHP invoked as a CGI or from CLI
+	 */
 	static public function isPhpCliMode()
 	{
-		return in_array(substr(php_sapi_name(), 0, 3), array('cgi', 'cli'));
+		return Piwik_Common::isPhpCliMode();
 	}
 	
 	static public function getCurrency()
@@ -396,7 +420,7 @@ class Piwik
 		static $symbol = null;
 		if(is_null($symbol))
 		{
-			$symbol = Zend_Registry::get('config')->General->default_currency;
+			$symbol = trim(Zend_Registry::get('config')->General->default_currency);
 		}
 		return $symbol;
 	}
@@ -486,7 +510,7 @@ class Piwik
 		$prefixTables = $config->database->tables_prefix;
 		$tables = array(
 			'user' => "CREATE TABLE {$prefixTables}user (
-						  login VARCHAR(20) NOT NULL,
+						  login VARCHAR(100) NOT NULL,
 						  password CHAR(32) NOT NULL,
 						  alias VARCHAR(45) NOT NULL,
 						  email VARCHAR(100) NOT NULL,
@@ -498,7 +522,7 @@ class Piwik
 			",
 			
 			'access' => "CREATE TABLE {$prefixTables}access (
-						  login VARCHAR(20) NOT NULL,
+						  login VARCHAR(100) NOT NULL,
 						  idsite INTEGER UNSIGNED NOT NULL,
 						  access VARCHAR(10) NULL,
 						  PRIMARY KEY(login, idsite)
@@ -550,7 +574,7 @@ class Piwik
 									  parameter_names_default_values TEXT NULL,
 									  parameter_values TEXT NULL,
 									  execution_time FLOAT NULL,
-									  caller_ip BIGINT NULL,
+									  caller_ip BIGINT UNSIGNED NULL,
 									  timestamp TIMESTAMP NULL,
 									  returned_value TEXT NULL,
 									  PRIMARY KEY(idlogger_api_call)
@@ -585,9 +609,10 @@ class Piwik
 			'log_action' => "CREATE TABLE {$prefixTables}log_action (
 									  idaction INTEGER(10) UNSIGNED NOT NULL AUTO_INCREMENT,
 									  name VARCHAR(255) NOT NULL,
+									  hash INTEGER(10) UNSIGNED NOT NULL,
   									  type TINYINT UNSIGNED NULL,
 									  PRIMARY KEY(idaction),
-									  INDEX index_type_name (type, name(15))
+									  INDEX index_type_hash (type, hash)
 						)  DEFAULT CHARSET=utf8 
 			",
 					
@@ -600,8 +625,8 @@ class Piwik
 							  visit_first_action_time DATETIME NOT NULL,
 							  visit_last_action_time DATETIME NOT NULL,
 							  visit_server_date DATE NOT NULL,
-							  visit_exit_idaction INTEGER(11) NOT NULL,
-							  visit_entry_idaction INTEGER(11) NOT NULL,
+							  visit_exit_idaction_url INTEGER(11) NOT NULL,
+							  visit_entry_idaction_url INTEGER(11) NOT NULL,
 							  visit_total_actions SMALLINT(5) UNSIGNED NOT NULL,
 							  visit_total_time SMALLINT(5) UNSIGNED NOT NULL,
 							  visit_goal_converted TINYINT(1) NOT NULL,
@@ -616,11 +641,15 @@ class Piwik
 							  config_resolution VARCHAR(9) NOT NULL,
 							  config_pdf TINYINT(1) NOT NULL,
 							  config_flash TINYINT(1) NOT NULL,
+							  config_java TINYINT(1) NOT NULL,
 							  config_director TINYINT(1) NOT NULL,
+							  config_quicktime TINYINT(1) NOT NULL,
 							  config_realplayer TINYINT(1) NOT NULL,
 							  config_windowsmedia TINYINT(1) NOT NULL,
+							  config_gears TINYINT(1) NOT NULL,
+							  config_silverlight TINYINT(1) NOT NULL,
 							  config_cookie TINYINT(1) NOT NULL,
-							  location_ip BIGINT(11) NOT NULL,
+							  location_ip BIGINT UNSIGNED NOT NULL,
 							  location_browser_lang VARCHAR(20) NOT NULL,
 							  location_country CHAR(3) NOT NULL,
 							  location_continent CHAR(3) NOT NULL,
@@ -635,8 +664,8 @@ class Piwik
 									  `visitor_idcookie` char(32) NOT NULL,
 									  `server_time` datetime NOT NULL,
 									  `visit_server_date` date NOT NULL,
-									  `idaction` int(11) NOT NULL,
-									  `idlink_va` int(11) NOT NULL,
+									  `idaction_url` int(11) default NULL,
+									  `idlink_va` int(11) default NULL,
 									  `referer_idvisit` int(10) unsigned default NULL,
 									  `referer_visit_server_date` date default NULL,
 									  `referer_type` int(10) unsigned default NULL,
@@ -656,8 +685,9 @@ class Piwik
 			'log_link_visit_action' => "CREATE TABLE {$prefixTables}log_link_visit_action (
 											  idlink_va INTEGER(11) NOT NULL AUTO_INCREMENT,
 											  idvisit INTEGER(10) UNSIGNED NOT NULL,
-											  idaction INTEGER(10) UNSIGNED NOT NULL,
-											  idaction_ref INTEGER(11) UNSIGNED NOT NULL,
+											  idaction_url INTEGER(10) UNSIGNED NOT NULL,
+											  idaction_url_ref INTEGER(10) UNSIGNED NOT NULL,
+											  idaction_name INTEGER(10) UNSIGNED,
 											  time_spent_ref_action INTEGER(10) UNSIGNED NOT NULL,
 											  PRIMARY KEY(idlink_va),
 											  INDEX index_idvisit(idvisit)
@@ -892,8 +922,7 @@ class Piwik
 			||  $currentAction != $newAction )
 		{
 			
-			$newUrl = Piwik_URL::getCurrentUrlWithoutQueryString() 
-				. Piwik_Url::getCurrentQueryStringWithParametersModified(
+			$newUrl = 'index.php' . Piwik_Url::getCurrentQueryStringWithParametersModified(
 						array('module' => $newModule, 'action' => $newAction)
 				);
 	
@@ -901,60 +930,297 @@ class Piwik
 		}
 		return false;
 	}
-	
-	static public function displayScreenForCoreAndPluginsUpdatesIfNecessary()
+
+	/**
+	 * Get "best" available transport method for sendHttpRequest() calls.
+	 */
+	static public function getTransportMethod()
 	{
-		require_once "Updater.php";
-		$updater = new Piwik_Updater();
-		$updater->addComponentToCheck('core', Piwik_Version::VERSION);
-		
-		$plugins = Piwik_PluginsManager::getInstance()->getInstalledPlugins();
-		foreach($plugins as $pluginName => $plugin)
+		$method = 'curl';
+		if(!extension_loaded('curl'))
 		{
-			$updater->addComponentToCheck($pluginName, $plugin->getVersion());
+			$method = 'stream';
+			if(@ini_get('allow_url_fopen') != '1')
+			{
+				$method = 'socket';
+				if(preg_match('/(^|,|\s)fsockopen($|,|\s)/', @ini_get('disable_functions')))
+				{
+					return null;
+				}
+			}
 		}
-		
-		$componentsWithUpdateFile = $updater->getComponentsWithUpdateFile();
-		if(count($componentsWithUpdateFile) == 0)
-		{
-			return;
-		}
-			
-		require_once "CoreUpdater/Controller.php";
-		$updaterController = new Piwik_CoreUpdater_Controller();
-		$updaterController->runUpdaterAndExit($updater, $componentsWithUpdateFile);
+		return $method;
 	}
-	
+
 	/**
 	 * Sends http request ensuring the request will fail before $timeout seconds
-	 * Returns the response content (no header, trimmed)
-	 * @param string $url
+	 *
+	 * If no $destinationPath is specified, the trimmed response (without header) is returned as a string.
+	 * If a $destinationPath is specified, the response (without header) is saved to a file.
+	 *
+	 * @param string $aUrl
 	 * @param int $timeout
-	 * @return string|false false if request failed
+	 * @param string $userAgent
+	 * @param string $destinationPath
+	 * @param int $followDepth
+	 * @return true (or string) on success; false on HTTP response error code (1xx or 4xx); throws exception on all other errors
 	 */
-	static public function sendHttpRequest($url, $timeout)
+	static public function sendHttpRequest($aUrl, $timeout, $userAgent = null, $destinationPath = null, $followDepth = 0)
 	{
-		$response = false;
-		// we make sure the request takes less than a few seconds to fail
-		// we create a stream_context (works in php >= 5.2.1)
-		// we also set the socket_timeout (for php < 5.2.1) 
-		$default_socket_timeout = @ini_get('default_socket_timeout');
-		@ini_set('default_socket_timeout', $timeout);
-		
-		$ctx = null;
-		if(function_exists('stream_context_create')) {
-			$ctx = stream_context_create(array('http' => array( 'timeout' => $timeout)));
-		}
-		$response = trim(@file_get_contents($url, 0, $ctx));
-		
-		// restore the socket_timeout value
-		if(!empty($default_socket_timeout))
+		// create output file
+		$file = null;
+		if($destinationPath)
 		{
-			@ini_set('default_socket_timeout', $default_socket_timeout);
+			if (($file = @fopen($destinationPath, 'wb')) === false || !is_resource($file))
+			{
+				throw new Exception('Error while creating the file: ' . $destinationPath);
+			}
 		}
-		return $response;
+
+		return self::sendHttpRequestBy(self::getTransportMethod(), $aUrl, $timeout, $userAgent, $destinationPath, $file, $followDepth); 			
 	}
-	
+
+	static public function sendHttpRequestBy($method = 'socket', $aUrl, $timeout, $userAgent = null, $destinationPath = null, $file = null, $followDepth = 0)
+	{
+		if ($followDepth > 3)
+		{
+			throw new Exception('Too many redirects ('.$followDepth.')');
+		}
+
+		$contentLength = 0;
+
+		if($method == 'socket')
+		{
+			// initialization
+			$url = @parse_url($aUrl);
+			if($url === false || !isset($url['scheme']))
+			{
+				throw new Exception('Malformed URL: '.$aUrl);
+			}
+
+			if($url['scheme'] != 'http')
+			{
+				throw new Exception('Invalid protocol/scheme: '.$url['scheme']);
+			}
+			$host = $url['host'];
+			$port = isset($url['port)']) ? $url['port'] : 80;
+			$path = isset($url['path']) ? $url['path'] : '/';
+			if(isset($url['query']))
+			{
+				$path .= '?'.$url['query'];
+			}
+			$errno = null;
+			$errstr = null;
+
+			// connection attempt
+			if (($fsock = @fsockopen($host, $port, $errno, $errstr, $timeout)) === false || !is_resource($fsock))
+			{
+				if(is_resource($file)) { @fclose($file); }
+				throw new Exception("Error while connecting to: $host. Please try again later. $errstr");
+			}
+
+			// send HTTP request header
+			fwrite($fsock,
+				"GET $path HTTP/1.0\r\n"
+				."Host: $host".($port != 80 ? ':'.$port : '')."\r\n"
+				."User-Agent: Piwik/".Piwik_Version::VERSION.($userAgent ? " $userAgent" : '')."\r\n"
+				.'Referer: http://'.Piwik_Common::getIpString()."/\r\n"
+				."Connection: close\r\n"
+				."\r\n"
+			);
+
+			$streamMetaData = array('timed_out' => false);
+			@stream_set_blocking($fsock, true);
+			@stream_set_timeout($fsock, $timeout);
+
+			// process header
+			$status = null;
+			$expectRedirect = false;
+			$fileLength = 0;
+
+			while (!feof($fsock))
+			{
+				$line = fgets($fsock, 4096);
+
+				$streamMetaData = @stream_get_meta_data($fsock);
+				if($streamMetaData['timed_out'])
+				{
+					if(is_resource($file)) { @fclose($file); }
+					@fclose($fsock);
+					throw new Exception('Timed out waiting for server response');
+				}
+
+				// a blank line marks the end of the server response header
+				if(rtrim($line, "\r\n") == '')
+				{
+					break;
+				}
+
+				// parse first line of server response header
+				if(!$status)
+				{
+					// expect first line to be HTTP response status line, e.g., HTTP/1.1 200 OK
+					if(!preg_match('~^HTTP/(\d\.\d)\s+(\d+)(\s*.*)?~', $line, $m))
+					{
+						if(is_resource($file)) { @fclose($file); }
+						@fclose($fsock);
+						throw new Exception('Expected server response code.  Got '.rtrim($line, "\r\n"));
+					}
+
+					$status = (integer) $m[2];
+
+					// Informational 1xx or Client Error 4xx
+					if ($status < 200 || $status >= 400)
+					{
+						if(is_resource($file)) { @fclose($file); }
+						@fclose($s);
+						return false;
+					}
+
+					continue;
+				}
+
+				// handle redirect
+				if(preg_match('/^Location:\s*(.+)/', rtrim($line, "\r\n"), $m))
+				{
+					if(is_resource($file)) { @fclose($file); }
+					@fclose($s);
+					// Successful 2xx vs Redirect 3xx
+					if($status < 300)
+					{
+						throw new Exception('Unexpected redirect to Location: '.rtrim($line).' for status code '.$status);
+					}
+					return self::sendHttpRequest(trim($m[1]), $pathDestination, $tries+1);
+				}
+
+				// save expected content length for later verification
+				if(preg_match('/^Content-Length:\s*(\d+)/', $line, $m))
+				{
+					$contentLength = (integer) $m[1];
+				}
+			}
+
+			if(feof($fsock))
+			{
+				throw new Exception('Unexpected end of transmission');
+			}
+
+			// process content/body
+			$response = '';
+
+			while (!feof($fsock))
+			{
+				$line = fread($fsock, 8192);
+
+				$streamMetaData = @stream_get_meta_data($fsock);
+				if($streamMetaData['timed_out'])
+				{
+					if(is_resource($file)) { @fclose($file); }
+					@fclose($fsock);
+					throw new Exception('Timed out waiting for server response');
+				}
+
+				if(is_resource($file))
+				{
+					// save to file
+					$fileLength += fwrite($file, $line);
+				}
+				else
+				{
+					// concatenate to response string
+					$response .= $line;
+				}
+			}
+
+			// determine success or failure
+			@fclose(@$fsock);
+		}
+		else if($method == 'stream')
+		{
+			$response = false;
+
+			// we make sure the request takes less than a few seconds to fail
+			// we create a stream_context (works in php >= 5.2.1)
+			// we also set the socket_timeout (for php < 5.2.1)
+			$default_socket_timeout = @ini_get('default_socket_timeout');
+			@ini_set('default_socket_timeout', $timeout);
+
+			$ctx = null;
+			if(function_exists('stream_context_create')) {
+				$stream_options = array(
+					'http' => array(
+						'header' => 'User-Agent: Piwik/'.Piwik_Version::VERSION.($userAgent ? " $userAgent" : '')."\r\n"
+						           .'Referer: http://'.Piwik_Common::getIpString()."/\r\n",
+						'max_redirects' => 3, // PHP 5.1.0
+						'timeout' => $timeout, // PHP 5.2.1
+					)
+				);
+				$ctx = stream_context_create($stream_options);
+			}
+
+			$response = @file_get_contents($aUrl, 0, $ctx);
+			if(is_resource($file))
+			{
+				// save to file
+				fwrite($file, $response);
+			}
+
+			// restore the socket_timeout value
+			if(!empty($default_socket_timeout))
+			{
+				@ini_set('default_socket_timeout', $default_socket_timeout);
+			}
+		}
+		else if($method == 'curl')
+		{
+			$ch = @curl_init();
+
+			$curl_options = array(
+				CURLOPT_URL => $aUrl,
+				CURLOPT_HEADER => false,
+				CURLOPT_RETURNTRANSFER => true,
+				CURLOPT_TIMEOUT => $timeout,
+				CURLOPT_BINARYTRANSFER => is_resource($file),
+				CURLOPT_FOLLOWLOCATION => true,
+				CURLOPT_MAXREDIRS => 3,
+				CURLOPT_USERAGENT => 'Piwik/'.Piwik_Version::VERSION.($userAgent ? " $userAgent" : ''),
+				CURLOPT_REFERER => 'http://'.Piwik_Common::getIpString(),
+			);
+			@curl_setopt_array($ch, $curl_options);
+
+			$response = @curl_exec($ch);
+			if(is_resource($file))
+			{
+				// save to file
+				fwrite($file, $response);
+			}
+
+			@curl_close($ch);
+			unset($ch);
+		}
+		else
+		{
+			throw new Exception('Invalid request method: '.$method);
+		}
+
+		if(is_resource($file))
+		{
+			fflush($file);
+			@fclose($file);
+			if($contentLength && (($fileLength != $contentLength) || (filesize($destinationPath) != $contentLength)))
+			{
+				throw new Exception('File size error: '.$destinationPath.'; expected '.$contentLength.' bytes; received '.$fileLength.' bytes');
+			}
+			return true;
+		}
+
+		if($contentLength && strlen($response) != $contentLength)
+		{
+			throw new Exception('Content length error: expected '.$contentLength.' bytes; received '.$fileLength.' bytes');
+		}
+		return trim($response);
+	}
+
 	/**
 	 * Fetch the file at $url in the destination $pathDestination
 	 * @param string $url
@@ -964,67 +1230,9 @@ class Piwik
 	 */
 	static public function fetchRemoteFile($url, $pathDestination, $tries = 0)
 	{
-		if ($tries > 3) {
-			return false;
-		}
-		
-		$file = @fopen($pathDestination, 'wb');
-		if(!$file) {
-			throw new Exception("Error while creating the file: ".$file);
-		}
-		$url = parse_url($url);
-		$host = $url['host'];
-		$path = $url['path'];
-		
-		if (($s = @fsockopen($host, $port = 80, $errno, $errstr, $timeout = 10)) === false) {
-			throw new Exception("Error while connecting to: $host. Please try again later.");
-		}
-		
-		fwrite($s,
-			'GET '.$path." HTTP/1.0\r\n"
-			.'Host: '.$host."\r\n"
-			."User-Agent: Piwik Update\r\n"
-			."\r\n"
-		);
-		
-		$i = 0;
-		$in_content = false;
-		while (!feof($s))
-		{
-			$line = fgets($s,4096);
-			if (rtrim($line,"\r\n") == '' && !$in_content) {
-				$in_content = true;
-				$i++;
-				continue;
-			}
-			if ($i == 0) {
-				if (!preg_match('/HTTP\/(\\d\\.\\d)\\s*(\\d+)\\s*(.*)/',rtrim($line,"\r\n"), $m)) {
-					fclose($s);
-					return false;
-				}
-				$status = (integer) $m[2];
-				if ($status < 200 || $status >= 400) {
-					fclose($s);
-					return false;
-				}
-			}
-			if (!$in_content) {
-				if (preg_match('/Location:\s+?(.+)$/',rtrim($line,"\r\n"),$m)) {
-					fclose($s);
-					return fetchRemote(trim($m[1]), $pathDestination, $tries+1);
-				}
-				$i++;
-				continue;
-			}
-			if (is_resource($file)) {
-				fwrite($file,$line);
-			}			
-			$i++;
-		}
-		fclose($s);
-		return true;
+		return self::sendHttpRequest($url, 10, 'Update', $pathDestination, $tries);
 	}
-	
+
 	/**
 	 * Recursively delete a directory
 	 *
@@ -1062,9 +1270,9 @@ class Piwik
 	 * 
 	 * @param string $source eg. './tmp/latest'
 	 * @param string $target eg. '.'
-	 * @return void
+	 * @param bool   $excludePhp
 	 */
-	static public function copyRecursive($source, $target )
+	static public function copyRecursive($source, $target, $excludePhp=false )
 	{
 		if ( is_dir( $source ) )
 		{
@@ -1080,22 +1288,41 @@ class Piwik
 				$sourcePath = $source . '/' . $entry;		   
 				if ( is_dir( $sourcePath ) )
 				{
-					self::copyRecursive( $sourcePath, $target . '/' . $entry );
+					self::copyRecursive( $sourcePath, $target . '/' . $entry, $excludePhp );
 					continue;
 				}
 				$destPath = $target . '/' . $entry;
-				self::copy($sourcePath, $destPath);
+				self::copy($sourcePath, $destPath, $excludePhp);
 			}
 			$d->close();
 		}
 		else
 		{
-			self::copy($source, $target);
+			self::copy($source, $target, $excludePhp);
 		}
 	}
 	
-	static public function copy($source, $dest)
+	/**
+	 * Copy individual file from $source to $target.
+	 * 
+	 * @param string $source eg. './tmp/latest/index.php'
+	 * @param string $target eg. './index.php'
+	 * @param bool   $excludePhp
+	 * @return bool
+	 */
+	static public function copy($source, $dest, $excludePhp=false)
 	{
+		static $phpExtensions = array('php', 'tpl');
+
+		if($excludePhp)
+		{
+			$path_parts = pathinfo($source);
+			if(in_array($path_parts['extension'], $phpExtensions))
+			{
+				return true;
+			}
+		}
+
 		if(!@copy( $source, $dest ))
 		{
 			@chmod($dest, 0755);
@@ -1112,9 +1339,38 @@ class Piwik
 		}
 		return true;
 	}
+
+	/**
+	 * Recursively find pathnames that match a pattern
+	 * @see glob()
+	 *
+	 * @param string $sDir directory
+	 * @param string $sPattern pattern
+	 * @param int $nFlags glob() flags
+	 * @return array
+	 */
+	public static function globr($sDir, $sPattern, $nFlags = NULL)
+	{
+		if(($aFiles = glob("$sDir/$sPattern", $nFlags)) == false)
+		{
+			$aFiles = array();
+		}
+		if(($aDirs = glob("$sDir/*", GLOB_ONLYDIR)) != false)
+		{
+			foreach ($aDirs as $sSubDir)
+			{
+				$aSubFiles = self::globr($sSubDir, $sPattern, $nFlags);
+				$aFiles = array_merge($aFiles, $aSubFiles);
+			}
+		}
+		return $aFiles;
+	}
+
 	/**
 	 * API was simplified in 0.2.27, but we maintain backward compatibility 
 	 * when calling Piwik::prefixTable
+	 *
+	 * @deprecated as of 0.2.27
 	 */
 	static public function prefixTable( $table )
 	{
@@ -1158,7 +1414,7 @@ class Piwik
 			$tablesInstalled = array_intersect($allMyTables, $allTables);
 			
 			// at this point we have only the piwik tables which is good
-			// but we still miss the piwik generated tables (using the class Piwik_TablePartitioning)`
+			// but we still miss the piwik generated tables (using the class Piwik_TablePartitioning)
 			$idSiteInSql = "no";
 			if(!is_null($idSite))
 			{
@@ -1182,13 +1438,13 @@ class Piwik
 		{
 			$dbName = Zend_Registry::get('config')->database->dbname;
 		}
-		Piwik_Query("CREATE DATABASE IF NOT EXISTS ".$dbName);
+		Piwik_Exec("CREATE DATABASE IF NOT EXISTS ".$dbName);
 	}
-	
+
 	static public function dropDatabase()
 	{
 		$dbName = Zend_Registry::get('config')->database->dbname;
-		Piwik_Query("DROP DATABASE IF EXISTS " . $dbName);
+		Piwik_Exec("DROP DATABASE IF EXISTS " . $dbName);
 	}
 	
 	static public function createDatabaseObject( $dbInfos = null )
@@ -1206,13 +1462,24 @@ class Piwik
 		Piwik_PostEvent('Reporting.createDatabase', $db);
 		if(is_null($db))
 		{
-			$db = Zend_Db::factory($config->database->adapter, $dbInfos);
+			if($dbInfos['port'][0] == '/')
+			{
+				$dbInfos['unix_socket'] = $dbInfos['port'];
+				unset($dbInfos['host']);
+				unset($dbInfos['port']);
+			}
+
+			$adapter = $dbInfos['adapter'];
+
+			// not used by Zend Framework
+			unset($dbInfos['tables_prefix']);
+			unset($dbInfos['adapter']);
+
+			$db = Piwik_Db::factory($adapter, $dbInfos);
 			$db->getConnection();
-			// see http://framework.zend.com/issues/browse/ZF-1398
-			$db->getConnection()->setAttribute(PDO::ATTR_EMULATE_PREPARES, true);
-			$db->getConnection()->setAttribute(PDO::MYSQL_ATTR_USE_BUFFERED_QUERY, true);		
+
 			Zend_Db_Table::setDefaultAdapter($db);
-			$db->resetConfigArray(); // we don't want this information to appear in the logs
+			$db->resetConfig(); // we don't want this information to appear in the logs
 		}
 		Zend_Registry::set('db', $db);
 	}
@@ -1222,18 +1489,41 @@ class Piwik
 		Zend_Registry::get('db')->closeConnection();
 	}
 	
+	/**
+	 * Returns the MySQL database server version
+	 *
+	 * @deprecated 0.4.4
+	 */
 	static public function getMysqlVersion()
 	{
 		return Piwik_FetchOne("SELECT VERSION()");
 	}
 
+	/**
+	 * Checks the database server version against the required minimum
+	 * version.
+	 *
+	 * @see config/global.ini.php
+	 * @since 0.4.4
+	 * @throws Exception if server version is less than the required version
+	 */
+	static public function checkDatabaseVersion()
+	{
+		Zend_Registry::get('db')->checkServerVersion();
+	}
+
+	/**
+	 * Check database connection character set is utf8.
+	 *
+	 * @return bool True if it is (or doesn't matter); false otherwise
+	 */
+	static public function isDatabaseConnectionUTF8()
+	{
+		return Zend_Registry::get('db')->isConnectionUTF8();
+	}
+
 	static public function createLogObject()
 	{
-		require_once "Log/APICall.php";
-		require_once "Log/Exception.php";
-		require_once "Log/Error.php";
-		require_once "Log/Message.php";
-		
 		$configAPI = Zend_Registry::get('config')->log;
 		
 		$aLoggers = array(
@@ -1300,14 +1590,14 @@ class Piwik
 		$tablesAlreadyInstalled = self::getTablesInstalled();
 		$db = Zend_Registry::get('db');
 		
-		$doNotDeletePattern = "(".implode("|",$doNotDelete).")";
+		$doNotDeletePattern = '/('.implode('|',$doNotDelete).')/';
 		
 		foreach($tablesAlreadyInstalled as $tableName)
 		{
 			
 			if( count($doNotDelete) == 0
 				|| (!in_array($tableName,$doNotDelete)
-					&& !ereg($doNotDeletePattern,$tableName)
+					&& !preg_match($doNotDeletePattern,$tableName)
 					)
 				)
 			{
@@ -1329,8 +1619,6 @@ class Piwik
 	
 	/**
 	 * Creates an entry in the User table for the "anonymous" user. 
-	 * 
-	 * @return void
 	 */
 	static public function createAnonymousUser()
 	{
@@ -1382,4 +1670,3 @@ class Piwik
 		$db->query( "DROP TABLE IF EXISTS ". implode(", ", self::getTablesNames()) );
 	}
 }
-
