@@ -4,25 +4,29 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: PluginsManager.php 583 2008-07-28 00:37:19Z matt $
+ * @version $Id: PluginsManager.php 1632 2009-12-08 22:48:44Z matt $
  * 
+ * @category Piwik
  * @package Piwik
  */
 
-require_once "Plugin.php";
-require_once "Event/Dispatcher.php";
-require_once "PluginsFunctions/Menu.php";
-require_once "PluginsFunctions/AdminMenu.php";
-require_once "PluginsFunctions/WidgetsList.php";
-require_once "PluginsFunctions/Sql.php";
+// no direct access
+defined('PIWIK_INCLUDE_PATH') or die;
 
-require_once "Zend/Exception.php";
-require_once "Zend/Loader.php"; 
-require_once "Auth.php";
-require_once "Controller.php";
+/**
+ * @see core/PluginsFunctions/Menu.php
+ * @see core/PluginsFunctions/AdminMenu.php
+ * @see core/PluginsFunctions/WidgetsList.php
+ * @see core/PluginsFunctions/Sql.php
+ */
+require_once PIWIK_INCLUDE_PATH . '/core/PluginsFunctions/Menu.php';
+require_once PIWIK_INCLUDE_PATH . '/core/PluginsFunctions/AdminMenu.php';
+require_once PIWIK_INCLUDE_PATH . '/core/PluginsFunctions/WidgetsList.php';
+require_once PIWIK_INCLUDE_PATH . '/core/PluginsFunctions/Sql.php';
 
 /**
  * @package Piwik
+ * @subpackage Piwik_PluginsManager
  */
 class Piwik_PluginsManager
 {
@@ -85,8 +89,8 @@ class Piwik_PluginsManager
 	 */
 	public function readPluginsDirectory()
 	{
-		$pluginsName = glob( PIWIK_INCLUDE_PATH . "/plugins/*", GLOB_ONLYDIR);
-		$pluginsName = array_map('basename', $pluginsName);
+		$pluginsName = glob( PIWIK_INCLUDE_PATH . '/plugins/*', GLOB_ONLYDIR);
+		$pluginsName = $pluginsName === false ? array() : array_map('basename', $pluginsName);
 		return $pluginsName;
 	}
 
@@ -188,9 +192,7 @@ class Piwik_PluginsManager
 	 */
 	public function getLoadedPluginsName()
 	{
-		$oPlugins = $this->getLoadedPlugins();
-		$pluginNames = array_map('get_class',$oPlugins);
-		return $pluginNames;
+		return array_map('get_class', $this->getLoadedPlugins());
 	}
 	
 	/**
@@ -262,8 +264,8 @@ class Piwik_PluginsManager
 		{
 			return $this->loadedPlugins[$pluginName];
 		}
-		$pluginFileName = $pluginName . '/' . $pluginName . ".php";
-		$pluginClassName = "Piwik_".$pluginName;
+		$pluginFileName = $pluginName . '/' . $pluginName . '.php';
+		$pluginClassName = 'Piwik_'.$pluginName;
 		
 		if( !Piwik_Common::isValidFilename($pluginName))
 		{
@@ -274,18 +276,19 @@ class Piwik_PluginsManager
 
 		if(!file_exists($path))
 		{
-			throw new Exception("The plugin '$pluginName' is enabled, but the file '$path' couldn't be found.
-							To continue, please disable the plugin manually by removing the line 
-							<pre>Plugins[] = $pluginName</pre>
-							in the configuration file <code>config/config.ini.php</code>");
+			throw new Exception("Unable to load plugin '$pluginName' because '$path' couldn't be found.
+			You can manually uninstall the plugin by removing the line <code>Plugins[] = $pluginName</code> from the Piwik config file.");
 		}
-		require_once $path;
+
+		// Don't remove this.
+		// Our autoloader can't find plugins/PluginName/PluginName.php
+		require_once $path; // prefixed by PIWIK_INCLUDE_PATH
 		
-		if(!class_exists($pluginClassName))
+		if(!class_exists($pluginClassName, false))
 		{
 			throw new Exception("The class $pluginClassName couldn't be found in the file '$path'");
 		}
-		$newPlugin = new $pluginClassName;
+		$newPlugin = new $pluginClassName();
 		
 		if(!($newPlugin instanceof Piwik_Plugin))
 		{
@@ -301,7 +304,6 @@ class Piwik_PluginsManager
 
 	/**
 	 * @param Piwik_Plugin $plugin
-	 * @return void
 	 */
 	public function unloadPlugin( $plugin )
 	{
@@ -344,7 +346,7 @@ class Piwik_PluginsManager
 		try{
 			$plugin->install();
 		} catch(Exception $e) {
-			throw new Piwik_Plugin_Exception($plugin->getName(), $plugin->getClassName(), $e->getMessage());		}	
+			throw new Piwik_PluginsManager_PluginException($plugin->getName(), $plugin->getClassName(), $e->getMessage());		}	
 	}
 	
 	
@@ -379,7 +381,7 @@ class Piwik_PluginsManager
 	private function loadTranslation( $plugin, $langCode )
 	{
 		// we are certainly in Tracker mode, Zend is not loaded
-		if(!class_exists('Zend_Loader'))
+		if(!class_exists('Zend_Loader', false))
 		{
 			return ;
 		}
@@ -398,7 +400,7 @@ class Piwik_PluginsManager
 		
 		$pluginName = $plugin->getClassName();
 		
-		$path = PIWIK_INCLUDE_PATH . "/plugins/" . $pluginName ."/lang/%s.php";
+		$path = PIWIK_INCLUDE_PATH . '/plugins/' . $pluginName .'/lang/%s.php';
 		
 		$defaultLangPath = sprintf($path, $langCode);
 		$defaultEnglishLangPath = sprintf($path, 'en');
@@ -425,7 +427,7 @@ class Piwik_PluginsManager
 	 */
 	public function getInstalledPluginsName()
 	{
-		if(!class_exists('Zend_Registry'))
+		if(!class_exists('Zend_Registry', false))
 		{
 			throw new Exception("Not possible to list installed plugins (case Tracker module)");
 		}
@@ -477,7 +479,11 @@ class Piwik_PluginsManager
 	}
 }
 
-class Piwik_Plugin_Exception extends Exception 
+/**
+ * @package Piwik
+ * @subpackage Piwik_PluginsManager
+ */
+class Piwik_PluginsManager_PluginException extends Exception 
 {
 	function __construct($pluginName, $className, $message)
 	{
@@ -506,19 +512,29 @@ function Piwik_AddAction( $hookName, $function )
 	Piwik_PluginsManager::getInstance()->dispatcher->addObserver( $function, $hookName );
 }
 
+/**
+ * @package Piwik
+ * @see Event_Notification, libs/Event/Notification.php
+ * @link http://pear.php.net/package/Event_Dispatcher/docs/latest/Event_Dispatcher/Event_Notification.html
+ */
 class Piwik_Event_Notification extends Event_Notification
 {
 	static $showProfiler = false;
-	function increaseNotificationCount($className, $method) {
+	function increaseNotificationCount(/* array($className|object, $method) */) {
 		parent::increaseNotificationCount();
-		if(self::$showProfiler)
+		if(self::$showProfiler && func_num_args() == 1)
 		{
-			echo "after $className -> $method <br>";
-			echo "-"; Piwik::printTimer();
-			echo "<br>";
-			echo "-"; Piwik::printMemoryLeak();
-			echo "<br>";
+			$callback = func_get_arg(0);
+			if(is_array($callback)) {
+				$className = is_object($callback[0]) ? get_class($callback[0]) : $callback[0];
+				$method = $callback[1];
+
+				echo "after $className -> $method <br>";
+				echo "-"; Piwik::printTimer();
+				echo "<br>";
+				echo "-"; Piwik::printMemoryLeak();
+				echo "<br>";
+			}
 		}
 	}
 }
-
