@@ -4,13 +4,12 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: function.url.php 168 2008-01-14 05:26:43Z matt $
+ * @version $Id: function.postEvent.php 1420 2009-08-22 13:23:16Z vipsoft $
  * 
+ * @category Piwik
  * @package SmartyPlugins
  */
 
-require_once "Url.php";
-
 /**
  * Posts an event from a smarty template. This event can then be hooked by another plugin.
  * The even will be posted along with a string value that plugins can edit.
