@@ -4,13 +4,12 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: function.url.php 168 2008-01-14 05:26:43Z matt $
+ * @version $Id: function.sparkline.php 1420 2009-08-22 13:23:16Z vipsoft $
  * 
+ * @category Piwik
  * @package SmartyPlugins
  */
 
-require_once "Visualization/Sparkline.php";
-
 /**
  * @param string $url
  * @return string IMG HTML tag 
