@@ -4,9 +4,10 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: Tracker.php 575 2008-07-26 23:08:32Z matt $
+ * @version $Id: Tracker.php 1632 2009-12-08 22:48:44Z matt $
  * 
- * @package Piwik_Tracker
+ * @category Piwik
+ * @package Piwik
  */
 
 /**
@@ -16,7 +17,8 @@
  * 
  * We try to include as little files as possible (no dependency on 3rd party modules).
  * 
- * @package Piwik_Tracker
+ * @package Piwik
+ * @subpackage Piwik_Tracker
  */
 class Piwik_Tracker
 {	
@@ -26,12 +28,14 @@ class Piwik_Tracker
 	/**
 	 * @var Piwik_Tracker_Db
 	 */
-	static protected $db = null;
+	protected static $db = null;
 	
 	const STATE_NOTHING_TO_NOTICE = 1;
 	const STATE_TO_REDIRECT_URL = 2;
 	const STATE_LOGGING_DISABLE = 10;
-	const STATE_NO_GET_VARIABLE = 11;
+	const STATE_EMPTY_REQUEST = 11;
+	const STATE_TRACK_ONLY = 12;
+	const STATE_NOSCRIPT_REQUEST = 13;
 		
 	const COOKIE_INDEX_IDVISITOR 				= 1;
 	const COOKIE_INDEX_TIMESTAMP_LAST_ACTION 	= 2;
@@ -45,9 +49,9 @@ class Piwik_Tracker
 	const COOKIE_INDEX_REFERER_KEYWORD			= 10;
 	const COOKIE_INDEX_VISITOR_RETURNING		= 11;
 	
-	public function __construct() 
+	public function __construct($args = null)
 	{
-		$this->request = $_GET + $_POST;
+		$this->request = $args ? $args : $_GET + $_POST;
 	}
 
 	public function main()
@@ -68,6 +72,7 @@ class Piwik_Tracker
 			} catch(Piwik_Tracker_Visit_Excluded $e) {
 			}
 		}
+
 		$this->end();
 	}	
 	
@@ -85,9 +90,10 @@ class Piwik_Tracker
 	{
 		$this->loadTrackerPlugins();
 		$this->handleDisabledTracker();
-		$this->handleEmptyGetVariable();
+		$this->handleEmptyRequest();
 		$this->handleDownloadRedirect();
 		$this->handleOutlinkRedirect();
+		$this->handleDataPush();
 	}
 
 	// display the logo or pixel 1*1 GIF
@@ -103,15 +109,20 @@ class Piwik_Tracker
 				$this->outputTransparentGif();
 			break;
 			
-			case self::STATE_NO_GET_VARIABLE:
-				printDebug("No get variables => Piwik page");
-				echo "<a href='index.php'>Piwik</a> is a free open source <a href='http://piwik.org'>web analytics</a> alternative to Google analytics.";
+			case self::STATE_EMPTY_REQUEST:
+				printDebug("Empty request => Piwik page");
+				echo "<a href='/'>Piwik</a> is a free open source <a href='http://piwik.org'>web analytics</a> alternative to Google analytics.";
 			break;
 			
 			case self::STATE_TO_REDIRECT_URL:
 				$this->sendHeader('Location: ' . $this->getUrlToRedirect());
 			break;
 			
+			case self::STATE_TRACK_ONLY:
+				printDebug("Data push, tracking only");
+			break;
+
+			case self::STATE_NOSCRIPT_REQUEST:
 			case self::STATE_NOTHING_TO_NOTICE:
 			default:
 				printDebug("Nothing to notice => default behaviour");
@@ -122,12 +133,37 @@ class Piwik_Tracker
 		
 		if($GLOBALS['PIWIK_TRACKER_DEBUG'] === true)
 		{
-			Piwik::printSqlProfilingReportTracker(self::$db);
+			if(isset(self::$db)) {
+				self::$db->recordProfiling();
+				Piwik::printSqlProfilingReportTracker(self::$db);
+			}
 		}
 		
 		self::disconnectDatabase();
 	}
-	
+
+	/**
+	 * Factory to create database objects
+	 *
+	 * @param array $configDb Database configuration
+	 * @return Piwik_Tracker_Db_*
+	 */
+	public static function factory($configDb)
+	{
+		switch($configDb['adapter'])
+		{
+			case 'PDO_MYSQL':
+				require_once PIWIK_INCLUDE_PATH .'/core/Tracker/Db/Pdo/Mysql.php';
+				return new Piwik_Tracker_Db_Pdo_Mysql($configDb);
+
+			case 'MYSQLI':
+				require_once PIWIK_INCLUDE_PATH .'/core/Tracker/Db/Mysqli.php';
+				return new Piwik_Tracker_Db_Mysqli($configDb);
+		}
+
+		throw new Exception('Unsupported database adapter '.$configDb['adapter']);
+	}
+
 	public static function connectPiwikTrackerDb()
 	{
 		$db = null;
@@ -138,11 +174,8 @@ class Piwik_Tracker
 			// before 0.2.4 there is no port specified in config file
 			$configDb['port'] = '3306';  
 		}
-		$db = new Piwik_Tracker_Db( 	$configDb['host'], 
-										$configDb['username'], 
-										$configDb['password'], 
-										$configDb['dbname'],
-										$configDb['port'] );
+
+		$db = self::factory( $configDb );
 		$db->connect();
 		
 		return $db;
@@ -177,6 +210,7 @@ class Piwik_Tracker
 		if(isset(self::$db))
 		{
 			self::$db->disconnect();
+			self::$db = null;
 		}
 	}
 
@@ -220,7 +254,7 @@ class Piwik_Tracker
 	protected function isVisitValid()
 	{
 		return $this->stateValid !== self::STATE_LOGGING_DISABLE
-				&&  $this->stateValid !== self::STATE_NO_GET_VARIABLE;
+				&&  $this->stateValid !== self::STATE_EMPTY_REQUEST;
 	}
 	
 	protected function getState()
@@ -260,42 +294,52 @@ class Piwik_Tracker
 		}
 	}
 	
+	protected function handleDataPush()
+	{
+		if( Piwik_Common::getRequestVar( 'data_push', 0, 'int', $this->request) == 1)
+		{
+			$this->setState( self::STATE_TRACK_ONLY );
+		}
+	}
+
 	protected function handleDownloadRedirect()
 	{
-		$downloadVariableName = Piwik_Tracker_Config::getInstance()->Tracker['download_url_var_name'];
-		$urlDownload = Piwik_Common::getRequestVar( $downloadVariableName, '', 'string', $this->request);
+		$urlDownload = Piwik_Common::getRequestVar( 'download', '', 'string', $this->request);
 
 		if( !empty($urlDownload) )
 		{
 			if( Piwik_Common::getRequestVar( 'redirect', 1, 'int', $this->request) == 1)
 			{
 				$this->setState( self::STATE_TO_REDIRECT_URL );
+				$this->setUrlToRedirect ( $urlDownload );
 			}
-			$this->setUrlToRedirect ( $urlDownload );
 		}
 	}
 	
 	protected function handleOutlinkRedirect()
 	{
-		$outlinkVariableName = Piwik_Tracker_Config::getInstance()->Tracker['outlink_url_var_name'];
-		$urlOutlink = Piwik_Common::getRequestVar( $outlinkVariableName, '', 'string', $this->request);
+		$urlOutlink = Piwik_Common::getRequestVar( 'link', '', 'string', $this->request);
 		
 		if( !empty($urlOutlink) )
 		{
-			$redirectVariableName = Piwik_Tracker_Config::getInstance()->Tracker['outlink_redirect_var_name'];
 			if( Piwik_Common::getRequestVar( 'redirect', 1, 'int', $this->request) == 1)
 			{
 				$this->setState( self::STATE_TO_REDIRECT_URL );
+				$this->setUrlToRedirect ( $urlOutlink);
 			}
-			$this->setUrlToRedirect ( $urlOutlink);
 		}
 	}
-	
-	protected function handleEmptyGetVariable()
+
+	protected function handleEmptyRequest()
 	{
-		if( count($_GET) == 0)
+		$countParameters = count($this->request);
+		if($countParameters == 0) 
 		{
-			$this->setState(self::STATE_NO_GET_VARIABLE);			
+			$this->setState(self::STATE_EMPTY_REQUEST);
+		}
+		if($countParameters == 1 )
+		{
+			$this->setState(self::STATE_NOSCRIPT_REQUEST);
 		}
 	}
 	
@@ -315,9 +359,9 @@ function printDebug( $info = '' )
 	{
 		if(is_array($info))
 		{
-			print("<PRE>");
+			print("<pre>");
 			print(var_export($info,true));
-			print("</PRE>");
+			print("</pre>");
 		}
 		else
 		{
