@@ -1,51 +1,47 @@
 <?php
 /**
  * Piwik - Open source web analytics
- * 
+ *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: Db.php 522 2008-06-11 00:31:03Z matt $
- * 
- * @package Piwik_Tracker
+ * @version $Id: Db.php 1475 2009-09-19 17:32:59Z vipsoft $
+ *
+ * @category Piwik
+ * @package Piwik
  */
 
 /**
- * Simple database PDO wrapper.
+ * Simple database wrapper.
  * We can't afford to have a dependency with the Zend_Db module in Tracker.
  * We wrote this simple class 
- * 
- * @package Piwik_Tracker
+ *
+ * @package Piwik
+ * @subpackage Piwik_Tracker
  */
-class Piwik_Tracker_Db 
+abstract class Piwik_Tracker_Db
 {
-	private $connection = null;
-	private $username;
-	private $password;
-	
-	static private $profiling = false;
+	protected static $profiling = false;
 
 	protected $queriesProfiling = array();
-	
+
 	/**
-	 * Builds the DB object
+	 * Enables the SQL profiling. 
+	 * For each query, saves in the DB the time spent on this query. 
+	 * Very useful to see the slow query under heavy load.
+	 * You can then use Piwik::printSqlProfilingReportTracker(); 
+	 * to display the SQLProfiling report and see which queries take time, etc.
 	 */
-	public function __construct( $host, $username, $password, $dbname, $port, $driverName = 'mysql') 
+	public static function enableProfiling()
 	{
-		if($host[0] == '/')
-		{
-			$this->dsn = $driverName.":dbname=$dbname;unix_socket=$host";
-		}
-		else
-		{
-			$this->dsn = $driverName.":dbname=$dbname;host=$host;port=$port";
-		}
-		$this->username = $username;
-		$this->password = $password;
+		self::$profiling = true;
 	}
 
-	public function __destruct() 
+	/** 
+	 * Disables the SQL profiling logging.
+	 */
+	public static function disableProfiling()
 	{
-		$this->connection = null;
+		self::$profiling = false;
 	}
 
 	/**
@@ -54,170 +50,27 @@ class Piwik_Tracker_Db
 	 * 
 	 * @return bool 
 	 */
-	static public function isProfilingEnabled()
+	public function isProfilingEnabled()
 	{
 		return self::$profiling;
 	}
-	
+
 	/**
-	 * Enables the SQL profiling. 
-	 * For each query, saves in the DB the time spent on this query. 
-	 * Very useful to see the slow query under heavy load.
-	 * You can then use Piwik::printSqlProfilingReportTracker(); 
-	 * to display the SQLProfiling report and see which queries take time, etc.
-	 */
-	static public function enableProfiling()
-	{
-		self::$profiling = true;
-	}
-	
-	/** 
-	 * Disables the SQL profiling logging.
-	 */
-	static public function disableProfiling()
-	{
-		self::$profiling = false;
-	}
-	
-	/**
-	 * Connects to the DB
-	 * 
-	 * @throws Exception if there was an error connecting the DB
-	 */
-	public function connect() 
-	{
-		if(self::$profiling)
-		{
-			$timer = $this->initProfiler();
-		}
-		
-		$this->connection = new PDO($this->dsn, $this->username, $this->password);
-		$this->connection->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
-		// we may want to setAttribute(PDO::ATTR_TIMEOUT ) to a few seconds (default is 60) in case the DB is locked
-		// the piwik.php would stay waiting for the database... bad!
-		// we delete the password from this object "just in case" it could be printed 
-		$this->password = '';
-		
-		if(self::$profiling)
-		{
-			$this->recordQueryProfile('connect', $timer);
-		}
-	}
-	
-	/**
-	 * Disconnects from the Mysql server
+	 * Initialize profiler
 	 *
-	 * @return void
+	 * @return Piwik_Timer
 	 */
-	public function disconnect()
-	{
-		if(self::$profiling)
-		{
-			$this->recordProfiling();
-		}
-		$this->connection = null;
-	}
-	
-	/**
-	 * Returns an array containing all the rows of a query result, using optional bound parameters.
-	 * 
-	 * @param string Query 
-	 * @param array Parameters to bind
-	 * @see also query()
-	 * @throws Exception if an exception occured
-	 */
-	public function fetchAll( $query, $parameters = array() )
-	{
-		try {
-			$sth = $this->query( $query, $parameters );
-			if($sth === false)
-			{
-				return false;
-			}
-			return $sth->fetchAll(PDO::FETCH_ASSOC);
-		} catch (PDOException $e) {
-			throw new Exception("Error query: ".$e->getMessage());
-		}
-	}
-	
-	/**
-	 * Returns the first row of a query result, using optional bound parameters.
-	 * 
-	 * @param string Query 
-	 * @param array Parameters to bind
-	 * @see also query()
-	 * 
-	 * @throws Exception if an exception occured
-	 */
-	public function fetch( $query, $parameters = array() )
-	{
-		try {
-			$sth = $this->query( $query, $parameters );
-			if($sth === false)
-			{
-				return false;
-			}
-			return $sth->fetch(PDO::FETCH_ASSOC);			
-		} catch (PDOException $e) {
-			throw new Exception("Error query: ".$e->getMessage());
-		}
-	}
-	
-	/**
-	 * This function is a proxy to fetch(), used to maintain compatibility with Zend_Db interface
-	 * @see fetch()
-	 */
-	public function fetchRow( $query, $parameters = array() )
-	{
-		return $this->fetch($query, $parameters);
-	}
-	
-	/**
-	 * Executes a query, using optional bound parameters.
-	 * 
-	 * @param string Query 
-	 * @param array|string Parameters to bind array('idsite'=> 1)
-	 * 
-	 * @return PDOStatement or false if failed
-	 * @throw Exception if an exception occured
-	 */
-	public function query($query, $parameters = array()) 
-	{
-		if(is_null($this->connection))
-		{
-			return false;
-		}
-		try {
-			if(self::$profiling)
-			{
-				$timer = $this->initProfiler();
-			}
-			
-			if(!is_array($parameters))
-			{
-				$parameters = array( $parameters );
-			}
-			$sth = $this->connection->prepare($query);
-			$sth->execute( $parameters );
-			
-			if(self::$profiling)
-			{
-				$this->recordQueryProfile($query, $timer);
-			}
-			return $sth;
-		} catch (PDOException $e) {
-			throw new Exception("Error query: ".$e->getMessage() . "
-								In query: $query
-								Parameters: ".var_export($parameters, true));
-		}
-	}
-	
 	protected function initProfiler()
 	{
-		require_once "Timer.php";
 		return new Piwik_Timer;
 	}
-	
+
+	/**
+	 * Record query profile
+	 *
+	 * @param string $query
+	 * @param Piwik_Timer $timer
+	 */	
 	protected function recordQueryProfile( $query, $timer )
 	{
 		if(!isset($this->queriesProfiling[$query])) $this->queriesProfiling[$query] = array('sum_time_ms' => 0, 'count' => 0);
@@ -227,17 +80,6 @@ class Piwik_Tracker_Db
 		$this->queriesProfiling[$query]	= array('sum_time_ms' => $time, 'count' => $count);
 	}
 	
-	/**
-	 * Returns the last inserted ID in the DB
-	 * Wrapper of PDO::lastInsertId()
-	 * 
-	 * @return int
-	 */
-	public function lastInsertId()
-	{
-		return $this->connection->lastInsertId();
-	}
-	
 	/**
 	 * When destroyed, if SQL profiled enabled, logs the SQL profiling information
 	 */
@@ -266,6 +108,85 @@ class Piwik_Tracker_Db
 		// turn back on profiling
 		self::$profiling = true;
 	}
+
+	/**
+	 * Connects to the DB
+	 * 
+	 * @throws Exception if there was an error connecting the DB
+	 */
+	abstract public function connect();
+	
+	/**
+	 * Disconnects from the server
+	 */
+	public function disconnect()
+	{
+		$this->connection = null;
+	}
+	
+	/**
+	 * Returns an array containing all the rows of a query result, using optional bound parameters.
+	 * 
+	 * @param string Query 
+	 * @param array Parameters to bind
+	 * @see also query()
+	 * @throws Exception if an exception occured
+	 */
+	abstract public function fetchAll( $query, $parameters = array() );
+	
+	/**
+	 * Returns the first row of a query result, using optional bound parameters.
+	 * 
+	 * @param string Query 
+	 * @param array Parameters to bind
+	 * @see also query()
+	 * 
+	 * @throws Exception if an exception occured
+	 */
+	abstract public function fetch( $query, $parameters = array() );
+	
+	/**
+	 * This function is a proxy to fetch(), used to maintain compatibility with Zend_Db interface
+	 * @see fetch()
+	 */
+	public function fetchRow( $query, $parameters = array() )
+	{
+		return $this->fetch($query, $parameters);
+	}
+
+	/**
+	 * Return number of affected rows in last query
+	 *
+	 * @param mixed $queryResult Result from query()
+	 * @return int
+	 */
+	abstract public function rowCount($queryResult);
+
+	/**
+	 * Executes a query, using optional bound parameters.
+	 * 
+	 * @param string Query 
+	 * @param array|string Parameters to bind array('idsite'=> 1)
+	 * 
+	 * @return PDOStatement or false if failed
+	 * @throws Exception if an exception occured
+	 */
+	abstract public function query($query, $parameters = array());
+
+	/**
+	 * Returns the last inserted ID in the DB
+	 * Wrapper of PDO::lastInsertId()
+	 * 
+	 * @return int
+	 */
+	abstract public function lastInsertId();
+
+	/**
+	 * Test error number
+	 *
+	 * @param Exception $e
+	 * @param string $errno
+	 * @return bool True if error number matches; false otherwise
+	 */
+	abstract public function isErrNo($e, $errno);
 }
-
-
