@@ -4,9 +4,10 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: Generator.php 492 2008-05-23 01:08:12Z matt $
+ * @version $Id: Generator.php 1530 2009-10-22 22:40:18Z matt $
  * 
- * @package Piwik_Tracker
+ * @category Piwik
+ * @package Piwik
  */
 
 /**
@@ -30,14 +31,12 @@
  * - action_name 
  * - HTML title
  * 
- *  
- * @package Piwik_Tracker
- * @subpackage Piwik_Tracker_Generator
+ * @package Piwik
+ * @subpackage Piwik_Tracker
  * 
  * 											"Le Generator, il est trop Fort!"
  * 											- Random fan
  */
-
 class Piwik_Tracker_Generator
 {
 	/**
@@ -117,8 +116,7 @@ class Piwik_Tracker_Generator
 		// init GET and REQUEST to the empty array
 		$this->setFakeRequest();
 		
-		require_once "Piwik.php";
-		Piwik::createConfigObject(PIWIK_INCLUDE_PATH . '/config/config.ini.php');
+		Piwik::createConfigObject(PIWIK_USER_PATH . '/config/config.ini.php');
 		Zend_Registry::get('config')->disableSavingConfigurationFileUpdates();
 		
 		// setup database	
@@ -181,7 +179,6 @@ class Piwik_Tracker_Generator
 	 * 
 	 * @param string Name of the parameter _GET[$name]
 	 * @param array|mixed Value of the parameter
-	 * @return void
 	 */
 	protected function addParam( $name, $aValue)
 	{
@@ -199,8 +196,6 @@ class Piwik_Tracker_Generator
 	/**
 	 * TRUNCATE all logs related tables to start a fresh logging database.
 	 * Be careful, any data deleted this way is deleted forever
-	 * 
-	 * @return void
 	 */
 	public function emptyAllLogTables()
 	{
@@ -222,16 +217,14 @@ class Piwik_Tracker_Generator
 	/**
 	 * This is called at the end of the Generator script.
 	 * Calls the Profiler output if the profiler is enabled.
-	 * 
-	 * @return void
 	 */
 	public function end()
 	{
-		Piwik_Tracker::disconnectDatabase();
 		if($this->profiling)
 		{
 			Piwik::printSqlProfilingReportTracker();
 		}
+		Piwik_Tracker::disconnectDatabase();
 	}
 	
 	/**
@@ -241,9 +234,7 @@ class Piwik_Tracker_Generator
 	 * - setup the different possible values for parameters such as 'resolution',
 	 * 		'color', 'hour', 'minute', etc.
 	 * - load from DataFiles and setup values for the other parameters such as UserAgent, Referers, AcceptedLanguages, etc.
-	 *  @see /misc/generateVisitsData/
-	 * 
-	 * @return void
+	 *   @see misc/generateVisitsData/
 	 */
 	public function init()
 	{
@@ -282,10 +273,8 @@ class Piwik_Tracker_Generator
 		 * Sets values for: outlinks, downloads, campaigns
 		 */
 		// we get the name of the Download/outlink variables
-		$downloadOrOutlink = array(
-						Piwik_Tracker_Config::getInstance()->Tracker['download_url_var_name'],
-						Piwik_Tracker_Config::getInstance()->Tracker['outlink_url_var_name'],
-		);
+		$downloadOrOutlink = array('download', 'link');
+
 		// we have a 20% chance to add a download or outlink variable to the URL 
 		$this->addParam('piwik_downloadOrOutlink', $downloadOrOutlink);
 		$this->addParam('piwik_downloadOrOutlink', array_fill(0,8,''));
@@ -304,7 +293,7 @@ class Piwik_Tracker_Generator
 		 */
 		// we load some real referers to be used by the generator
 		$referers = array();
-		require_once PIWIK_INCLUDE_PATH . "/misc/generateVisitsData/Referers.php";
+		require_once PIWIK_INCLUDE_PATH . '/misc/generateVisitsData/Referers.php';
 
 		$this->addParam('urlref',$referers);
 
@@ -313,8 +302,8 @@ class Piwik_Tracker_Generator
 		
 		// load some user agent and accept language
 		$userAgent = $acceptLanguages = array();
-		require_once PIWIK_INCLUDE_PATH . "/misc/generateVisitsData/UserAgent.php";
-		require_once PIWIK_INCLUDE_PATH . "/misc/generateVisitsData/AcceptLanguage.php";
+		require_once PIWIK_INCLUDE_PATH . '/misc/generateVisitsData/UserAgent.php';
+		require_once PIWIK_INCLUDE_PATH . '/misc/generateVisitsData/AcceptLanguage.php';
 		$this->userAgents=$userAgent;
 		$this->acceptLanguage=$acceptLanguages;
 	}
@@ -322,8 +311,6 @@ class Piwik_Tracker_Generator
 	/**
 	 * If the SQL profiler is enabled and if the reinit at every request is set to true,
 	 * then we TRUNCATE the profiling information so that we only profile one visitor at a time
-	 * 
-	 * @return void
 	 */
 	protected function initProfiler()
 	{
@@ -374,8 +361,6 @@ class Piwik_Tracker_Generator
 	 * Also generates a random IP.
 	 * 
 	 * We change the superglobal values of HTTP_USER_AGENT, HTTP_CLIENT_IP, HTTP_ACCEPT_LANGUAGE to the generated value.
-	 * 
-	 * @return void
 	 */
 	protected function generateNewVisit()
 	{
@@ -387,10 +372,14 @@ class Piwik_Tracker_Generator
 		$this->setCurrentRequest( 'm' ,$this->getRandom('m'));
 		$this->setCurrentRequest( 's' ,$this->getRandom('s'));
 		$this->setCurrentRequest( 'fla' ,$this->getRandom01());
+		$this->setCurrentRequest( 'java' ,$this->getRandom01());
 		$this->setCurrentRequest( 'dir' ,$this->getRandom01());
+		$this->setCurrentRequest( 'qt' ,$this->getRandom01());
 		$this->setCurrentRequest( 'realp' ,$this->getRandom01());
 		$this->setCurrentRequest( 'pdf' ,$this->getRandom01());
 		$this->setCurrentRequest( 'wma' ,$this->getRandom01());
+		$this->setCurrentRequest( 'gears' ,$this->getRandom01());
+		$this->setCurrentRequest( 'ag' ,$this->getRandom01());
 		$this->setCurrentRequest( 'cookie',$this->getRandom01());
 
 		$_SERVER['HTTP_CLIENT_IP'] = mt_rand(0,255).".".mt_rand(0,255).".".mt_rand(0,255).".".mt_rand(0,255);
@@ -404,16 +393,13 @@ class Piwik_Tracker_Generator
 	 * We generate a new Referer, that would be read in the case the visit last page is older than 30 minutes.
 	 * 
 	 * This function tries to generate actions that use the features of Piwik (campaigns, downloads, outlinks, action_name set in the JS tag, etc.)
-	 * 
-	 * @return void
-	 * 
 	 */
 	protected function generateActionVisit()
 	{		
 		// we don't keep the previous action values 
 		// reinit them to empty string
-		$this->setCurrentRequest( Piwik_Tracker_Config::getInstance()->Tracker['download_url_var_name'],'');
-		$this->setCurrentRequest( Piwik_Tracker_Config::getInstance()->Tracker['outlink_url_var_name'],'');
+		$this->setCurrentRequest( 'download', '');
+		$this->setCurrentRequest( 'link', '');
 		$this->setCurrentRequest( 'action_name', '');
 
 		// generate new url referer ; case the visitor stays more than 30min
@@ -460,19 +446,12 @@ class Piwik_Tracker_Generator
 				// add the parameter to the url
 				$this->setCurrentRequest( $GETParamToAdd , $urlValue);
 			}
-			
-			// if we didn't set any campaign NOR any download click
-			// then we sometimes set a special action name to the current action
-			elseif(rand(0,2)==1)
-			{
-				$this->setCurrentRequest( 'action_name' , $this->getRandomString(1,1));
-			}
 		}
 		
 		$this->setCurrentRequest( 'url' ,$url);
 		
 		// setup the title of the page
-		$this->setCurrentRequest( 'title',$this->getRandomString(15,5));
+		$this->setCurrentRequest( 'action_name',$this->getRandomString(15,5));
 	}
 	
 	/**
@@ -575,8 +554,6 @@ class Piwik_Tracker_Generator
 	 * @see setCurrentRequest()
 	 * This method is called once the current action parameters array has been generated from 
 	 * the global parameters array
-	 * 
-	 * @return void
 	 */
 	protected function setFakeRequest()
 	{
@@ -633,17 +610,12 @@ class Piwik_Tracker_Generator
 	 * - load the Tracker class and call the method to launch the recording
 	 * 
 	 * This will save the visit in the database
-	 * 
-	 * @return void
 	 */
 	protected function saveVisit()
 	{
 		$this->setFakeRequest();
-		$process = new Piwik_Tracker_Generator_Tracker;
+		$process = new Piwik_Tracker_Generator_Tracker();
 		$process->main();
 		unset($process);
-	}
-	
+	}	
 }
-require_once "Generator/Tracker.php";
-require_once "Generator/Visit.php";
