@@ -1,24 +1,31 @@
 <?php
+/**
+ * Piwik - Open source web analytics
+ * 
+ * @link http://piwik.org
+ * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
+ * @version $Id: GoalManager.php 1632 2009-12-08 22:48:44Z matt $
+ * 
+ * @category Piwik
+ * @package Piwik
+ */
 
+/**
+ * @package Piwik
+ * @subpackage Piwik_Tracker
+ */
 class Piwik_Tracker_GoalManager 
 {
 	/**
-	 * @var Piwik_Cookie 
+	 * @var Piwik_Cookie
 	 */
 	protected $cookie = null;
 	/**
 	 * @var Piwik_Tracker_Action
 	 */
 	protected $action = null;
-	protected $matchedGoals = array();
+	protected $convertedGoals = array();
 	protected $idsite = null;
-	
-	function __construct($action)
-	{
-		$this->action = $action;
-		
-		
-	}
 
 	function setCookie($cookie)
 	{
@@ -34,7 +41,7 @@ class Piwik_Tracker_GoalManager
 		}
 		return array();
 	}
-	
+
 	static public function getGoalDefinition( $idSite, $idGoal )
 	{
 		$goals = self::getGoalDefinitions( $idSite );
@@ -47,7 +54,7 @@ class Piwik_Tracker_GoalManager
 		}
 		throw new Exception("The goal id = $idGoal couldn't be found.");
 	}
-	
+
 	static public function getGoalIds( $idSite )
 	{
 		$goals = self::getGoalDefinitions( $idSite );
@@ -58,31 +65,37 @@ class Piwik_Tracker_GoalManager
 		}
 		return $goalIds;
 	}
-	
-	//TODO does this code work for manually triggered goals, with custom revenue? 
-	function detectGoals($idSite)
+
+	private function isGoalPluginEnabled()
 	{
-		if(!Piwik_PluginsManager::getInstance()->isPluginActivated('Goals'))
+		return Piwik_PluginsManager::getInstance()->isPluginActivated('Goals');
+	}
+
+	function detectGoalsMatchingUrl($idSite, $action)
+	{
+		if(!$this->isGoalPluginEnabled())
 		{
 			return false;
 		}
-		$url = $this->action->getActionUrl();
-		$actionType = $this->action->getActionType();
+		$sanitizedUrl = $action->getActionUrl();
+		$url = htmlspecialchars_decode($sanitizedUrl);
+		$actionType = $action->getActionType();
 		$goals = $this->getGoalDefinitions($idSite);
 		foreach($goals as $goal)
 		{
 			$attribute = $goal['match_attribute'];
 			// if the attribute to match is not the type of the current action
-			if(		($actionType == Piwik_Tracker_Action::TYPE_ACTION && $attribute != 'url')
+			if(		($actionType == Piwik_Tracker_Action::TYPE_ACTION_URL && $attribute != 'url')
 				||	($actionType == Piwik_Tracker_Action::TYPE_DOWNLOAD && $attribute != 'file')
 				||	($actionType == Piwik_Tracker_Action::TYPE_OUTLINK && $attribute != 'external_website')
+				||	($attribute == 'manually')
 				)
 			{
 				continue;
 			}
-			
+
 			$pattern_type = $goal['pattern_type'];
-			
+
 			switch($pattern_type)
 			{
 				case 'regex':
@@ -121,29 +134,45 @@ class Piwik_Tracker_GoalManager
 			}
 			if($match)
 			{
-				$this->matchedGoals[] = $goal;
+				$goal['url'] = $sanitizedUrl;
+				$this->convertedGoals[] = $goal;
 			}
 		}
-//		var_dump($this->matchedGoals);exit;
-		return count($this->matchedGoals) > 0;
+//		var_dump($this->convertedGoals);exit;
+		return count($this->convertedGoals) > 0;
 	}
-	
-	function recordGoals($visitorInformation)
+
+	function detectGoalId($idSite, $idGoal, $request)
+	{
+		if(!$this->isGoalPluginEnabled())
+		{
+			return false;
+		}
+		$goals = $this->getGoalDefinitions($idSite);
+		if(!isset($goals[$idGoal]))
+		{
+			return false;
+		}
+		$goal = $goals[$idGoal];
+		$goal['url'] = Piwik_Common::getRequestVar( 'url', '', 'string', $request);
+		$goal['revenue'] = Piwik_Common::getRequestVar('revenue', $goal['revenue'], 'float', $request);
+		$this->convertedGoals[] = $goal;
+		return true;
+	}
+
+	function recordGoals($visitorInformation, $action)
 	{
 		$location_country = isset($visitorInformation['location_country']) ? $visitorInformation['location_country'] : Piwik_Common::getCountry(Piwik_Common::getBrowserLanguage(), $enableLanguageToCountryGuess = Piwik_Tracker_Config::getInstance()->Tracker['enable_language_to_country_guess']);
 		$location_continent = isset($visitorInformation['location_continent']) ? $visitorInformation['location_continent'] : Piwik_Common::getContinent($location_country);
-		
+
 		$goal = array(
 			'idvisit' 			=> $visitorInformation['idvisit'],
 			'idsite' 			=> $visitorInformation['idsite'],
 			'visitor_idcookie' 	=> $visitorInformation['visitor_idcookie'],
 			'server_time' 		=> Piwik_Tracker::getDatetimeFromTimestamp($visitorInformation['visit_last_action_time']),
 			'visit_server_date' => $visitorInformation['visit_server_date'],
-			'idaction' 			=> $this->action->getIdAction(),
-			'idlink_va' 		=> $this->action->getIdLinkVisitAction(),
 			'location_country'  => $location_country,
 			'location_continent'=> $location_continent,
-			'url' 				=> $this->action->getActionUrl(),
 			'visitor_returning' => $this->cookie->get( Piwik_Tracker::COOKIE_INDEX_VISITOR_RETURNING ),
 		);
 
@@ -159,24 +188,30 @@ class Piwik_Tracker_GoalManager
 			);
 		}
 
-		foreach($this->matchedGoals as $matchedGoal)
+		foreach($this->convertedGoals as $convertedGoal)
 		{
-			printDebug("- Goal ".$matchedGoal['idgoal'] ." matched. Recording...");
+			printDebug("- Goal ".$convertedGoal['idgoal'] ." matched. Recording...");
 			$newGoal = $goal;
-			$newGoal['idgoal'] = $matchedGoal['idgoal'];
-			$newGoal['revenue'] = $matchedGoal['revenue'];
+			$newGoal['idgoal'] = $convertedGoal['idgoal'];
+			$newGoal['url'] = $convertedGoal['url'];
+			$newGoal['revenue'] = $convertedGoal['revenue'];
+			if(!is_null($action))
+			{
+				$newGoal['idaction_url'] = $action->getIdActionUrl();
+				$newGoal['idlink_va'] = $action->getIdLinkVisitAction();
+			}
 			printDebug($newGoal);
-			
+
 			$fields = implode(", ", array_keys($newGoal));
 			$bindFields = substr(str_repeat( "?,",count($newGoal)),0,-1);
-			
+
 			try {
 				Piwik_Tracker::getDatabase()->query(
-					"INSERT INTO " . Piwik_Common::prefixTable('log_conversion') . "	($fields) 
-					VALUES ($bindFields) ", array_values($newGoal) 
+					"INSERT INTO " . Piwik_Common::prefixTable('log_conversion') . "	($fields)
+					VALUES ($bindFields) ", array_values($newGoal)
 				);
 			} catch( Exception $e) {
-				if(strpos($e->getMessage(), '1062') !== false)
+				if(Piwik_Tracker::isErrNo($e, '1062'))
 				{
 					// integrity violation when same visit converts to the same goal twice
 					printDebug("--> Goal already recorded for this (idvisit, idgoal)");
@@ -186,7 +221,6 @@ class Piwik_Tracker_GoalManager
 					throw $e;
 				}
 			}
-			//$idlog_goal = Piwik_Tracker::getDatabase()->lastInsertId();
 		}
 	}
 }
