@@ -4,8 +4,9 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: Translate.php 526 2008-06-25 23:57:04Z matt $
+ * @version $Id: Translate.php 1587 2009-11-16 01:11:41Z vipsoft $
  * 
+ * @category Piwik
  * @package Piwik
  */
 
@@ -32,7 +33,7 @@ class Piwik_Translate
 
 	public function loadEnglishTranslation()
 	{
-		require PIWIK_INCLUDE_PATH . "/lang/en.php";
+		require PIWIK_INCLUDE_PATH . '/lang/en.php';
 		$this->mergeTranslationArray($translations);
 		$this->setLocale();
 		$this->englishLanguageLoaded = true;
@@ -47,7 +48,7 @@ class Piwik_Translate
 			return;
 		}
 		
-		require PIWIK_INCLUDE_PATH . "/lang/" . $language . ".php";
+		require PIWIK_INCLUDE_PATH . '/lang/' . $language . '.php';
 		$this->mergeTranslationArray($translations);
 		$this->setLocale();
 	}
@@ -59,7 +60,7 @@ class Piwik_Translate
 			$GLOBALS['Piwik_translations'] = array();
 		}
 		// we could check that no string overlap here
-		$GLOBALS['Piwik_translations'] = array_merge($GLOBALS['Piwik_translations'], $translation);
+		$GLOBALS['Piwik_translations'] = array_merge($GLOBALS['Piwik_translations'], array_filter($translation, 'strlen'));
 	}
 	
 	/**
@@ -96,9 +97,9 @@ class Piwik_Translate
 	 */
 	public function getJavascriptTranslations(array $moduleList)
 	{
-		if( empty($moduleList) )
+		if(!in_array('General', $moduleList))
 		{
-			return '';
+			$moduleList[] = 'General';
 		}
 		
 		$js = 'var translations = {';
@@ -109,7 +110,7 @@ class Piwik_Translate
 			$moduleRegex .= $module.'|'; 
 		}
 		$moduleRegex = substr($moduleRegex, 0, -1);
-		$moduleRegex .= ')_([^_]+)_js$#i';
+		$moduleRegex .= ')_.*_js$#i';
 		
 		foreach($GLOBALS['Piwik_translations'] as $key => $value)
 		{
@@ -134,6 +135,13 @@ class Piwik_Translate
 	}
 }
 
+/**
+ * Returns translated string or given message if translation is not found.
+ *
+ * @param string Translation string index
+ * @param array $args sprintf arguments
+ * @return string
+ */
 function Piwik_Translate($string, $args = array())
 {
 	if(!is_array($args))
@@ -151,20 +159,22 @@ function Piwik_Translate($string, $args = array())
 	return vsprintf($string, $args);
 }
 
-
 /**
  * Returns translated string or given message if translation is not found.
  * This function does not throw any exception. Use it to translate exceptions.
  *
- * @param string Translation string index
+ * @param string $message Translation string index
+ * @param array $args sprintf arguments
  * @return string
  */
 function Piwik_TranslateException($message, $args = array())
 {
-	try {
+	try
+	{
 		return Piwik_Translate($message, $args);		
 	} 
-	catch(Exception $e) {
+	catch(Exception $e)
+	{
 		return $message;
 	}
 }
