@@ -1,6 +1,30 @@
 <?php
-require_once "Option.php";
+/**
+ * Piwik - Open source web analytics
+ * 
+ * @link http://piwik.org
+ * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
+ * @version $Id: Updater.php 1719 2009-12-17 16:10:22Z matt $
+ * 
+ * @category Piwik
+ * @package Piwik
+ */
 
+// no direct access
+defined('PIWIK_INCLUDE_PATH') or die;
+
+/**
+ * @see core/Option.php
+ */
+require_once PIWIK_INCLUDE_PATH . '/core/Option.php';
+
+/**
+ * Load and execute all relevant, incremental update scripts for Piwik core and plugins, and bump the component version numbers for completed updates.
+ *
+ * @package Piwik
+ * @subpackage Piwik_Updater
+ * @see Piwik_iUpdate
+ */
 class Piwik_Updater
 {
 	const INDEX_CURRENT_VERSION = 0;
@@ -18,9 +42,10 @@ class Piwik_Updater
 	}
 
 	/**
+	 * Add component to check
+	 *
 	 * @param string $name
 	 * @param string $version
-	 * @return void
 	 */
 	public function addComponentToCheck($name, $version)
 	{
@@ -28,9 +53,10 @@ class Piwik_Updater
 	}
 	
 	/**
+	 * Record version of successfully completed component update
+	 *
 	 * @param string $name
 	 * @param string $version
-	 * @return void
 	 */
 	public function recordComponentSuccessfullyUpdated($name, $version)
 	{
@@ -44,7 +70,7 @@ class Piwik_Updater
 	/**
 	 * Returns a list of components (core | plugin) that need to run through the upgrade process.
 	 *
-	 * @return array( componentName => array( updateFile1, [...]), [...])
+	 * @return array( componentName => array( file1 => version1, [...]), [...])
 	 */
 	public function getComponentsWithUpdateFile()
 	{
@@ -54,17 +80,35 @@ class Piwik_Updater
 	}
 
 	/**
+	 * Update the named component
+	 *
 	 * @param string $name
 	 * @return array of warning strings if applicable
 	 */
 	public function update($name)
 	{
 		$warningMessages = array();
-		foreach($this->componentsWithUpdateFile[$name] as $file)
+		foreach($this->componentsWithUpdateFile[$name] as $file => $fileVersion)
 		{
 			try {
-				require_once $file;
-			} catch( UpdateErrorException $e) {
+				require_once $file; // prefixed by PIWIK_INCLUDE_PATH
+
+				if($name == 'core')
+				{
+					$className = 'Piwik_Updates_' . str_replace('.', '_', $fileVersion);
+				}
+				else
+				{
+					$className = 'Piwik_'. $name .'_Updates_' . str_replace('.', '_', $fileVersion);
+				}
+
+				if(class_exists($className, false))
+				{
+					call_user_func( array($className, 'update') );
+				}
+
+				$this->recordComponentSuccessfullyUpdated($name, $fileVersion);
+			} catch( Piwik_Updater_UpdateErrorException $e) {
 				throw $e;
 			} catch( Exception $e) {
 				$warningMessages[] = $e->getMessage();
@@ -75,9 +119,11 @@ class Piwik_Updater
 		$this->recordComponentSuccessfullyUpdated($name, $this->componentsWithNewVersion[$name][self::INDEX_NEW_VERSION]);
 		return $warningMessages;
 	}
-	
+
 	/**
-	 * @return array array( componentName => array( file1, [...]), [...])
+	 * Construct list of update files for the outdated components
+	 *
+	 * @return array( componentName => array( file1 => version1, [...]), [...])
 	 */
 	private function loadComponentsWithUpdateFile()
 	{
@@ -89,11 +135,11 @@ class Piwik_Updater
 			
 			if($name == 'core')
 			{
-				$pathToUpdates = $this->pathUpdateFileCore . '*';
+				$pathToUpdates = $this->pathUpdateFileCore . '*.php';
 			}
 			else
 			{
-				$pathToUpdates = sprintf($this->pathUpdateFilePlugins, $name) . '*';
+				$pathToUpdates = sprintf($this->pathUpdateFilePlugins, $name) . '*.php';
 			}
 			
 			$files = glob( $pathToUpdates );
@@ -106,14 +152,14 @@ class Piwik_Updater
 				$fileVersion = basename($file, '.php');
 				if(version_compare($currentVersion, $fileVersion) == -1)
 				{
-					$componentsWithUpdateFile[$name][] = $file;
+					$componentsWithUpdateFile[$name][$file] = $fileVersion;
 				}
 			}
 			
 			if(isset($componentsWithUpdateFile[$name]))
 			{
 				// order the update files by version asc
-				usort($componentsWithUpdateFile[$name], "version_compare");
+				uasort($componentsWithUpdateFile[$name], "version_compare");
 			}
 			else
 			{
@@ -125,6 +171,8 @@ class Piwik_Updater
 	}
 	
 	/**
+	 * Construct list of outdated components
+	 *
 	 * @return array array( componentName => array( oldVersion, newVersion), [...])
 	 */
 	private function loadComponentsWithNewVersion()
@@ -144,8 +192,17 @@ class Piwik_Updater
 			try {
 				$currentVersion = Piwik_GetOption('version_'.$name);
 			} catch( Exception $e) {
-				// case when the option table is not yet created (before 0.2.10)
-				$currentVersion = false;
+				// mysql error 1146: table doesn't exist
+				if(Zend_Registry::get('db')->isErrNo($e, '1146'))
+				{
+					// case when the option table is not yet created (before 0.2.10)
+					$currentVersion = false;
+				}
+				else
+				{
+					// failed for some other reason
+					throw $e;
+				}
 			}
 			if($currentVersion === false)
 			{
@@ -175,6 +232,35 @@ class Piwik_Updater
 		}
 		return $componentsToUpdate;
 	}
+
+	/**
+	 * Performs database update(s)
+	 *
+	 * @param string $file Update script filename
+	 * @param array $sqlarray An array of SQL queries to be executed
+	 */
+	static function updateDatabase($file, $sqlarray)
+	{
+		foreach($sqlarray as $update => $ignoreError)
+		{
+			try {
+				Piwik_Exec( $update );
+			} catch(Exception $e) {
+				if(($ignoreError === false) 
+					|| !Zend_Registry::get('db')->isErrNo($e, $ignoreError))
+				{
+					$message =  $file .":\nError trying to execute the query '". $update ."'.\nThe error was: ". $e->getMessage();
+					throw new Piwik_Updater_UpdateErrorException($message);
+				}
+			}
+		}
+	}
 }
 
-class UpdateErrorException extends Exception {}
+/**
+ * Exception thrown by updater if a non-recoverable error occurs
+ *
+ * @package Piwik
+ * @subpackage Piwik_Updater
+ */
+class Piwik_Updater_UpdateErrorException extends Exception {}
