@@ -4,21 +4,24 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: Url.php 498 2008-05-29 03:08:13Z matt $
+ * @version $Id: Url.php 1702 2009-12-14 18:51:37Z matt $
  * 
- * @package Piwik_Helper
+ * @category Piwik
+ * @package Piwik
  */
 
 /**
- * @package Piwik_Helper
+ * Class to retrieve absolute URL or URI components of the current URL,
+ * and handle URL redirection.
  *
+ * @package Piwik
  */
 class Piwik_Url 
 {
-
 	/**
 	 * If current URL is "http://example.org/dir1/dir2/index.php?param1=value1&param2=value2"
 	 * will return "http://example.org/dir1/dir2/index.php?param1=value1&param2=value2"
+	 *
 	 * @return string
 	 */
 	static public function getCurrentUrl()
@@ -31,6 +34,7 @@ class Piwik_Url
 	/**
 	 * If current URL is "http://example.org/dir1/dir2/index.php?param1=value1&param2=value2"
 	 * will return "http://example.org/dir1/dir2/index.php"
+	 *
 	 * @return string
 	 */
 	static public function getCurrentUrlWithoutQueryString()
@@ -42,6 +46,7 @@ class Piwik_Url
 	/**
 	 * If current URL is "http://example.org/dir1/dir2/index.php?param1=value1&param2=value2"
 	 * will return "http://example.org/dir1/dir2/"
+	 *
 	 * @return string with trailing slash
 	 */
 	static public function getCurrentUrlWithoutFileName()
@@ -54,6 +59,7 @@ class Piwik_Url
 	/**
 	 * If current URL is "http://example.org/dir1/dir2/index.php?param1=value1&param2=value2"
 	 * will return "/dir1/dir2/"
+	 *
 	 * @return string with trailing slash
 	 */
 	static public function getCurrentScriptPath()
@@ -74,6 +80,7 @@ class Piwik_Url
 	/**
 	 * If current URL is "http://example.org/dir1/dir2/index.php?param1=value1&param2=value2"
 	 * will return "/dir1/dir2/index.php"
+	 *
 	 * @return string
 	 */
 	static public function getCurrentScriptName()
@@ -102,24 +109,29 @@ class Piwik_Url
 		return $url;
 	}
 
+	static public function getCurrentScheme()
+	{
+    	if(isset($_SERVER['HTTPS'])
+    			&& ($_SERVER['HTTPS'] == 'on' || $_SERVER['HTTPS'] === true)
+    			)
+		{
+			$scheme = 'https';
+		}
+		else 
+		{
+			$scheme = 'http';
+		}
+		return $scheme;
+	}
 	/**
 	 * If current URL is "http://example.org/dir1/dir2/index.php?param1=value1&param2=value2"
 	 * will return "http://example.org"
+	 *
 	 * @return string
 	 */
 	static public function getCurrentHost()
 	{
-		if(isset($_SERVER['HTTPS'])
-			&& ($_SERVER['HTTPS'] == 'on' || $_SERVER['HTTPS'] === true)
-			)
-		{
-			$url = 'https';
-		}
-		else
-		{
-			$url = 'http';
-		}
-		
+		$url = self::getCurrentScheme();
 		$url .= '://';
 		
 		if(isset($_SERVER['HTTP_HOST']))
@@ -136,6 +148,7 @@ class Piwik_Url
 	/**
 	 * If current URL is "http://example.org/dir1/dir2/index.php?param1=value1&param2=value2"
 	 * will return "?param1=value1&param2=value2"
+	 *
 	 * @return string
 	 */
 	static public function getCurrentQueryString()
@@ -191,6 +204,7 @@ class Piwik_Url
 	/**
 	 * Given an array of parameters name->value, returns the query string.
 	 * Also works with array values using the php array syntax for GET parameters.
+	 *
 	 * @param $parameters eg. array( 'param1' => 10, 'param2' => array(1,2))
 	 * @return string eg. "param1=10&param2[]=1&param2[]=2"
 	 */
@@ -222,8 +236,6 @@ class Piwik_Url
 	/**
 	 * Redirects the user to the Referer if found. 
 	 * If the user doesn't have a referer set, it redirects to the current URL without query string.
-	 *
-	 * @return void http Location: header sent
 	 */
 	static public function redirectToReferer()
 	{
@@ -239,7 +251,6 @@ class Piwik_Url
 	 * Redirects the user to the specified URL
 	 *
 	 * @param string $url
-	 * @return void http Location: header sent
 	 */
 	static public function redirectToUrl( $url )
 	{
@@ -260,6 +271,4 @@ class Piwik_Url
 		}
 		return false;
 	}
-
 }
-
