@@ -1,10 +1,20 @@
 <?php
-require_once "ViewDataTable/GenerateGraphData.php";
+/**
+ * Piwik - Open source web analytics
+ * 
+ * @link http://piwik.org
+ * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
+ * @version $Id: ChartEvolution.php 1478 2009-09-22 15:06:57Z vipsoft $
+ * 
+ * @category Piwik
+ * @package Piwik
+ */
+
 /**
  * Piwik_ViewDataTable_GenerateGraphData for the Evolution graph (eg. Last 30 days visits) using Piwik_Visualization_Chart_Evolution
  * 
- * @package Piwik_ViewDataTable
- *
+ * @package Piwik
+ * @subpackage Piwik_ViewDataTable
  */
 class Piwik_ViewDataTable_GenerateGraphData_ChartEvolution extends Piwik_ViewDataTable_GenerateGraphData
 {
@@ -15,8 +25,7 @@ class Piwik_ViewDataTable_GenerateGraphData_ChartEvolution extends Piwik_ViewDat
 	
 	function __construct()
 	{
-		require_once "Visualization/Chart/Evolution.php";
-		$this->view = new Piwik_Visualization_Chart_Evolution;
+		$this->view = new Piwik_Visualization_Chart_Evolution();
 	}
 	
 	protected function guessUnitFromRequestedColumnNames($requestedColumnNames)
@@ -58,7 +67,7 @@ class Piwik_ViewDataTable_GenerateGraphData_ChartEvolution extends Piwik_ViewDat
 		foreach($this->dataTable->metadata as $idDataTable => $metadataDataTable)
 		{
 			//eg. "Aug 2009"
-			$xLabels[] = $metadataDataTable['period']->getLocalizedShortString();
+			$xLabels[] = html_entity_decode($metadataDataTable['period']->getLocalizedShortString(), ENT_COMPAT, 'UTF-8');
 			// we keep track of all unique data table that we need to set a Y value for
 			$uniqueIdsDataTable[] = $idDataTable;
 		}
