@@ -1,10 +1,20 @@
 <?php
-require_once "ViewDataTable/GenerateGraphHTML.php";
+/**
+ * Piwik - Open source web analytics
+ * 
+ * @link http://piwik.org
+ * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
+ * @version $Id: ChartEvolution.php 1420 2009-08-22 13:23:16Z vipsoft $
+ * 
+ * @category Piwik
+ * @package Piwik
+ */
+
 /**
  * Generates HTML embed for the Evolution graph
  *  
- * @package Piwik_ViewDataTable
- *
+ * @package Piwik
+ * @subpackage Piwik_ViewDataTable
  */
 class Piwik_ViewDataTable_GenerateGraphHTML_ChartEvolution extends Piwik_ViewDataTable_GenerateGraphHTML
 {
