@@ -4,9 +4,10 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: Html.php 581 2008-07-27 23:07:52Z matt $
+ * @version $Id: HtmlTable.php 1564 2009-11-04 03:35:44Z vipsoft $
  * 
- * @package Piwik_ViewDataTable
+ * @category Piwik
+ * @package Piwik
  */
 
 /**
@@ -14,8 +15,8 @@
  * 
  * Reads the requested DataTable from the API.
  * 
- * @package Piwik_ViewDataTable
- *
+ * @package Piwik
+ * @subpackage Piwik_ViewDataTable
  */
 class Piwik_ViewDataTable_HtmlTable extends Piwik_ViewDataTable
 {
@@ -68,8 +69,14 @@ class Piwik_ViewDataTable_HtmlTable extends Piwik_ViewDataTable
 			return;
 		}
 		$this->mainAlreadyExecuted = true;
-		
-		$this->loadDataTableFromAPI();
+
+		$this->isDataAvailable = true;
+		try {
+			$this->loadDataTableFromAPI();
+		} catch(Exception $e) {
+			$this->isDataAvailable = false;
+		}
+
 		$this->postDataTableLoadedFromAPI();
 		$this->view = $this->buildView();
 	}
@@ -87,27 +94,35 @@ class Piwik_ViewDataTable_HtmlTable extends Piwik_ViewDataTable
 	 */
 	protected function buildView()
 	{
-		$columns = $this->getColumnsToDisplay();
-		$columnTranslations = array();
-		foreach($columns as $columnName)
-		{
-			$columnTranslations[$columnName] = $this->getColumnTranslation($columnName);
-		}
-		$nbColumns = count($columns);
-		// case no data in the array we use the number of columns set to be displayed 
-		if($nbColumns == 0)
-		{
-			$nbColumns = count($this->columnsToDisplay);
-		}
-
 		$view = new Piwik_View($this->dataTableTemplate);
-		$view->arrayDataTable 	= $this->getPHPArrayFromDataTable();
-		$view->dataTableColumns = $columns;
-		$view->columnTranslations = $columnTranslations;
-		$view->nbColumns = $nbColumns;
+
+		if(!$this->isDataAvailable)
+		{
+			$view->arrayDataTable = array();
+		}
+		else
+		{
+			$columns = $this->getColumnsToDisplay();
+			$columnTranslations = array();
+			foreach($columns as $columnName)
+			{
+				$columnTranslations[$columnName] = $this->getColumnTranslation($columnName);
+			}
+			$nbColumns = count($columns);
+			// case no data in the array we use the number of columns set to be displayed 
+			if($nbColumns == 0)
+			{
+				$nbColumns = count($this->columnsToDisplay);
+			}
+
+			$view->arrayDataTable 	= $this->getPHPArrayFromDataTable();
+			$view->dataTableColumns = $columns;
+			$view->columnTranslations = $columnTranslations;
+			$view->nbColumns = $nbColumns;
+			$view->defaultWhenColumnValueNotDefined = '-';
+		}
 		$view->javascriptVariablesToSet = $this->getJavascriptVariablesToSet();
 		$view->properties = $this->getViewProperties();
-		$view->defaultWhenColumnValueNotDefined = '-';
 		return $view;
 	}
 
@@ -152,9 +167,6 @@ class Piwik_ViewDataTable_HtmlTable extends Piwik_ViewDataTable
 	}
 
 	/**
-	 * Sets the columns in the HTML table as not sortable (they are not clickable) 
-	 *
-	 * @return void
 	 */
 	public function disableSort()
 	{
@@ -205,4 +217,3 @@ class Piwik_ViewDataTable_HtmlTable extends Piwik_ViewDataTable
 		}
 	}
 }
-
