@@ -1,6 +1,19 @@
 <?php
-require_once "ViewDataTable/HtmlTable.php";
+/**
+ * Piwik - Open source web analytics
+ * 
+ * @link http://piwik.org
+ * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
+ * @version $Id: AllColumns.php 1420 2009-08-22 13:23:16Z vipsoft $
+ * 
+ * @category Piwik
+ * @package Piwik
+ */
 
+/**
+ * @package Piwik
+ * @subpackage Piwik_ViewDataTable
+ */
 class Piwik_ViewDataTable_HtmlTable_AllColumns extends Piwik_ViewDataTable_HtmlTable 
 {
 	protected function getViewDataTableId()
