@@ -1,6 +1,19 @@
 <?php
-require_once "ViewDataTable/HtmlTable.php";
+/**
+ * Piwik - Open source web analytics
+ * 
+ * @link http://piwik.org
+ * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
+ * @version $Id: Goals.php 1420 2009-08-22 13:23:16Z vipsoft $
+ * 
+ * @category Piwik
+ * @package Piwik
+ */
 
+/**
+ * @package Piwik
+ * @subpackage Piwik_ViewDataTable
+ */
 class Piwik_ViewDataTable_HtmlTable_Goals extends Piwik_ViewDataTable_HtmlTable 
 {
 	protected function getViewDataTableId()
@@ -46,8 +59,6 @@ class Piwik_ViewDataTable_HtmlTable_Goals extends Piwik_ViewDataTable_HtmlTable
 		{
 			if($columnName == 'goal_%s_conversion_rate')
 			{
-				require_once "Tracker/GoalManager.php";
-				require_once "Goals/API.php";
 				$goals = Piwik_Goals_API::getGoals( $this->getIdSite() );
 				foreach($goals as $goal)
 				{
