@@ -4,19 +4,27 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: OpenFlashChart.php 386 2008-03-18 19:27:54Z julien $
+ * @version $Id: Sparkline.php 1431 2009-08-23 14:27:44Z vipsoft $
  *
- * @package Piwik_Visualization
+ * @category Piwik
+ * @package Piwik
  */
 
-require_once 'sparkline/lib/Sparkline_Line.php';
+// no direct access
+defined('PIWIK_INCLUDE_PATH') or die;
 
+/**
+ * @see libs/sparkline/lib/Sparkline_Line.php
+ * @link http://sparkline.org
+ */
+require_once PIWIK_INCLUDE_PATH . '/libs/sparkline/lib/Sparkline_Line.php';
 
 /**
  * Renders a sparkline image given a PHP data array.
  * Using the Sparkline PHP Graphing Library sparkline.org 
  * 
- * @package Piwik_Visualization
+ * @package Piwik
+ * @subpackage Piwik_Visualization
  */
 class Piwik_Visualization_Sparkline implements Piwik_iView
 {
