@@ -3,10 +3,10 @@
  *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id$
+ * @version $Id: piwik.js 1590 2009-11-16 01:55:54Z vipsoft $
  */
 
-/*jslint browser:true, forin:true, plusplus:false, onevar:false, eqeqeq:false */
+/*jslint browser:true, forin:true, plusplus:false, onevar:false, eqeqeq:false; strict:false */
 /*global window escape unescape ActiveXObject */
 
 // Note: YUICompressor 2.4.2 won't compress piwik_log() because of the the "evil" eval().
@@ -21,10 +21,8 @@
  */
 
 // Guard against loading the script twice
-var Piwik;
-try {
-	if (Piwik.getTracker) { }
-} catch (e) {
+var Piwik, piwik_log, piwik_track;
+if (!this.Piwik) {
 	// Piwik singleton and namespace
 	Piwik = (function () {
 		/************************************************************
@@ -41,6 +39,7 @@ try {
 		navigatorAlias = navigator,
 		screenAlias = screen,
 		windowAlias = window,
+		hostnameAlias = windowAlias.location.hostname,
 
 		/* DOM Ready */
 		hasLoaded = false,
@@ -172,23 +171,26 @@ try {
 			// Site ID
 			configTrackerSiteId = siteId || '',
 
+			// Document URL
+			configUrl = documentAlias.location.href,
+
 			// Document title
-			configTitle = '',
+			configTitle = documentAlias.title,
 
 			// Extensions to be treated as download links
-			configDownloadExtensions = '7z|aac|arc|arj|asf|asx|avi|bin|csv|doc|exe|flv|gif|gz|gzip|hqx|jar|jpe?g|js|mp(2|3|4|e?g)|mov(ie)?|msi|msp|pdf|phps|png|ppt|qtm?|ra(m|r)?|sea|sit|tar|tgz|torrent|txt|wav|wma|wmv|wpd||xls|xml|z|zip',
+			configDownloadExtensions = '7z|aac|arc|arj|asf|asx|avi|bin|csv|deb|dmg|doc|exe|flv|gif|gz|gzip|hqx|jar|jpe?g|js|mp(2|3|4|e?g)|mov(ie)?|msi|msp|pdf|phps|png|ppt|qtm?|ra(m|r)?|rpm|sea|sit|tar|t?bz2?|tgz|torrent|txt|wav|wma|wmv|wpd||xls|xml|z|zip',
 
 			// Hosts or alias(es) to not treat as outlinks
-			configHostsAlias = [windowAlias.location.hostname],
+			configHostsAlias = [hostnameAlias],
 
 			// Anchor classes to not track
 			configIgnoreClasses = [],
 
 			// Download class name
-			configDownloadClass = 'piwik_download',
+			configDownloadClasses = [],
 
 			// (Out) Link class name
-			configLinkClass = 'piwik_link',
+			configLinkClasses = [],
 
 			// Maximum delay to wait for web bug image to be fetched (in milliseconds)
 			configTrackerPause = 500,
@@ -200,23 +202,21 @@ try {
 			browserHasCookies = '0',
 			pageReferrer,
 
-			// Plugin, Parameter name, MIME type, ActiveX progid, detected, version
+			// Plugin, Parameter name, MIME type, detected
 			pluginMap = {
-				director:    ['dir',   'application/x-director',
-				                        ['SWCtl.SWctl.1'],
-				                        '0', ''],
-				flash:       ['fla',   'application/x-shockwave-flash',
-				                        ['ShockwaveFlash.ShockwaveFlash.1'],
-				                        '0', ''],
-				pdf:         ['pdf',   'application/pdf',
-				                        ['AcroPDF.PDF.1', 'PDF.PdfCtrl.6', 'PDF.PdfCtrl.5', 'PDF.PdfCtrl.1'],
-				                        '0', ''],
-				realplayer:  ['realp', 'audio/x-pn-realaudio-plugin',
-				                        ['rmocx.RealPlayer G2 Control.1', 'RealPlayer.RealPlayer(tm) ActiveX Control (32-bit)'],
-				                        '0', ''],
-				wma:         ['wma',   'application/x-mplayer2',
-				                        ['WMPlayer.OCX', 'MediaPlayer.MediaPlayer.1'],
-				                        '0', '']
+				// document types
+				pdf:         ['pdf',   'application/pdf',               '0'],
+				// media players
+				quicktime:   ['qt',    'video/quicktime',               '0'],
+				realplayer:  ['realp', 'audio/x-pn-realaudio-plugin',   '0'],
+				wma:         ['wma',   'application/x-mplayer2',        '0'],
+				// interactive multimedia 
+				director:    ['dir',   'application/x-director',        '0'],
+				flash:       ['fla',   'application/x-shockwave-flash', '0'],
+				// RIA
+				java:        ['java',  'application/x-java-vm',         '0'],
+				gears:       ['gears', 'application/x-googlegears',     '0'],
+				silverlight: ['ag',    'application/x-silverlight',     '0']
 			},
 
 			// Guard against installing the link tracker more than once per Tracker instance
@@ -240,7 +240,7 @@ try {
 			 */
 			stringify = function (value) {
 
-				var escapable = /[\\\"\x00-\x1f\x7f-\x9f\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g,
+				var escapable = new RegExp('[\\\"\x00-\x1f\x7f-\x9f\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]', 'g'),
 					// table of character substitutions
 					meta = {'\b': '\\b', '\t': '\\t', '\n': '\\n', '\f': '\\f', '\r': '\\r', '"' : '\\"', '\\': '\\\\'};
 
@@ -349,16 +349,6 @@ try {
 			 */
 			registeredHooks = {};
 
-			/*
-			 * Platform test for Internet Explorer on Windows
-			 */
-			function isWindowsIE() {
-				var agent = navigatorAlias.userAgent.toLowerCase();
-
-				return (agent.indexOf('msie') != -1) && (agent.indexOf('opera') == -1) &&
-				       ((agent.indexOf('win') != -1) || (agent.indexOf('32bit') != -1));
-			}
-
 			/*
 			 * Set cookie value
 			 */
@@ -382,10 +372,8 @@ try {
 			/*
 			 * Get cookie value
 			 */
-			function getCookie(cookieName, path, domain) {
-				var cookiePattern = new RegExp('(^|;)[ ]*' + cookieName + '=([^;]*)' +
-						(path ? '(;[ ]*expires=[^;]*)?;[ ]*path=' + path.replace('/', '\\/') + '' : '') +
-						(domain ? ';[ ]*domain=' + domain + '(;|$)' : '')),
+			function getCookie(cookieName) {
+				var cookiePattern = new RegExp('(^|;)[ ]*' + cookieName + '=([^;]*)'),
 
 					cookieMatch = cookiePattern.exec(documentAlias.cookie);
 
@@ -407,6 +395,7 @@ try {
 
 			/*
 			 * Send image request to Piwik server using GET.
+			 * The infamous web bug is a transparent, single pixel (1x1) image
 			 */
 			function getImage(url, delay) {
 				var now = new Date(),
@@ -422,45 +411,27 @@ try {
 			 * Browser plugin tests
 			 */
 			function detectBrowserPlugins() {
-				var i, mimeTypes = '';
+				var i, mimeType;
 
-				function setPluginInfo(pluginName, mimeType) {
-					if (mimeTypes.indexOf(mimeType) != -1 && navigatorAlias.mimeTypes[mimeType].enabledPlugin !== null) {
-						pluginMap[pluginName][3] = '1';
-					}
+				// Safari and Opera
+				// IE6: typeof navigator.javaEnabled == 'unknown'
+				if (typeof navigatorAlias.javaEnabled !== 'undefined' && navigatorAlias.javaEnabled()) {
+					pluginMap.java[2] = '1';
 				}
 
-				/*
-				 * Note: an ActiveXObject object has no intrinsic properties or methods;
-				 *       thus, no standard means of getting a plugin's version number
-				 */
-				function setIEPluginInfo(pluginName, progids) {
-					if (progids !== null && isDefined(windowAlias.ActiveXObject)) {
-						for (var j = 0; j < progids.length; j++) {
-							try {
-								if (new ActiveXObject(progids[j])) {
-									pluginMap[pluginName][3] = '1';
-									break;
-								}
-							} catch (e) { }
+				// Firefox
+				if (typeof windowAlias.GearsFactory === 'function') {
+					pluginMap.gears[2] = '1';
+				}
+
+				if (navigatorAlias.mimeTypes && navigatorAlias.mimeTypes.length) {
+					for (i in pluginMap) {
+						mimeType = navigatorAlias.mimeTypes[pluginMap[i][1]];
+						if (mimeType && mimeType.enabledPlugin) {
+							pluginMap[i][2] = '1';
 						}
 					}
 				}
-
-				// Begin detection of browser plugins
-				if (isWindowsIE()) {
-					for (i in pluginMap) {
-						setIEPluginInfo(i, pluginMap[i][2]);
-					}
-				} else {
-					for (i = 0; i < navigatorAlias.mimeTypes.length; i++) {
-						mimeTypes += navigatorAlias.mimeTypes[i].type.toLowerCase();
-					}
-
-					for (i in pluginMap) {
-						setPluginInfo(i, pluginMap[i][1]);
-					}
-				}
 			}
 
 			/*
@@ -499,73 +470,90 @@ try {
 				return navigatorAlias.cookieEnabled ? '1' : '0';
 			}
 
-
 			/*
-			 * Get the web bug image (transparent single pixel, 1x1, image) to log visit in Piwik
+			 * Returns the URL to call piwik.php, 
+			 * with the standard parameters (plugins, resolution, url, referer, etc.)
 			 */
-			function getWebBug() {
-				var i, customDataString, pluginString, extraString, now, request, query;
-
-				/*
-				 * encode custom vars
-				 */
-				customDataString = '';
-				if (isDefined(configCustomData)) {
-					customDataString = '&data=' + escapeWrapper(stringify(configCustomData));
-				}
-
-				/*
-				 * encode plugin data
-				 */
-				pluginString = '';
-				for (i in pluginMap) {
-					pluginString += '&' + pluginMap[i][0] + '=' + pluginMap[i][3];
-				}
-
-				extraString = executePluginMethod('log');
-
+			function getRequest() {
+				var i, now, request;
 				now = new Date();
-
-				query = 'idsite=' + configTrackerSiteId +
-				        '&url=' + escapeWrapper(documentAlias.location.href) +
-				        '&action_name=' + escapeWrapper(configTitle) + // refs #530
+				request = 'idsite=' + configTrackerSiteId +
+				        '&url=' + escapeWrapper(configUrl) +
 				        '&res=' + screenAlias.width + 'x' + screenAlias.height +
 				        '&h=' + now.getHours() + '&m=' + now.getMinutes() + '&s=' + now.getSeconds() +
 				        '&cookie=' + browserHasCookies +
 				        '&urlref=' + escapeWrapper(pageReferrer) +
-				        pluginString + customDataString + extraString;
+				        '&rand=' + Math.random();
+				// plugin data
+				for (i in pluginMap) {
+					request += '&' + pluginMap[i][0] + '=' + pluginMap[i][2];
+				}
 
-				request =  configTrackerUrl + '?' + query;
-
-				getImage(request, configTrackerPause);
+				request =  configTrackerUrl + '?' + request;
+				return request;
 			}
 
+			/*
+			 * Log the page view / visit
+			 */
+			function logPageView() {
+				var request = getRequest();
+				request += '&action_name=' + escapeWrapper(configTitle); // refs #530;
+
+				// encode custom data
+				if (isDefined(configCustomData)) {
+					request += '&data=' + escapeWrapper(stringify(configCustomData));
+				}
+
+				request += executePluginMethod('log');
+				getImage(request, configTrackerPause);
+			}
+			
+			/*
+			 * Log the goal with the server
+			 */
+			function logGoal(idGoal, customRevenue, customData) {
+				var request = getRequest();
+				request += '&idgoal=' + idGoal;
+
+				if (isDefined(customRevenue) && customRevenue !== null) {
+					request += '&revenue=' + customRevenue;
+				}
+
+				// encode custom data
+				if (isDefined(customData)) {
+					if (customData !== null) {
+						request += '&data=' + escapeWrapper(stringify(customData));
+					}
+				} else if (isDefined(configCustomData)) {
+					request += '&data=' + escapeWrapper(stringify(configCustomData));
+				}
+
+				request += executePluginMethod('goal');
+				getImage(request, configTrackerPause);
+			}
+			
 			/*
 			 * Log the click with the server
 			 */
 			function logClick(url, linkType, customData) {
-				var customDataString, extraString, request, query;
+				var request;
+				request = 'idsite=' + configTrackerSiteId +
+				          '&' + linkType + '=' + escapeWrapper(url) +
+				          '&rand=' + Math.random() +
+				          '&redirect=0';
 
-				/*
-				 * encode custom data
-				 */
-				customDataString = '';
+				// encode custom data
 				if (isDefined(customData)) {
-					customDataString = '&data=' + escapeWrapper(stringify(customData));
+					if (customData !== null) {
+						request += '&data=' + escapeWrapper(stringify(customData));
+					}
 				} else if (isDefined(configCustomData)) {
-					customDataString = '&data=' + escapeWrapper(stringify(configCustomData));
+					request += '&data=' + escapeWrapper(stringify(configCustomData));
 				}
 
-				extraString = executePluginMethod('click');
-
-				query = 'idsite=' + configTrackerSiteId +
-				        '&' + linkType + '=' + escapeWrapper(url) +
-				        '&rand=' + Math.random() +
-				        '&redirect=0' +
-				        customDataString + extraString;
-
-				request = configTrackerUrl + '?' + query;
-
+				request += executePluginMethod('click');
+				request = configTrackerUrl + '?' + request;
 				getImage(request, configTrackerPause);
 			}
 
@@ -597,6 +585,22 @@ try {
 				return false;
 			}
 
+			/*
+			 * Construct regular expression of classes
+			 */
+			function getClassesRegExp(configClasses, defaultClass) {
+				var i, classesRegExp = '(^| )(piwik_' + defaultClass;
+
+				if (isDefined(configClasses)) {
+					for (i = 0; i < configClasses.length; i++) {
+						classesRegExp += '|' + configClasses[i];
+					}
+				}
+				classesRegExp += ')( |$)';
+
+				return new RegExp(classesRegExp);
+			}
+
 			/*
 			 * Link or Download?
 			 */
@@ -607,27 +611,24 @@ try {
 				}
 
 				// does class indicate whether it is an (explicit/forced) outlink or a download?
-				var downloadOrLinkPattern = new RegExp('(^| )(' + configDownloadClass + '|' + configLinkClass + ')( |$)'),
-				match = downloadOrLinkPattern.exec(className),
+				var downloadPattern = getClassesRegExp(configDownloadClasses, 'download'),
+				linkPattern = getClassesRegExp(configLinkClasses, 'link'),
 
 				// does file extension indicate that it is a download?
-				downloadExtensionsPattern = new RegExp('\\.(' + configDownloadExtensions + ')$', 'i');
+				downloadExtensionsPattern = new RegExp('\\.(' + configDownloadExtensions + ')([?&#]|$)', 'i');
 
-				// optimization of the nested if..elseif..else construct below
-				return match ? (match[2] == configDownloadClass ? 'download' : 'link') :
-					    (downloadExtensionsPattern.test(href) ? 'download' : 0);
+				// optimization of the if..elseif..else construct below
+				return linkPattern.test(className) ? 'link' : (downloadPattern.test(className) || downloadExtensionsPattern.test(href) ? 'download' : 0);
 
 /*
 				var linkType;
 
-				if (match) {
-					if (match[2] == configDownloadClass) {
-						// class attribute contains 'piwik_download' (or user's override)
-						linkType = 'download';
-					} else {
-						// class attribute contains 'piwik_link' (or user's override)
-						linkType = 'link';
-					}
+				if (linkPattern.test(className)) {
+					// class attribute contains 'piwik_link' (or user's override)
+					linkType = 'link';
+				} else if (downloadPattern.test(className)) {
+					// class attribute contains 'piwik_download' (or user's override)
+					linkType = 'download';
 				} else if (downloadExtensionsPattern.test(sourceHref)) {
 					// file extension matches a defined download extension
 					linkType = 'download';
@@ -644,7 +645,7 @@ try {
 			 * Handle click event
 			 */
 			function clickHandler(clickEvent) {
-				var sourceElement, tag, linkType;
+				var sourceElement, parentElement, tag, linkType;
 
 				if (!isDefined(clickEvent)) {
 					clickEvent = windowAlias.event;
@@ -655,11 +656,12 @@ try {
 				} else if (isDefined(clickEvent.srcElement)) {
 					sourceElement = clickEvent.srcElement;
 				} else {
-					return true;
+					return;
 				}
 
-				while ((tag = sourceElement.tagName) != 'A' && tag != 'AREA') {
-					sourceElement = sourceElement.parentNode;
+				while ((parentElement = sourceElement.parentNode) &&
+				       ((tag = sourceElement.tagName) != 'A' && tag != 'AREA')) {
+					sourceElement = parentElement;
 				}
 
 				if (isDefined(sourceElement.href)) {
@@ -667,7 +669,7 @@ try {
 					var originalSourceHostName = sourceElement.hostname,
 						sourceHostName = originalSourceHostName.toLowerCase(),
 						sourceHref = sourceElement.href.replace(originalSourceHostName, sourceHostName),
-						scriptProtocol = /^(javascript|vbscript|jscript|mocha|livescript|ecmascript): */i;
+						scriptProtocol = new RegExp('^(javascript|vbscript|jscript|mocha|livescript|ecmascript): *', 'i');
 
 					// ignore script pseudo-protocol links
 					if (!scriptProtocol.test(sourceHref)) {
@@ -678,25 +680,6 @@ try {
 						}
 					}
 				}
-
-				// Returns true so href isn't cancelled
-				return true;
-			}
-
-			/*
-			 * Construct regular expression of classes to be ignored
-			 */
-			function getIgnoreRegExp() {
-				var i, ignoreRegExp = '(^| )(piwik_ignore';
-
-				if (isDefined(configIgnoreClasses)) {
-					for (i = 0; i < configIgnoreClasses.length; i++) {
-						ignoreRegExp += '|' + configIgnoreClasses[i];
-					}
-				}
-				ignoreRegExp += ')( |$)';
-
-				return new RegExp(ignoreRegExp);
 			}
 
 			/*
@@ -715,7 +698,7 @@ try {
 
 					// iterate through anchor elements with href and AREA elements
 
-					var i, ignorePattern = getIgnoreRegExp(), linkElements = documentAlias.links;
+					var i, ignorePattern = getClassesRegExp(configIgnoreClasses, 'ignore'), linkElements = documentAlias.links;
 
 					if (linkElements) {
 						for (i = 0; i < linkElements.length; i++) {
@@ -838,10 +821,10 @@ try {
 				setDomains: function (hostsAlias) {
 					if (typeof hostsAlias == 'object' && hostsAlias instanceof Array) {
 						configHostsAlias = hostsAlias;
-						// configHostAlias.push(windowAlias.location.hostname); // array.push added in IE5.5
-						configHostsAlias[configHostsAlias.length] = windowAlias.location.hostname;
+						// configHostAlias.push(hostnameAlias); // array.push added in IE5.5
+						configHostsAlias[configHostsAlias.length] = hostnameAlias;
 					} else if (typeof hostsAlias == 'string') {
-						configHostsAlias = [hostsAlias, windowAlias.location.hostname];
+						configHostsAlias = [hostsAlias, hostnameAlias];
 					}
 				},
 
@@ -856,6 +839,15 @@ try {
 					}
 				},
 
+				/*
+				 * Override url
+				 */
+				setCustomUrl: function (url) {
+					if (isDefined(url)) {
+						configUrl = url;
+					}
+				},
+
 				/*
 				 * Override document.title
 				 */
@@ -865,21 +857,45 @@ try {
 					}
 				},
 
+				/*
+				 * Set array of classes to be treated as downloads
+				 */
+				setDownloadClasses: function (downloadClasses) {
+					if (typeof downloadClasses == 'object' && downloadClasses instanceof Array) {
+						configDownloadClasses = downloadClasses;
+					} else if (typeof downloadClasses == 'string') {
+						configDownloadClasses = [downloadClasses];
+					}
+				},
+
 				/*
 				 * Set download class name (i.e., override default: piwik_download)
+				 * (deprecated)
 				 */
 				setDownloadClass: function (className) {
-					if (typeof className == 'string' && className.length > 0) {
-						configDownloadClass = className;
+					if (typeof className == 'string') {
+						configDownloadClasses = [className];
+					}
+				},
+
+				/*
+				 * Set array of classes to be treated as outlinks
+				 */
+				setLinkClasses: function (linkClasses) {
+					if (typeof linkClasses == 'object' && linkClasses instanceof Array) {
+						configLinkClasses = linkClasses;
+					} else if (typeof linkClasses == 'string') {
+						configLinkClasses = [linkClasses];
 					}
 				},
 
 				/*
 				 * Set outlink class name (i.e., override default: piwik_link)
+				 * (deprecated)
 				 */
 				setLinkClass: function (className) {
-					if (typeof className == 'string' && className.length > 0) {
-						configLinkClass = className;
+					if (typeof className == 'string') {
+						configLinkClasses = [className];
 					}
 				},
 
@@ -909,7 +925,14 @@ try {
 				},
 
 				/*
-				 * Manually log a click from your own code.
+				 * Trigger a goal
+				 */
+				trackGoal: function (idGoal, customRevenue, customData) {
+					logGoal(idGoal, customRevenue, customData);
+				},
+
+				/*
+				 * Manually log a click from your own code
 				 */
 				trackLink: function (sourceUrl, linkType, customData) {
 					logClick(sourceUrl, linkType, customData);
@@ -919,7 +942,7 @@ try {
 				 * Log visit to this page
 				 */
 				trackPageView: function () {
-					getWebBug();
+					logPageView();
 				}
 			};
 		}
@@ -964,15 +987,11 @@ try {
 	 *   var piwik_install_tracker, piwik_tracker_pause, piwik_download_extensions, piwik_hosts_alias, piwik_ignore_classes;
 	 */
 
-	/*
-	 * Track click manually (function is defined below)
-	 */
-	var piwik_track;
 
 	/*
 	 * Track page visit
 	 */
-	function piwik_log(documentTitle, siteId, piwikUrl, customData) {
+	piwik_log = function (documentTitle, siteId, piwikUrl, customData) {
 
 		function getOption(optionName) {
 			try {
@@ -1001,7 +1020,9 @@ try {
 		// default is to install the link tracker
 		if (getOption('install_tracker') !== false) {
 
-			// set-up click handler
+			/*
+			 * Track click manually (function is defined below)
+			 */
 			piwik_track = function (sourceUrl, siteId, piwikUrl, linkType) {
 				piwikTracker.setSiteId(siteId);
 				piwikTracker.setTrackerUrl(piwikUrl);
@@ -1011,5 +1032,5 @@ try {
 			// set-up link tracking
 			piwikTracker.enableLinkTracking();
 		}
-	}
+	};
 }
