@@ -20,7 +20,7 @@ $translations = array(
 	'General_Done' => 'Fet',
 	'General_LoadingData' => 'Les dades s\'estan carregant&hellip;',
 	'General_ErrorRequest' => 'Ups! Hi ha hagut un problema amb la sol&middot;licitud, torneu-ho a intentar.',
-	'General_Next' => 'Seg&uuml;ent',
+	'General_Next' => 'Següent',
 	'General_Previous' => 'Anterior',
 	'General_Search' => 'Cerca',
 	'General_Others' => 'Altres',
@@ -56,7 +56,7 @@ $translations = array(
 	'General_DisplayMoreData' => 'Mostra més dades',
 	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Hi ha una nova versió del Piwik, %s, disponible! %s Si us plau, actualitzeu ara!%s (%s Mostra els canvis%s)',
 	'General_BackToPiwik' => 'Torna al Piwik',
-	'General_Loading' => '',
+	'General_Loading' => 'Carregant&hellip;',
 	'General_ExportAsImage' => 'Exporta com una imatge',
 	'General_SaveImageOnYourComputer' => 'Per a desar la imatge al vostre ordinador, piqueu-hi amb el botó dret del ratolí i seleccioneu "Anomena i desa la imatge..."',
 	'General_ColumnNbActions' => 'Accions',
@@ -107,13 +107,13 @@ $translations = array(
 	'Actions_SubmenuOutlinks' => 'Enlla&ccedil;os externs',
 	'Actions_SubmenuDownloads' => 'Descàrregues',
 	'Actions_Actions' => 'Accions',
-	'Actions_ColumnClicks' => '',
-	'Actions_ColumnUniqueClicks' => '',
-	'Actions_ColumnDownloads' => '',
-	'Actions_ColumnUniqueDownloads' => '',
-	'Actions_ColumnPageName' => '',
-	'Actions_ColumnClickedURL' => '',
-	'Actions_ColumnDownloadURL' => '',
+	'Actions_ColumnClicks' => 'Clics',
+	'Actions_ColumnUniqueClicks' => 'Clics únics',
+	'Actions_ColumnDownloads' => 'Descàrregues',
+	'Actions_ColumnUniqueDownloads' => 'Descàrregues úniques',
+	'Actions_ColumnPageName' => 'Nom de la pàgina',
+	'Actions_ColumnClickedURL' => 'URL picada',
+	'Actions_ColumnDownloadURL' => 'URL de descàrrega',
 	'API_QuickDocumentation' => '<h2>Guia ràpida de l\'API</h2><p>Si no teniu dades per a avui, podeu <a href=\'misc/generateVisits.php\' target=\'_blank\'>generar-ne fent servir el Generador de visites</a>.</p><p><strong>Si voleu més informació, passeu-vos per la <a href=\'http://dev.piwik.org/trac/wiki/API\'>documentació oficial de l\'API (en anglès)</a> o les <a href=\'http://dev.piwik.org/trac/wiki/API/Reference\'>referències de l\'API</a>.</strong></p><h2>Autenticació de l\'usuari</h2><p><strong>Si voleu sol&middot;licitar les dades amb un script, una tasca (crontab), etc.</strong>, necessiteu afegir el paràmetre <code><u>&token_auth=%s</u></code> per a poder invocar les URLs de l\'API que necessiten autenticació.</p><p>Aquest <tt>token_auth</tt> és tan secret com el vostre usuari i contrassenya, <strong>no l\'heu de donar a ningú!</strong></p>',
 	'API_LoadedAPIs' => 'S\'ha carregat correctament un total de %s API',
 	'CoreHome_NoPrivileges' => 'Heu iniciat la sessió fent servir l\'usuari \'%s\', però sembla que no teniu cap permís configurat al Piwik.<br />Demaneu a l\'administrador que us doni permisos de \'vista\' a algun lloc web.',
@@ -139,7 +139,7 @@ $translations = array(
 	'CoreHome_DaySa_js' => 'ds',
 	'CoreHome_MonthJanuary_js' => 'Gener',
 	'CoreHome_MonthFebruary_js' => 'Febrer',
-	'CoreHome_MonthMarch_js' => 'Mar&ccedil;',
+	'CoreHome_MonthMarch_js' => 'Març',
 	'CoreHome_MonthApril_js' => 'Abril',
 	'CoreHome_MonthMay_js' => 'Maig',
 	'CoreHome_MonthJune_js' => 'Juny',
@@ -199,6 +199,21 @@ $translations = array(
 	'CoreUpdater_InstallingTheLatestVersion' => 'S\'està instal·lant la darrera versió',
 	'CoreUpdater_PiwikUpdatedSuccessfully' => 'El Piwik s\'ha actualitzat correctament!',
 	'CoreUpdater_UpdateHasBeenCancelledExplanation' => 'L\'actualització en un clic del Piwik ha estat cancel·lada. Si no podeu arreglar l\'error de més amunt, us recomanem que actualitzeu el Piwik manualment. %s Si us plau, mireu-vos la %sDocumentació d\'actualització (en anglès)%s per a començar!',
+	'CoreUpdater_TheUpgradeProcessMayFail' => 'Si teniu una base de dades molt gran, les actualitzacions poden trigar massa temps en acabar a través del navegador. En aquesta situació podeu executar les actualitzacions des del terminal:
+<code>$ php path/to/piwik/index.php</code>',
+	'CoreUpdater_ErrorDIYHelp' => 'Si sou un usuari avançat i trobeu un error en l\'actualització de la base de dades:',
+	'CoreUpdater_ErrorDIYHelp_1' => 'identifiqueu i corregiu l\'origen de l\'error (per exemple: memory_limit o max_execution_time)',
+	'CoreUpdater_ErrorDIYHelp_2' => 'executeu les consultes restants de l\'actualització que han fallat',
+	'CoreUpdater_ErrorDIYHelp_3' => 'actualitzeu la taula `option` de la base de dades del Piwik, introduint la versió que ha fallat a l\'hora d\'actualitzar a version_core',
+	'CoreUpdater_ErrorDIYHelp_4' => 'torneu a engegar l\'actualització (a través del navegador o la línia de comandes) per a continuar amb les actualitzacions restants.',
+	'CoreUpdater_ErrorDIYHelp_5' => 'informeu sobre el problema (i la solució) per tal que puguem millorar el Piwik',
+	'CoreUpdater_DownloadingUpdateFromX' => 'S\'està descarregant l\'actualització de %s',
+	'CoreUpdater_UnpackingTheUpdate' => 'S\'està desempacant l\'actualització',
+	'CoreUpdater_EmptyDatabaseError' => 'La base de dades %s està buida. Heu d\'editar o esborrar el fitxer de configuració del Piwik.',
+	'CoreUpdater_ExceptionAlreadyLatestVersion' => 'El Piwik està actualitzat a la versió %s.',
+	'CoreUpdater_ExceptionArchiveIncompatible' => 'Arxiu incompatible: %s',
+	'CoreUpdater_ExceptionArchiveEmpty' => 'Arxiu buit',
+	'CoreUpdater_ExceptionArchiveIncomplete' => 'L\'arxiu és incomplet: manquen alguns fitxers (per exemple, %s).',
 	'Dashboard_AddWidget' => 'Afegeix un giny&hellip;',
 	'Dashboard_DeleteWidgetConfirm' => 'Realment voleu esborrar aquest giny?',
 	'Dashboard_SelectWidget' => 'Escolliu el giny que voleu afegir a la consola',
@@ -220,13 +235,13 @@ $translations = array(
 	'DBStats_DataSize' => 'Grandària de les dades',
 	'DBStats_IndexSize' => 'Grandària del l\'índex',
 	'DBStats_TotalSize' => 'Grandària total',
-	'Goals_ColumnConversions' => '',
-	'Goals_ColumnConversionRate' => '',
-	'Goals_ColumnRevenue' => '',
-	'Installation_Installation' => 'Instal&middot;lació',
-	'Installation_InstallationStatus' => 'Estat de la instal&middot;lació',
+	'Goals_ColumnConversions' => 'Conversions',
+	'Goals_ColumnConversionRate' => 'Raó de conversions',
+	'Goals_ColumnRevenue' => 'Ingressos',
+	'Installation_Installation' => 'Instal·lació',
+	'Installation_InstallationStatus' => 'Estat de la instal·lació',
 	'Installation_PercentDone' => '%s%% fet',
-	'Installation_NoConfigFound' => 'No s\'ha trobat el fitxer de configuració del Piwik i esteu intentant accedir una pàgina del Piwik.<br /><strong>&nbsp;&nbsp;&raquo;Podeu <a href=\'index.php\'>instal&middot;lar el Piwik ara</a></strong>.<br /><small>Si heu instal·lat el Piwik abans i teniu algunes taules a la vostra base de dades, no us preocupeu; podeu continuar fent servir les mateixes taules i les dades existents es conservaran!</small>',
+	'Installation_NoConfigFound' => 'No s\'ha trobat el fitxer de configuració del Piwik i esteu intentant accedir una pàgina del Piwik.<br /><strong>&nbsp;&nbsp;&raquo;Podeu <a href=\'index.php\'>instal&middot;lar el Piwik ara</a></strong>.<br /><small>Si heu instal·lat el Piwik abans i teniu algunes taules a la vostra base de dades, no us amoïneu; podeu continuar fent servir les mateixes taules i les dades existents es conservaran!</small>',
 	'Installation_MysqlSetup' => 'Configuració de la base de dades MySQL',
 	'Installation_MysqlErrorConnect' => 'Hi ha hagut un error en l\'intent de connexió amb la base de dades.',
 	'Installation_JsTag' => 'Etiqueta JavaScript',
@@ -270,17 +285,44 @@ $translations = array(
 	'Installation_DatabaseCreatedSuccess' => 'La base de dades %s s\'ha creat correctament!',
 	'Installation_ContinueToPiwik' => 'Vés cap al Piwik',
 	'Installation_SuperUserLogin' => 'Usuari administrador principal',
-	'Installation_Password' => 'Contrassenya',
-	'Installation_PasswordRepeat' => 'Torneu a escriure la contrassenya',
+	'Installation_Password' => 'Contrasenya',
+	'Installation_PasswordRepeat' => 'Torneu a escriure la contrasenya',
 	'Installation_Email' => 'Correu-e',
 	'Installation_SecurityNewsletter' => 'Envieu-me correus-e sobre les actualitzacions grans del Piwik i les alertes de seguretat',
 	'Installation_CommunityNewsletter' => 'Envieu-me correus-e amb les actualitzacions de la comunitat (nous connectors, funcionalitats, etc.)',
-	'Installation_PasswordDoNotMatch' => 'Les contrassenyes no coincideixen',
+	'Installation_PasswordDoNotMatch' => 'Les contrasenyes no coincideixen',
 	'Installation_SubmitGo' => 'Vés-hi!',
-	'Installation_TablesWithSameNamesFound' => '',
-	'Installation_GoBackAndDefinePrefix' => '',
-	'Installation_ConfirmDeleteExistingTables' => '',
-	'Installation_ErrorInvalidState' => '',
+	'Installation_TablesWithSameNamesFound' => 'Algunes %s taules de la base de dades %s tenen el mateix nom que les taules que el Piwik intenta crear',
+	'Installation_GoBackAndDefinePrefix' => 'Torna enrere i defineix un prefix per a les taules',
+	'Installation_ConfirmDeleteExistingTables' => 'Realment voleu esborrar les taules %s de la base de dades? AVÍS: NO ES PODRAN RECUPERAR LES DADES!',
+	'Installation_ErrorInvalidState' => 'Hi ha hagut un error: sembla que  esteu intentant saltar-vos un pas de la instal·lació, o teniu les galetes desactivades o el fitxer de configuració del Piwik ja existeix. %sAssegureu-vos que teniu les galetes activades%s i torneu enrera %s al primer pas de la instal·lació %s.',
+	'Installation_DatabaseSetup' => 'Configuració de la base de dades',
+	'Installation_DatabaseErrorConnect' => 'Hi ha hagut un error amb la connexió al servidor de bases de dades.',
+	'Installation_ConnectionCharacterSetNotUtf8' => 'La connexió del client al servidor de bases de dades no és UTF8 (unicode)',
+	'Installation_JsTagQuicHelpk' => 'Ajuda ràpida',
+	'Installation_JsTagArchivingHelp' => 'Per a llocs amb un tràfic mitjà o alt, visiteu <a target="" href="http://piwik.org/docs/setup-auto-archiving/">Com configurar una pàgina d\'autoarxivació (en anglès)</a> per tal que el Piwik vagi realment ràpid!',
+	'Installation_SetupWebsiteSetupSuccess' => 'El lloc %s s\'ha creat amb èxit!',
+	'Installation_Requirements' => 'Requeriments del Piwik',
+	'Installation_Optional' => 'Opcional',
+	'Installation_Legend' => 'Llegenda',
+	'Installation_Extension' => 'extensió',
+	'Installation_SystemCheckExtensions' => 'Altres extensions necessàries',
+	'Installation_SystemCheckDatabaseHelp' => 'El Piwik necessita l\'extensió mysqli o ambdues extensións PDO i pdo_mysql.',
+	'Installation_SystemCheckPdoAndMysqliHelp' => 'En un servidor Linux podeu compilar el php amb les següents opcions: %s Al fitxer php.ini, afegiu les línies: %s',
+	'Installation_SystemCheckPhpPdoAndMysqliSite' => 'Trobareu més informació a <a style="color:red" href="http://php.net/pdo">PHP PDO</a> i <a style="color:red" href="http://php.net/mysqli">MYSQLI</a>.',
+	'Installation_SystemCheckWinPdoAndMysqliHelp' => 'En un servidor Windows podeu afegir les línies següents al fitxer php.ini: %s',
+	'Installation_SystemCheckSplHelp' => 'Heu de configurar i recompilar el PHP amb la biblioteca Standard PHP Library (SPL) activada (per defecte).',
+	'Installation_SystemCheckZlibHelp' => 'Heu de configurar i recompilar el PHP amb el suport per a "zlib" habilitat, --with-zlib.',
+	'Installation_SystemCheckJson' => 'JSON',
+	'Installation_SystemCheckJsonHelp' => 'Heu de configurar i recompilar el PHP amb les extensions "json" o "xml" activades.',
+	'Installation_SystemCheckJsonSite' => 'Podeu trobar meś informació a <a style="color:red" href="http://php.net/json">PHP JSON</a>.',
+	'Installation_SystemCheckXml' => 'XML',
+	'Installation_SystemCheckXmlHelp' => 'Alguns connectors de tercers i biblioteques de desenvolupament poden necessitar l\'extensió "xml".',
+	'Installation_SystemCheckXmlSite' => 'Podeu trobar meś informació a <a style="color:red" href="http://php.net/xml">PHP XML</a>.',
+	'Installation_SystemCheckOpenURL' => 'Obre l\'adreça',
+	'Installation_SystemCheckOpenURLHelp' => 'Les subscripcions a les llistes de correu, notificacions d\'actualització i actualitzacions en un clic necessiten l\'extensió "curl", allow_url_fopen=On, o fsockopen() actiu.',
+	'Installation_SystemCheckFunctions' => 'Funcions necessàries',
+	'Installation_SystemCheckMailHelp' => 'Les opinions i els missatges de pèrdua de la contrassenya no s\'enviaran sense la funció mail().',
 	'Login_PluginDescription' => 'Pàgina d\'inici de sessió, dóna les credencials als usuaris',
 	'Login_LoginPasswordNotCorrect' => 'L\'usuari o la contrasenya no són correctes',
 	'Login_Login' => 'Nom d\'usuari',
@@ -294,12 +336,18 @@ $translations = array(
 	'Login_InvalidUsernameEmail' => 'Aquest usuari i/o direcció de correu-e és invàlid.',
 	'Login_MailTopicPasswordRecovery' => 'Recuperació de la contrasenya',
 	'Login_MailBodyPasswordRecovery' => 'Hola %1s! La vostra nova contrasenya és %2s<br />Ara ja podeu iniciar la sessió a %3s',
-	'Login_PasswordSent' => 'La contrasenya s\'acaba d\'enviar. Reviseu el vostre correu-e',
+	'Login_PasswordSent' => 'La informació per a canviar la contrasenya s\'ha enviat. Reviseu el vostre correu-e',
 	'Login_ContactAdmin' => 'Possiblement sigui perquè el vostre proveïdor d\'allotjament ha desactivat la funció mail().<br />Contacteu amb l\'administrador del lloc.',
-	'Login_MailPasswordRecoveryBody' => 'Hola %1s, \n\n La nova contrasenya que teniu és: %2s \n\n Ja podeu iniciar la vostra sessió a %3s',
+	'Login_MailPasswordRecoveryBody' => 'Hola %s, una petició de reinicialització de la contrasenya ha estat rebuda de %s. Per a reiniciar-la: 1)Aneu al formulari de reinicialització de contrasenyes a %s 2)Introduïu el següent codi: %s 3)Ompliu el formulari (introduint la nova contrasenya dos cops) i envieu-lo. Nota: el codi caduca en 24 hores.',
+	'Login_PasswordRepeat' => 'Contrasenya (torneu-la a escriure)',
+	'Login_ChangePassword' => 'Canvia la contrasenya',
+	'Login_PasswordResetToken' => 'Codi de reinicialització de la contrasenya.',
+	'Login_PasswordsDoNotMatch' => 'Les contrasenyes no coincideixen',
+	'Login_PasswordSuccessfullyChanged' => 'La contrasenya ha estat canviada amb èxit!',
+	'Login_InvalidOrExpiredToken' => 'El codi és invàlid o ha caducat',
 	'Provider_WidgetProviders' => 'Proveïdors',
 	'Provider_SubmenuLocationsProvider' => 'Localitzacions i proveïdors',
-	'Provider_ColumnProvider' => '',
+	'Provider_ColumnProvider' => 'Proveïdor',
 	'Referers_SearchEngines' => 'Cercadors',
 	'Referers_Keywords' => 'Paraules clau',
 	'Referers_DirectEntry' => 'Registre directe',
@@ -329,20 +377,20 @@ $translations = array(
 	'Referers_WidgetSearchEngines' => 'Millors motors de cerca',
 	'Referers_WidgetOverview' => 'Resum',
 	'Referers_Referers' => 'Referents',
-	'Referers_MetricsFromRefererTypeGraphLegend' => '',
-	'Referers_ColumnRefererType' => '',
-	'Referers_ColumnSearchEngine' => '',
-	'Referers_ColumnWebsite' => '',
-	'Referers_ColumnWebsitePage' => '',
-	'Referers_ColumnKeyword' => '',
-	'Referers_ColumnCampaign' => '',
-	'Referers_DetailsByRefererType' => '',
-	'Referers_Distinct' => '',
-	'Referers_DistinctSearchEngines' => '',
-	'Referers_DistinctKeywords' => '',
-	'Referers_DistinctCampaigns' => '',
-	'Referers_DistinctWebsites' => '',
-	'Referers_UsingNDistinctUrls' => '',
+	'Referers_MetricsFromRefererTypeGraphLegend' => '%1s (de %2s)',
+	'Referers_ColumnRefererType' => 'Tipus de referent',
+	'Referers_ColumnSearchEngine' => 'Cercador',
+	'Referers_ColumnWebsite' => 'Lloc web',
+	'Referers_ColumnWebsitePage' => 'Pàgina web',
+	'Referers_ColumnKeyword' => 'Paraula clau',
+	'Referers_ColumnCampaign' => 'Campanya',
+	'Referers_DetailsByRefererType' => 'Detalls segons el tipus de referent',
+	'Referers_Distinct' => 'Referents diferents segons el tipus',
+	'Referers_DistinctSearchEngines' => 'cercadors diferents',
+	'Referers_DistinctKeywords' => 'paraules clau diferents',
+	'Referers_DistinctCampaigns' => 'campanyes diferents',
+	'Referers_DistinctWebsites' => 'llocs web diferents',
+	'Referers_UsingNDistinctUrls' => '(fent servir %2s adreces diferents)',
 	'SitesManager_Sites' => 'Llocs',
 	'SitesManager_JsCode' => 'Codi JavaScript',
 	'SitesManager_JsCodeHelp' => 'Aquí teniu el codi JavaScript que heu d\'incloure a totes les pàgines',
@@ -351,15 +399,18 @@ $translations = array(
 	'SitesManager_AddSite' => 'Afegeix un lloc nou',
 	'SitesManager_Id' => 'ID',
 	'SitesManager_Name' => 'Nom',
-	'SitesManager_Urls' => 'URLs',
+	'SitesManager_Urls' => 'Adreces',
 	'SitesManager_MenuSites' => 'Llocs',
 	'SitesManager_DeleteConfirm_js' => 'Realment voleu esborrar el lloc \'%s\'?',
 	'SitesManager_ExceptionDeleteSite' => 'No és possible eliminar aquest lloc ja que és l\'únic configurat. Afegiu un altre lloc primer i, llavors, ja esborrareu aquest.',
 	'SitesManager_ExceptionNoUrl' => 'Heu d\'especificar una URL com a mínim.',
 	'SitesManager_ExceptionEmptyName' => 'El nom del lloc no pot estar buit.',
-	'SitesManager_ExceptionInvalidUrl' => 'La URL \'%s\' no és vàlida.',
+	'SitesManager_ExceptionInvalidUrl' => 'L\'adreça \'%s\' no és vàlida.',
 	'SitesManager_WebsitesManagement' => 'Gestiona els llocs',
-	'SitesManager_MainDescription' => 'Els informes d\'anàlisi web necessiten llocs web! Afegiu, actualitzeu i esborreu-ne. Veieu també el codi JavaScript que heu d\'inserir a les pàgines',
+	'SitesManager_MainDescription' => 'Els informes d\'anàlisi web necessiten llocs web! Afegiu, actualitzeu i esborreu-ne. Veieu també el codi JavaScript que heu d\'inserir a les pàgines.',
+	'SitesManager_JsTrackingTag' => 'Etiqueta de seguiment JavaScript',
+	'SitesManager_JsTrackingTagHelp' => 'Aquí teniu l\'etiqueta de seguiment JavaScript per tal d\'incloure-la a totes les pàgines',
+	'SitesManager_ShowTrackingTag' => 'mostra l\'etiqueta de seguiment',
 	'TranslationsAdmin_MenuTranslations' => 'Traduccions',
 	'TranslationsAdmin_MenuLanguages' => 'Idiomes',
 	'TranslationsAdmin_Plugin' => 'Connector',
@@ -519,11 +570,11 @@ $translations = array(
 	'UserCountry_country_mg' => 'Madagascar',
 	'UserCountry_country_mh' => 'Illes Marshall',
 	'UserCountry_country_mk' => 'Macedònia',
-	'UserCountry_country_ml' => 'Mañi',
+	'UserCountry_country_ml' => 'Mali',
 	'UserCountry_country_mm' => 'Myanmar',
 	'UserCountry_country_mn' => 'Mongòlia',
 	'UserCountry_country_mo' => 'Macau',
-	'UserCountry_country_mp' => 'Illes Mariannes Septentrionals',
+	'UserCountry_country_mp' => 'Illes Marianes Septentrionals',
 	'UserCountry_country_mq' => 'Martinica',
 	'UserCountry_country_mr' => 'Mauritània',
 	'UserCountry_country_ms' => 'Montserrat',
@@ -540,7 +591,7 @@ $translations = array(
 	'UserCountry_country_nf' => 'Illa Norfolk',
 	'UserCountry_country_ng' => 'Nigèria',
 	'UserCountry_country_ni' => 'Nicaragua',
-	'UserCountry_country_nl' => 'Pa&iuml;sos Baixos',
+	'UserCountry_country_nl' => 'Països Baixos',
 	'UserCountry_country_no' => 'Noruega',
 	'UserCountry_country_np' => 'Nepal',
 	'UserCountry_country_nr' => 'Nauru',
@@ -652,7 +703,7 @@ $translations = array(
 	'UserSettings_Browsers' => 'Navegadors',
 	'UserSettings_Plugins' => 'Connectors',
 	'UserSettings_Configurations' => 'Configuracions',
-	'UserSettings_OperatinsSystems' => 'Sistemes operatius',
+	'UserSettings_OperatingSystems' => 'Sistemes operatius',
 	'UserSettings_Resolutions' => 'Resolucions',
 	'UserSettings_WideScreen' => 'Pantalla panoràmica',
 	'UserSettings_WidgetResolutions' => 'Resoulucions',
@@ -663,14 +714,14 @@ $translations = array(
 	'UserSettings_WidgetOperatingSystems' => 'Sistemes operatius',
 	'UserSettings_WidgetGlobalVisitors' => 'Configuracions globals dels visitants',
 	'UserSettings_SubmenuSettings' => 'Configuracions',
-	'UserSettings_VisitorSettings' => '',
-	'UserSettings_ColumnBrowserFamily' => '',
-	'UserSettings_ColumnBrowser' => '',
-	'UserSettings_ColumnPlugin' => '',
-	'UserSettings_ColumnConfiguration' => '',
-	'UserSettings_ColumnOperatinsSystem' => '',
-	'UserSettings_ColumnResolution' => '',
-	'UserSettings_ColumnTypeOfScreen' => '',
+	'UserSettings_VisitorSettings' => 'Configuració del visitant',
+	'UserSettings_ColumnBrowserFamily' => 'Família del navegador',
+	'UserSettings_ColumnBrowser' => 'Navegador',
+	'UserSettings_ColumnPlugin' => 'Connector',
+	'UserSettings_ColumnConfiguration' => 'Configuració',
+	'UserSettings_ColumnOperatingSystem' => 'Sistema operatiu',
+	'UserSettings_ColumnResolution' => 'Resolució',
+	'UserSettings_ColumnTypeOfScreen' => 'Tipus de pantalla',
 	'UsersManager_ManageAccess' => 'Gestiona els permisos',
 	'UsersManager_Sites' => 'Llocs',
 	'UsersManager_AllWebsites' => 'Tots els llocs',
@@ -703,22 +754,22 @@ $translations = array(
 Podeu configurar els seus permisos a dalt.',
 	'UsersManager_MainDescription' => 'Decidiu quin tipus d\'accés té cada usuari al Piwik. També podeu configurar tots els llocs web de cop.',
 	'UsersManager_ExceptionInvalidLoginFormat' => 'El nom d\'usuari ha de tenir una longitud d\'entre %s i %s caràcters i estar format únicament per lletres, xifres o els caràcters \'_\', \'-\' o \'.\'',
-	'UsersManager_ExceptionSuperUser' => '',
+	'UsersManager_ExceptionSuperUser' => 'Aquest és el superusuari i no es pot consultar, editar o esborrar mitjançant l\'API. Podeu editar-lo manualment en el fitxer de configuració del Piwik.',
 	'VisitFrequency_Evolution' => 'Evolució del període',
-	'VisitFrequency_ReturnVisits' => 'Han tornat %s visites',
-	'VisitFrequency_ReturnActions' => 'Les visites que han tornat han fet %s accions',
-	'VisitFrequency_ReturnMaxActions' => 'Una visita que ha tornat ha fet un màxim de %s accions',
-	'VisitFrequency_ReturnTotalTime' => '%s de temps que han fet servir les visites que han tornat',
+	'VisitFrequency_ReturnVisits' => 'Han tornat %s visitants',
+	'VisitFrequency_ReturnActions' => 'Els visitants que han tornat han fet %s accions',
+	'VisitFrequency_ReturnMaxActions' => 'Un visitant que ha tornat ha fet un màxim de %s accions',
+	'VisitFrequency_ReturnTotalTime' => 'Els visitants que han tornat han estat %s',
 	'VisitFrequency_ReturnBounces' => 'Una visita que ha tornat ha rebotat %s cops (ha abandonat el lloc després de veure només una pàgina)',
-	'VisitFrequency_WidgetOverview' => 'Resum de la freq&uuml;ència',
+	'VisitFrequency_WidgetOverview' => 'Resum de la freqüència',
 	'VisitFrequency_WidgetGraphReturning' => 'Gràfic de les visites que han tornat',
-	'VisitFrequency_SubmenuFrequency' => 'Freq&uuml;ència',
-	'VisitFrequency_ColumnReturningVisits' => '',
-	'VisitFrequency_ColumnActionsByReturningVisits' => '',
-	'VisitFrequency_ColumnMaximumActionsByAReturningVisit' => '',
-	'VisitFrequency_ColumnTotalTimeSpentByReturningVisits' => '',
-	'VisitFrequency_ColumnBounceRateForReturningVisits' => '',
-	'VisitFrequency_ReturnBounceRate' => '',
+	'VisitFrequency_SubmenuFrequency' => 'Freqüència',
+	'VisitFrequency_ColumnReturningVisits' => 'Visitants que retornen (antics)',
+	'VisitFrequency_ColumnActionsByReturningVisits' => 'Accions dels visitants antics',
+	'VisitFrequency_ColumnMaximumActionsByAReturningVisit' => 'Quantitat màxima d\'accions fetes per un visitant antic',
+	'VisitFrequency_ColumnTotalTimeSpentByReturningVisits' => 'Temps total que ha passat un visitant antic (en segons)',
+	'VisitFrequency_ColumnBounceRateForReturningVisits' => 'Raó de rebots',
+	'VisitFrequency_ReturnBounceRate' => '%s visitants antics han rebotat (abandonat el lloc després de veure una pàgina)',
 	'VisitorInterest_VisitsPerDuration' => 'Visites segons la durada',
 	'VisitorInterest_VisitsPerNbOfPages' => 'Visites segons el nombre de pàgines',
 	'VisitorInterest_WidgetLengths' => 'Durada de les visites',
@@ -729,8 +780,8 @@ Podeu configurar els seus permisos a dalt.',
 	'VisitorInterest_OnePage' => '1 pàgina',
 	'VisitorInterest_NPages' => '%s pàgines',
 	'VisitorInterest_BetweenXYSeconds' => '%1s-%2ss',
-	'VisitorInterest_ColumnVisitDuration' => '',
-	'VisitorInterest_ColumnPagesPerVisit' => '',
+	'VisitorInterest_ColumnVisitDuration' => 'Durada de la visita',
+	'VisitorInterest_ColumnPagesPerVisit' => 'Pàgines per visita',
 	'VisitsSummary_NbVisits' => '%s visites',
 	'VisitsSummary_NbUniqueVisitors' => '%s visitants únics',
 	'VisitsSummary_NbActions' => '%s accions (pàgines vistes)',
@@ -746,14 +797,15 @@ Podeu configurar els seus permisos a dalt.',
 	'VisitsSummary_WidgetLastVisitors' => 'Gràfic dels darrers visitants únics',
 	'VisitsSummary_WidgetOverviewGraph' => 'Resum amb gràfic',
 	'VisitsSummary_SubmenuOverview' => 'Resum',
-	'VisitsSummary_NbVisitsBounced' => '',
-	'VisitsSummary_EvolutionOverLastPeriods' => '',
+	'VisitsSummary_NbVisitsBounced' => '%s visites han rebotat (abandonat el lloc després de veure una pàgina)',
+	'VisitsSummary_EvolutionOverLastPeriods' => 'Evolució dels darrers %s',
+	'VisitsSummary_VisitsSummary' => 'Resum de les visites',
 	'VisitTime_LocalTime' => 'Visites segons l\'hora local',
 	'VisitTime_ServerTime' => 'Visites segons l\'hora del servidor',
 	'VisitTime_WidgetLocalTime' => 'Visites segons l\'hora local',
 	'VisitTime_WidgetServerTime' => 'Visites segons l\'hora del servidor',
 	'VisitTime_SubmenuTimes' => 'Hores',
 	'VisitTime_NHour' => '%sh',
-	'VisitTime_ColumnServerTime' => '',
-	'VisitTime_ColumnLocalTime' => '',
-);
\ No newline at end of file
+	'VisitTime_ColumnServerTime' => 'Hora del servidor',
+	'VisitTime_ColumnLocalTime' => 'Hora local',
+);
