@@ -138,25 +138,51 @@ $translations = array(
 	'CoreHome_PeriodWeeks' => 'týdnů',
 	'CoreHome_PeriodMonths' => 'měsíců',
 	'CoreHome_PeriodYears' => 'let',
-	'CoreHome_DaySu_js' => 'Ne',
-	'CoreHome_DayMo_js' => 'Po',
-	'CoreHome_DayTu_js' => 'Út',
-	'CoreHome_DayWe_js' => 'St',
-	'CoreHome_DayTh_js' => 'Čt',
-	'CoreHome_DayFr_js' => 'Pá',
-	'CoreHome_DaySa_js' => 'So',
-	'CoreHome_MonthJanuary_js' => 'Leden',
-	'CoreHome_MonthFebruary_js' => 'Únor',
-	'CoreHome_MonthMarch_js' => 'Březen',
-	'CoreHome_MonthApril_js' => 'Duben',
-	'CoreHome_MonthMay_js' => 'Květen',
-	'CoreHome_MonthJune_js' => 'Červen',
-	'CoreHome_MonthJuly_js' => 'Červenec',
-	'CoreHome_MonthAugust_js' => 'Srpen',
-	'CoreHome_MonthSeptember_js' => 'Záři',
-	'CoreHome_MonthOctober_js' => 'Říjen',
-	'CoreHome_MonthNovember_js' => 'Listopad',
-	'CoreHome_MonthDecember_js' => 'Prosinec',
+	'CoreHome_DaySu_js' => 'ne',
+	'CoreHome_DayMo_js' => 'po',
+	'CoreHome_DayTu_js' => 'út',
+	'CoreHome_DayWe_js' => 'st',
+	'CoreHome_DayTh_js' => 'čt',
+	'CoreHome_DayFr_js' => 'pá',
+	'CoreHome_DaySa_js' => 'so',
+	'CoreHome_ShortDay_1_js' => 'ne',
+	'CoreHome_ShortDay_2_js' => 'po',
+	'CoreHome_ShortDay_3_js' => 'út',
+	'CoreHome_ShortDay_4_js' => 'st',
+	'CoreHome_ShortDay_5_js' => 'čt',
+	'CoreHome_ShortDay_6_js' => 'pá',
+	'CoreHome_ShortDay_7_js' => 'so',
+	'CoreHome_LongDay_1_js' => 'neděle',
+	'CoreHome_LongDay_2_js' => 'pondělí',
+	'CoreHome_LongDay_3_js' => 'úterý',
+	'CoreHome_LongDay_4_js' => 'středa',
+	'CoreHome_LongDay_5_js' => 'čtvrtek',
+	'CoreHome_LongDay_6_js' => 'pátek',
+	'CoreHome_LongDay_7_js' => 'sobota',
+	'CoreHome_ShortMonth_1_js' => 'led',
+	'CoreHome_ShortMonth_2_js' => 'úno',
+	'CoreHome_ShortMonth_3_js' => 'bře',
+	'CoreHome_ShortMonth_4_js' => 'dub',
+	'CoreHome_ShortMonth_5_js' => 'kvě',
+	'CoreHome_ShortMonth_6_js' => 'čer',
+	'CoreHome_ShortMonth_7_js' => 'čvc',
+	'CoreHome_ShortMonth_8_js' => 'srp',
+	'CoreHome_ShortMonth_9_js' => 'zář',
+	'CoreHome_ShortMonth_10_js' => 'říj',
+	'CoreHome_ShortMonth_11_js' => 'lis',
+	'CoreHome_ShortMonth_12_js' => 'pro',
+	'CoreHome_MonthJanuary_js' => 'leden',
+	'CoreHome_MonthFebruary_js' => 'únor',
+	'CoreHome_MonthMarch_js' => 'březen',
+	'CoreHome_MonthApril_js' => 'duben',
+	'CoreHome_MonthMay_js' => 'květen',
+	'CoreHome_MonthJune_js' => 'červen',
+	'CoreHome_MonthJuly_js' => 'červenec',
+	'CoreHome_MonthAugust_js' => 'srpen',
+	'CoreHome_MonthSeptember_js' => 'září',
+	'CoreHome_MonthOctober_js' => 'říjen',
+	'CoreHome_MonthNovember_js' => 'listopad',
+	'CoreHome_MonthDecember_js' => 'prosinec',
 	'CoreUpdater_UpdateTitle' => 'Piwik &rsaquo; Update',
 	'CoreUpdater_DatabaseUpgradeRequired' => 'Vyžadováno povýšení databáze',
 	'CoreUpdater_YourDatabaseIsOutOfDate' => 'Vaše databáze Piwiku jw zastaralá a musí být aktualizována než budete pokračovat.',
@@ -247,14 +273,14 @@ $translations = array(
 	'UserSettings_Browsers' => 'WWW prohlížeče',
 	'UserSettings_Plugins' => 'Pluginy',
 	'UserSettings_Configurations' => 'Nastavení',
-	'UserSettings_OperatinsSystems' => 'Operační systémy',
+	'UserSettings_OperatingSystems' => 'Operační systémy',
 	'UserSettings_Resolutions' => 'Rozlišení',
 	'UserSettings_WideScreen' => 'Širokoúhlá obrazovka',
 	'UserSettings_ColumnBrowserFamily' => 'Rodina WWW prohlížeče',
 	'UserSettings_ColumnBrowser' => 'WWW prohlížeč',
 	'UserSettings_ColumnPlugin' => 'Plugin',
 	'UserSettings_ColumnConfiguration' => 'Konfigurace',
-	'UserSettings_ColumnOperatinsSystem' => 'Operační systém',
+	'UserSettings_ColumnOperatingSystem' => 'Operační systém',
 	'UserSettings_ColumnResolution' => 'Rozlišení',
 	'UserSettings_ColumnTypeOfScreen' => 'Typ obrazovky',
 	'UserSettings_WidgetResolutions' => 'Rozlišení obrazovky',
@@ -585,7 +611,7 @@ $translations = array(
 	'VisitorInterest_WidgetPages' => 'Stránek za návštěvu',
 	'VisitorInterest_SubmenuFrequencyLoyalty' => 'Frekvence & věrnost',
 	'VisitorInterest_PlusXMin' => '%s min',
-	'VisitorInterest_BetweenXYMinutes' => '%1s-%2s min',
+	'VisitorInterest_BetweenXYMinutes' => '%1s-%1s min',
 	'VisitorInterest_OnePage' => '1 stránka',
 	'VisitorInterest_NPages' => '%s stránek',
 	'VisitorInterest_BetweenXYSeconds' => '%1s-%2ss',
