@@ -25,8 +25,8 @@ $translations = array(
 'General_Close' => 'Luk',
 'General_Logout' => 'Log af',
 'General_Done' => 'Færdig',
-'General_LoadingData' => 'Henter data...',
-'General_Loading' => 'Henter...',
+'General_LoadingData' => 'Indlæser data...',
+'General_Loading' => 'Indlæser...',
 'General_ErrorRequest' => 'Oops&hellip; problemer, prøv igen.',
 'General_Next' => 'Næste',
 'General_Previous' => 'Forrige',
@@ -46,7 +46,7 @@ $translations = array(
 'General_ColumnNbActions' => 'Handlinger',
 'General_ColumnMaxActions' => 'Max handlinger i et besøg',
 'General_ColumnSumVisitLength' => 'Total tid brugt af besøgende visitors (i sekunder)',
-'General_ColumnLabel' => 'Titel',
+'General_ColumnLabel' => 'Etiket',
 'General_ColumnActionsPerVisit' => 'Handlinger pr. besøg',
 'General_ColumnAvgTimeOnSite' => 'Gennemsnitstid på netsted',
 'General_ColumnBounceRate' => 'Afvisningsfrekvens',
@@ -54,12 +54,12 @@ $translations = array(
 'General_ColumnUniquePageviews' => 'Unikke sidevisninger',
 'General_ColumnValuePerVisit' => 'Værdi pr. besøg',
 'General_ColumnVisitsWithConversions' => 'Besøg med konverteringer',
-'General_Save' => 'Gemme',
+'General_Save' => 'Gem',
 'General_Website' => 'Side',
 'General_NoDataForGraph' => 'Ingen data endnu',
 'General_NoDataForTagCloud' => 'Ingen data for emnesky.',
 'General_DisplayNormalTable' => 'Vis normal tabel',
-'General_DisplayMoreData' => 'Vis mere information',
+'General_DisplayMoreData' => 'Vis flere data',
 'General_PiwikIsACollaborativeProjectYouCanContribute' => '%s Piwik %s er et åbent kodeprojekt (OS). %s Hvis du vil hjælpe, så se: %s Hvordan kan man bidrage til Piwik?%s.',
 'General_YouAreCurrentlyViewingDemoOfPiwik' => 'Du bruger en demo af %s; %shent%s fuld version! Se %s',
 'General_PiwikXIsAvailablePleaseUpdateNow' => 'Piwik %s er udkommet. %s Opdater nu!%s (se %s ændringer%s).',
@@ -118,17 +118,17 @@ $translations = array(
 'CorePluginsAdmin_Deactivate' => 'Deaktiver',
 'CorePluginsAdmin_Activate' => 'Aktiver',
 'CorePluginsAdmin_MenuPlugins' => 'Plugins',
-'API_QuickDocumentation' => '<h2>API - hurtig i  gang dokumentation</h2><p>Hvis du ikke har data før i \'dag\' kan du <a href=\'misc/generateVisits.php\' target=_blank>genere data</a> med besøgsgeneratoren.</p><p>Du kan prøve de forskellige formater der findes for de forskellige metoder. Det er meget let at udtrække data som ønsket fra Piwik!</p><p><b>Mere information findes på den <a href=\'http://dev.piwik.org/trac/wiki/API\'>officiellle API dokumentation </a>side eller her <a href=\'http://dev.piwik.org/trac/wiki/API/Reference\'>API reference</a>.</b></P><h2>Bruger authentication</h2><p>Hvis du ønsker at <b>hente data i scripts, i crontab, m.m. </b> skal du tilføje parameteren <code><u>&token_auth=%s</u></code> til API kaldets URLs som kræver authentication.</p><p>token_auth er ligeså hemmeligt som brugernavn og adgangskode, <b>del det ikke ud!</p>',
+'API_QuickDocumentation' => '<h2>API - hurtig i  gang dokumentation</h2><p>Hvis du ikke har data før i \'dag\' kan du <a href=\'misc/generateVisits.php\' target=_blank>genere data</a> med besøgsgeneratoren.</p><p>Du kan prøve de forskellige formater der findes for de forskellige metoder. Det er meget let at udtrække data som ønsket fra Piwik!</p><p><b>Mere information findes på den <a href=\'http://dev.piwik.org/trac/wiki/API\'>officiellle API dokumentation </a>side eller her <a href=\'http://dev.piwik.org/trac/wiki/API/Reference\'>API reference</a>.</b></P><h2>Bruger authentication</h2><p>Hvis du ønsker at <b>hente data i scripts, i crontab, m.m. </b> skal du tilføje parameteren <code><u>&token_auth=%s</u></code> til API kaldets webadresse som kræver authentication.</p><p>token_auth er ligeså hemmeligt som brugernavn og adgangskode, <b>del det ikke ud!</p>',
 'API_LoadedAPIs' => '%s APIs indlæst',
 'CoreHome_NoPrivileges' => 'Du er logget på som \'%s\' men det ser ikke ud som du har adgang til Piwik.<br />Spørg Piwik administrator om læseadgang.',
 'CoreHome_JavascriptDisabled' => 'JavaSript skal være aktiveret for at Piwik kan bruges i standardvisning. JavaScript er enten deaktiver eller ikke understøttet i netlæseren.<br />For at bruge standardvisning, aktiver JavaScript i indstillingerne for netlæseren, og %1s prøv igen %2s.<br />',
 'CoreHome_TableNoData' => 'Ingen data endnu.',
 'CoreHome_CategoryNoData' => 'Ingen data i kategorien. Prøv at \'Inkluder hele populationen\'.',
 'CoreHome_ShowJSCode' => 'Vis JavaScript-koden til at indsætte på websiden.',
-'CoreHome_IncludeAllPopulation_js' => 'Vis alle data',
-'CoreHome_ExcludeLowPopulation_js' => 'Skjul enkelte data',
+'CoreHome_IncludeAllPopulation_js' => 'Medtag alle data',
+'CoreHome_ExcludeLowPopulation_js' => 'Skjul mindste data',
 'CoreHome_PageOf_js' => '%s af %s',
-'CoreHome_Loading_js' => 'Henter...',
+'CoreHome_Loading_js' => 'Indlæser...',
 'CoreHome_DayFormat' => '%longDay% %day% %longMonth% %longYear%',
 'CoreHome_PeriodDay' => 'Dag',
 'CoreHome_PeriodWeek' => 'Uge',
@@ -138,13 +138,39 @@ $translations = array(
 'CoreHome_PeriodWeeks' => 'uger',
 'CoreHome_PeriodMonths' => 'måneder',
 'CoreHome_PeriodYears' => 'år',
-'CoreHome_DaySu_js' => 'Søn',
-'CoreHome_DayMo_js' => 'Man',
-'CoreHome_DayTu_js' => 'Tir',
-'CoreHome_DayWe_js' => 'Ons',
-'CoreHome_DayTh_js' => 'Tor',
-'CoreHome_DayFr_js' => 'Fre',
-'CoreHome_DaySa_js' => 'Lør',
+'CoreHome_DaySu_js' => 'Sø',
+'CoreHome_DayMo_js' => 'Ma',
+'CoreHome_DayTu_js' => 'Ti',
+'CoreHome_DayWe_js' => 'On',
+'CoreHome_DayTh_js' => 'To',
+'CoreHome_DayFr_js' => 'Fr',
+'CoreHome_DaySa_js' => 'Lø',
+'CoreHome_ShortDay_1_js' => 'Søn',
+'CoreHome_ShortDay_2_js' => 'Man',
+'CoreHome_ShortDay_3_js' => 'Tir',
+'CoreHome_ShortDay_4_js' => 'Ons',
+'CoreHome_ShortDay_5_js' => 'Tor',
+'CoreHome_ShortDay_6_js' => 'Fre',
+'CoreHome_ShortDay_7_js' => 'Lør',
+'CoreHome_LongDay_1_js' => 'Søndag',
+'CoreHome_LongDay_2_js' => 'Mandag',
+'CoreHome_LongDay_3_js' => 'Tirsdag',
+'CoreHome_LongDay_4_js' => 'Onsdag',
+'CoreHome_LongDay_5_js' => 'Torsdag',
+'CoreHome_LongDay_6_js' => 'Fredag',
+'CoreHome_LongDay_7_js' => 'Lørdag',
+'CoreHome_ShortMonth_1_js' => 'Jan',
+'CoreHome_ShortMonth_2_js' => 'Feb',
+'CoreHome_ShortMonth_3_js' => 'Mar',
+'CoreHome_ShortMonth_4_js' => 'Apr',
+'CoreHome_ShortMonth_5_js' => 'Maj',
+'CoreHome_ShortMonth_6_js' => 'Jun',
+'CoreHome_ShortMonth_7_js' => 'Jul',
+'CoreHome_ShortMonth_8_js' => 'Aug',
+'CoreHome_ShortMonth_9_js' => 'Sep',
+'CoreHome_ShortMonth_10_js' => 'Okt',
+'CoreHome_ShortMonth_11_js' => 'Nov',
+'CoreHome_ShortMonth_12_js' => 'Dec',
 'CoreHome_MonthJanuary_js' => 'Januar',
 'CoreHome_MonthFebruary_js' => 'Februar',
 'CoreHome_MonthMarch_js' => 'Marts',
@@ -159,31 +185,31 @@ $translations = array(
 'CoreHome_MonthDecember_js' => 'December',
 'CoreUpdater_UpdateTitle' => 'Piwik &rsaquo; opdatering',
 'CoreUpdater_DatabaseUpgradeRequired' => 'Database opdatering er nødvendig',
-'CoreUpdater_YourDatabaseIsOutOfDate' => 'Piwik databasen er opdateret, og skal opgraderes før der kan fortsættes.',
-'CoreUpdater_PiwikWillBeUpgradedFromVersionXToVersionY' => 'Piwik vil blive opgraderet fra version %s til version %s.',
+'CoreUpdater_YourDatabaseIsOutOfDate' => 'Piwik databasen er ikke opdateret, og skal opgraderes før du kan fortsættes.',
+'CoreUpdater_PiwikWillBeUpgradedFromVersionXToVersionY' => 'Piwik vil blive opgraderet fra version %s til version den nye %s.',
 'CoreUpdater_TheFollowingPluginsWillBeUpgradedX' => 'Følgende plugins vil blive opgraderet: %s.',
 'CoreUpdater_TheUpgradeProcessMayTakeAWhilePleaseBePatient' => 'Opgraderingen kan tage lidt tid, vær tålmodig.',
 'CoreUpdater_UpgradePiwik' => 'Opgrader Piwik',
-'CoreUpdater_HelpMessageContent' => 'se %s Piwik FAQ %s som forklarer de mest hyppige fejl om opgraderinger. %s Spørg systemadministratoren - vedkommende kan måske hjælpe med fejlen som sikkert har at skyldes server eller MySQL-installation/opsætning.',
-'CoreUpdater_CriticalErrorDuringTheUpgradeProcess' => 'Kritisk fejl med opgraderingen:',
+'CoreUpdater_HelpMessageContent' => 'se %s Piwik FAQ %s som forklarer de mest almindelige fejl om opdateringer. %s Spørg systemadministratoren - vedkommende kan måske hjælpe med fejlen som sikkert har at skyldes server eller MySQL-installation/opsætning.',
+'CoreUpdater_CriticalErrorDuringTheUpgradeProcess' => 'Kritisk fejl med opdateringen:',
 'CoreUpdater_HelpMessageIntroductionWhenError' => 'ovenfor vises fejlmeldingen. Den bør hjælpe med at forklare årsagen, men hvis der behøves mere hjælp:',
-'CoreUpdater_HelpMessageIntroductionWhenWarning' => 'Opgraderingen er fuldført, men det var nogle småproblemer under processen. Læs detaljerne ovenfor. For videre hjælp:',
+'CoreUpdater_HelpMessageIntroductionWhenWarning' => 'Opdateringen er fuldført, men det var nogle småproblemer under processen. Læs detaljerne ovenfor. For videre hjælp:',
 'CoreUpdater_UpgradeComplete' => 'Opgradering fuldført!',
 'CoreUpdater_WarningMessages' => 'Advarsler:',
-'CoreUpdater_ErrorDuringPluginsUpdates' => 'Fejl under plugin opgradering:',
+'CoreUpdater_ErrorDuringPluginsUpdates' => 'Fejl under plugin opdatering:',
 'CoreUpdater_WeAutomaticallyDeactivatedTheFollowingPlugins' => 'Vil automatisk deaktivere følgende plugins: %s',
-'CoreUpdater_PiwikHasBeenSuccessfullyUpgraded' => 'Piwik blev opgraderet!',
+'CoreUpdater_PiwikHasBeenSuccessfullyUpgraded' => 'Piwik blev opdateret!',
 'CoreUpdater_ContinueToPiwik' => 'Fortsæt til Piwik',
 'CoreUpdater_UpdateAutomatically' => 'Opdater automatisk',
 'CoreUpdater_ThereIsNewVersionAvailableForUpdate' => 'Ny version af Piwik tilgængelig for opdatering',
 'CoreUpdater_YouCanUpgradeAutomaticallyOrDownloadPackage' => 'Opdater til version %s automatisk eller hent programpakken og installer manuelt:',
 'CoreUpdater_DownloadX' => 'Hent %s',
-'CoreUpdater_UpdateHasBeenCancelledExplanation' => 'Piwik et klik opdatering er blevet annulleret. Kan ovenstående fejlmeddelelse ike løses, anbefales det at opdatere Piwik manuelt. %s Læs %sOpdaterings dokumentationen%s for at komme i gang!',
+'CoreUpdater_UpdateHasBeenCancelledExplanation' => 'Piwik ét klik-opdatering er blevet annulleret. Kan ovenstående fejlmeddelelse ike løses, anbefales det at opdatere Piwik manuelt. %s Læs %sOpdaterings dokumentationen%s for at komme i gang!',
 'CoreUpdate_DownloadingUpdateFromX' => 'Henter opdatering fra %s',
 'CoreUpdate_UnpackingTheUpdate' => 'Opdatering pakkes ud',
 'CoreUpdater_VerifyingUnpackedFiles' => 'Kontrollerer filer',
 'CoreUpdater_CreatingBackupOfConfigurationFile' => 'Backup af konfigurationfiler i %s',
-'CoreUpdater_InstallingTheLatestVersion' => 'Installerer nyester version',
+'CoreUpdater_InstallingTheLatestVersion' => 'Installerer den nyeste version',
 'CoreUpdater_PiwikUpdatedSuccessfully' => 'Piwik er opdateret!',
 'Actions_Actions' => 'Handlinger',
 'Actions_SubmenuPages' => 'Sider',
@@ -194,8 +220,8 @@ $translations = array(
 'Actions_ColumnDownloads' => 'Filhentninger',
 'Actions_ColumnUniqueDownloads' => 'Unikke filhentninger',
 'Actions_ColumnPageName' => 'Sidenavn',
-'Actions_ColumnClickedURL' => 'Klik URL',
-'Actions_ColumnDownloadURL' => 'Download URL',
+'Actions_ColumnClickedURL' => 'Klikkede på webadresser',
+'Actions_ColumnDownloadURL' => 'Download webadresser',
 'Dashboard_Dashboard' => 'Kontrolpanel',
 'Dashboard_AddWidget' => 'Tilføj en widget...',
 'Dashboard_DeleteWidgetConfirm' => 'Bekræft fjernelse af widget fra kontrolpanelet?',
@@ -204,12 +230,12 @@ $translations = array(
 'Dashboard_WidgetPreview_js' => 'Forhåndsvisning af widget',
 'Dashboard_Close_js' => 'Luk',
 'Dashboard_TitleWidgetInDashboard_js' => 'Widget er allerede i kontrolpanelet',
-'Dashboard_TitleClickToAdd_js' => 'Klik her for at tilføje til kontrolpanelet',
-'Dashboard_LoadingWidget_js' => 'Henter Widget, vent...',
+'Dashboard_TitleClickToAdd_js' => 'Klik for at tilføje til kontrolpanelet',
+'Dashboard_LoadingWidget_js' => 'Indlæser Widget, vent...',
 'Dashboard_WidgetNotFound_js' => 'Fandt ikke widget',
 'Referers_Referers' => 'Henvisninger',
-'Referers_SearchEngines' => 'Søgemotor',
-'Referers_Keywords' => 'Nøgleord',
+'Referers_SearchEngines' => 'Søgemaskine',
+'Referers_Keywords' => ' Top søgeord',
 'Referers_DirectEntry' => 'Direkte træf',
 'Referers_Websites' => 'Websider',
 'Referers_Campaigns' => 'Kampagner',
@@ -217,44 +243,44 @@ $translations = array(
 'Referers_Evolution' => 'Udvikling over perioden',
 'Referers_Type' => 'Kilde type',
 'Referers_ColumnRefererType' => 'Henvisningstype',
-'Referers_ColumnSearchEngine' => 'Søge motor',
+'Referers_ColumnSearchEngine' => 'Søgemaskine',
 'Referers_ColumnWebsite' => 'Websted',
 'Referers_ColumnWebsitePage' => 'Websider',
-'Referers_ColumnKeyword' => 'Nøgleord',
+'Referers_ColumnKeyword' => 'Søgeord',
 'Referers_ColumnCampaign' => 'Kampagner',
 'Referers_DetailsByRefererType' => 'Detaljer efter kildetype',
 'Referers_TypeDirectEntries' => '%s direkte træf',
-'Referers_TypeSearchEngines' => '%s fra søgemotorer',
+'Referers_TypeSearchEngines' => '%s fra søgemaskine',
 'Referers_TypeWebsites' => '%s fra websider',
 'Referers_TypeCampaigns' => '%s fra kampagner',
 'Referers_Distinct' => 'Distinkte kilder efter kildetype',
-'Referers_DistinctSearchEngines' => '%s distinkte søgemotorer',
-'Referers_DistinctKeywords' => '%s distinkte nøgleord',
+'Referers_DistinctSearchEngines' => '%s distinkte søgemaskine',
+'Referers_DistinctKeywords' => '%s distinkte søgeord',
 'Referers_DistinctCampaigns' => 'distinkte kampagner',
 'Referers_DistinctWebsites' => 'Distinkte websider ',
-'Referers_UsingNDistinctUrls' => ' (bruger %2s distinkte URLs)',
+'Referers_UsingNDistinctUrls' => ' (bruger %2s distinkte webadresser)',
 'Referers_SubmenuEvolution' => 'Udvikling',
-'Referers_SubmenuSearchEngines' => 'Søgemotorer og nøgleord',
+'Referers_SubmenuSearchEngines' => 'Søgemaskine og søgeord',
 'Referers_SubmenuWebsites' => 'Websider',
 'Referers_SubmenuCampaigns' => 'Kampagner',
-'Referers_WidgetKeywords' => 'Nøgleord',
+'Referers_WidgetKeywords' => 'Søgeord',
 'Referers_WidgetCampaigns' => 'Kampagner',
 'Referers_WidgetExternalWebsites' => 'Eksterne henvisninger',
-'Referers_WidgetSearchEngines' => 'Bedste søgemotorer',
+'Referers_WidgetSearchEngines' => 'Top søgemaskine',
 'Referers_WidgetOverview' => 'Oversigt',
 'UserSettings_VisitorSettings' => 'Besøgendes indstillinger',
 'UserSettings_BrowserFamilies' => 'Netlæsertyper',
 'UserSettings_Browsers' => 'Netlæsere',
 'UserSettings_Plugins' => 'Plugins',
 'UserSettings_Configurations' => 'Indstillinger',
-'UserSettings_OperatinsSystems' => 'Operativsystemer',
+'UserSettings_OperatingSystems' => 'Styresystemer',
 'UserSettings_Resolutions' => 'Opløsninger',
 'UserSettings_WideScreen' => 'Widescreen',
 'UserSettings_ColumnBrowserFamily' => 'Netlæsertype',
 'UserSettings_ColumnBrowser' => 'Netlæser',
 'UserSettings_ColumnPlugin' => 'Plugin',
 'UserSettings_ColumnConfiguration' => 'Konfiguration',
-'UserSettings_ColumnOperatinsSystem' => 'Operativ system',
+'UserSettings_ColumnOperatingSystem' => 'Styresystem',
 'UserSettings_ColumnResolution' => 'Opløsning',
 'UserSettings_ColumnTypeOfScreen' => 'Skærmtype',
 'UserSettings_WidgetResolutions' => 'Skærmopløsninger',
@@ -262,7 +288,7 @@ $translations = array(
 'UserSettings_WidgetPlugins' => 'Plugins',
 'UserSettings_WidgetWidescreen' => 'Normal/Widescreen',
 'UserSettings_WidgetBrowserFamilies' => 'Netlæsere efter type',
-'UserSettings_WidgetOperatingSystems' => 'Operativsystemer',
+'UserSettings_WidgetOperatingSystems' => 'Styresystemer',
 'UserSettings_WidgetGlobalVisitors' => 'Besøgendes konfiguration',
 'UserSettings_SubmenuSettings' => 'Indstillinger',
 'UserCountry_Country' => 'Land',
@@ -543,32 +569,32 @@ $translations = array(
 'VisitsSummary_NbVisits' => '%s besøg',
 'VisitsSummary_NbUniqueVisitors' => '%s unikke besøgende',
 'VisitsSummary_NbActions' => '%s handlinger (sidevisninger)',
-'VisitsSummary_TotalTime' => '%s total tid brugt af besøgende',
-'VisitsSummary_MaxNbActions' => '%s maks. handlinger i et besøg',
-'VisitsSummary_NbVisitsBounced' => '%s har forladt websted efter en sidevisning',
+'VisitsSummary_TotalTime' => '%s samlet tid brugt af besøgende',
+'VisitsSummary_MaxNbActions' => '%s maks. handlinger i ét besøg',
+'VisitsSummary_NbVisitsBounced' => '%s har forladt websted efter én sidevisning',
 'VisitsSummary_EvolutionOverLastPeriods' => 'Udvikling de sidste %s',
 'VisitsSummary_Report' => 'Rapport',
 'VisitsSummary_GenerateTime' => 'Siden generedes på %s sek.',
 'VisitsSummary_GenerateQueries' => '%s forespørgelser kørt',
 'VisitsSummary_WidgetLastVisits' => 'Seneste besøg',
 'VisitsSummary_WidgetVisits' => 'Besøgsoversigt',
-'VisitsSummary_WidgetLastVisitors' => 'Sidste unikke besøgende',
+'VisitsSummary_WidgetLastVisitors' => 'Seneste unikke besøgende',
 'VisitsSummary_WidgetOverviewGraph' => 'Oversigt med grafik',
 'VisitsSummary_SubmenuOverview' => 'Oversigt',
 'VisitFrequency_Evolution' => 'Udvikling i perioden',
 'VisitFrequency_ColumnReturningVisits' => 'Tilbagevendende besøg',
 'VisitFrequency_ColumnActionsByReturningVisits' => 'Handlinger af tilbagevendene besøg',
 'VisitFrequency_ColumnMaximumActionsByAReturningVisit' => 'Max antal handlinger af tilbagevendene besøg',
-'VisitFrequency_ColumnTotalTimeSpentByReturningVisits' => 'Total tid brugt af tilbagevendene besøg (i sekunder)',
+'VisitFrequency_ColumnTotalTimeSpentByReturningVisits' => 'Samlet tid brugt af tilbagevendene besøg (i sekunder)',
 'VisitFrequency_ColumnBounceRateForReturningVisits' => 'Afvisningsfrekvens for tilbagevendene besøg',
 'VisitFrequency_ReturnVisits' => '%s tilbagevendende besøg',
 'VisitFrequency_ReturnActions' => '%s handlinger af de tilbagevendende besøg',
 'VisitFrequency_ReturnMaxActions' => '%s maks. handlinger af de tilbagevendende besøg',
 'VisitFrequency_ReturnTotalTime' => '%s total tid brugt af de tilbagevendende besøg',
 'VisitFrequency_ReturnBounceRate' => '%s tilbagevendende besøg har forladt siden efter en sidevisning.',
-'VisitFrequency_WidgetOverview' => 'Frekvensoversigt',
+'VisitFrequency_WidgetOverview' => 'Hyppighedsoversigt',
 'VisitFrequency_WidgetGraphReturning' => 'Tilbagevendende besøg',
-'VisitFrequency_SubmenuFrequency' => 'Frekvens',
+'VisitFrequency_SubmenuFrequency' => 'Hyppighed',
 'VisitTime_LocalTime' => 'Besøg pr. lokaltid',
 'VisitTime_ServerTime' => 'Besøg pr. servertid',
 'VisitTime_ColumnServerTime' => 'Servertid',
@@ -583,9 +609,9 @@ $translations = array(
 'VisitorInterest_ColumnPagesPerVisit' => 'Sider pr. besøg',
 'VisitorInterest_WidgetLengths' => 'Besøgslængde',
 'VisitorInterest_WidgetPages' => 'Sidevisninger pr. besøg',
-'VisitorInterest_SubmenuFrequencyLoyalty' => 'Frekvens og loyalitet',
+'VisitorInterest_SubmenuFrequencyLoyalty' => 'Hyppighed og loyalitet',
 'VisitorInterest_PlusXMin' => '%s min.',
-'VisitorInterest_BetweenXYMinutes' => '%1s-%2s min.',
+'VisitorInterest_BetweenXYMinutes' => '%1s-%1s min.',
 'VisitorInterest_OnePage' => '1 side',
 'VisitorInterest_NPages' => '%s sider',
 'VisitorInterest_BetweenXYSeconds' => '%1s-%2 sek.',
@@ -597,19 +623,19 @@ $translations = array(
 'Login_Logout' => 'Log af',
 'Login_LostYourPassword' => 'Glemt adgangskode?',
 'Login_RemindPassword' => 'Husk adgangskode',
-'Login_PasswordReminder' => 'Skriv dit brugernavn eller e-mailadresse. Du vil få en ny adgangskode med e-mail.',
+'Login_PasswordReminder' => 'Skriv dit brugernavn eller e-mailadresse. Du vil modtage en ny adgangskode med e-mail.',
 'Login_InvalidUsernameEmail' => 'Fejl i brugernavn og/eller e-mailadresse.',
 'Login_MailTopicPasswordRecovery' => 'Genopret adgangskode',
 'Login_MailPasswordRecoveryBody' => 'Hej %1s, \n\m Ny adgangskode er: %2s \n\n Du kan logge på her: %3s',
-'Login_PasswordSent' => 'Adgangskoden er sendt. Check din e-mail.',
+'Login_PasswordSent' => 'Adgangskoden er sendt. Tjek din e-mail.',
 'Login_ContactAdmin' => 'Mulig grund: udbyderen har måske deaktiveret mail()-funktionen. <br />Kontakt Piwik administrator.',
-'UsersManager_UsersManagement' => 'Brugerkonfiguration',
+'UsersManager_UsersManagement' => 'Bruger administration',
 'UsersManager_UsersManagementMainDescription' => 'Opret nye brugere eller opdater eksisterende. Efterfølgende kan tilladelser ændres.',
-'UsersManager_ManageAccess' => 'Konfigurer adgang',
+'UsersManager_ManageAccess' => 'Administrer adgang',
 'UsersManager_MainDescription' => 'Bestem hvilken bruger der har adgang til Piwik på websiderne. Adgang kan også sættes på alle websider på en gang.',
-'UsersManager_Sites' => 'Websider',
-'UsersManager_AllWebsites' => 'Alle websider',
-'UsersManager_ApplyToAllWebsites' => 'Tilføj til alle websider',
+'UsersManager_Sites' => 'Websteder',
+'UsersManager_AllWebsites' => 'Alle websteder',
+'UsersManager_ApplyToAllWebsites' => 'Tilføj til alle websteder',
 'UsersManager_User' => 'Bruger',
 'UsersManager_PrivNone' => 'Ingen adgang',
 'UsersManager_PrivView' => 'Vis',
@@ -619,7 +645,6 @@ $translations = array(
 'UsersManager_Password' => 'Adgangskode',
 'UsersManager_Email' => 'E-mail',
 'UsersManager_Alias' => 'Alias',
-'UsersManager_Token' => 'token_auth',
 'UsersManager_Edit' => 'Ændre',
 'UsersManager_AddUser' => 'Opret ny bruger',
 'UsersManager_MenuUsers' => 'Brugere',
@@ -631,40 +656,40 @@ $translations = array(
 'UsersManager_ExceptionInvalidEmail' => 'E-mailadressen er ikke i gyldig format.',
 'UsersManager_ExceptionDeleteDoesNotExist' => 'Bruger \'%s\' eksisterer ikke, og kan derfor ikke  slettes.',
 'UsersManager_ExceptionAdminAnonymous' => 'Administrator-adgang kan ikke gives til \'anonyme\'-bruger.',
-'UsersManager_ExceptionEditAnonymous' => 'Anonyme brugere kan ikke redigeres eller slettet. Bliver brugt af Piwik for at definere en bruger som ikke er blevet logget på endnu.',
-'UsersManager_ExceptionSuperUser' => 'Anmodede bruger er Superbrugeren og kan ikke  forespørges, rettes eller slettes gennem API. Kan rettes manuelt under Super bruger detaljer i  Piwik konfigurationsfilen.',
+'UsersManager_ExceptionEditAnonymous' => 'Anonyme brugere kan ikke redigeres eller slettet. Anvendes af Piwik til at definere en bruger, som ikke er blevet logget på endnu. For eksempel kan du gøre din statistik offentlig ved at give  \'se\' adgang til \'anonym\' bruger', 
+'UsersManager_ExceptionSuperUser' => 'Anmodede bruger er Superbrugeren og kan ikke  forespørges, rettes eller slettes gennem API. Kan rettes manuelt under Superbruger detaljer i  Piwik konfigurationsfilen.',
 'UsersManager_ExceptionUserDoesNotExist' => 'Bruger \'%s\' findes ikke.',
 'UsersManager_ExceptionAccessValues' => 'Parameteren skal have en af de følgende værdier: [ %s ]',
-'SitesManager_Sites' => 'Websider',
-'SitesManager_WebsitesManagement' => 'Administration af websider',
-'SitesManager_MainDescription' => 'Analyser behøver websider! Tilføj, opdater, slet websider, og vis JavaScriptkoden som skal tilføjes på  websiderne.',
-'SitesManager_JsCode' => 'JavaScript kode',
-'SitesManager_JsCodeHelp' => 'Her er JavaScript-koden som skal tilføjes til alle sider',
-'SitesManager_ShowJsCode' => 'vis kode',
-'SitesManager_NoWebsites' => 'Der er ingen websider at administrere',
-'SitesManager_AddSite' => 'Opret en ny webside',
+'SitesManager_Sites' => 'Websteder',
+'SitesManager_WebsitesManagement' => 'Administration af websteder',
+'SitesManager_MainDescription' => 'Analyser behøver websteder! Tilføj, opdater, slet websteder, og vis JavaScriptkoden som skal tilføjes webstederne.',
+'SitesManager_JsTrackingTag' => 'JavaScript sporingskode',
+'SitesManager_JsTrackingTagHelp' => 'JavaScript-sporingskoden som skal tilføjes til alle sider',
+'SitesManager_ShowTrackingTag' => 'vis sporingskode',
+'SitesManager_NoWebsites' => 'Der er ingen websteder at administrere',
+'SitesManager_AddSite' => 'Tilføj et nyt websted',
 'SitesManager_Id' => 'ID',
 'SitesManager_Name' => 'Navn',
-'SitesManager_Urls' => 'URLs',
-'SitesManager_MenuSites' => 'Websider',
-'SitesManager_DeleteConfirm_js' => 'Bekræft sletning af følgende webside? %s',
-'SitesManager_ExceptionDeleteSite' => 'Det er ikke muligt at slette websiden, da den er den eneste webside. Opret en ny webside, og så slet.',
-'SitesManager_ExceptionNoUrl' => 'Angiv mindst 1 URL til websiden.',
-'SitesManager_ExceptionEmptyName' => 'Sidenavn kan ikke være tomt.',
-'SitesManager_ExceptionInvalidUrl' => 'Url\'en \'%s\' er ikke en gyldig URL.',
+'SitesManager_Urls' => 'Webadresser',
+'SitesManager_MenuSites' => 'Websteder',
+'SitesManager_DeleteConfirm_js' => 'Bekræft sletning af følgende websted? %s',
+'SitesManager_ExceptionDeleteSite' => 'Det er ikke muligt at slette webstedet, da det er det eneste oprettede websted. Tilføj et nyt websted, og slet så dette .',
+'SitesManager_ExceptionNoUrl' => 'Angiv mindst én webadresse til webstedet.',
+'SitesManager_ExceptionEmptyName' => 'Webstedets navn kan ikke være tomt.',
+'SitesManager_ExceptionInvalidUrl' => 'Webadressen \'%s\' er ikke gyldig.',
 'Installation_Installation' => 'Installation',
 'Installation_InstallationStatus' => 'Installationstatus',
-'Installation_PercentDone' => '%s %% færdig',
-'Installation_NoConfigFound' => 'Piwik-konfigurationsfil blev ikke fundet og du prøver at få adgang til Piwik. <br /><b>&nbsp;&nbsp;&raquo;Du kan <a href=\'index.php\'>installere Piwik nu</a></b><br /><small>Hvis du prøvde at installere Piwik tidligere, og har nogle tabeller i databasen, bliver gamle data liggende!</small>',
+'Installation_PercentDone' => '%s %% udført',
+'Installation_NoConfigFound' => 'Piwik-konfigurationsfil blev ikke fundet og du prøver at få adgang til Piwik. <br /><b>&nbsp;&nbsp;&raquo;Du kan <a href=\'index.php\'>installere Piwik nu</a></b><br /><small> Hvis du har installeret Piwik tidliger og har nogle tabeller i databasen, kan du genbruge tabellerne og holde dine eksisterende data!</small>',
 'Installation_MysqlSetup' => 'MySQL database oprettet',
 'Installation_MysqlErrorConnect' => 'Fejl ved tilkobling til databasen',
 'Installation_JsTag' => 'JavaScript kode',
 'Installation_JsTagHelp' => '<p>For at tælle alle besøgende, indsættes JavaScript-koden på alle sider.</p><p>Siderne behøver ikke være lavet med PHP, Piwik vil virke på alle typer sider (uanset om det er HTML, ASP, Perl eller et andet sprog).</p><p>Her er koden der skal indsættes: (kopier og indsæt på alle sider)</p>',
 'Installation_Congratulations' => 'Tillykke',
-'Installation_CongratulationsHelp' => '<p>Tillykke! Piwik installation er fuldført.</p><p>Sørg for at JavaScript-koden er tilføjet på  sider, og vent på de første besøgende!</p>',
+'Installation_CongratulationsHelp' => '<p>Tillykke! Piwik installationen er færdig.</p><p>Sørg for at JavaScript-koden er tilføjet på  dine sider, og vent på de første besøgende!</p>',
 'Installation_ContinueToPiwik' => 'Fortsæt til Piwik',
-'Installation_SetupWebsite' => 'Tilføj en webside',
-'Installation_SetupWebsiteError' => 'Fejl ved tilføjelse af en webside',
+'Installation_SetupWebsite' => 'Tilføj et websted',
+'Installation_SetupWebsiteError' => 'Fejl ved tilføjelse af websted',
 'Installation_GeneralSetup' => 'Generel opsætning',
 'Installation_GeneralSetupSuccess' => 'Generel opsætning gemt',
 'Installation_SuperUserLogin' => 'superbruger log på',
@@ -681,23 +706,23 @@ $translations = array(
 'Installation_SystemCheckPdoMysql' => 'Pdo_MySql udvidelse',
 'Installation_SystemCheckPdoError' => 'Aktivere PDO og PDO_MYSQL i php.ini filen.',
 'Installation_SystemCheckPdoHelp' => 'På en Windows-server tilføj følgende linjer til php-ini %s <br /><br />På en linux-server kompilere php med følgende valg %s I php.ini, tilføj følgende linjer %s<br /><br />Mere information findes på <a style=\'color:red\' href=\'http://php.net/pdo\'>PHP.net</a>.',
-'Installation_SystemCheckWriteDirs' => 'Kataloger med skriveadgang',
+'Installation_SystemCheckWriteDirs' => 'Mapper med skriveadgang',
 'Installation_SystemCheckWriteDirsHelp' => 'Prøv at skrive følgende kommandoer for at rette fejlen på et linux-system',
 'Installation_SystemCheckMemoryLimit' => 'Hukommelses grænse',
-'Installation_SystemCheckMemoryLimitHelp' => 'På en stærkt trafikeret webside, kan arkiveringsprocessen kræve mere hukommelse end der er tilladt.<br />Se på memory_limit i php.ini filen hvis nødvendig.',
+'Installation_SystemCheckMemoryLimitHelp' => 'På et stærkt trafikeret websted, kan arkiveringsprocessen kræve mere hukommelse end der er tilladt.<br />Se på memory_limit i php.ini filen hvis nødvendig.',
 'Installation_SystemCheckGD' => 'GD &gt; 2.x (grafik)',
 'Installation_SystemCheckGDHelp' => 'Mindre grafiske elementer vil ikke fungere som ønsket.',
 'Installation_SystemCheckTimeLimit' => 'set_time_limit() tilladt',
-'Installation_SystemCheckTimeLimitHelp' => 'På et stærkt trafikeret webside, kan arkiveringsprocessen kræve mere tid end der tilladt.<br />Se på max_execution_time i php.ini filen hvis nødvendig.',
+'Installation_SystemCheckTimeLimitHelp' => 'På et stærkt trafikeret websted, kan arkiveringsprocessen kræve mere tid end der tilladt.<br />Se på max_execution_time i php.ini filen hvis nødvendig.',
 'Installation_SystemCheckMail' => 'mail() tilgængelig',
 'Installation_SystemCheckError' => 'En fejl opstod - skal rettes før der kan fortsættes',
-'Installation_SystemCheckWarning' => 'Piwik vil virke normalt, men nogle tjenester vil måske mangle',
+'Installation_SystemCheckWarning' => 'Piwik vil virke normalt, men nogle funktioner vil måske mangle',
 'Installation_Tables' => 'Opretter tabeller',
 'Installation_TablesWithSameNamesFound' => 'Nogle %s tabeller i databasen %s har samme navn, som dem Piwik prøver at oprette',
 'Installation_TablesFound' => 'Følgende tabeller blev fundet i databasen',
-'Installation_TablesWarningHelp' => 'Vælg enten at bruge de eksisterende tabeller eller vælg en ren installation for at slette alle eksisterende data.',
-'Installation_TablesReuse' => 'Brug de eksisterende tabeller',
-'Installation_TablesDelete' => 'Slet de opdaterede tabeller',
+'Installation_TablesWarningHelp' => 'Vælg enten at genbruge de eksisterende tabeller eller vælg en ren installation for at slette alle eksisterende data.',
+'Installation_TablesReuse' => 'Genbrug de eksisterende tabeller',
+'Installation_TablesDelete' => 'Slet detekterede tabeller',
 'Installation_TablesDeletedSuccess' => 'Eksisterende Piwik-tabeller blev slettet',
 'Installation_TablesCreatedSuccess' => 'Tabellerne blev oprettet!',
 'Installation_DatabaseCreatedSuccess' => 'Databasen %s blev oprettet!',
@@ -708,7 +733,7 @@ $translations = array(
 'Installation_ErrorInvalidState' => 'Fejl: Det lader til at du forsøger at springe et skridt af installationen over, eller cookies er slået fra, eller Piwik opsætningsfil  allerede er oprettet. %sSørg for, at cookies er aktiveret%s og gå tilbage%s til den første side i installationen%s. ',
 'Provider_WidgetProviders' => 'Udbydere',
 'Provider_ColumnProvider' => 'Udbyder',
-'Provider_SubmenuLocationsProvider' => 'Lokationer & udbydere',
+'Provider_SubmenuLocationsProvider' => 'Sted og udbyder',
 'Goals_ColumnConversions' => 'Omregninger',
 'Goals_ColumnConversionRate' => 'Omregnings frekvens',
 'Goals_ColumnRevenue' => 'Indtægter',
@@ -716,8 +741,8 @@ $translations = array(
 'DBStats_MainDescription' => 'Piwik gemmer al statistik i MySQL-databasen. Lige nu bruger Piwik-tabellen %s.',
 'DBStats_Table' => 'Tabel',
 'DBStats_RowNumber' => 'Antal rækker',
-'DBStats_DataSize' => 'Datastørrelse',
-'DBStats_IndexSize' => 'Index størrelse',
+'DBStats_DataSize' => 'Data',
+'DBStats_IndexSize' => 'Index',
 'DBStats_TotalSize' => 'Samlet størrelse',
 'TranslationsAdmin_MenuTranslations' => 'Oversættelser',
 'TranslationsAdmin_MenuLanguages' => 'Sprog',
