@@ -1,4 +1,4 @@
-<?php 
+<?php
 $translations = array(
 	'General_Locale' => 'en_EN.UTF-8',
 	'General_TranslatorName' => '-',
@@ -7,7 +7,8 @@ $translations = array(
 	'General_OriginalLanguageName' => 'English',
 	'General_HelloUser'	=> 'Hello, %s!',
 	'General_OpenSourceWebAnalytics' => 'Open Source Web Analytics',
-	'General_YourDashboard' => 'Your Dashboard',
+	'General_Dashboard' => 'Dashboard',
+	'General_MultiSitesSummary' => 'All Websites',
 	'General_API' => 'API',
 	'General_Widgets' => 'Widgets',
 	'General_Settings'	=> 'Settings',
@@ -37,8 +38,8 @@ $translations = array(
 	'General_TagCloud' => 'Tag Cloud',
 	'General_VBarGraph' => 'Vertical bar graph',
 	'General_Export' => 'Export',
-	'General_ExportAsImage' => 'Export as Image',
-	'General_SaveImageOnYourComputer' => 'To save the image on your computer, right click on the image and select "Save Image As..."',
+	'General_ExportAsImage_js' => 'Export as Image',
+	'General_SaveImageOnYourComputer_js' => 'To save the image on your computer, right click on the image and select "Save Image As..."',
 	'General_Refresh' => 'Refresh the page',
 	'General_Visitors' => 'Visitors',
 	'General_ColumnNbUniqVisitors' => 'Unique visitors',
@@ -48,7 +49,7 @@ $translations = array(
 	'General_ColumnSumVisitLength' => 'Total time spent by visitors (in seconds)',
 	'General_ColumnLabel' => 'Label',
 	'General_ColumnActionsPerVisit' => 'Actions per Visit',
-	'General_ColumnAvgTimeOnSite' => 'Avg. Time on Site',
+	'General_ColumnAvgTimeOnSite' => 'Avg. Time on Website',
 	'General_ColumnBounceRate' => 'Bounce Rate',
 	'General_ColumnPageviews' => 'Pageviews',
 	'General_ColumnUniquePageviews' => 'Unique Pageviews',
@@ -56,7 +57,9 @@ $translations = array(
 	'General_ColumnVisitsWithConversions' => 'Visits with Conversions',
 	'General_Save' => 'Save',
 	'General_Website' => 'Website',
-	'General_NoDataForGraph' => 'No data for this graph',
+	'General_RequiresFlash' => 'Displaying Graphs in Piwik requires Flash',
+	'General_GraphHelp' => 'More information about displaying graphs in Piwik.',
+	'General_NoDataForGraph' => 'No data for this graph.',
 	'General_NoDataForTagCloud' => 'No data for this tag cloud.',
 	'General_DisplayNormalTable' => 'Display normal table',
 	'General_DisplayMoreData' => 'Display more data',
@@ -102,6 +105,7 @@ $translations = array(
 	'General_LongDay_5' => 'Friday',
 	'General_LongDay_6' => 'Saturday',
 	'General_LongDay_7' => 'Sunday',
+	'General_ExceptionDatabaseVersion' => 'Your %s version is %s but Piwik requires at least %s.',
 	'CorePluginsAdmin_Plugins' => 'Plugins',
 	'CorePluginsAdmin_PluginsManagement' => 'Plugins Management',
 	'CorePluginsAdmin_MainDescription' => 'Plugins extend and expand the functionality of Piwik. Once a plugin is installed, you may activate it or deactivate it here.',
@@ -121,7 +125,7 @@ $translations = array(
 	'API_QuickDocumentation' => '<h2>API quick documentation</h2><p>If you don\'t have data for today you can first <a href=\'misc/generateVisits.php\' target=_blank>generate some data</a> using the Visits Generator script.</p><p>You can try the different formats available for every method. It is very easy to extract any data you want from Piwik!</p><p><b>For more information have a look at the <a href=\'http://dev.piwik.org/trac/wiki/API\'>official API Documentation</a> or the <a href=\'http://dev.piwik.org/trac/wiki/API/Reference\'>API Reference</a>.</b></P><h2>User authentication</h2><p>If you want to <b>request the data in your scripts, in a crontab, etc. </b> you need to add the parameter <code><u>&token_auth=%s</u></code> to the API calls URLs that require authentication.</p><p>This token_auth is as secret as your login and password, <b>do not share it!</p>',
 	'API_LoadedAPIs' => 'Loaded successfully %s APIs',
 	'CoreHome_NoPrivileges' => 'You are logged in as \'%s\' but it seems you don\'t have any permission set in Piwik.<br />Ask your Piwik administrator to give you \'view\' access to a website.',
-	'CoreHome_JavascriptDisabled' => 'JavaScript must be enabled in order for you to use Piwik in standard view.<br />However, it seems JavaScript is either disabled or not supported by your browser.<br />To use standard view, enable JavaScript by changing your browser options, then %1stry again%2s.<br />',
+	'CoreHome_JavascriptDisabled' => 'JavaScript must be enabled in order for you to use Piwik in standard view.<br />However, it seems JavaScript is either disabled or not supported by your browser.<br />To use standard view, enable JavaScript by changing your browser options, then %stry again%s.<br />',
 	'CoreHome_TableNoData' => 'No data for this table.',
 	'CoreHome_CategoryNoData' => 'No data in this category. Try to "Include all population".',
 	'CoreHome_ShowJSCode' => 'Show the JavaScript code to insert',
@@ -145,6 +149,32 @@ $translations = array(
 	'CoreHome_DayTh_js' => 'Th',
 	'CoreHome_DayFr_js' => 'Fr',
 	'CoreHome_DaySa_js' => 'Sa',
+	'CoreHome_ShortDay_1_js' => 'Sun',
+	'CoreHome_ShortDay_2_js' => 'Mon',
+	'CoreHome_ShortDay_3_js' => 'Tue',
+	'CoreHome_ShortDay_4_js' => 'Wed',
+	'CoreHome_ShortDay_5_js' => 'Thu',
+	'CoreHome_ShortDay_6_js' => 'Fri',
+	'CoreHome_ShortDay_7_js' => 'Sat',
+	'CoreHome_LongDay_1_js' => 'Sunday',
+	'CoreHome_LongDay_2_js' => 'Monday',
+	'CoreHome_LongDay_3_js' => 'Tuesday',
+	'CoreHome_LongDay_4_js' => 'Wednesday',
+	'CoreHome_LongDay_5_js' => 'Thursday',
+	'CoreHome_LongDay_6_js' => 'Friday',
+	'CoreHome_LongDay_7_js' => 'Saturday',
+	'CoreHome_ShortMonth_1_js' => 'Jan',
+	'CoreHome_ShortMonth_2_js' => 'Feb',
+	'CoreHome_ShortMonth_3_js' => 'Mar',
+	'CoreHome_ShortMonth_4_js' => 'Apr',
+	'CoreHome_ShortMonth_5_js' => 'May',
+	'CoreHome_ShortMonth_6_js' => 'Jun',
+	'CoreHome_ShortMonth_7_js' => 'Jul',
+	'CoreHome_ShortMonth_8_js' => 'Aug',
+	'CoreHome_ShortMonth_9_js' => 'Sep',
+	'CoreHome_ShortMonth_10_js' => 'Oct',
+	'CoreHome_ShortMonth_11_js' => 'Nov',
+	'CoreHome_ShortMonth_12_js' => 'Dec',
 	'CoreHome_MonthJanuary_js' => 'January',
 	'CoreHome_MonthFebruary_js' => 'February',
 	'CoreHome_MonthMarch_js' => 'March',
@@ -157,13 +187,20 @@ $translations = array(
 	'CoreHome_MonthOctober_js' => 'October',
 	'CoreHome_MonthNovember_js' => 'November',
 	'CoreHome_MonthDecember_js' => 'December',
-	'CoreUpdater_UpdateTitle' => 'Piwik &rsaquo; Update',
+	'CoreUpdater_UpdateTitle' => 'Update',
 	'CoreUpdater_DatabaseUpgradeRequired' => 'Database Upgrade Required',
 	'CoreUpdater_YourDatabaseIsOutOfDate' => 'Your Piwik database is out-of-date, and must be upgraded before you can continue.',
 	'CoreUpdater_PiwikWillBeUpgradedFromVersionXToVersionY' => 'Piwik database will be upgraded from version %s to the new version %s.',
 	'CoreUpdater_TheFollowingPluginsWillBeUpgradedX' => 'The following plugins will be updated: %s.',
+	'CoreUpdater_TheUpgradeProcessMayFailExecuteCommand' => 'If you have a large Piwik database, updates might take too long to run in the browser. In this situation, you can execute the updates from your command line: %s',
 	'CoreUpdater_TheUpgradeProcessMayTakeAWhilePleaseBePatient' => 'The database upgrade process may take a while, so please be patient.',
 	'CoreUpdater_UpgradePiwik' => 'Upgrade Piwik',
+	'CoreUpdater_ErrorDIYHelp' => 'If you are an advanced user and encounter an error in the database upgrade:',
+	'CoreUpdater_ErrorDIYHelp_1' => 'identify and correct the source of the problem (e.g., memory_limit or max_execution_time)',
+	'CoreUpdater_ErrorDIYHelp_2' => 'execute the remaining queries in the update that failed',
+	'CoreUpdater_ErrorDIYHelp_3' => 'manually update the `option` table in your Piwik database, setting the value of version_core to the version of the failed update',
+	'CoreUpdater_ErrorDIYHelp_4' => 're-run the updater (through the browser or command-line) to continue with the remaining updates',
+	'CoreUpdater_ErrorDIYHelp_5' => 'report the problem (and solution) so that Piwik can be improved',
 	'CoreUpdater_HelpMessageContent' => 'Check the %s Piwik FAQ %s which explains most common errors during update. %s Ask your system administrator - they may be able to help you with the error which is most likely related to your server or MySQL setup.',
 	'CoreUpdater_CriticalErrorDuringTheUpgradeProcess' => 'Critical Error during the update process:',
 	'CoreUpdater_HelpMessageIntroductionWhenError' => 'The above is the core error message. It should help explain the cause, but if you require further help please:',
@@ -179,14 +216,20 @@ $translations = array(
 	'CoreUpdater_YouCanUpgradeAutomaticallyOrDownloadPackage' => 'You can update to version %s automatically or download the package and install it manually:',
 	'CoreUpdater_DownloadX' => 'Download %s',
 	'CoreUpdater_UpdateHasBeenCancelledExplanation' => 'Piwik One Click Update has been cancelled. If you can\'t fix the above error message, it is recommended that you manually update Piwik. %s Please check out the %sUpdate documentation%s to get started!',
-	'CoreUpdate_DownloadingUpdateFromX' => 'Downloading update from %s',
-	'CoreUpdate_UnpackingTheUpdate' => 'Unpacking the update',
+	'CoreUpdater_DownloadingUpdateFromX' => 'Downloading update from %s',
+	'CoreUpdater_UnpackingTheUpdate' => 'Unpacking the update',
 	'CoreUpdater_VerifyingUnpackedFiles' => 'Verifying the unpacked files',
 	'CoreUpdater_CreatingBackupOfConfigurationFile' => 'Creating a backup of the configuration file in %s',
 	'CoreUpdater_InstallingTheLatestVersion' => 'Installing the latest version',
 	'CoreUpdater_PiwikUpdatedSuccessfully' => 'Piwik updated successfully!',
+	'CoreUpdater_EmptyDatabaseError' => 'Database %s is empty. You must edit or remove your Piwik configuration file.',
+	'CoreUpdater_ExceptionAlreadyLatestVersion' => 'Your Piwik version %s is up to date.',
+	'CoreUpdater_ExceptionArchiveIncompatible' => 'Incompatible archive: %s',
+	'CoreUpdater_ExceptionArchiveEmpty' => 'Empty archive.',
+	'CoreUpdater_ExceptionArchiveIncomplete' => 'Archive is incomplete: some files are missing (eg. %s).',
 	'Actions_Actions' => 'Actions',
 	'Actions_SubmenuPages' => 'Pages',
+	'Actions_SubmenuPageTitles' => 'Page titles',
 	'Actions_SubmenuOutlinks' => 'Outlinks',
 	'Actions_SubmenuDownloads' => 'Downloads',
 	'Actions_ColumnClicks' => 'Clicks',
@@ -194,6 +237,7 @@ $translations = array(
 	'Actions_ColumnDownloads' => 'Downloads',
 	'Actions_ColumnUniqueDownloads' => 'Unique Downloads',
 	'Actions_ColumnPageName' => 'Page Name',
+	'Actions_ColumnPageURL' => 'Page URL',
 	'Actions_ColumnClickedURL' => 'Clicked URL',
 	'Actions_ColumnDownloadURL' => 'Download URL',
 	'Dashboard_Dashboard' => 'Dashboard',
@@ -213,7 +257,7 @@ $translations = array(
 	'Referers_DirectEntry' => 'Direct Entry',
 	'Referers_Websites' => 'Websites',
 	'Referers_Campaigns' => 'Campaigns',
-	'Referers_MetricsFromRefererTypeGraphLegend' => '%1s (from %2s)',
+	'Referers_MetricsFromRefererTypeGraphLegend' => '%s (from %s)',
 	'Referers_Evolution' => 'Evolution over the period',
 	'Referers_Type' => 'Referer Type',
 	'Referers_ColumnRefererType' => 'Referer Type',
@@ -234,7 +278,7 @@ $translations = array(
 	'Referers_DistinctWebsites' => 'distinct websites',
 	'Referers_UsingNDistinctUrls' => ' (using %2s distinct urls)',
 	'Referers_SubmenuEvolution' => 'Evolution',
-	'Referers_SubmenuSearchEngines' => 'Search engines & keywords',
+	'Referers_SubmenuSearchEngines' => 'Search Engines &amp; Keywords',
 	'Referers_SubmenuWebsites' => 'Websites',
 	'Referers_SubmenuCampaigns' => 'Campaigns',
 	'Referers_WidgetKeywords' => 'List of Keywords',
@@ -247,14 +291,14 @@ $translations = array(
 	'UserSettings_Browsers' => 'Browsers',
 	'UserSettings_Plugins' => 'Plugins',
 	'UserSettings_Configurations' => 'Configurations',
-	'UserSettings_OperatinsSystems' => 'Operating systems',
+	'UserSettings_OperatingSystems' => 'Operating systems',
 	'UserSettings_Resolutions' => 'Resolutions',
 	'UserSettings_WideScreen' => 'Wide Screen',
 	'UserSettings_ColumnBrowserFamily' => 'Browser family',
 	'UserSettings_ColumnBrowser' => 'Browser',
 	'UserSettings_ColumnPlugin' => 'Plugin',
 	'UserSettings_ColumnConfiguration' => 'Configuration',
-	'UserSettings_ColumnOperatinsSystem' => 'Operating system',
+	'UserSettings_ColumnOperatingSystem' => 'Operating system',
 	'UserSettings_ColumnResolution' => 'Resolution',
 	'UserSettings_ColumnTypeOfScreen' => 'Type of screen',
 	'UserSettings_WidgetResolutions' => 'Screen resolutions',
@@ -540,12 +584,13 @@ $translations = array(
 	'UserCountry_continent_ams' => 'South and Central America',
 	'UserCountry_continent_amn' => 'North America',
 	'UserCountry_continent_oce' => 'Oceania',
+	'VisitsSummary_VisitsSummary' => 'Visits Summary',
 	'VisitsSummary_NbVisits' => '%s visits',
 	'VisitsSummary_NbUniqueVisitors' => '%s unique visitors',
 	'VisitsSummary_NbActions' => '%s actions (page views)',
 	'VisitsSummary_TotalTime' => '%s total time spent by the visitors',
 	'VisitsSummary_MaxNbActions' => '%s max actions in one visit',
-	'VisitsSummary_NbVisitsBounced' => '%s visits have bounced (left the site after one page)',
+	'VisitsSummary_NbVisitsBounced' => '%s visits have bounced (left the website after one page)',
 	'VisitsSummary_EvolutionOverLastPeriods' => 'Evolution over the last %s',
 	'VisitsSummary_Report' => 'Report',
 	'VisitsSummary_GenerateTime' => '%s seconds to generate the page',
@@ -565,7 +610,7 @@ $translations = array(
 	'VisitFrequency_ReturnActions' => '%s actions by the returning visits',
 	'VisitFrequency_ReturnMaxActions' => '%s maximum actions by a returning visit',
 	'VisitFrequency_ReturnTotalTime' => '%s total time spent by returning visits',
-	'VisitFrequency_ReturnBounceRate' => '%s returning visits have bounced (left the site after one page)',
+	'VisitFrequency_ReturnBounceRate' => '%s returning visits have bounced (left the website after one page)',
 	'VisitFrequency_WidgetOverview' => 'Frequency overview',
 	'VisitFrequency_WidgetGraphReturning' => 'Graph returning visits',
 	'VisitFrequency_SubmenuFrequency' => 'Frequency',
@@ -583,31 +628,37 @@ $translations = array(
 	'VisitorInterest_ColumnPagesPerVisit' => 'Pages per visit',
 	'VisitorInterest_WidgetLengths' => 'Length of Visits',
 	'VisitorInterest_WidgetPages' => 'Pages per visit',
-	'VisitorInterest_SubmenuFrequencyLoyalty' => 'Frequency & Loyalty',
+	'VisitorInterest_SubmenuFrequencyLoyalty' => 'Frequency &amp; Loyalty',
 	'VisitorInterest_PlusXMin' => '%s min',
-	'VisitorInterest_BetweenXYMinutes' => '%1s-%2s min',
+	'VisitorInterest_BetweenXYMinutes' => '%1s-%1s min',
 	'VisitorInterest_OnePage' => '1 page',
 	'VisitorInterest_NPages' => '%s pages',
 	'VisitorInterest_BetweenXYSeconds' => '%1s-%2ss',
 	'Login_LoginPasswordNotCorrect' => 'Username & Password not correct',
 	'Login_Login' => 'Username',
 	'Login_Password' => 'Password',
+	'Login_PasswordRepeat' => 'Password (repeat)',
+	'Login_ChangePassword' => 'Change password',
 	'Login_LoginOrEmail' => 'Login or E-mail',
 	'Login_LogIn' => 'Sign in',
 	'Login_Logout' => 'Sign out',
 	'Login_LostYourPassword' => 'Lost your password?',
-	'Login_RemindPassword' => 'Remind password',
-	'Login_PasswordReminder' => 'Please enter your username or e-mail address. You will receive a new password via e-mail.',
+	'Login_RemindPassword' => 'Send password reset',
+	'Login_PasswordResetToken' => 'Password reset token',
+	'Login_PasswordReminder' => 'Please enter your username or e-mail address. You will receive an e-mail with information to reset your password.',
+	'Login_PasswordsDoNotMatch' => 'Passwords do not match.',
+	'Login_PasswordSuccessfullyChanged' => 'Password successfully changed!',
 	'Login_InvalidUsernameEmail' => 'Invalid username and/or e-mail address',
+	'Login_InvalidOrExpiredToken' => 'Token is invalid or has expired',
 	'Login_MailTopicPasswordRecovery' => 'Password recovery',
-	'Login_MailPasswordRecoveryBody' => 'Hi %1s, \n\n Your new password is: %2s \n\n You can login now at: %3s',
-	'Login_PasswordSent' => 'Password has been just sent. Check your e-mail.',
+	'Login_MailPasswordRecoveryBody' => "Hi %s,\n\nA password reset request was received from %s.\n\nTo reset your password:\n\n1) Go to the Password Reset Form at:\n\t%s\n\n2) Enter the following token:\n\t%s\n\n3) Fill out the form (entering your new password twice) and submit.\n\nNote: this token will expire in 24 hrs.\n",
+	'Login_PasswordSent' => 'Information to reset your password has been sent. Check your e-mail.',
 	'Login_ContactAdmin' => 'Possible reason: your host may have disabled the mail() function. <br />Please contact your Piwik administrator.',
 	'UsersManager_UsersManagement' => 'Users Management',
 	'UsersManager_UsersManagementMainDescription' => 'Create new users or update the existing users. You can then set their permissions above.',
 	'UsersManager_ManageAccess' => 'Manage access',
 	'UsersManager_MainDescription' => 'Decide which users have which Piwik access on your Websites. You can also set the permissions on all the Websites at once.',
-	'UsersManager_Sites' => 'Sites',
+	'UsersManager_Sites' => 'Websites',
 	'UsersManager_AllWebsites' => 'All websites',
 	'UsersManager_ApplyToAllWebsites' => 'Apply to all websites',
 	'UsersManager_User' => 'User',
@@ -634,36 +685,58 @@ $translations = array(
 	'UsersManager_ExceptionSuperUser' => 'Requested user is the Super User and cannot be queried, edited or deleted via the API. You can manually edit the Super User details in your Piwik configuration file.',
 	'UsersManager_ExceptionUserDoesNotExist' => 'User \'%s\' doesn\'t exist.',
 	'UsersManager_ExceptionAccessValues' => 'The parameter access must have one of the following values : [ %s ]',
-	'SitesManager_Sites' => 'Sites',
+	'SitesManager_Sites' => 'Websites',
 	'SitesManager_WebsitesManagement' => 'Websites Management',
 	'SitesManager_MainDescription' => 'Your Web Analytics reports need Websites! Add, update, delete Websites, and show the JavaScript to insert in your pages.',
 	'SitesManager_JsTrackingTag' => 'JavaScript Tracking Tag',
 	'SitesManager_JsTrackingTagHelp' => 'Here is the JavaScript Tracking tag to include on all your pages',
 	'SitesManager_ShowTrackingTag' => 'show tracking tag',
 	'SitesManager_NoWebsites' => 'You don\'t have any website to administrate.',
-	'SitesManager_AddSite' => 'Add a new Site',
+	'SitesManager_AddSite' => 'Add a new website',
+	'SitesManager_AliasUrlHelp' => 'It is recommended, but not required, to specify the various URLs that your visitors use to access this website. 
+Alias URLs for a website will not appear in the Referers > Websites report. 
+Note that it is not necessary to specify the URLs with and without \'www\' as Piwik automatically considers both.',
 	'SitesManager_Id' => 'Id',
 	'SitesManager_Name' => 'Name',
 	'SitesManager_Urls' => 'URLs',
-	'SitesManager_MenuSites' => 'Sites',
+	'SitesManager_MenuSites' => 'Websites',
 	'SitesManager_DeleteConfirm_js' => 'Are you sure you want to delete the website %s?',
 	'SitesManager_ExceptionDeleteSite' => 'It is not possible to delete this website as it is the only registered website. Add a new website first, then delete this one.',
-	'SitesManager_ExceptionNoUrl' => 'You must specify at least one URL for the site.',
-	'SitesManager_ExceptionEmptyName' => 'The site name can\'t be empty.',
+	'SitesManager_ExceptionNoUrl' => 'You must specify at least one URL for the website.',
+	'SitesManager_ExceptionEmptyName' => 'The website name can\'t be empty.',
 	'SitesManager_ExceptionInvalidUrl' => 'The url \'%s\' is not a valid URL.',
 	'Installation_Installation' => 'Installation',
 	'Installation_InstallationStatus' => 'Installation status',
 	'Installation_PercentDone' => '%s %% Done',
 	'Installation_NoConfigFound' => 'The Piwik configuration file couldn\'t be found and you are trying to access a Piwik page.<br /><b>&nbsp;&nbsp;&raquo; You can <a href=\'index.php\'>install Piwik now</a></b><br /><small>If you installed Piwik before and have some tables in your DB, don\'t worry, you can reuse the same tables and keep your existing data!</small>',
-	'Installation_MysqlSetup' => 'MySQL database setup',
-	'Installation_MysqlErrorConnect' => 'Error while trying to connect to the MySQL database',
+	'Installation_DatabaseSetup' => 'Database setup',
+	'Installation_DatabaseSetupServer' => 'database server',
+	'Installation_DatabaseSetupLogin' => 'login',
+	'Installation_DatabaseSetupPassword' => 'password',
+	'Installation_DatabaseSetupDatabaseName' => 'database name',
+	'Installation_DatabaseSetupTablePrefix' => 'table prefix',
+	'Installation_DatabaseSetupAdapter' => 'adapter',
+	'Installation_DatabaseErrorConnect' => 'Error while trying to connect to the database server',
+	'Installation_DatabaseCheck' => 'Database check',
+	'Installation_DatabaseServerVersion' => 'Database server version',
+	'Installation_DatabaseCreation' => 'Database creation',
+	'Installation_DatabaseClientCharset' => 'Database client character set',
+	'Installation_ConnectionCharacterSetNotUtf8' => 'Client connection to the database server is not set to UTF8 by default. This is not critical issue: <b>Piwik should work correctly</b>. However for consistency, it is recommended that you do one of the following: <ul style="list-style: disc;margin-left:10px"><li>in your piwik config/config.ini.php, add <code>charset = utf8</code> under the [database] section of your Piwik configuration file <code>config/config.ini.php</code></li><li>recompile libmysql --with-charset=utf8</li></ul>',
+	'Installation_DatabaseTimezone' => 'Database timezone',
+	'Installation_TimezoneMismatch' => 'PHP date.timezone is not the same as the database server timezone. This might cause issues with reports not showing data for the right hours of the day. More information at %s',
 	'Installation_JsTag' => 'JavaScript tag',
 	'Installation_JsTagHelp' => '<p>To count all visitors, you must insert the JavaScript code on all of your pages.</p><p>Your pages do not have to be made with PHP, Piwik will work on all kinds of pages (whether it is HTML, ASP, Perl or any other languages).</p><p>Here is the code you have to insert: (copy and paste on all your pages) </p>',
+	'Installation_JsTagHelpTitle' => 'How to insert the tag in your websites?',
+	'Installation_LargePiwikInstances' => 'Help for large Piwik instances',
+	'Installation_JsTagArchivingHelp' => 'For medium and high traffic websites, check out the  <a target="_blank" href="http://piwik.org/docs/setup-auto-archiving/">How to setup auto archiving page</a> to make Piwik run really fast!',
 	'Installation_Congratulations' => 'Congratulations',
 	'Installation_CongratulationsHelp' => '<p>Congratulations! Your Piwik installation is complete.</p><p>Make sure your JavaScript code is entered on your pages, and wait for your first visitors!</p>',
 	'Installation_ContinueToPiwik' => 'Continue to Piwik',
 	'Installation_SetupWebsite' => 'Setup a website',
+	'Installation_SetupWebSiteName' => 'website name',
+	'Installation_SetupWebSiteURL' => 'website URL',
 	'Installation_SetupWebsiteError' => 'There was an error when adding the website',
+	'Installation_SetupWebsiteSetupSuccess' => 	'Website %s created with success!',
 	'Installation_GeneralSetup' => 'General Setup',
 	'Installation_GeneralSetupSuccess' => 'General Setup configured with success',
 	'Installation_SuperUserLogin' => 'super user login',
@@ -674,23 +747,42 @@ $translations = array(
 	'Installation_CommunityNewsletter' => 'email me with community updates (new plugins, new features, etc.)',
 	'Installation_PasswordDoNotMatch' => 'password do not match',
 	'Installation_SubmitGo' => 'Go!',
+	'Installation_Requirements' => 'Piwik Requirements',
+	'Installation_Optional' => 'Optional',
+	'Installation_Legend' => 'Legend',
+	'Installation_Extension' => 'extension',
 	'Installation_SystemCheck' => 'System check',
 	'Installation_SystemCheckPhp' => 'PHP version',
-	'Installation_SystemCheckPdo' => 'Pdo extension',
-	'Installation_SystemCheckPdoMysql' => 'Pdo_Mysql extension',
-	'Installation_SystemCheckPdoError' => 'You need to enable the PDO and PDO_MYSQL extensions in your php.ini file.',
-	'Installation_SystemCheckPdoHelp' => 'On a windows server you can add the following lines in your php.ini %s <br /><br />On a Linux server you can compile php with the following option %s In your php.ini, add the following lines %s<br /><br />More information on the <a style="color:red" href="http://php.net/pdo">PHP website</a>.',
+	'Installation_SystemCheckExtensions' => 'Other required extensions',
+	'Installation_SystemCheckDatabaseHelp' => 'Piwik requires either the mysqli extension or both the PDO and pdo_mysql extensions.',
+	'Installation_SystemCheckPdoAndMysqliHelp' => "On a Linux server you can compile php with the following options: %s\nIn your php.ini, add the following lines: %s",
+	'Installation_SystemCheckPhpPdoAndMysqliSite' => 'More information on: <a style="color:red" href="http://php.net/pdo">PHP PDO</a> and <a style="color:red" href="http://php.net/mysqli">MYSQLI</a>.',
+	'Installation_SystemCheckWinPdoAndMysqliHelp' => 'On a Windows server you can add the following lines to your php.ini: %s',
+	'Installation_SystemCheckSplHelp' => 'You need to configure and rebuild PHP with the Standard PHP Library (SPL) enabled (by default).',
+	'Installation_SystemCheckZlibHelp' => 'You need to configure and rebuild PHP with "zlib" support enabled, --with-zlib.',
+	'Installation_SystemCheckIconvHelp' => 'You need to configure and rebuild PHP with "iconv" support enabled, --with-iconv.',
+	'Installation_SystemCheckDomHelp' => 'DOM is part of PHP core. You probably need to install the dom module, e.g., php-5-dom.',
+	'Installation_SystemCheckJson' => 'JSON',
+	'Installation_SystemCheckJsonHelp' => 'You need to configure and rebuild PHP with either "json" or "xml" extensions enabled.',
+	'Installation_SystemCheckJsonSite' => 'More information on: <a style="color:red" href="http://php.net/json">PHP JSON</a>.',
+	'Installation_SystemCheckXml' => 'XML',
+	'Installation_SystemCheckXmlHelp' => 'Some third-party plugins and developer libraries may require the "xml" extension.',
+	'Installation_SystemCheckXmlSite' => 'More information on: <a style="color:red" href="http://php.net/xml">PHP XML</a>.',
 	'Installation_SystemCheckWriteDirs' => 'Directories with write access',
 	'Installation_SystemCheckWriteDirsHelp' => 'To fix this error on your Linux system, try typing in the following command(s)',
 	'Installation_SystemCheckMemoryLimit' => 'Memory limit',
-	'Installation_SystemCheckMemoryLimitHelp' => 'On a high traffic website, the archiving process may require more memory than currently allowed.<br />See the directive memory_limit in your php.ini file if necessary.',
+	'Installation_SystemCheckMemoryLimitHelp' => 'On a high traffic website, the archiving process may require more memory than currently allowed.  If necessary, change the memory_limit directive in your php.ini file.',
+	'Installation_SystemCheckOpenURL' => 'Open URL',
+	'Installation_SystemCheckOpenURLHelp' => 'Newsletter subscriptions, update notifications, and one-click updates requires the "curl" extension, allow_url_fopen=On, or fsockopen() enabled.',
 	'Installation_SystemCheckGD' => 'GD &gt; 2.x (graphics)',
 	'Installation_SystemCheckGDHelp' => 'The sparklines (small graphs) will not work.',
-	'Installation_SystemCheckTimeLimit' => 'set_time_limit() allowed',
-	'Installation_SystemCheckTimeLimitHelp' => 'On a high traffic website, executing the archiving process may require more time than currently allowed.<br />See the directive max_execution_time  in your php.ini file if necessary',
-	'Installation_SystemCheckMail' => 'mail() allowed',
+	'Installation_SystemCheckFunctions' => 'Required functions',
+	'Installation_SystemCheckTimeLimitHelp' => 'On a high traffic website, executing the archiving process may require more time than currently allowed.  If necessary, change the max_execution_time directive in your php.ini file.',
+	'Installation_SystemCheckMailHelp' => 'Feedback and Lost Password messages will not be sent without mail().',
 	'Installation_SystemCheckError' => 'An error occured - must be fixed before you proceed',
 	'Installation_SystemCheckWarning' => 'Piwik will work normally but some features may be missing',
+	'Installation_SystemCheckProtocol' => 'Protocol',
+	'Installation_SystemCheckProtocolHelp' => 'If you are behind a reverse proxy, add these lines to config/config.ini.php under the [General] section:',
 	'Installation_Tables' => 'Creating the tables',
 	'Installation_TablesWithSameNamesFound' => 'Some %s tables in your database %s have the same names as the tables Piwik is trying to create',
 	'Installation_TablesFound' => 'The following tables have been found in the database',
@@ -707,14 +799,15 @@ $translations = array(
 	'Installation_ErrorInvalidState' => 'Error: it seems you try to skip a step of the Installation process, or your cookies are disabled, or the Piwik configuration file is already created. %sMake sure your cookies are enabled%s and go back %s to the first page of the installation %s.',
 	'Provider_WidgetProviders' => 'Providers',
 	'Provider_ColumnProvider' => 'Provider',
-	'Provider_SubmenuLocationsProvider' => 'Locations & provider',
+	'Provider_SubmenuLocationsProvider' => 'Locations &amp; Provider',
 	'Goals_ColumnConversions' => 'Conversions',
 	'Goals_ColumnConversionRate' => 'Conversion Rate',
 	'Goals_ColumnRevenue' => 'Revenue',
 	'DBStats_DatabaseUsage' => 'Database usage',
 	'DBStats_MainDescription' => 'Piwik is storing all your web analytics data in the MySQL database. Currently, Piwik tables are using %s.',
+	'DBStats_LearnMore' => 'To learn more about how Piwik processes data and how to make Piwik work well for medium and high traffic websites, check out the documentation %s.',
 	'DBStats_Table' => 'Table',
-	'DBStats_RowNumber' => 'Row number',
+	'DBStats_RowCount' => 'Row count',
 	'DBStats_DataSize' => 'Data size',
 	'DBStats_IndexSize' => 'Index size',
 	'DBStats_TotalSize' => 'Total size',
@@ -731,4 +824,13 @@ $translations = array(
 	'TranslationsAdmin_LanguageCode' => 'Language code',
 	'TranslationsAdmin_Export' => 'Export language',
 	'TranslationsAdmin_Import' => 'Import language',
+	'SecurityInfo_Security' => 'Security',
+	'SecurityInfo_SecurityInformation' => 'PHP Security Information',
+	'SecurityInfo_PluginDescription' => 'Based on PhpSecInfo from the PHP Security Consortium, this plugin provides security information about your PHP environment and offers suggestions for improvement. It is a tool in a multilayered security approach. It does not replace secure development practices nor audit the code/application.',
+	'SecurityInfo_Test' => 'Test',
+	'SecurityInfo_Result' => 'Result',
+	'Live_VisitorLog' => 'Visitor Log',
+	'Live_Date' => 'Date',
+	'Live_Time' => 'Time',
+	'Live_Referrer_URL' => 'Referrer URL',
 );
