@@ -44,10 +44,10 @@ $translations = array(
 	'General_ColumnNbUniqVisitors' => 'Visitantes únicos',
 	'General_ColumnNbVisits' => 'Visitas',
 	'General_ColumnNbActions' => 'Acciones',
-	'General_ColumnMaxActions' => 'Máximo de acciones en una visita',
+	'General_ColumnMaxActions' => 'acciones máximas en una visita',
 	'General_ColumnSumVisitLength' => 'Tiempo total de los visitantes en el sitio (en segundos)',
 	'General_ColumnLabel' => 'Etiqueta',
-	'General_ColumnActionsPerVisit' => 'Acciones por Visita',
+	'General_ColumnActionsPerVisit' => 'Acciones por visita',
 	'General_ColumnAvgTimeOnSite' => 'Promedio de tiempo en el sitio',
 	'General_ColumnBounceRate' => 'Porcentaje de rebote',
 	'General_ColumnPageviews' => 'Páginas vistas',
@@ -61,7 +61,7 @@ $translations = array(
 	'General_DisplayNormalTable' => 'Mostrar la tabla normal',
 	'General_DisplayMoreData' => 'Mostrar más datos',
 	'General_PiwikIsACollaborativeProjectYouCanContribute' => '%s Piwik %s es un proyecto colaborativo. %s ¡Si te gusta Piwik, puedes ayudar! Comprueba %s ¿Cómo contribuir con Piwik?%s ',
-	'General_YouAreCurrentlyViewingDemoOfPiwik' => 'You are currently viewing the demo of %s; %sdownload%s the full version! Check out %s', // Not translated
+	'General_YouAreCurrentlyViewingDemoOfPiwik' => 'Estás viendo en este momento la demo de %s; ¡%sdescarga%s la versión completa! Comprueba %s',
 	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Piwik %s está disponible. %s ¡Por favor, actualice ahora!%s (ver %s cambios%s).',
 	'General_BackToPiwik' => 'Volver a Piwik',
 	'General_ShortMonth_1' => 'Ene',
@@ -123,9 +123,9 @@ $translations = array(
 	'CoreHome_NoPrivileges' => 'Está conectado como \'%s\' pero parece que no tiene ningún permiso configurado en Piwik.<br />Pregúntele a su administrador de Piwik para que le de el acceso \'ver\' un sitio web.',
 	'CoreHome_JavascriptDisabled' => 'JavaScript debe estar activado para poder utilizar Piwik en la vista estándar.<br />Sin embargo, parece que el JavaScript está desactivado o no es compatible con su navegador.<br />Para utilizar la vista estándar, active JavaScript cambiando las opciones de su navegador, a continuación, %1sinténtelo de nuevo%2s.<br />',
 	'CoreHome_TableNoData' => 'No hay datos para esta tabla.',
-	'CoreHome_CategoryNoData' => 'No hay datos en esta categoría. Try to "Incluir toda al población".',
+	'CoreHome_CategoryNoData' => 'No hay datos en esta categoría. Intenta "Incluir toda la población".',
 	'CoreHome_ShowJSCode' => 'Mostrar el código JavaScript para insertar',
-	'CoreHome_IncludeAllPopulation_js' => 'Incluir toda al población',
+	'CoreHome_IncludeAllPopulation_js' => 'Incluir toda la población',
 	'CoreHome_ExcludeLowPopulation_js' => 'Excluir baja población',
 	'CoreHome_PageOf_js' => '%s de %s',
 	'CoreHome_Loading_js' => 'Cargando...',
@@ -138,13 +138,39 @@ $translations = array(
 	'CoreHome_PeriodWeeks' => 'semanas',
 	'CoreHome_PeriodMonths' => 'meses',
 	'CoreHome_PeriodYears' => 'años',
-	'CoreHome_DaySu_js' => 'D',
-	'CoreHome_DayMo_js' => 'L',
-	'CoreHome_DayTu_js' => 'M',
-	'CoreHome_DayWe_js' => 'X',
-	'CoreHome_DayTh_js' => 'J',
-	'CoreHome_DayFr_js' => 'V',
-	'CoreHome_DaySa_js' => 'S',
+	'CoreHome_DaySu_js' => 'Do',
+	'CoreHome_DayMo_js' => 'Lu',
+	'CoreHome_DayTu_js' => 'Ma',
+	'CoreHome_DayWe_js' => 'Mi',
+	'CoreHome_DayTh_js' => 'Ju',
+	'CoreHome_DayFr_js' => 'Vi',
+	'CoreHome_DaySa_js' => 'Sá',
+	'CoreHome_ShortDay_1_js' => 'Dom',
+	'CoreHome_ShortDay_2_js' => 'Lun',
+	'CoreHome_ShortDay_3_js' => 'Mar',
+	'CoreHome_ShortDay_4_js' => 'Mié',
+	'CoreHome_ShortDay_5_js' => 'Juv',
+	'CoreHome_ShortDay_6_js' => 'Vie',
+	'CoreHome_ShortDay_7_js' => 'Sáb',
+	'CoreHome_LongDay_1_js' => 'Domingo',
+	'CoreHome_LongDay_2_js' => 'Lunes',
+	'CoreHome_LongDay_3_js' => 'Martes',
+	'CoreHome_LongDay_4_js' => 'Miércoles',
+	'CoreHome_LongDay_5_js' => 'Jueves',
+	'CoreHome_LongDay_6_js' => 'Viernes',
+	'CoreHome_LongDay_7_js' => 'Sábado',
+	'CoreHome_ShortMonth_1_js' => 'Ene',
+	'CoreHome_ShortMonth_2_js' => 'Feb',
+	'CoreHome_ShortMonth_3_js' => 'Mar',
+	'CoreHome_ShortMonth_4_js' => 'Abr',
+	'CoreHome_ShortMonth_5_js' => 'May',
+	'CoreHome_ShortMonth_6_js' => 'Jun',
+	'CoreHome_ShortMonth_7_js' => 'Jul',
+	'CoreHome_ShortMonth_8_js' => 'Ago',
+	'CoreHome_ShortMonth_9_js' => 'Sep',
+	'CoreHome_ShortMonth_10_js' => 'Oct',
+	'CoreHome_ShortMonth_11_js' => 'Nov',
+	'CoreHome_ShortMonth_12_js' => 'Dic',
 	'CoreHome_MonthJanuary_js' => 'Enero',
 	'CoreHome_MonthFebruary_js' => 'Febrero',
 	'CoreHome_MonthMarch_js' => 'Marzo',
@@ -182,15 +208,16 @@ $translations = array(
 	'CoreUpdate_DownloadingUpdateFromX' => 'Descargando actualización desde %s',
 	'CoreUpdate_UnpackingTheUpdate' => 'Desempaquetando la actualización',
 	'CoreUpdater_VerifyingUnpackedFiles' => 'Verificando los archivos desempaquetados',
-	'CoreUpdater_CreatingBackupOfConfigurationFile' => 'Crando una copia de seguridad del archivo de configuración en %s',
+	'CoreUpdater_CreatingBackupOfConfigurationFile' => 'Creando una copia de seguridad del archivo de configuración en %s',
 	'CoreUpdater_InstallingTheLatestVersion' => 'Instalando la última versión',
 	'CoreUpdater_PiwikUpdatedSuccessfully' => '¡Piwik actualizado con éxito!',
+	'CoreUpdater_EmptyDatabaseError' => 'La base de datos %s está vacía. Debes modificar o eliminar tu archivo de configuración de Piwik.',
 	'Actions_Actions' => 'Acciones',
 	'Actions_SubmenuPages' => 'Páginas',
 	'Actions_SubmenuOutlinks' => 'Enlaces externos',
 	'Actions_SubmenuDownloads' => 'Descargas',
 	'Actions_ColumnClicks' => 'Clics',
-	'Actions_ColumnUniqueClicks' => ' Clics Únicos',
+	'Actions_ColumnUniqueClicks' => ' Clics únicos',
 	'Actions_ColumnDownloads' => 'Descargas',
 	'Actions_ColumnUniqueDownloads' => 'Descargas Únicas',
 	'Actions_ColumnPageName' => 'Páginas',
@@ -222,7 +249,7 @@ $translations = array(
 	'Referers_ColumnWebsitePage' => 'Página web',
 	'Referers_ColumnKeyword' => 'Palabras clave',
 	'Referers_ColumnCampaign' => 'Campaña',
-	'Referers_DetailsByRefererType' => 'Detailles por tipo de referencia',
+	'Referers_DetailsByRefererType' => 'Detalles por tipo de referencia',
 	'Referers_TypeDirectEntries' => '%s entradas directas',
 	'Referers_TypeSearchEngines' => '%s desde motores de búsqueda',
 	'Referers_TypeWebsites' => '%s desde páginas webs',
@@ -247,16 +274,16 @@ $translations = array(
 	'UserSettings_Browsers' => 'Navegadores',
 	'UserSettings_Plugins' => 'Plugins',
 	'UserSettings_Configurations' => 'Configuración',
-	'UserSettings_OperatinsSystems' => 'Sistemas operativos',
+	'UserSettings_OperatingSystems' => 'Sistemas operativos',
 	'UserSettings_Resolutions' => 'Resoluciones',
 	'UserSettings_WideScreen' => 'Pantalla panorámica',
 	'UserSettings_ColumnBrowserFamily' => 'Buscadores por familia',
 	'UserSettings_ColumnBrowser' => 'Navegador',
 	'UserSettings_ColumnPlugin' => 'Plugin',
 	'UserSettings_ColumnConfiguration' => 'Configuración',
-	'UserSettings_ColumnOperatinsSystem' => 'Sistemas operativos',
+	'UserSettings_ColumnOperatingSystem' => 'Sistemas operativos',
 	'UserSettings_ColumnResolution' => 'Resoluciones',
-	'UserSettings_ColumnTypeOfScreen' => 'Type of screen',
+	'UserSettings_ColumnTypeOfScreen' => 'Tipo de pantalla',
 	'UserSettings_WidgetResolutions' => 'Resoluciones de pantalla',
 	'UserSettings_WidgetBrowsers' => 'Navegadores de los visitantes',
 	'UserSettings_WidgetPlugins' => 'Lista de Plugins',
@@ -268,7 +295,7 @@ $translations = array(
 	'UserCountry_Country' => 'País',
 	'UserCountry_Continent' => 'Continente',
 	'UserCountry_DistinctCountries' => '%s países distintos',
-	'UserCountry_SubmenuLocations' => 'Locations',
+	'UserCountry_SubmenuLocations' => 'Localizaciones',
 	'UserCountry_WidgetContinents' => 'Continentes de los visitantes',
 	'UserCountry_WidgetCountries' => 'Países de los visitantes',
 	'UserCountry_country_ac' => 'Isla Ascensión',
@@ -544,8 +571,8 @@ $translations = array(
 	'VisitsSummary_NbUniqueVisitors' => '%s visitas únicas',
 	'VisitsSummary_NbActions' => '%s acciones (páginas vistas)',
 	'VisitsSummary_TotalTime' => '%s tiempo total empleado por los visitantes',
-	'VisitsSummary_MaxNbActions' => '%s máximo de acciones en una visita',
-	'VisitsSummary_NbVisitsBounced' => '%s visits have bounced (left the site after one page)',
+	'VisitsSummary_MaxNbActions' => '%s acciones máximas en una visita',
+	'VisitsSummary_NbVisitsBounced' => '%s de visitas que han vuelto (abandonaron el sitio después de una página)',
 	'VisitsSummary_EvolutionOverLastPeriods' => 'Evolución en los últimos %s',
 	'VisitsSummary_Report' => 'Informe',
 	'VisitsSummary_GenerateTime' => '%s segundos para generar la página',
@@ -558,16 +585,16 @@ $translations = array(
 	'VisitFrequency_Evolution' => 'Evolución en el periodo',
 	'VisitFrequency_ColumnReturningVisits' => 'Visitante que ha vuelto',
 	'VisitFrequency_ColumnActionsByReturningVisits' => 'Acciones por un visitante que ha vuelto',
-	'VisitFrequency_ColumnMaximumActionsByAReturningVisit' => 'Máximo de acciones por un visitante que ha vuelto',
+	'VisitFrequency_ColumnMaximumActionsByAReturningVisit' => 'acciones máximas por un visitante que ha vuelto',
 	'VisitFrequency_ColumnTotalTimeSpentByReturningVisits' => 'Tiempo total empleado por un visitante que ha vuelto (en segundos)',
 	'VisitFrequency_ColumnBounceRateForReturningVisits' => 'Porcentaje de rebote por un visitante que ha vuelto',
 	'VisitFrequency_ReturnVisits' => '%s visitantes que han vuelto',
 	'VisitFrequency_ReturnActions' => '%s acciones realizadas por los visitantes que han vuelto',
-	'VisitFrequency_ReturnMaxActions' => '%s máximo de acciones por un visitante que vuelve',
+	'VisitFrequency_ReturnMaxActions' => '%s acciones máximas por un visitante que ha vuelto',
 	'VisitFrequency_ReturnTotalTime' => '%s tiempo total empleado por los visitantes que han vuelto',
 	'VisitFrequency_ReturnBounceRate' => '%s rebotes visitas que han vuelto (abandonaron el sitio después de una página)',
 	'VisitFrequency_WidgetOverview' => 'Vista general de frecuencia',
-	'VisitFrequency_WidgetGraphReturning' => 'Gráfica de visitantes que vuelven',
+	'VisitFrequency_WidgetGraphReturning' => 'Gráfica de visitantes que han vuelto',
 	'VisitFrequency_SubmenuFrequency' => 'Frecuencia',
 	'VisitTime_LocalTime' => 'Visitas por hora local',
 	'VisitTime_ServerTime' => 'Visitas por hora del servidor',
@@ -585,7 +612,7 @@ $translations = array(
 	'VisitorInterest_WidgetPages' => 'Páginas por visita',
 	'VisitorInterest_SubmenuFrequencyLoyalty' => 'Frecuencia y Fidelidad',
 	'VisitorInterest_PlusXMin' => '%s min',
-	'VisitorInterest_BetweenXYMinutes' => '%1s-%2s min',
+	'VisitorInterest_BetweenXYMinutes' => '%1s-%1s min',
 	'VisitorInterest_OnePage' => '1 página',
 	'VisitorInterest_NPages' => '%s páginas',
 	'VisitorInterest_BetweenXYSeconds' => '%1s-%2ss',
@@ -619,7 +646,6 @@ $translations = array(
 	'UsersManager_Password' => 'Contraseña',
 	'UsersManager_Email' => 'Email',
 	'UsersManager_Alias' => 'Alias',
-	'UsersManager_Token' => 'token_auth', // Not translated
 	'UsersManager_Edit' => 'Editar',
 	'UsersManager_AddUser' => 'Añadir un nuevo usuario',
 	'UsersManager_MenuUsers' => 'Usuarios',
@@ -638,9 +664,9 @@ $translations = array(
 	'SitesManager_Sites' => 'Sitios',
 	'SitesManager_WebsitesManagement' => 'Adminitración de Sitios',
 	'SitesManager_MainDescription' => '¡Su informe de Análisis Web necesita Sitios Web! Añada, actualice, borre Sitios Web, y muestre el código JavaScript para insertar en sus páginas.',
-	'SitesManager_JsCode' => 'Código JavaScript',
-	'SitesManager_JsCodeHelp' => 'Aquí está el código JavaScript para incluir en todas sus páginas',
-	'SitesManager_ShowJsCode' => 'mostrar código',
+	'SitesManager_JsTrackingTag' => 'Código de seguimiento JavaScript',
+	'SitesManager_JsTrackingTagHelp' => 'Aquí está el código de seguimiento JavaScript para incluir en todas sus páginas',
+	'SitesManager_ShowTrackingTag' => 'mostrar código de seguimiento',
 	'SitesManager_NoWebsites' => 'Usted no tiene ningún sitio web que administrar.',
 	'SitesManager_AddSite' => 'Añadir un nuevo Sitio',
 	'SitesManager_Id' => 'Id',
@@ -675,21 +701,25 @@ $translations = array(
 	'Installation_CommunityNewsletter' => 'envíeme un email con las actualizaciones de la comunidad (nuevos plugins, nuevas características, etc.)',
 	'Installation_PasswordDoNotMatch' => 'las contraseñas no coinciden',
 	'Installation_SubmitGo' => '¡Ir!',
+	'Installation_Requirements' => 'Requisitos de Piwik',
+	'Installation_Optional' => 'Opcional',
+	'Installation_Legend' => 'Leyenda',
 	'Installation_SystemCheck' => 'Comprobación del sistema',
 	'Installation_SystemCheckPhp' => 'Versión PHP',
-	'Installation_SystemCheckPdo' => 'Extensión Pdo',
-	'Installation_SystemCheckPdoMysql' => 'Extensión Pdo_Mysql',
-	'Installation_SystemCheckPdoError' => 'Necesita habilitar las extensiones PDO y PDO_MYSQL en su archivo php.ini.',
-	'Installation_SystemCheckPdoHelp' => 'En un servidor Windows usted puede añadir las siguientes lineas en su php.ini %s <br /><br />En un servidor Linux puede compilar php con la siguiente opción %s En su php.ini, añada las siguientes líneas %s<br /><br />Más información en <a style="color:red" href="http://php.net/pdo">la web de PHP</a>.',
+	'Installation_SystemCheckExtensions' => 'Extensiones requeridas',
+	'Installation_SystemCheckPdoHelp' => 'Necesitas habilitar la extensión PDO en tu archivo php.ini.',
+	'Installation_SystemCheckPdoMysqlHelp' => 'Necesitas habilitar la extensión PDO_MYSQL en tu archivo php.ini.',
+	'Installation_SystemCheckSplHelp' => 'Necesitas configurar y reconstruir PHP con la Librería Estándar de PHP habilitada (por defecto).',
+	'Installation_SystemCheckZlibHelp' => 'Necesitas configurar y reconstruir PHP con el soporte zlib habilitado, --with-zlib.',
 	'Installation_SystemCheckWriteDirs' => 'Directorios con acceso de escritura',
 	'Installation_SystemCheckWriteDirsHelp' => 'Para arreglar este error en su sistema Linux, intente tecleando los siguientes comandos',
 	'Installation_SystemCheckMemoryLimit' => 'Límite de memoria',
 	'Installation_SystemCheckMemoryLimitHelp' => 'On a high traffic website, the archiving process may require more memory than currently allowed.<br />See the directive memory_limit in your php.ini file if necessary.',
 	'Installation_SystemCheckGD' => 'GD &gt; 2.x (gráficas)',
 	'Installation_SystemCheckGDHelp' => 'Las "sparklines" (gráficas pequeñas) no funcionarán.',
-	'Installation_SystemCheckTimeLimit' => 'set_time_limit() permitido',
+	'Installation_SystemCheckFunctions' => 'Funciones requeridas',
 	'Installation_SystemCheckTimeLimitHelp' => 'En un sitio web con un tráfico elevado, la ejecución del proceso de archivado puede requerir más tiempo del permitido.<br />Mire la directiva max_execution_time en su archivo php.ini si es necesario',
-	'Installation_SystemCheckMail' => 'mail() permitido',
+	'Installation_SystemCheckMailHelp' => 'Los mensajes de Feedback y Recuperar Contraseña no se enviarán sin mail().',
 	'Installation_SystemCheckError' => 'Se ha producido un error - debe ser arreglado antes de continuar',
 	'Installation_SystemCheckWarning' => 'Piwik funcionará normalmente, pero algunas características pueden faltar',
 	'Installation_Tables' => 'Creando las tablas',
