@@ -37,7 +37,7 @@ $translations = array(
 	'General_TagCloud' => 'Nuage de tags',
 	'General_VBarGraph' => 'Histogramme vertical',
 	'General_Export' => 'Exporter',
-	'General_ExportAsImage' => 'Exporter au format Image',
+	'General_ExportAsImage_js' => 'Exporter au format Image',
 	'General_SaveImageOnYourComputer' => 'Pour enregistrer l\'image sur votre ordinateur, faites un clic droit sur l\'image et sélectionnez "Enregistrer l\'image sous..."',
 	'General_Refresh' => 'Rafraîchir la page',
 	'General_Visitors' => 'Visiteurs',
@@ -55,7 +55,9 @@ $translations = array(
 	'General_ColumnValuePerVisit' => 'Valeur par Visite',
 	'General_ColumnVisitsWithConversions' => 'Visites avec Conversions',
 	'General_Save' => 'Enregistrer',
-	'General_Website' => 'Site :',
+	'General_Website' => 'Site',
+	'General_RequiresFlash' => 'L\'affichage des Graphs dans Piwik requiert Flash',
+	'General_GraphHelp' => 'Plus d\'informations à propos de l\'affichage des graphs dans Piwik.',
 	'General_NoDataForGraph' => 'Aucune donnée pour ce graphique',
 	'General_NoDataForTagCloud' => 'Aucune donnée pour ce nuage de tags.',
 	'General_DisplayNormalTable' => 'Voir tableau normal',
@@ -102,6 +104,7 @@ $translations = array(
 	'General_LongDay_5' => 'Vendredi',
 	'General_LongDay_6' => 'Samedi',
 	'General_LongDay_7' => 'Dimanche',
+	'General_ExceptionDatabaseVersion' => 'Votre version de %s est %s mais Piwik a besoin au minimum de la version %s.',
 	'CorePluginsAdmin_Plugins' => 'Plugins',
 	'CorePluginsAdmin_PluginsManagement' => 'Gestionnaire de plugins',
 	'CorePluginsAdmin_MainDescription' => 'Les plugins étendent et ajoutent des fonctionnalités à Piwik. Une fois un plugin installé, vous pouvez l\'activer ou le désactiver ici.',
@@ -145,6 +148,32 @@ $translations = array(
 	'CoreHome_DayTh_js' => 'Je',
 	'CoreHome_DayFr_js' => 'Ve',
 	'CoreHome_DaySa_js' => 'Sa',
+	'CoreHome_ShortDay_1_js' => 'Dim',
+	'CoreHome_ShortDay_2_js' => 'Lun',
+	'CoreHome_ShortDay_3_js' => 'Mar',
+	'CoreHome_ShortDay_4_js' => 'Mer',
+	'CoreHome_ShortDay_5_js' => 'Jeu',
+	'CoreHome_ShortDay_6_js' => 'Ven',
+	'CoreHome_ShortDay_7_js' => 'Sam',
+	'CoreHome_LongDay_1_js' => 'Dimanche',
+	'CoreHome_LongDay_2_js' => 'Lundi',
+	'CoreHome_LongDay_3_js' => 'Mardi',
+	'CoreHome_LongDay_4_js' => 'Mercredi',
+	'CoreHome_LongDay_5_js' => 'Jeudi',
+	'CoreHome_LongDay_6_js' => 'Vendredi',
+	'CoreHome_LongDay_7_js' => 'Samedi',
+	'CoreHome_ShortMonth_1_js' => 'Jan',
+	'CoreHome_ShortMonth_2_js' => 'Fév',
+	'CoreHome_ShortMonth_3_js' => 'Mar',
+	'CoreHome_ShortMonth_4_js' => 'Avr',
+	'CoreHome_ShortMonth_5_js' => 'Mai',
+	'CoreHome_ShortMonth_6_js' => 'Jun',
+	'CoreHome_ShortMonth_7_js' => 'Jul',
+	'CoreHome_ShortMonth_8_js' => 'Aoû',
+	'CoreHome_ShortMonth_9_js' => 'Sep',
+	'CoreHome_ShortMonth_10_js' => 'Oct',
+	'CoreHome_ShortMonth_11_js' => 'Nov',
+	'CoreHome_ShortMonth_12_js' => 'Déc',
 	'CoreHome_MonthJanuary_js' => 'Janvier',
 	'CoreHome_MonthFebruary_js' => 'Février',
 	'CoreHome_MonthMarch_js' => 'Mars',
@@ -162,8 +191,15 @@ $translations = array(
 	'CoreUpdater_YourDatabaseIsOutOfDate' => 'Votre base de données est expirée et doit être mise à jour avant de pouvoir continuer.',
 	'CoreUpdater_PiwikWillBeUpgradedFromVersionXToVersionY' => 'La base de données de Piwik sera mise à jour depuis la version %s vers la version %s.',
 	'CoreUpdater_TheFollowingPluginsWillBeUpgradedX' => 'Les plugins suivants seront mis à jour : %s.',
-	'CoreUpdater_TheUpgradeProcessMayTakeAWhilePleaseBePatient' => 'Le procédé de mise à jour peut être long, soyez patients.',
+	'CoreUpdater_TheUpgradeProcessMayFailExecuteCommand' => 'Si votre base de données Piwik est trop volumineuse, la mise à jour pourra être trop longue pour l\'effectuer depuis le navigateur. dans ce cas exécutez depuis la ligne de commande : %s',
+	'CoreUpdater_TheUpgradeProcessMayTakeAWhilePleaseBePatient' => 'Le procédé de mise à jour peut être long, veuillez patienter.',
 	'CoreUpdater_UpgradePiwik' => 'Mettez Piwik à jour',
+	'CoreUpdater_ErrorDIYHelp' => 'Si vous êtes un utilisateur avancé et que vous rencontrez une erreur lors de la mise à jour de la base de données :',
+	'CoreUpdater_ErrorDIYHelp_1' => 'identifiez la source exacte du problème (ex, memory_limit ou max_execution_time)',
+	'CoreUpdater_ErrorDIYHelp_2' => 'exécutez les requêtes restantes qui ont échoué',
+	'CoreUpdater_ErrorDIYHelp_3' => 'mettez à jour manuellement la table `otpion` de votre base de données Piwik, en spécifiant la valeur de version_core à la version de celle de l\'échec de la mise à jour',
+	'CoreUpdater_ErrorDIYHelp_4' => 'ré-exécutez le gestionnaire de mise à jour (en commande ou via le navigateur) pour continuer l\'installation des mises à jour restantes',
+	'CoreUpdater_ErrorDIYHelp_5' => 'rapportez le problème et la solution à Piwik, de cette manière il pourra être vérifié et distribué',
 	'CoreUpdater_HelpMessageContent' => 'Consultez la %s FAQ Piwik %s qui tente d\'expliquer les erreurs les plus communes lors des mises à jour. $s Demandez à votre administrateur système, il pourrait être capable de vous aider à corriger l\'erreur qui est fort probablement reliée à votre serveur ou configuration MySQL.',
 	'CoreUpdater_CriticalErrorDuringTheUpgradeProcess' => 'Erreur Critique pendant le procédé de mise à jour :',
 	'CoreUpdater_HelpMessageIntroductionWhenError' => 'Ci-dessus est le message d\'erreur du noyau. Cela devrait expliquer la cause, mais si vous nécessitez d\'avantage d\'aide merci de :',
@@ -179,14 +215,20 @@ $translations = array(
 	'CoreUpdater_YouCanUpgradeAutomaticallyOrDownloadPackage' => 'Vous pouvez mettre à jour vers la version %s automatiquement ou télécharger l\'archive et l\'installer manuellement:',
 	'CoreUpdater_DownloadX' => 'Télécharger %s',
 	'CoreUpdater_UpdateHasBeenCancelled' => 'La mise à jour a été annulée.',
-	'CoreUpdate_DownloadingUpdateFromX' => 'Téléchargement de la mise à jour depuis %s',
-	'CoreUpdate_UnpackingTheUpdate' => 'Décompression de la mise à jour',
+	'CoreUpdater_DownloadingUpdateFromX' => 'Téléchargement de la mise à jour depuis %s',
+	'CoreUpdater_UnpackingTheUpdate' => 'Décompression de la mise à jour',
 	'CoreUpdater_VerifyingUnpackedFiles' => 'Vérification des fichiers décompressés',
 	'CoreUpdater_CreatingBackupOfConfigurationFile' => 'Création d\'un backup du fichier de configuration dans le répertoire %s',
 	'CoreUpdater_InstallingTheLatestVersion' => 'Installation de la dernière version',
 	'CoreUpdater_PiwikUpdatedSuccessfully' => 'Piwik a été mis à jour avec succès!',
+	'CoreUpdater_EmptyDatabaseError' => 'La base de données %s est vide. Vous devez éditer ou supprimer votre fichier de configuration Piwik.',
+	'CoreUpdater_ExceptionAlreadyLatestVersion' => 'Votre version de Piwik %s est à jour.',
+	'CoreUpdater_ExceptionArchiveIncompatible' => 'Archive incompatible: %s',
+	'CoreUpdater_ExceptionArchiveEmpty' => 'Archive vide.',
+	'CoreUpdater_ExceptionArchiveIncomplete' => 'L\'archive est incomplète: des fichiers sont manquants (ex. %s).',
 	'Actions_Actions' => 'Actions',
 	'Actions_SubmenuPages' => 'Pages',
+	'Actions_SubmenuPageTitles' => 'Titres de la page',
 	'Actions_SubmenuOutlinks' => 'Liens de sortie',
 	'Actions_SubmenuDownloads' => 'Téléchargements',
 	'Actions_ColumnClicks' => 'Clics',
@@ -194,14 +236,15 @@ $translations = array(
 	'Actions_ColumnDownloads' => 'Téléchargements',
 	'Actions_ColumnUniqueDownloads' => 'Téléchargements uniques',
 	'Actions_ColumnPageName' => 'Nom de la page',
+	'Actions_ColumnPageURL' => 'URL de la page',
 	'Actions_ColumnClickedURL' => 'URL sélectionnée',
 	'Actions_ColumnDownloadURL' => 'URL de téléchargement',
 	'Dashboard_Dashboard' => 'Tableau de bord',
 	'Dashboard_AddWidget' => 'Ajouter un widget...',
 	'Dashboard_DeleteWidgetConfirm' => 'Êtes-vous sûr de vouloir supprimer ce widget du tableau de bord?',
 	'Dashboard_SelectWidget' => 'Sélectionnez le widget à ajouter au tableau de bord',
-	'Dashboard_AddPreviewedWidget' => 'Ajouter le widget visualisé au tableau de bord',
-	'Dashboard_WidgetPreview' => 'Prévisualisation du Widget',
+	'Dashboard_AddPreviewedWidget_js' => 'Ajouter le widget visualisé au tableau de bord',
+	'Dashboard_WidgetPreview_js' => 'Prévisualisation du Widget',
 	'Dashboard_Close_js' => 'Fermer',
 	'Dashboard_TitleWidgetInDashboard_js' => 'Widget déjà présent sur le tableau de bord',
 	'Dashboard_TitleClickToAdd_js' => 'Cliquez pour ajouter au tableau de bord',
@@ -540,13 +583,14 @@ $translations = array(
 	'UserCountry_continent_ams' => 'Amérique du sud et centrale',
 	'UserCountry_continent_amn' => 'Amérique du nord',
 	'UserCountry_continent_oce' => 'Océanie',
+	'VisitsSummary_VisitsSummary' => 'Récapitulatif des visites',
 	'VisitsSummary_NbVisits' => '%s visites',
 	'VisitsSummary_NbUniqueVisitors' => '%s visiteurs uniques',
 	'VisitsSummary_NbActions' => '%s actions (pages vues)',
 	'VisitsSummary_TotalTime' => '%s temps total passé par les visiteurs',
 	'VisitsSummary_MaxNbActions' => '%s actions maximums en une visite',
 	'VisitsSummary_NbVisitsBounced' => '%s visiteurs ont survolé (quitté le site après une page)',
-	'VisitsSummary_EvolutionOverLastPeriods' => 'Évolution sur les 30 derniers %ss',
+	'VisitsSummary_EvolutionOverLastPeriods' => 'Évolution sur les 30 derniers %s',
 	'VisitsSummary_Report' => 'Rapport',
 	'VisitsSummary_GenerateTime' => '%s secondes pour générer la page',
 	'VisitsSummary_GenerateQueries' => '%s requêtes exécutées',
@@ -565,7 +609,7 @@ $translations = array(
 	'VisitFrequency_ReturnActions' => '%s actions de visites de visiteurs connus',
 	'VisitFrequency_ReturnMaxActions' => '%s actions maximums par visite de visiteur connus',
 	'VisitFrequency_ReturnTotalTime' => '%s temps total passé par des visiteurs connus',
-	'VisitFrequency_ReturnBounces' => '%s visiteurs connus ont survolé (quitté le site après une page)',
+	'VisitFrequency_ReturnBounceRate' => '%s visiteurs connus ont survolé (quitté le site après une page)',
 	'VisitFrequency_WidgetOverview' => 'Récapitulatif de la Fréquence',
 	'VisitFrequency_WidgetGraphReturning' => 'Graphique de visites de visiteurs connus',
 	'VisitFrequency_SubmenuFrequency' => 'Fréquence',
@@ -585,20 +629,26 @@ $translations = array(
 	'VisitorInterest_WidgetPages' => 'Pages par visite',
 	'VisitorInterest_SubmenuFrequencyLoyalty' => 'Fréquence et Fidélité',
 	'VisitorInterest_PlusXMin' => '%s min',
-	'VisitorInterest_BetweenXYMinutes' => '%1s-%2s min',
+	'VisitorInterest_BetweenXYMinutes' => '%1s-%1s min',
 	'VisitorInterest_OnePage' => '1 page',
 	'VisitorInterest_NPages' => '%s pages',
 	'VisitorInterest_BetweenXYSeconds' => '%1s-%2ss',
 	'Login_LoginPasswordNotCorrect' => 'Mot de passe et nom d\'utilisateur incorrects.',
 	'Login_Login' => 'Nom d\'utilisateur',
 	'Login_Password' => 'Mot de passe',
+	'Login_PasswordRepeat' => 'Mot de passe (répétez)',
+	'Login_ChangePassword' => 'Modifier le mot de passe',
 	'Login_LoginOrEmail' => 'Nom d\'utilisateur ou courriel',
 	'Login_LogIn' => 'Connexion',
 	'Login_Logout' => 'Déconnexion',
 	'Login_LostYourPassword' => 'Mot de passe perdu ?',
 	'Login_RemindPassword' => 'Rappeler le mot de passe',
+	'Login_PasswordResetToken' => 'Clef de remise à zéro du mot de passe',
 	'Login_PasswordReminder' => 'Entrez un nom d\'utilisateur ou un courriel valide, vous recevrez votre nouveau mot de passe par courriel.',
+	'Login_PasswordsDoNotMatch' => 'Les mots de passe ne correspondent pas.',
+	'Login_PasswordSuccessfullyChanged' => 'Mot de passe modifié avec succès!',
 	'Login_InvalidUsernameEmail' => 'Nom d\'utilisateur et/ou courriel invalide.',
+	'Login_InvalidOrExpiredToken' => 'La Clef est invalide ou a expiré',
 	'Login_MailTopicPasswordRecovery' => 'Récupération du mot de passe',
 	'Login_MailPasswordRecoveryBody' => 'Hi %1s, \n\n Votre nouveau mot de passe est : %2s \n\n Vous pouvez vous connecter maintenant ici : %3s',
 	'Login_PasswordSent' => 'Le mot de passe vient juste d\'être envoyé. Veuillez vérifier vos courriels.',
@@ -619,7 +669,6 @@ $translations = array(
 	'UsersManager_Password' => 'Mot de passe',
 	'UsersManager_Email' => 'Courriel',
 	'UsersManager_Alias' => 'Alias',
-	'UsersManager_Token' => 'token_auth',
 	'UsersManager_Edit' => 'Éditer',
 	'UsersManager_AddUser' => 'Ajouter un nouvel utilisateur',
 	'UsersManager_MenuUsers' => 'Utilisateurs',
@@ -638,11 +687,14 @@ $translations = array(
 	'SitesManager_Sites' => 'Sites',
 	'SitesManager_WebsitesManagement' => 'Gestion des sites',
 	'SitesManager_MainDescription' => 'Piwik a besoin de sites pour générer des rapports ! Ajoutez, éditez et supprimez des sites, et voyez le code JavaScript à inclure dans vos pages.',
-	'SitesManager_JsCode' => 'Code JavaScript',
-	'SitesManager_JsCodeHelp' => 'Ici se trouve le code JavaScript à inclure dans toutes vos pages ',
-	'SitesManager_ShowJsCode' => 'Afficher le code',
+	'SitesManager_JsTrackingTag' => 'Code JavaScript de suivit',
+	'SitesManager_JsTrackingTagHelp' => 'Ci-dessous le code JavaScript à inclure dans toutes vos pages ',
+	'SitesManager_ShowTrackingTag' => 'Afficher le code',
 	'SitesManager_NoWebsites' => 'Vous n\'avez aucun site Internet à administrer.',
 	'SitesManager_AddSite' => 'Ajouter un site',
+	'SitesManager_AliasUrlHelp' => 'Il est recommandé, mais pas requis, de spécifier les URL différentes que vos utilisateurs utilisent pour accéder au site web. 
+Les URL d\'alias pour un site n\'apparaitront pas dans Reférents > Sites Internet. 
+Il n\'est pas nécessaire d\'entrer les URL avec et sans les www, Piwik les traite automatiquement.',
 	'SitesManager_Id' => 'Id',
 	'SitesManager_Name' => 'Nom',
 	'SitesManager_Urls' => 'URLs',
@@ -656,15 +708,34 @@ $translations = array(
 	'Installation_InstallationStatus' => 'Statut de l\'installation',
 	'Installation_PercentDone' => '%s %% Fait',
 	'Installation_NoConfigFound' => 'Le fichier de configuration de Piwik ne peut être trouvé et vous essayez d\'accéder à une page de Piwik.<br> <b>&nbsp;&nbsp;&raquo; Vous pouvez <a href=\'index.php\'>installer Piwik maintenant</a></b><br><small>Si vous avez déjà installé Piwik ne vous inquiétez pas Piwik réutilisera ces tables et leurs données.</small>',
-	'Installation_MysqlSetup' => 'Configuration de la base de données MySQL',
-	'Installation_MysqlErrorConnect' => 'Erreur durant la connexion à la base de données MySQL',
+	'Installation_DatabaseSetup' => 'Installation de la base de données',
+	'Installation_DatabaseSetupServer' => 'serveur de la base de données',
+	'Installation_DatabaseSetupLogin' => 'compte',
+	'Installation_DatabaseSetupPassword' => 'mot de passe',
+	'Installation_DatabaseSetupDatabaseName' => 'nom de la base',
+	'Installation_DatabaseSetupTablePrefix' => 'préfixe des tables',
+	'Installation_DatabaseSetupAdapter' => 'adaptateur',
+	'Installation_DatabaseErrorConnect' => 'Erreur lors de la tentative de connexion au serveur de base de données',
+	'Installation_DatabaseCheck' => 'Vérification de la base de données',
+	'Installation_DatabaseServerVersion' => 'Version du serveur de base de données',
+	'Installation_DatabaseCreation' => 'Création de la base de données',
+	'Installation_DatabaseClientCharset' => 'Jeu de caractères client de la base de données',
+	'Installation_ConnectionCharacterSetNotUtf8' => 'La connexion au serveur de base de données n\'est pas en UTF8. Ceci n\'est pas une erreur critique: <b>Piwik devrait fonctionner correctement</b>. Par soucis de cohérence il est recommandé d\'effectuer les tâches suivantes: <ul style="list-style: disc;margin-left:10px"><li>dans votre config/config.ini.php de piwik, ajoutez <code>charset = utf8</code> en dessous de la section  [database] </li><li>recompilez libmysql --with-charset=utf8</li></ul>',
+	'Installation_DatabaseTimezone' => 'Fuseau horaire de la base de données',
+	'Installation_TimezoneMismatch' => 'PHP date.timezone n\'est pas la même que le le fuseau horaire du serveur de base de données. Ceci pourrait causer un problème de décallage des heures et jours dans les rapports. Plus d\'informations ici %s',
 	'Installation_JsTag' => 'Tag JavaScript',
 	'Installation_JsTagHelp' => '<p>Pour comptabiliser tous les visiteurs vous devez copier le tag sur toutes vos pages.</p><p>Vos pages n\'ont pas besoin d\'être en PHP, Piwik fonctionne avec tout type de pages (HTML, ASP, Perl ou n\'importe quel autre langage).</p><p>Ici se trouve le code à insérer : (copiez/collez dans toutes vos pages) </p>',
+	'Installation_JsTagHelpTitle' => 'Comment insérer le tag dans vos sites web?',
+	'Installation_LargePiwikInstances' => 'Aide pour les instances de Piwik volumineuses',
+	'Installation_JsTagArchivingHelp' => 'Pour les sites à moyen et fort trafic, lisez <a target="_blank" href="http://piwik.org/docs/setup-auto-archiving/">la page d\'explication sur comment mettre en place une page d\'auto archivage</a> pour que Piwik devienne réellement rapide!',
 	'Installation_Congratulations' => 'Félicitations',
 	'Installation_CongratulationsHelp' => '<p>Félicictations! Votre installation de Piwik est terminée.</p><p>Assurez vous que le code JavaScript est présent sur toutes vos pages et attendez vos premiers visiteurs!</p>',
 	'Installation_ContinueToPiwik' => 'Continuer vers Piwik',
 	'Installation_SetupWebsite' => 'Paramètrer un site',
+	'Installation_SetupWebSiteName' => 'nom du site web',
+	'Installation_SetupWebSiteURL' => 'Url du site web',
 	'Installation_SetupWebsiteError' => 'Une erreur a été recontrée pendant l\'ajout du site',
+	'Installation_SetupWebsiteSetupSuccess' => 	'Site %s créé avec succès!',
 	'Installation_GeneralSetup' => 'Paramètres généraux',
 	'Installation_GeneralSetupSuccess' => 'Paramètres génraux configurés avec succès',
 	'Installation_SuperUserLogin' => 'login du super user',
@@ -675,21 +746,38 @@ $translations = array(
 	'Installation_CommunityNewsletter' => 'Envoyez moi un courriel pour les nouveautés de la communauté (nouveaux plugins, nouvelles fonctionnalités, etc.)',
 	'Installation_PasswordDoNotMatch' => 'Le mot de passe ne concorde pas',
 	'Installation_SubmitGo' => 'Go!',
+	'Installation_Requirements' => 'Pré-requis Piwik',
+	'Installation_Optional' => 'Optionel',
+	'Installation_Legend' => 'Légendes',
+	'Installation_Extension' => 'extension',
 	'Installation_SystemCheck' => 'Vérification du système',
 	'Installation_SystemCheckPhp' => 'Version PHP',
-	'Installation_SystemCheckPdo' => 'Extension Pdo',
-	'Installation_SystemCheckPdoMysql' => 'Extension Pdo_Mysql',
-	'Installation_SystemCheckPdoError' => 'Vous devez activer les extensions PDO et POD_MYSQL dans votre fichier de configuration php.ini.',
-	'Installation_SystemCheckPdoHelp' => 'Sur un serveur windows vous pouvez ajouter les lignes suivantes à votre php.ini %s <br /><br />Sur un serveur Linux vous pouvez compiler PHP avec les options suivantes %s Dans votre php.ini, ajoutez les lignes suivantes %s<br /><br />Plus d\'informations sur le <a style="color:red" href="http://php.net/pdo">Site de PHP</a>.',
+	'Installation_SystemCheckExtensions' => 'Extensions requises',
+	'Installation_SystemCheckDatabaseHelp' => 'Piwik requiert ou l\'extension mysqli ou les extensions pdo et pdo_mysql.',
+	'Installation_SystemCheckPdoAndMysqliHelp' => "Sur un serveur linux vous pouvez compiler PHP avec les options suivantes : %s\n Dans votre php.ini, ajoutez les lignes suivantes: %s",
+	'Installation_SystemCheckPhpPdoAndMysqliSite' => 'Plus d\'informations sur: <a style="color:red" href="http://php.net/pdo">PHP PDO</a> et <a style="color:red" href="http://php.net/mysqli">MYSQLI</a>.',
+	'Installation_SystemCheckWinPdoAndMysqliHelp' => 'Sur un serveur windows vous pouvez ajouter les lignes suivantes à votre php.ini: %s',
+	'Installation_SystemCheckSplHelp' => 'Vous devez configurer et recompiler PHP avec la librairie standart (par défaut).',
+	'Installation_SystemCheckZlibHelp' => 'Vous devez reconfigurer et recompiler PHP avec le support zlib, --with-zlib.',
+	'Installation_SystemCheckIconvHelp' => 'Vous devez configurer PHP et le recompiler avec le support "iconv" activé, --with-iconv.',
+	'Installation_SystemCheckDomHelp' => 'DOM est une partie du coeur de PHP. Vous avez probablement besoin d\'installer le module dom ex, php-5-dom.',
+	'Installation_SystemCheckJson' => 'JSON',
+	'Installation_SystemCheckJsonHelp' => 'Vous devez recompiler PHP avec l\'extension "json" ou "xml" activée.',
+	'Installation_SystemCheckJsonSite' => 'Plus d\'informations sur : <a style="color:red" href="http://php.net/json">PHP JSON</a>.',
+	'Installation_SystemCheckXml' => 'XML',
+	'Installation_SystemCheckXmlHelp' => 'Des plugins et librairies tierces pourront avoir besoin de l\'extension XML.',
+	'Installation_SystemCheckXmlSite' => 'Plus d\'informations sur: <a style="color:red" href="http://php.net/xml">PHP XML</a>.',
 	'Installation_SystemCheckWriteDirs' => 'Répertoires avec les droits d\'accès en écriture',
 	'Installation_SystemCheckWriteDirsHelp' => 'Pour corriger les erreurs sur votre système Linux essayez de taper les commandes suivantes',
 	'Installation_SystemCheckMemoryLimit' => 'Limite mémoire',
 	'Installation_SystemCheckMemoryLimitHelp' => 'Sur un site à trafic important le processus d\'archivage peut prendre plus de mémoire que la limite actuelle autorisée.<br />Référez vous à la configuration memory_limit de votre php.ini si nécessaire.',
+	'Installation_SystemCheckOpenURL' => 'Ouvrez l\'URL',
+	'Installation_SystemCheckOpenURLHelp' => 'Abonnements à la newsletter, notifications des mises à jour, et mise à jour en un click requièrent l\'extension curl, allow_url_fopen=On, ou fsockopen() activé.',
 	'Installation_SystemCheckGD' => 'GD &gt; 2.x (graphiques)',
 	'Installation_SystemCheckGDHelp' => 'Les sparklines (petits graphs) ne fonctionneront pas.',
-	'Installation_SystemCheckTimeLimit' => 'set_time_limit() autorisé',
+	'Installation_SystemCheckFunctions' => 'Fonctions requises',
 	'Installation_SystemCheckTimeLimitHelp' => 'Sur un site à trafic important le processus d\'archivage peut prendre plus de temps qu\'il n\'est déjà autorisé.<br /> Référez vous à la configuration max_execution_time de votre php.ini si nécessaire.',
-	'Installation_SystemCheckMail' => 'mail() autoristé',
+	'Installation_SystemCheckMailHelp' => 'Les Feedback (commentaires) et mots de passe perdus ne pourront être envoyés sans la fonciton mail().',
 	'Installation_SystemCheckError' => 'Une erreur s\'est produite — elle doit être corrigée avant de pouvoir continuer',
 	'Installation_SystemCheckWarning' => 'Piwik fonctionnera normalement mais certaines fonctionnalités seront manquantes',
 	'Installation_Tables' => 'Création des tables',
@@ -714,6 +802,7 @@ $translations = array(
 	'Goals_ColumnRevenue' => 'Revenu',
 	'DBStats_DatabaseUsage' => 'Utilisation de la base de données',
 	'DBStats_MainDescription' => 'Piwil conserve toutes vos analyses web dans la base de données MySQL. Présentement, les tables utilisent %s.',
+	'DBStats_LearnMore' => 'Pour en apprendre plus sur la manière de Piwik de traiter les données et sur comment faire fonctionner Piwik correctement pour les sites à trafic moyen et fort, veuillez consulter cette documentation %s.',
 	'DBStats_Table' => 'Table',
 	'DBStats_RowNumber' => 'Numéro de rangée',
 	'DBStats_DataSize' => 'Taille des données',
