@@ -117,7 +117,7 @@ $translations = array(
 	'UserSettings_Browsers' => 'Navegadores',
 	'UserSettings_Plugins' => 'Plugins',
 	'UserSettings_Configurations' => 'Configuracións',
-	'UserSettings_OperatinsSystems' => 'Sistemas Operativos',
+	'UserSettings_OperatingSystems' => 'Sistemas Operativos',
 	'UserSettings_Resolutions' => 'Resolucións',
 	'UserSettings_WideScreen' => 'Pantalla panorámica',
 	'UserSettings_WidgetResolutions' => 'Resolucións de pantalla',
@@ -392,7 +392,7 @@ $translations = array(
 	'VisitsSummary_TotalTime' => '%s tempo total dos usuarios en liña',
 	'VisitsSummary_MaxNbActions' => '%s accións máximas nunha visita',
 	'VisitsSummary_NbBounced' => '%s visitantes sairon (saiu da páxina despois dunha páxina)',
-	'VisitsSummary_Evolution' => 'Evolución nos derradeiros 30 %ss',
+	'VisitsSummary_Evolution' => 'Evolución nos derradeiros 30 %s',
 	'VisitsSummary_Report' => 'Informe',
 	'VisitsSummary_GenerateTime' => '%s segundos para xerar a páxina',
 	'VisitsSummary_GenerateQueries' => '%s consultas executadas',
@@ -536,4 +536,4 @@ $translations = array(
 	'TranslationsAdmin_LanguageCode' => 'Código de idioma',
 	'TranslationsAdmin_Export' => 'Exportar idioma',
 	'TranslationsAdmin_Import' => 'Importar idioma',
-);
\ No newline at end of file
+);
