@@ -145,6 +145,32 @@ $translations = array(
 	'CoreHome_DayTh_js' => 'Cs',
 	'CoreHome_DayFr_js' => 'P',
 	'CoreHome_DaySa_js' => 'Szo',
+	'CoreHome_ShortDay_1_js' => 'Vas',
+	'CoreHome_ShortDay_2_js' => 'Hét',
+	'CoreHome_ShortDay_3_js' => 'Ked',
+	'CoreHome_ShortDay_4_js' => 'Sze',
+	'CoreHome_ShortDay_5_js' => 'Csü',
+	'CoreHome_ShortDay_6_js' => 'Pén',
+	'CoreHome_ShortDay_7_js' => 'Szo',
+	'CoreHome_LongDay_1_js' => 'Vasámap',
+	'CoreHome_LongDay_2_js' => 'Hétfö',
+	'CoreHome_LongDay_3_js' => 'Kedd',
+	'CoreHome_LongDay_4_js' => 'Szerda',
+	'CoreHome_LongDay_5_js' => 'Csütörtök',
+	'CoreHome_LongDay_6_js' => 'Péntek',
+	'CoreHome_LongDay_7_js' => 'Szombat',
+	'CoreHome_ShortMonth_1_js' => 'Jan',
+	'CoreHome_ShortMonth_2_js' => 'Feb',
+	'CoreHome_ShortMonth_3_js' => 'Már',
+	'CoreHome_ShortMonth_4_js' => 'Ápr',
+	'CoreHome_ShortMonth_5_js' => 'Máj',
+	'CoreHome_ShortMonth_6_js' => 'Jún',
+	'CoreHome_ShortMonth_7_js' => 'Júl',
+	'CoreHome_ShortMonth_8_js' => 'Aug',
+	'CoreHome_ShortMonth_9_js' => 'Szep',
+	'CoreHome_ShortMonth_10_js' => 'Okt',
+	'CoreHome_ShortMonth_11_js' => 'Nov',
+	'CoreHome_ShortMonth_12_js' => 'Dec',
 	'CoreHome_MonthJanuary_js' => 'Január',
 	'CoreHome_MonthFebruary_js' => 'Február',
 	'CoreHome_MonthMarch_js' => 'Március',
@@ -247,14 +273,14 @@ $translations = array(
 	'UserSettings_Browsers' => 'Böngészők',
 	'UserSettings_Plugins' => 'Bővítmények',
 	'UserSettings_Configurations' => 'Konfigurációk',
-	'UserSettings_OperatinsSystems' => 'Operációs rendszerek',
+	'UserSettings_OperatingSystems' => 'Operációs rendszerek',
 	'UserSettings_Resolutions' => 'Felbontások',
 	'UserSettings_WideScreen' => 'Képernyő oldalarányai',
 	'UserSettings_ColumnBrowserFamily' => 'Böngészőcsalád',
 	'UserSettings_ColumnBrowser' => 'Böngésző',
 	'UserSettings_ColumnPlugin' => 'Bővítmény',
 	'UserSettings_ColumnConfiguration' => 'Konfiguráció',
-	'UserSettings_ColumnOperatinsSystem' => 'Operációs rendszer',
+	'UserSettings_ColumnOperatingSystem' => 'Operációs rendszer',
 	'UserSettings_ColumnResolution' => 'Felbontás',
 	'UserSettings_ColumnTypeOfScreen' => 'Képernyő típusa',
 	'UserSettings_WidgetResolutions' => 'Képernyőfelbontások',
@@ -570,7 +596,7 @@ $translations = array(
 	'VisitorInterest_WidgetPages' => 'Oldalak/látogatás',
 	'VisitorInterest_SubmenuFrequencyLoyalty' => 'Gyakoriság és hűség',
 	'VisitorInterest_PlusXMin' => '%s perc',
-	'VisitorInterest_BetweenXYMinutes' => '%1s-%2s perc',
+	'VisitorInterest_BetweenXYMinutes' => '%1s-%1s perc',
 	'VisitorInterest_OnePage' => '1 oldal',
 	'VisitorInterest_NPages' => '%s oldal',
 	'VisitorInterest_BetweenXYSeconds' => '%1s-%2s s',
@@ -717,4 +743,4 @@ $translations = array(
 	'TranslationsAdmin_LanguageCode' => 'Nyelvi kód',
 	'TranslationsAdmin_Export' => 'Nyelv exportálása',
 	'TranslationsAdmin_Import' => 'Nyelv importálása',
-);
\ No newline at end of file
+);
