@@ -1,8 +1,8 @@
 <?php 
 $translations = array(
 	'General_Locale' => 'nl_NL.UTF-8',
-	'General_TranslatorName' => 'Martijn van Laar',
-	'General_TranslatorEmail' => 'martijn@mvanlaar.net',
+	'General_TranslatorName' => 'Martijn van Laar, Hannes Bossuyt',
+	'General_TranslatorEmail' => 'martijn@mvanlaar.net, hannes@randomize.be',
 	'General_EnglishLanguageName' => 'Dutch',
 	'General_OriginalLanguageName' => 'Nederlands',
 	'General_Unknown' => 'Onbekend',
@@ -54,12 +54,61 @@ $translations = array(
 	'General_DisplayNormalTable' => 'Geef een normale tabel weer',
 	'General_DisplayMoreData' => 'Geef meer data weer',
 	'General_YouAreCurrentlyViewingDemoOfPiwik' => 'Je kijkt op dit moment naar een demo van %s; %sdownload%s de volledige versie! Kijk naar %s',
-	'API_QuickDocumentation' => '<h2>API beknopte documentatie</h2><p>Wanneer u geen data voor vandaag heeft, kunt u eerst <a href=\'misc/generateVisits.php\' target=_blank>wat data genereren</a> door middel van het Bezoek Generator script.</p><p>U kunt voor elke methode een ander formaat proberen. Het is heel eenvoudig data uit piwik te halen!</p><p><b>Voor meer informatie bekijk de <a href=\'http://dev.piwik.org/trac/wiki/API\'>officiele API Documentatie</a> of de <a href=\'http://dev.piwik.org/trac/wiki/API/Reference\'>API Reference</a>.</b></P><h2>Gebruiker herkenning</h2><p>Wanneer u <b>de data van uw scripts opvraagt middels een crontab, etc. </b> u dient de volgende parameter <code><u>&token_auth=%s</u></code> toe te voegen aan de API oproep URLs die identificatie vereisen.</p><p>Deze token_auth is zo persoonlijk als uw login en password, <b>deel deze informatie niet met anderen!</p>',
-	'API_LoadedAPIs' => 'Succesvol %s APIs geladen',
+	'General_Loading' => 'Laden...',
+	'General_ExportAsImage' => 'Exporteer als afbeelding',
+	'General_SaveImageOnYourComputer' => 'Om de afbeelding op te slaan op uw computer, klik rechts op de afbeelding en selecteer "Sla afbeelding op als..."',
+	'General_ColumnNbActions' => 'Acties',
+	'General_ColumnMaxActions' => 'Maximaal aantal acties per bezoek.',
+	'General_ColumnSumVisitLength' => 'Totale tijd gespendeerd door de bezoekers (in seconden)',
+	'General_ColumnValuePerVisit' => 'Waarde per bezoek',
+	'General_ColumnVisitsWithConversions' => 'Bezoekers met conversies',
+	'General_PiwikIsACollaborativeProjectYouCanContribute' => '%s Piwik %s is een samenwerkings project. %s Als je Piwik handig vindt, dan kun je helpen! Zoek uit %s Hoe je kan meehelpen aan Piwik.%s',
+	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Piwik %s is beschikbaar. %s Gelieve nu te updaten! %s \'zie %s wijzigingen%s)',
+	'General_BackToPiwik' => 'Terug naar Piwik',
+	'General_ShortMonth_1' => 'Jan',
+	'General_ShortMonth_2' => 'Feb',
+	'General_ShortMonth_3' => 'Mrt',
+	'General_ShortMonth_4' => 'Apr',
+	'General_ShortMonth_5' => 'Mei',
+	'General_ShortMonth_6' => 'Jun',
+	'General_ShortMonth_7' => 'Jul',
+	'General_ShortMonth_8' => 'Aug',
+	'General_ShortMonth_9' => 'Sep',
+	'General_ShortMonth_10' => 'Okt',
+	'General_ShortMonth_11' => 'Nov',
+	'General_ShortMonth_12' => 'Dec',
+	'General_LongMonth_1' => 'Januari',
+	'General_LongMonth_2' => 'Februari',
+	'General_LongMonth_3' => 'Maart',
+	'General_LongMonth_4' => 'April',
+	'General_LongMonth_5' => 'Mei',
+	'General_LongMonth_6' => 'Juni',
+	'General_LongMonth_7' => 'Juli',
+	'General_LongMonth_8' => 'Augustus',
+	'General_LongMonth_9' => 'September',
+	'General_LongMonth_10' => 'Oktober',
+	'General_LongMonth_11' => 'November',
+	'General_LongMonth_12' => 'December',
+	'General_ShortDay_1' => 'Ma',
+	'General_ShortDay_2' => 'Di',
+	'General_ShortDay_3' => 'Wo',
+	'General_ShortDay_4' => 'Do',
+	'General_ShortDay_5' => 'Vr',
+	'General_ShortDay_6' => 'Za',
+	'General_ShortDay_7' => 'Zo',
+	'General_LongDay_1' => 'Maandag',
+	'General_LongDay_2' => 'Dinsdag',
+	'General_LongDay_3' => 'Woensdag',
+	'General_LongDay_4' => 'Donderdag',
+	'General_LongDay_5' => 'Vrijdag',
+	'General_LongDay_6' => 'Zaterdag',
+	'General_LongDay_7' => 'Zondag',
 	'Actions_Actions' => 'Acties',
 	'Actions_SubmenuPages' => 'Pagina\'s',
 	'Actions_SubmenuOutlinks' => 'Externe links',
 	'Actions_SubmenuDownloads' => 'Downloads',
+	'API_QuickDocumentation' => '<h2>API beknopte documentatie</h2><p>Wanneer u geen data voor vandaag heeft, kunt u eerst <a href=\'misc/generateVisits.php\' target=_blank>wat data genereren</a> door middel van het Bezoek Generator script.</p><p>U kunt voor elke methode een ander formaat proberen. Het is heel eenvoudig data uit piwik te halen!</p><p><b>Voor meer informatie bekijk de <a href=\'http://dev.piwik.org/trac/wiki/API\'>officiele API Documentatie</a> of de <a href=\'http://dev.piwik.org/trac/wiki/API/Reference\'>API Reference</a>.</b></P><h2>Gebruiker herkenning</h2><p>Wanneer u <b>de data van uw scripts opvraagt middels een crontab, etc. </b> u dient de volgende parameter <code><u>&token_auth=%s</u></code> toe te voegen aan de API oproep URLs die identificatie vereisen.</p><p>Deze token_auth is zo persoonlijk als uw login en password, <b>deel deze informatie niet met anderen!</p>',
+	'API_LoadedAPIs' => 'Succesvol %s APIs geladen',
 	'CoreHome_NoPrivileges' => 'U bent ingelogd als \'%s\' maar het lijkt er op dat u niet voldoende rechten bezit Piwik te gebruiken.<br />Vraag uw Piwik administrator om \'kijkers rechten\' voor een website.',
 	'CoreHome_JavascriptDisabled' => 'JavaScript moet geactiveerd zijn om Piwik in de standaard modus te gebruiken.<br />Het lijkt er op dat JavaScript of uitgeschakeld is of niet ondersteund wordt door uw browser.<br />Om de standaard modus te gebruiken, activeer JavaScript in uw browser instellingen, probeer het daarna %1snogmaals%2s.<br />',
 	'CoreHome_TableNoData' => 'Geen data voor deze tabel gevonden.',
@@ -126,13 +175,6 @@ $translations = array(
 	'CoreUpdater_WeAutomaticallyDeactivatedTheFollowingPlugins' => 'We hebben de volgende plugins ge-deactiveerd',
 	'CoreUpdater_PiwikHasBeenSuccessfullyUpgraded' => 'Piwik upgrade was succesvol!',
 	'CoreUpdater_ContinueToPiwik' => 'Ga verder naar Piwik',
-	'DBStats_DatabaseUsage' => 'Database gebruik',
-	'DBStats_MainDescription' => 'Piwik slaat alle analyse data op in een MySQL database. Momenteel is de omvang van deze database %s.',
-	'DBStats_Table' => 'Tabel',
-	'DBStats_RowNumber' => 'Rij nummer',
-	'DBStats_DataSize' => 'Data omvang',
-	'DBStats_IndexSize' => 'Index grootte',
-	'DBStats_TotalSize' => 'Totale grootte',
 	'Dashboard_Dashboard' => 'Dashboard',
 	'Dashboard_AddWidget' => 'Voeg een widget toe...',
 	'Dashboard_DeleteWidgetConfirm' => 'Weet u zeker dat u deze widget van het dashboard wilt verwijderen?',
@@ -144,268 +186,13 @@ $translations = array(
 	'Dashboard_LoadingPreview_js' => 'Bezig voorvertoning te laden, even geduld a.u.b...',
 	'Dashboard_LoadingWidget_js' => 'Bezig widget te laden, even geduld a.u.b...',
 	'Dashboard_WidgetNotFound_js' => 'Widget niet gevonden',
-	'GeoIP_Country' => 'Land',
-	'GeoIP_Continent' => 'Continent',
-	'GeoIP_DistinctCountries' => '%s unieke landen',
-	'GeoIP_SubmenuLocations' => 'Locaties',
-	'GeoIP_WidgetContinents' => 'Bezoeker continenten',
-	'GeoIP_WidgetCountries' => 'Bezoeker landen',
-	'GeoIP_country_' => 'Data niet beschikbaar',
-	'GeoIP_country_ac' => 'Ascension eilanden',
-	'GeoIP_country_ad' => 'Andorra',
-	'GeoIP_country_ae' => 'Verenigde Emiraten',
-	'GeoIP_country_af' => 'Afghanistan',
-	'GeoIP_country_ag' => 'Antigua en Brabuda',
-	'GeoIP_country_ai' => 'Anguilla',
-	'GeoIP_country_al' => 'Albani&euml;',
-	'GeoIP_country_am' => 'Armeni&euml;',
-	'GeoIP_country_an' => 'Nederlandse Antillen',
-	'GeoIP_country_ao' => 'Angola',
-	'GeoIP_country_aq' => 'Antartica',
-	'GeoIP_country_ar' => 'Argentini&euml;',
-	'GeoIP_country_as' => 'Samoa',
-	'GeoIP_country_at' => 'Oostenrijk',
-	'GeoIP_country_au' => 'Australi&euml;',
-	'GeoIP_country_aw' => 'Aruba',
-	'GeoIP_country_az' => 'Azerbeijan',
-	'GeoIP_country_ba' => 'Bosni&euml; en Herzegovina',
-	'GeoIP_country_bb' => 'Barbados',
-	'GeoIP_country_bd' => 'Bangladesh',
-	'GeoIP_country_be' => 'Belgi&euml;',
-	'GeoIP_country_bf' => 'Burkina Faso',
-	'GeoIP_country_bg' => 'Bulgari&euml;',
-	'GeoIP_country_bh' => 'Bahrain',
-	'GeoIP_country_bi' => 'Burundi',
-	'GeoIP_country_bj' => 'Benin',
-	'GeoIP_country_bm' => 'Bermuda',
-	'GeoIP_country_bn' => 'Bruneo',
-	'GeoIP_country_bo' => 'Bolivi&euml;',
-	'GeoIP_country_br' => 'Barzili&euml;',
-	'GeoIP_country_bs' => 'Bahamas',
-	'GeoIP_country_bt' => 'Bhutan',
-	'GeoIP_country_bv' => 'Bouvet eiland',
-	'GeoIP_country_bw' => 'Botswana',
-	'GeoIP_country_by' => 'Belarus',
-	'GeoIP_country_bz' => 'Blize',
-	'GeoIP_country_ca' => 'Canada',
-	'GeoIP_country_cc' => 'Cocos eilanden',
-	'GeoIP_country_cd' => 'Congo',
-	'GeoIP_country_cf' => 'Centraal Afrika',
-	'GeoIP_country_cg' => 'Congo',
-	'GeoIP_country_ch' => 'Zwitserland',
-	'GeoIP_country_ci' => 'Ivoorkust',
-	'GeoIP_country_ck' => 'Cook eilanden',
-	'GeoIP_country_cl' => 'Chili',
-	'GeoIP_country_cm' => 'Kameroen',
-	'GeoIP_country_cn' => 'China',
-	'GeoIP_country_co' => 'Colombia',
-	'GeoIP_country_cr' => 'Costa Rica',
-	'GeoIP_country_cs' => 'Montenegro',
-	'GeoIP_country_cu' => 'Cuba',
-	'GeoIP_country_cv' => 'Kaap de goed hoop',
-	'GeoIP_country_cx' => 'Paaseilanden',
-	'GeoIP_country_cy' => 'Cyprus',
-	'GeoIP_country_cz' => 'Tsjechi&euml;',
-	'GeoIP_country_de' => 'Duitsland',
-	'GeoIP_country_dj' => 'Djibouti',
-	'GeoIP_country_dk' => 'Denemarken',
-	'GeoIP_country_dm' => 'Dominica',
-	'GeoIP_country_do' => 'Dominicaanse republiek',
-	'GeoIP_country_dz' => 'Algerij&euml;',
-	'GeoIP_country_ec' => 'Ecuador',
-	'GeoIP_country_ee' => 'Estonia',
-	'GeoIP_country_eg' => 'Egypte',
-	'GeoIP_country_eh' => 'West Sahara',
-	'GeoIP_country_er' => 'Eritrea',
-	'GeoIP_country_es' => 'Spanje',
-	'GeoIP_country_et' => 'Ethiopi&euml;',
-	'GeoIP_country_fi' => 'Finland',
-	'GeoIP_country_fj' => 'Fiji',
-	'GeoIP_country_fk' => 'Falkland Eilanden',
-	'GeoIP_country_fm' => 'Micronesia',
-	'GeoIP_country_fo' => 'Farao Eilanden',
-	'GeoIP_country_fr' => 'Frankrijk',
-	'GeoIP_country_ga' => 'Gabon',
-	'GeoIP_country_gd' => 'Grenada',
-	'GeoIP_country_ge' => 'Georgi&euml;',
-	'GeoIP_country_gf' => 'Frans Guinea',
-	'GeoIP_country_gg' => 'Guernsey',
-	'GeoIP_country_gh' => 'Ghana',
-	'GeoIP_country_gi' => 'Gibraltar',
-	'GeoIP_country_gl' => 'Groenland',
-	'GeoIP_country_gm' => 'Gambia',
-	'GeoIP_country_gn' => 'Guinea',
-	'GeoIP_country_gp' => 'Guadeloupe',
-	'GeoIP_country_gq' => 'Equatoriaal Guinea',
-	'GeoIP_country_gr' => 'Griekenland',
-	'GeoIP_country_gs' => 'Zuid Georgi&euml; ',
-	'GeoIP_country_gt' => 'Guatemala',
-	'GeoIP_country_gu' => 'Guam',
-	'GeoIP_country_gw' => 'Guinea-Bissau',
-	'GeoIP_country_gy' => 'Guyana',
-	'GeoIP_country_hk' => 'Hong Kong',
-	'GeoIP_country_hm' => 'Heard eiland en McDonald eilanden',
-	'GeoIP_country_hn' => 'Honduras',
-	'GeoIP_country_hr' => 'Kroati&euml;',
-	'GeoIP_country_ht' => 'Haiti',
-	'GeoIP_country_hu' => 'Hongarij&euml;',
-	'GeoIP_country_id' => 'Indonesi&euml;',
-	'GeoIP_country_ie' => 'Ierland',
-	'GeoIP_country_il' => 'Isra&euml;l',
-	'GeoIP_country_im' => 'Man eiland',
-	'GeoIP_country_in' => 'India',
-	'GeoIP_country_io' => 'Brits Indisch territoriale wateren',
-	'GeoIP_country_iq' => 'Irak',
-	'GeoIP_country_ir' => 'Iran',
-	'GeoIP_country_is' => 'IJsland',
-	'GeoIP_country_it' => 'Itali&euml;',
-	'GeoIP_country_je' => 'Jersey',
-	'GeoIP_country_jm' => 'Jamaica',
-	'GeoIP_country_jo' => 'Jordaan',
-	'GeoIP_country_jp' => 'Japan',
-	'GeoIP_country_ke' => 'Kenia',
-	'GeoIP_country_kg' => 'Kyrgyzstan',
-	'GeoIP_country_kh' => 'Cambodja',
-	'GeoIP_country_ki' => 'Kiribati',
-	'GeoIP_country_km' => 'Comoros',
-	'GeoIP_country_kn' => 'Sint Kitts en Nevis',
-	'GeoIP_country_kp' => 'Noord Korea',
-	'GeoIP_country_kr' => 'Zuid Korea',
-	'GeoIP_country_kw' => 'Koeweit',
-	'GeoIP_country_ky' => 'Kaaiman eilanden',
-	'GeoIP_country_kz' => 'Kazachstan',
-	'GeoIP_country_la' => 'Laos',
-	'GeoIP_country_lb' => 'Libanon',
-	'GeoIP_country_lc' => 'Sint Lucia',
-	'GeoIP_country_li' => 'Liechtenstein',
-	'GeoIP_country_lk' => 'Sri Lanka',
-	'GeoIP_country_lr' => 'Libi&euml;',
-	'GeoIP_country_ls' => 'Lesbos',
-	'GeoIP_country_lt' => 'Litouwen',
-	'GeoIP_country_lu' => 'Luxemburg',
-	'GeoIP_country_lv' => 'Letland',
-	'GeoIP_country_ly' => 'Libi&euml;',
-	'GeoIP_country_ma' => 'Marokko',
-	'GeoIP_country_mc' => 'Monaco',
-	'GeoIP_country_md' => 'Moldavi&euml;',
-	'GeoIP_country_mg' => 'Madagaskar',
-	'GeoIP_country_mh' => '',
-	'GeoIP_country_mk' => 'Macedoni&euml;',
-	'GeoIP_country_ml' => 'Mali',
-	'GeoIP_country_mm' => 'Myanmar',
-	'GeoIP_country_mn' => 'Mongoli&euml;',
-	'GeoIP_country_mo' => 'Macau',
-	'GeoIP_country_mp' => 'Noordelijk Marina eilanden',
-	'GeoIP_country_mq' => 'Martinique',
-	'GeoIP_country_mr' => 'Mauritania',
-	'GeoIP_country_ms' => 'Montserrat',
-	'GeoIP_country_mt' => 'Malta',
-	'GeoIP_country_mu' => 'Mauristius',
-	'GeoIP_country_mv' => 'Malledieven',
-	'GeoIP_country_mw' => 'Malawi',
-	'GeoIP_country_mx' => 'Mexico',
-	'GeoIP_country_my' => 'Maleisi&euml;',
-	'GeoIP_country_mz' => 'Mozambique',
-	'GeoIP_country_na' => 'Namibi&euml;',
-	'GeoIP_country_nc' => 'Nieuw Caledonia',
-	'GeoIP_country_ne' => 'Niger',
-	'GeoIP_country_nf' => 'Norfolk eiland',
-	'GeoIP_country_ng' => 'Nigeria',
-	'GeoIP_country_ni' => 'Nicaragua',
-	'GeoIP_country_nl' => 'Nederland',
-	'GeoIP_country_no' => 'Noorwegen',
-	'GeoIP_country_np' => 'Nepal',
-	'GeoIP_country_nr' => 'Nauru',
-	'GeoIP_country_nu' => 'Niue',
-	'GeoIP_country_nz' => 'Nieuw Zeeland',
-	'GeoIP_country_om' => 'Oman',
-	'GeoIP_country_pa' => 'Panama',
-	'GeoIP_country_pe' => 'Peru',
-	'GeoIP_country_pf' => 'Frans Polynesi&euml;',
-	'GeoIP_country_pg' => 'Papua Nieuw Guinea',
-	'GeoIP_country_ph' => 'Filipijnen',
-	'GeoIP_country_pk' => 'Pakistan',
-	'GeoIP_country_pl' => 'Polen',
-	'GeoIP_country_pm' => 'Sint Petersburg',
-	'GeoIP_country_pn' => 'Pitcairn',
-	'GeoIP_country_pr' => 'Puerto Rico',
-	'GeoIP_country_ps' => 'Palestijnen',
-	'GeoIP_country_pt' => 'Portugal',
-	'GeoIP_country_pw' => 'Palau',
-	'GeoIP_country_py' => 'Paraguay',
-	'GeoIP_country_qa' => 'Qatar',
-	'GeoIP_country_re' => 'Reunie eiland',
-	'GeoIP_country_ro' => 'Roemeni&euml;',
-	'GeoIP_country_ru' => 'Rusland',
-	'GeoIP_country_rs' => 'Rusland',
-	'GeoIP_country_rw' => 'Rwanda',
-	'GeoIP_country_sa' => 'Saudi Arabi&euml;',
-	'GeoIP_country_sb' => 'Solomon Eilanden',
-	'GeoIP_country_sc' => 'Seychelles',
-	'GeoIP_country_sd' => 'Sudan',
-	'GeoIP_country_se' => 'Zweden',
-	'GeoIP_country_sg' => 'Singapore',
-	'GeoIP_country_sh' => 'Sint Helena',
-	'GeoIP_country_si' => 'Sloveni&euml;',
-	'GeoIP_country_sj' => 'Svalbard',
-	'GeoIP_country_sk' => 'Slovaki&euml;',
-	'GeoIP_country_sl' => 'Sierra Leone',
-	'GeoIP_country_sm' => 'San Marino',
-	'GeoIP_country_sn' => 'Senegal',
-	'GeoIP_country_so' => 'Somali&euml;',
-	'GeoIP_country_sr' => 'Suriname',
-	'GeoIP_country_st' => 'Sao Tome en Principe',
-	'GeoIP_country_su' => 'Voormalig rusland',
-	'GeoIP_country_sv' => 'El Salvador',
-	'GeoIP_country_sy' => 'Syrische republiek',
-	'GeoIP_country_sz' => 'Swaziland',
-	'GeoIP_country_tc' => 'Turkse en Caicos Eilanden',
-	'GeoIP_country_td' => 'Chad',
-	'GeoIP_country_tf' => 'Franse territorialen',
-	'GeoIP_country_tg' => 'Togo',
-	'GeoIP_country_th' => 'Thailand',
-	'GeoIP_country_tj' => 'Tsjikistan',
-	'GeoIP_country_tk' => 'Tokelau',
-	'GeoIP_country_tm' => 'Turkmenistan',
-	'GeoIP_country_tn' => 'Tunisi&euml;',
-	'GeoIP_country_to' => 'Tonga',
-	'GeoIP_country_tp' => 'Oost Timor',
-	'GeoIP_country_tr' => 'Turkije',
-	'GeoIP_country_tt' => 'Trinidad en Tobago',
-	'GeoIP_country_tv' => 'Tuvalu',
-	'GeoIP_country_tw' => 'Taiwan',
-	'GeoIP_country_tz' => 'Tanzani&euml;',
-	'GeoIP_country_ua' => 'Oekra&iuml;ne',
-	'GeoIP_country_ug' => 'Uganda',
-	'GeoIP_country_uk' => 'Verenigd Koningkrijk',
-	'GeoIP_country_gb' => 'Groot britanni&euml;',
-	'GeoIP_country_um' => 'Eilanden van de Verenigde Staten',
-	'GeoIP_country_us' => 'Verenigde Staten',
-	'GeoIP_country_uy' => 'Uruguay',
-	'GeoIP_country_uz' => 'Uzbekistan',
-	'GeoIP_country_va' => 'Vaticaanstad',
-	'GeoIP_country_vc' => 'Sint Vincent en de Grenadinen',
-	'GeoIP_country_ve' => 'Venezuela',
-	'GeoIP_country_vg' => 'Britse Maagden eilanden',
-	'GeoIP_country_vi' => 'Maagden eilanden',
-	'GeoIP_country_vn' => 'Vietnam',
-	'GeoIP_country_vu' => 'Vanuatu',
-	'GeoIP_country_wf' => 'Wallis en Futuna',
-	'GeoIP_country_ws' => 'Samoa',
-	'GeoIP_country_ye' => 'Jemen',
-	'GeoIP_country_yt' => 'Mayotte',
-	'GeoIP_country_yu' => 'Joegoslavi&euml;',
-	'GeoIP_country_za' => 'Zuid Afrika',
-	'GeoIP_country_zm' => 'Zambia',
-	'GeoIP_country_zr' => 'Zaire',
-	'GeoIP_country_zw' => 'Zimbabwe',
-	'GeoIP_continent_' => 'Data niet bechikbaar',
-	'GeoIP_continent_eur' => 'Europa',
-	'GeoIP_continent_afr' => 'Afrika',
-	'GeoIP_continent_asi' => 'Asi&euml;',
-	'GeoIP_continent_ams' => 'Zuid- en Centraal Amerika',
-	'GeoIP_continent_amn' => 'Noord Amerika',
-	'GeoIP_continent_oce' => 'Oceanie',
+	'DBStats_DatabaseUsage' => 'Database gebruik',
+	'DBStats_MainDescription' => 'Piwik slaat alle analyse data op in een MySQL database. Momenteel is de omvang van deze database %s.',
+	'DBStats_Table' => 'Tabel',
+	'DBStats_RowNumber' => 'Rij nummer',
+	'DBStats_DataSize' => 'Data omvang',
+	'DBStats_IndexSize' => 'Index grootte',
+	'DBStats_TotalSize' => 'Totale grootte',
 	'Installation_Installation' => 'Installatie',
 	'Installation_InstallationStatus' => 'Installatie status',
 	'Installation_PercentDone' => '%s %% Gereed',
@@ -790,7 +577,7 @@ $translations = array(
 	'UserSettings_Browsers' => 'Browser per versie',
 	'UserSettings_Plugins' => 'Ge&iuml;nstalleerde plugins',
 	'UserSettings_Configurations' => 'Configuraties',
-	'UserSettings_OperatinsSystems' => 'Besturings systemen',
+	'UserSettings_OperatingSystems' => 'Besturings systemen',
 	'UserSettings_Resolutions' => 'Scherm resoluties',
 	'UserSettings_WideScreen' => 'Scherm configuratie',
 	'UserSettings_WidgetResolutions' => 'Scherm resoluties',
@@ -841,19 +628,13 @@ $translations = array(
 	'VisitFrequency_WidgetOverview' => 'Frequentie overzicht',
 	'VisitFrequency_WidgetGraphReturning' => 'Terugkerende bezoekers',
 	'VisitFrequency_SubmenuFrequency' => 'Frequentie',
-	'VisitTime_LocalTime' => 'Uur van de dag (tijdzone bezoeker)',
-	'VisitTime_ServerTime' => 'Uur van de dag (tijdzone server)',
-	'VisitTime_WidgetLocalTime' => 'Uur van de dag (tijdzone bezoeker)',
-	'VisitTime_WidgetServerTime' => 'Uur van de dag (tijdzone server)',
-	'VisitTime_SubmenuTimes' => 'Uur van de dag',
-	'VisitTime_NHour' => '%s uur',
 	'VisitorInterest_VisitsPerDuration' => 'Duur bezoek',
 	'VisitorInterest_VisitsPerNbOfPages' => 'Pagina\'s per bezoek',
 	'VisitorInterest_WidgetLengths' => 'Lengte bezoek',
 	'VisitorInterest_WidgetPages' => 'Pagina\'s per bezoek',
 	'VisitorInterest_SubmenuFrequencyLoyalty' => 'Frequentie &amp; Loyaliteit',
 	'VisitorInterest_PlusXMin' => '%s min.',
-	'VisitorInterest_BetweenXYMinutes' => '%1s-%2s min.',
+	'VisitorInterest_BetweenXYMinutes' => '%1s-%1s min.',
 	'VisitorInterest_OnePage' => '1 pagina',
 	'VisitorInterest_NPages' => '%s pagina\'s',
 	'VisitorInterest_BetweenXYSeconds' => '%1s-%2s sec.',
@@ -872,4 +653,10 @@ $translations = array(
 	'VisitsSummary_WidgetLastVisitors' => 'Recente unieke bezoekers',
 	'VisitsSummary_WidgetOverviewGraph' => 'Totalen',
 	'VisitsSummary_SubmenuOverview' => 'Totalen',
-);
\ No newline at end of file
+	'VisitTime_LocalTime' => 'Uur van de dag (tijdzone bezoeker)',
+	'VisitTime_ServerTime' => 'Uur van de dag (tijdzone server)',
+	'VisitTime_WidgetLocalTime' => 'Uur van de dag (tijdzone bezoeker)',
+	'VisitTime_WidgetServerTime' => 'Uur van de dag (tijdzone server)',
+	'VisitTime_SubmenuTimes' => 'Uur van de dag',
+	'VisitTime_NHour' => '%s uur',
+);
