@@ -86,13 +86,39 @@ $translations = array(
 	'CoreHome_PeriodWeek' => 'Tydzień',
 	'CoreHome_PeriodMonth' => 'Miesiąc',
 	'CoreHome_PeriodYear' => 'Rok',
-	'CoreHome_DaySu_js' => 'Nie',
-	'CoreHome_DayMo_js' => 'Pon',
-	'CoreHome_DayTu_js' => 'Wto',
-	'CoreHome_DayWe_js' => 'śro',
-	'CoreHome_DayTh_js' => 'Czw',
-	'CoreHome_DayFr_js' => 'Pią',
-	'CoreHome_DaySa_js' => 'Sob',
+	'CoreHome_DaySu_js' => 'N',
+	'CoreHome_DayMo_js' => 'Pn',
+	'CoreHome_DayTu_js' => 'Wt',
+	'CoreHome_DayWe_js' => 'Śr',
+	'CoreHome_DayTh_js' => 'Cz',
+	'CoreHome_DayFr_js' => 'Pt',
+	'CoreHome_DaySa_js' => 'So',
+	'CoreHome_ShortDay_1_js' => 'Nie',
+	'CoreHome_ShortDay_2_js' => 'Pn',
+	'CoreHome_ShortDay_3_js' => 'Wt',
+	'CoreHome_ShortDay_4_js' => 'Śr',
+	'CoreHome_ShortDay_5_js' => 'Czw',
+	'CoreHome_ShortDay_6_js' => 'Pt',
+	'CoreHome_ShortDay_7_js' => 'So',
+	'CoreHome_LongDay_1_js' => 'Niedziela',
+	'CoreHome_LongDay_2_js' => 'Poniedzialek',
+	'CoreHome_LongDay_3_js' => 'Wtorek',
+	'CoreHome_LongDay_4_js' => 'Środa',
+	'CoreHome_LongDay_5_js' => 'Czwartek',
+	'CoreHome_LongDay_6_js' => 'Piątek',
+	'CoreHome_LongDay_7_js' => 'Sobota',
+	'CoreHome_ShortMonth_1_js' => 'Sty',
+	'CoreHome_ShortMonth_2_js' => 'Lu',
+	'CoreHome_ShortMonth_3_js' => 'Mar',
+	'CoreHome_ShortMonth_4_js' => 'Kw',
+	'CoreHome_ShortMonth_5_js' => 'Maj',
+	'CoreHome_ShortMonth_6_js' => 'Cze',
+	'CoreHome_ShortMonth_7_js' => 'Lip',
+	'CoreHome_ShortMonth_8_js' => 'Sie',
+	'CoreHome_ShortMonth_9_js' => 'Wrz',
+	'CoreHome_ShortMonth_10_js' => 'Pa',
+	'CoreHome_ShortMonth_11_js' => 'Lis',
+	'CoreHome_ShortMonth_12_js' => 'Gru',
 	'CoreHome_MonthJanuary_js' => 'Styczeń',
 	'CoreHome_MonthFebruary_js' => 'Luty',
 	'CoreHome_MonthMarch_js' => 'Marzec',
@@ -168,7 +194,7 @@ $translations = array(
 	'UserSettings_Browsers' => 'Przeglądarki',
 	'UserSettings_Plugins' => 'Plugin\'y',
 	'UserSettings_Configurations' => 'Konfiguracja',
-	'UserSettings_OperatinsSystems' => 'Systemy operacyjne',
+	'UserSettings_OperatingSystems' => 'Systemy operacyjne',
 	'UserSettings_Resolutions' => 'Rozdzielczość',
 	'UserSettings_WideScreen' => 'Ekran panoramiczny',
 	'UserSettings_WidgetResolutions' => 'Rozdzielczość ekrany',
@@ -445,7 +471,7 @@ $translations = array(
 	'VisitsSummary_TotalTime' => '%s całkowity czas spędzony na stronie',
 	'VisitsSummary_MaxNbActions' => '%s maksymalne akcje podczas jednej wizyty',
 	'VisitsSummary_NbBounced' => '%s goście odrzucający (opuścili stronę po obejrzeniu jednej strony)',
-	'VisitsSummary_Evolution' => 'Postęp ostatnich 30 %ss',
+	'VisitsSummary_Evolution' => 'Postęp ostatnich 30 %s',
 	'VisitsSummary_Report' => 'Raport',
 	'VisitsSummary_GenerateTime' => 'Czas wygenerowania strony: %s sekund',
 	'VisitsSummary_GenerateQueries' => '%s wykonanych zapytań',
@@ -475,7 +501,7 @@ $translations = array(
 	'VisitorInterest_WidgetPages' => 'Strion na wizytę',
 	'VisitorInterest_SubmenuFrequencyLoyalty' => 'Częstotliwość i lojalność',
 	'VisitorInterest_PlusXMin' => '%s min',
-	'VisitorInterest_BetweenXYMinutes' => '%1s-%2s min',
+	'VisitorInterest_BetweenXYMinutes' => '%1s-%1s min',
 	'VisitorInterest_OnePage' => '1 strona',
 	'VisitorInterest_NPages' => '%s stron',
 	'VisitorInterest_BetweenXYSeconds' => '%1s-%2ss',
@@ -607,4 +633,4 @@ $translations = array(
 	'TranslationsAdmin_LanguageCode' => 'Kod języka',
 	'TranslationsAdmin_Export' => 'Eksportuj język',
 	'TranslationsAdmin_Import' => 'Importuj język',
-);
\ No newline at end of file
+);
