@@ -88,20 +88,46 @@ $translations = array(
 	'CoreHome_PeriodWeek' => 'Saptamana',
 	'CoreHome_PeriodMonth' => 'Luna',
 	'CoreHome_PeriodYear' => 'An',
-	'CoreHome_DaySu_js' => 'Dum',
-	'CoreHome_DayMo_js' => 'Lun',
-	'CoreHome_DayTu_js' => 'Mar',
-	'CoreHome_DayWe_js' => 'Mie',
-	'CoreHome_DayTh_js' => 'Joi',
-	'CoreHome_DayFr_js' => 'Vin',
-	'CoreHome_DaySa_js' => 'Sam',
+	'CoreHome_DaySu_js' => 'Du',
+	'CoreHome_DayMo_js' => 'Lu',
+	'CoreHome_DayTu_js' => 'Ma',
+	'CoreHome_DayWe_js' => 'Mi',
+	'CoreHome_DayTh_js' => 'Jo',
+	'CoreHome_DayFr_js' => 'Vi',
+	'CoreHome_DaySa_js' => 'Sâ',
+	'CoreHome_ShortDay_1_js' => 'Dum',
+	'CoreHome_ShortDay_2_js' => 'Lun',
+	'CoreHome_ShortDay_3_js' => 'Mar',
+	'CoreHome_ShortDay_4_js' => 'Mie',
+	'CoreHome_ShortDay_5_js' => 'Joi',
+	'CoreHome_ShortDay_6_js' => 'Vin',
+	'CoreHome_ShortDay_7_js' => 'Sâm',
+	'CoreHome_LongDay_1_js' => 'Duminică',
+	'CoreHome_LongDay_2_js' => 'Luni',
+	'CoreHome_LongDay_3_js' => 'Marţi',
+	'CoreHome_LongDay_4_js' => 'Miercuri',
+	'CoreHome_LongDay_5_js' => 'Joi',
+	'CoreHome_LongDay_6_js' => 'Vineri',
+	'CoreHome_LongDay_7_js' => 'Sâmbătă',
+	'CoreHome_ShortMonth_1_js' => 'Ian',
+	'CoreHome_ShortMonth_2_js' => 'Feb',
+	'CoreHome_ShortMonth_3_js' => 'Mar',
+	'CoreHome_ShortMonth_4_js' => 'Apr',
+	'CoreHome_ShortMonth_5_js' => 'Mai',
+	'CoreHome_ShortMonth_6_js' => 'Iun',
+	'CoreHome_ShortMonth_7_js' => 'Iul',
+	'CoreHome_ShortMonth_8_js' => 'Aug',
+	'CoreHome_ShortMonth_9_js' => 'Sep',
+	'CoreHome_ShortMonth_10_js' => 'Oct',
+	'CoreHome_ShortMonth_11_js' => 'Nov',
+	'CoreHome_ShortMonth_12_js' => 'Dec',
 	'CoreHome_MonthJanuary_js' => 'Ianuarie',
 	'CoreHome_MonthFebruary_js' => 'Februarie',
 	'CoreHome_MonthMarch_js' => 'Martie',
 	'CoreHome_MonthApril_js' => 'Aprilie',
 	'CoreHome_MonthMay_js' => 'Mai',
-	'CoreHome_MonthJune_js' => 'Junie',
-	'CoreHome_MonthJuly_js' => 'Julie',
+	'CoreHome_MonthJune_js' => 'Iunie',
+	'CoreHome_MonthJuly_js' => 'Iulie',
 	'CoreHome_MonthAugust_js' => 'August',
 	'CoreHome_MonthSeptember_js' => 'Septembrie',
 	'CoreHome_MonthOctober_js' => 'Octombrie',
@@ -181,7 +207,7 @@ $translations = array(
 	'UserSettings_Browsers' => 'Browsere',
 	'UserSettings_Plugins' => 'Pluginuri',
 	'UserSettings_Configurations' => 'Configurare',
-	'UserSettings_OperatinsSystems' => 'Sisteme operare',
+	'UserSettings_OperatingSystems' => 'Sisteme operare',
 	'UserSettings_Resolutions' => 'Rezolutii',
 	'UserSettings_WideScreen' => 'Ecran extins',
 	'UserSettings_WidgetResolutions' => 'Rezolutii ecran',
@@ -503,7 +529,7 @@ $translations = array(
 	'VisitorInterest_WidgetPages' => 'Pagini per vizita',
 	'VisitorInterest_SubmenuFrequencyLoyalty' => 'Frecventa si loialitate',
 	'VisitorInterest_PlusXMin' => '%s min',
-	'VisitorInterest_BetweenXYMinutes' => '%1s-%2s min',
+	'VisitorInterest_BetweenXYMinutes' => '%1s-%1s min',
 	'VisitorInterest_OnePage' => '1 pagina',
 	'VisitorInterest_NPages' => '%s pagini',
 	'VisitorInterest_BetweenXYSeconds' => '%1s-%2ss',
