@@ -100,8 +100,34 @@ $translations = array(
 	'CoreHome_DayTu_js' => 'Ut',
 	'CoreHome_DayWe_js' => 'St',
 	'CoreHome_DayTh_js' => 'Št',
-	'CoreHome_DayFr_js' => 'Pi',
+	'CoreHome_DayFr_js' => 'Pia',
 	'CoreHome_DaySa_js' => 'So',
+	'CoreHome_ShortDay_1_js' => 'Ned',
+	'CoreHome_ShortDay_2_js' => 'Pon',
+	'CoreHome_ShortDay_3_js' => 'Uto',
+	'CoreHome_ShortDay_4_js' => 'Str',
+	'CoreHome_ShortDay_5_js' => 'Štv',
+	'CoreHome_ShortDay_6_js' => 'Pia',
+	'CoreHome_ShortDay_7_js' => 'Sob',
+	'CoreHome_LongDay_1_js' => "Nedel'a",
+	'CoreHome_LongDay_2_js' => 'Pondelok',
+	'CoreHome_LongDay_3_js' => 'Utorok',
+	'CoreHome_LongDay_4_js' => 'Streda',
+	'CoreHome_LongDay_5_js' => 'Štvrtok',
+	'CoreHome_LongDay_6_js' => 'Piatok',
+	'CoreHome_LongDay_7_js' => 'Sobota',
+	'CoreHome_ShortMonth_1_js' => 'Jan',
+	'CoreHome_ShortMonth_2_js' => 'Feb',
+	'CoreHome_ShortMonth_3_js' => 'Mar',
+	'CoreHome_ShortMonth_4_js' => 'Apr',
+	'CoreHome_ShortMonth_5_js' => 'Máj',
+	'CoreHome_ShortMonth_6_js' => 'Jún',
+	'CoreHome_ShortMonth_7_js' => 'Júl',
+	'CoreHome_ShortMonth_8_js' => 'Aug',
+	'CoreHome_ShortMonth_9_js' => 'Sep',
+	'CoreHome_ShortMonth_10_js' => 'Okt',
+	'CoreHome_ShortMonth_11_js' => 'Nov',
+	'CoreHome_ShortMonth_12_js' => 'Dec',
 	'CoreHome_MonthJanuary_js' => 'Január',
 	'CoreHome_MonthFebruary_js' => 'Február',
 	'CoreHome_MonthMarch_js' => 'Marec',
@@ -123,7 +149,7 @@ $translations = array(
 	'CoreUpdater_TheFollowingPluginsWillBeUpgradedX' => 'Nasledujúce moduly budú zaktualizované: %s.',
 	'CoreUpdater_TheUpgradeProcessMayTakeAWhilePleaseBePatient' => 'Aktualizácia databázy môžte chvíľu trvať, tak buďte prosím trpezlivý.',
 	'CoreUpdater_UpgradePiwik' => 'Aktualizácia Piwik',
-	'CoreUpdater_HelpMessageContent' => 'Pozrite si %s Piwik FAQ %s, kde sú vysvetlené najčastejšie problémy počas aktualizácie. %s Požiadajte svojho systémového administrátora - mal by Vám vedieť pomôcť s chybami, ktoré sa s najväčšou pravdepodobnosťou týkajú Vášho servera alebo nastavenia MySQ.',
+	'CoreUpdater_HelpMessageContent' => 'Pozrite si %s Piwik FAQ %s, kde sú vysvetlené najčastejšie problémy počas aktualizácie. %s Požiadajte svojho systémového administrátora - mal by Vám vedieť pomôcť s chybami, ktoré sa s najväčšou pravdepodobnosťou týkajú Vášho servera alebo nastavenia MySQL.',
 	'CoreUpdater_CriticalErrorDuringTheUpgradeProcess' => 'Kritická chyba počas procesu aktualizácie:',
 	'CoreUpdater_HelpMessageIntroductionWhenError' => 'Vyššie je uvedená hlavná chybová správa, ktorá by mala vysvetliť problém. Ak potrebujete ďalšiu pomoc, tak prosím:',
 	'CoreUpdater_HelpMessageIntroductionWhenWarning' => 'Aktualizácia je úspešne ukončená, vyskytli sa však problémy. Prečítajte si nasledovné detaily. Ďalšiu pomoc nájdete na:',
@@ -194,7 +220,7 @@ $translations = array(
 	'UserSettings_Browsers' => 'Prehliadače',
 	'UserSettings_Plugins' => 'Zásuvné moduly',
 	'UserSettings_Configurations' => 'Konfigurácia',
-	'UserSettings_OperatinsSystems' => 'Operačný systém',
+	'UserSettings_OperatingSystems' => 'Operačný systém',
 	'UserSettings_Resolutions' => 'Rozlíšenie',
 	'UserSettings_WideScreen' => 'Širokouhlá obrazovka',
 	'UserSettings_WidgetResolutions' => 'Rozlíšenie obrazovky',
@@ -507,7 +533,7 @@ $translations = array(
 	'VisitorInterest_WidgetPages' => 'Strany na návštevu',
 	'VisitorInterest_SubmenuFrequencyLoyalty' => 'Frekvencia & Lojalita',
 	'VisitorInterest_PlusXMin' => '%s min',
-	'VisitorInterest_BetweenXYMinutes' => '%1s-%2s min',
+	'VisitorInterest_BetweenXYMinutes' => '%1s-%1s min',
 	'VisitorInterest_OnePage' => '1 stránka',
 	'VisitorInterest_NPages' => '%s stránok',
 	'VisitorInterest_BetweenXYSeconds' => '%1s-%2ss',
@@ -578,8 +604,8 @@ $translations = array(
 	'Installation_InstallationStatus' => 'Stav inštalácie',
 	'Installation_PercentDone' => '%s %% Dokončené',
 	'Installation_NoConfigFound' => 'Piwik konfiguračný súbor nie je možné nájsť a vy sa pokúšate pripojiť k Piwik stránke. <br /><b>&nbsp;&nbsp;&raquo; Môžete <a href=\'index.php\'>teraz nainštalovať Piwik</a></b><br /><small>Ak ste nainštalovali Piwik už skôr, a máte nejaké tabuľky s dátami v databáze, nemusíte sa báť, budete ich ďalej používať!</small>',
-	'Installation_MysqlSetup' => 'Nastavenie Mysql databázy',
-	'Installation_MysqlErrorConnect' => 'Vyskytla sa chyba počas testu pripojenia k Mysql databáze',
+	'Installation_MysqlSetup' => 'Nastavenie MySQL databázy',
+	'Installation_MysqlErrorConnect' => 'Vyskytla sa chyba počas testu pripojenia k MySQL databáze',
 	'Installation_JsTag' => 'Javascript značka (tag)',
 	'Installation_JsTagHelp' => '<p>Na spočítanie všetkých vašich návštevníkov musíte vložiť do svojich stránok javascript kód.</p><p>Vaše stránky nemusia byť vytvorené v PHP, Piwik bude fungovať na všetkých typoch stránok (či už to bude HTML, ASP, Perl alebo iný jazyk).</p><p>Tu je kód, ktorý musíte použiť: (skopírujte a vložte ho do svojich stránok)</p>',
 	'Installation_Congratulations' => 'Blahoželanie',
@@ -666,4 +692,101 @@ $translations = array(
 	'UserCountry_country_sf' => 'Fínsko',
 	'UserCountry_country_ta' => 'Tristan da Cunha',
 	'UserCountry_country_tl' => 'Východný Timor',
-);
\ No newline at end of file
+	'General_Loading' => 'Načítavanie…',
+	'General_ExportAsImage' => 'Exportovať ako obrázok',
+	'General_SaveImageOnYourComputer' => 'Pre uloženie obrázku na vašom počítači kliknite pravým tlačidlom na obrázok a vyberte „Uložiť obrázok ako…“',
+	'General_ColumnNbActions' => 'Akcie',
+	'General_ColumnMaxActions' => 'Maximum akcií počas jednej návštevy',
+	'General_ColumnSumVisitLength' => 'Celkový čas strávený návštevníkmi (v sekundách)',
+	'General_ColumnValuePerVisit' => 'Hodnota na návštevu',
+	'General_ColumnVisitsWithConversions' => 'Návštevy s konverziou',
+	'General_ShortMonth_1' => 'Jan',
+	'General_ShortMonth_2' => 'Feb',
+	'General_ShortMonth_3' => 'Mar',
+	'General_ShortMonth_4' => 'Apr',
+	'General_ShortMonth_5' => 'Máj',
+	'General_ShortMonth_6' => 'Jún',
+	'General_ShortMonth_7' => 'Júl',
+	'General_ShortMonth_8' => 'Aug',
+	'General_ShortMonth_9' => 'Sep',
+	'General_ShortMonth_10' => 'Okt',
+	'General_ShortMonth_11' => 'Nov',
+	'General_ShortMonth_12' => 'Dec',
+	'General_LongMonth_1' => 'Január',
+	'General_LongMonth_2' => 'Február',
+	'General_LongMonth_3' => 'Marec',
+	'General_LongMonth_4' => 'Apríl',
+	'General_LongMonth_5' => 'Máj',
+	'General_LongMonth_6' => 'Jún',
+	'General_LongMonth_7' => 'Júl',
+	'General_LongMonth_8' => 'August',
+	'General_LongMonth_9' => 'September',
+	'General_LongMonth_10' => 'Október',
+	'General_LongMonth_11' => 'November',
+	'General_LongMonth_12' => 'December',
+	'General_ShortDay_1' => 'Pon',
+	'General_ShortDay_2' => 'Uto',
+	'General_ShortDay_3' => 'Str',
+	'General_ShortDay_4' => 'Štv',
+	'General_ShortDay_5' => 'Pia',
+	'General_ShortDay_6' => 'Sob',
+	'General_ShortDay_7' => 'Ned',
+	'General_LongDay_1' => 'Pondelok',
+	'General_LongDay_2' => 'Utorok',
+	'General_LongDay_3' => 'Streda',
+	'General_LongDay_4' => 'Štvrtok',
+	'General_LongDay_5' => 'Piatok',
+	'General_LongDay_6' => 'Sobota',
+	'General_LongDay_7' => 'Nedeľa',
+	'Actions_ColumnPageName' => 'Názov stránky',
+	'Actions_ColumnClickedURL' => 'Kliknuté URL',
+	'Actions_ColumnDownloadURL' => 'Stiahnuté URL',
+	'CoreHome_DayFormat' => '%longDay% %day% %longMonth% %longYear%',
+	'Dashboard_AddPreviewedWidget_js' => 'Pridať prezeranú miniaplikáciu do panelu',
+	'Dashboard_WidgetPreview_js' => 'Náhľad na miniaplikáciu',
+	'Dashboard_Close_js' => 'Zatvoriť',
+	'ExamplePlugin_exampleWidget' => 'Príklad miniaplikácie',
+	'ExamplePlugin_blogPiwikRss' => 'Blog Piwik RSS',
+	'ExamplePlugin_photostreamMatt' => 'Mattove fotky',
+	'Goals_ColumnConversions' => 'Konverzie',
+	'Goals_ColumnConversionRate' => 'Miera konverzie',
+	'Goals_ColumnRevenue' => 'Tržba',
+	'Provider_ColumnProvider' => 'Poskytovateľ',
+	'Referers_MetricsFromRefererTypeGraphLegend' => '%1s (z %2s)',
+	'Referers_ColumnRefererType' => 'Typ odkazu',
+	'Referers_ColumnSearchEngine' => 'Vyhľadávač',
+	'Referers_ColumnWebsite' => 'Portál',
+	'Referers_ColumnWebsitePage' => 'Stránka portálu',
+	'Referers_ColumnKeyword' => 'Kľúčové slovo',
+	'Referers_ColumnCampaign' => 'Kampaň',
+	'Referers_Distinct' => 'Rozlíšiť odkazy podľa typu odkazu',
+	'Referers_DistinctSearchEngines' => 'rôzne vyhľadávače',
+	'Referers_DistinctKeywords' => 'rôzne kľúčové strany',
+	'Referers_DistinctCampaigns' => 'rôzne kampane',
+	'Referers_DistinctWebsites' => 'rôzne portály',
+	'Referers_UsingNDistinctUrls' => '(používanie %2s rôznych url)',
+	'UserSettings_VisitorSettings' => 'Nastavenia návštevníkov',
+	'UserSettings_ColumnBrowserFamily' => 'Rodina prehliadača',
+	'UserSettings_ColumnBrowser' => 'Prehliadač',
+	'UserSettings_ColumnPlugin' => 'Zásuvný modul',
+	'UserSettings_ColumnConfiguration' => 'Konfigurácia',
+	'UserSettings_ColumnOperatingSystem' => 'Operačný systém',
+	'UserSettings_ColumnResolution' => 'Rozlíšenie',
+	'UserSettings_ColumnTypeOfScreen' => 'Typ obrazovky',
+	'VisitFrequency_ColumnReturningVisits' => 'Vracajúce sa návštevy',
+	'VisitFrequency_ColumnActionsByReturningVisits' => 'Akcie vracajúcich sa návštevníkov',
+	'VisitFrequency_ColumnMaximumActionsByAReturningVisit' => 'Maximum akcií vracajúcich sa návštev',
+	'VisitFrequency_ColumnTotalTimeSpentByReturningVisits' => 'Celkový čas strávený vracajúcimi sa návštevami (v sek.)',
+	'VisitFrequency_ColumnBounceRateForReturningVisits' => 'Miera odskočení vracajúcich sa návštev',
+	'VisitFrequency_ReturnBounceRate' => '%s vracajúcich sa návštev odskočilo (odišli po zobrazení jednej stránky)',
+	'VisitorInterest_ColumnVisitDuration' => 'Trvanie návštevy',
+	'VisitorInterest_ColumnPagesPerVisit' => 'Stránky na návštevu',
+	'VisitsSummary_NbVisitsBounced' => '%s návštev odskočilo (odišli po zobrazení jednej stránky)',
+	'VisitsSummary_EvolutionOverLastPeriods' => 'Vývoj za posledné %s',
+	'VisitTime_ColumnServerTime' => 'Serverový čas',
+	'VisitTime_ColumnLocalTime' => 'Miestny čas',
+	'SitesManager_JsTrackingTag' => 'JavaScript sledovacia značka (tag)
+',
+	'SitesManager_JsTrackingTagHelp' => 'Tu je JavaScript sledovacia značka (tag) na vloženie do vašich stránok',
+	'SitesManager_ShowTrackingTag' => 'zobraziť sledovaciu značku',
+);
