@@ -26,6 +26,7 @@ $translations = array(
 	'General_Logout' => 'Logga ut',
 	'General_Done' => 'Klar',
 	'General_LoadingData' => 'Laddar data...',
+	'General_Loading' => 'Laddar...',
 	'General_ErrorRequest' => 'Oops&hellip; ett problem p&aring;tr&auml;ffades under f&ouml;rfr&aring;gningen, var v&auml;nlig f&ouml;rs&ouml;k igen.',
 	'General_Next' => 'N&auml;sta',
 	'General_Previous' => 'F&ouml;reg&aring;ende',
@@ -36,6 +37,8 @@ $translations = array(
 	'General_TagCloud' => 'Taggmoln',
 	'General_VBarGraph' => 'Stapeldiagram',
 	'General_Export' => 'Exportera',
+	'General_ExportAsImage' => 'Exportera som bild',
+	'General_SaveImageOnYourComputer' => 'F&ouml;r att spara bilden till datorn, h&ouml;gerklicka p&aring; bilden och v&auml;lj "Spara bild som..."',
 	'General_Refresh' => 'Uppdatera sidan',
 	'General_Visitors' => 'Bes&ouml;kare',
 	'General_ColumnNbUniqVisitors' => 'Unika bes&ouml;kare',
@@ -57,7 +60,7 @@ $translations = array(
 	'General_NoDataForTagCloud' => 'Ingen data f&ouml;r taggmolnet',
 	'General_DisplayNormalTable' => 'Visa normal tabell',
 	'General_DisplayMoreData' => 'Visa mer data',
-	'General_PiwikIsACollaborativeProject' => '%s Piwik %s &auml;r ett samarbetsprojekt och fortfarande i betastadiet. %s V&auml;nligen %s kontakta oss%s om du vill hj&auml;lpa till!',
+	'General_PiwikIsACollaborativeProjectYouCanContribute' => '%s Piwik %s &auml;r ett samarbetsprojekt och fortfarande i betastadiet. %s V&auml;nligen %s kontakta oss%s om du vill hj&auml;lpa till!',
 	'General_YouAreCurrentlyViewingDemoOfPiwik' => 'Du ser just nu ett demo av %s; %sladda ner%s den fullst&auml;ndiga versionen! Kolla in %s',
 	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Piwik %s finns tillg&auml;ngligt. %s Var v&auml;nlig uppdatera! %s (se %s &auml;ndringar%s).',
 	'General_BackToPiwik' => 'Tillbaka till Piwik',
@@ -135,13 +138,39 @@ $translations = array(
 	'CoreHome_PeriodWeeks' => 'veckor',
 	'CoreHome_PeriodMonths' => 'm&aring;nader',
 	'CoreHome_PeriodYears' => '&aring;r',
-	'CoreHome_DaySu_js' => 'S&ouml;n',
-	'CoreHome_DayMo_js' => 'M&aring;n',
-	'CoreHome_DayTu_js' => 'Tis',
-	'CoreHome_DayWe_js' => 'Ons',
-	'CoreHome_DayTh_js' => 'Tor',
-	'CoreHome_DayFr_js' => 'Fre',
-	'CoreHome_DaySa_js' => 'L&ouml;r',
+	'CoreHome_DaySu_js' => 'Sö',
+	'CoreHome_DayMo_js' => 'Må',
+	'CoreHome_DayTu_js' => 'Ti',
+	'CoreHome_DayWe_js' => 'On',
+	'CoreHome_DayTh_js' => 'To',
+	'CoreHome_DayFr_js' => 'Fr',
+	'CoreHome_DaySa_js' => 'Lö',
+	'CoreHome_ShortDay_1_js' => 'Sön',
+	'CoreHome_ShortDay_2_js' => 'Mån',
+	'CoreHome_ShortDay_3_js' => 'Tis',
+	'CoreHome_ShortDay_4_js' => 'Ons',
+	'CoreHome_ShortDay_5_js' => 'Tor',
+	'CoreHome_ShortDay_6_js' => 'Fre',
+	'CoreHome_ShortDay_7_js' => 'Lör',
+	'CoreHome_LongDay_1_js' => 'Söndag',
+	'CoreHome_LongDay_2_js' => 'Måndag',
+	'CoreHome_LongDay_3_js' => 'Tisdag',
+	'CoreHome_LongDay_4_js' => 'Onsdag',
+	'CoreHome_LongDay_5_js' => 'Torsdag',
+	'CoreHome_LongDay_6_js' => 'Fredag',
+	'CoreHome_LongDay_7_js' => 'Lördag',
+	'CoreHome_ShortMonth_1_js' => 'Jan',
+	'CoreHome_ShortMonth_2_js' => 'Feb',
+	'CoreHome_ShortMonth_3_js' => 'Mar',
+	'CoreHome_ShortMonth_4_js' => 'Apr',
+	'CoreHome_ShortMonth_5_js' => 'Maj',
+	'CoreHome_ShortMonth_6_js' => 'Jun',
+	'CoreHome_ShortMonth_7_js' => 'Jul',
+	'CoreHome_ShortMonth_8_js' => 'Aug',
+	'CoreHome_ShortMonth_9_js' => 'Sep',
+	'CoreHome_ShortMonth_10_js' => 'Okt',
+	'CoreHome_ShortMonth_11_js' => 'Nov',
+	'CoreHome_ShortMonth_12_js' => 'Dec',
 	'CoreHome_MonthJanuary_js' => 'Januari',
 	'CoreHome_MonthFebruary_js' => 'Februari',
 	'CoreHome_MonthMarch_js' => 'Mars',
@@ -190,12 +219,15 @@ $translations = array(
 	'Actions_ColumnUniqueClicks' => 'Unika klick',
 	'Actions_ColumnDownloads' => 'Nedladdningar',
 	'Actions_ColumnUniqueDownloads' => 'Unika nedladdningar',
+	'Actions_ColumnPageName' => 'Sidnamn',
+	'Actions_ColumnClickedURL' => 'Klickad URL',
+	'Actions_ColumnDownloadURL' => 'Nedladdad URL',
 	'Dashboard_Dashboard' => 'Kontrollpanel',
 	'Dashboard_AddWidget' => 'L&auml;gg till en widget...',
 	'Dashboard_DeleteWidgetConfirm' => 'Vill du verkligen ta bort den h&auml;r widgeten fr&aring;n kontrollpanelen?',
 	'Dashboard_SelectWidget' => 'V&auml;lj widget att l&auml;gga till i kontrollpanelen',
-	'Dashboard_AddPreviewedWidget' => 'L&auml;gg till f&ouml;rhandsgranskad widget i kontrollpanelen',
-	'Dashboard_WidgetPreview' => 'F&ouml;rhandsgranska widget',
+	'Dashboard_AddPreviewedWidget_js' => 'L&auml;gg till f&ouml;rhandsgranskad widget i kontrollpanelen',
+	'Dashboard_WidgetPreview_js' => 'F&ouml;rhandsgranska widget',
 	'Dashboard_Close_js' => 'St&auml;ng',
 	'Dashboard_TitleWidgetInDashboard_js' => 'Widgeten finns redan i kontrollpanelen',
 	'Dashboard_TitleClickToAdd_js' => 'Klicka f&ouml;r att l&auml;gga till kontrollpanelen',
@@ -209,7 +241,13 @@ $translations = array(
 	'Referers_Campaigns' => 'Kampanjer',
 	'Referers_MetricsFromRefererTypeGraphLegend' => '%1s (fr&aring;n %2s)',
 	'Referers_Evolution' => 'Utveckling under perioden',
-	'Referers_Type' => 'H&auml;nvisningstyp',
+	'Referers_Type' => 'Typ av k&auml;lla',
+	'Referers_ColumnRefererType' => 'Typ av k&auml;lla',
+	'Referers_ColumnSearchEngine' => 'S&ouml;kmotor',
+	'Referers_ColumnWebsite' => 'Webbplats',
+	'Referers_ColumnWebsitePage' => 'Webbsida',
+	'Referers_ColumnKeyword' => 'S&ouml;kord',
+	'Referers_ColumnCampaign' => 'Kampanj',
 	'Referers_DetailsByRefererType' => 'Detaljer efter h&auml;nvisningstyp',
 	'Referers_TypeDirectEntries' => '%s direkta bes&ouml;k',
 	'Referers_TypeSearchEngines' => '%s fr&aring;n s&ouml;kmotorer',
@@ -235,9 +273,16 @@ $translations = array(
 	'UserSettings_Browsers' => 'Webbl&auml;sare',
 	'UserSettings_Plugins' => 'Till&auml;gg',
 	'UserSettings_Configurations' => 'Konfigurationer',
-	'UserSettings_OperatinsSystems' => 'Operativsystem',
+	'UserSettings_OperatingSystems' => 'Operativsystem',
 	'UserSettings_Resolutions' => 'Sk&auml;rmuppl&ouml;sning',
 	'UserSettings_WideScreen' => 'Wide Screen',
+	'UserSettings_ColumnBrowserFamily' => 'Webbl&auml;sarfamilj',
+	'UserSettings_ColumnBrowser' => 'Webbl&auml;sare',
+	'UserSettings_ColumnPlugin' => 'Till&auml;gg',
+	'UserSettings_ColumnConfiguration' => 'Konfiguration',
+	'UserSettings_ColumnOperatingSystem' => 'Operativsystem',
+	'UserSettings_ColumnResolution' => 'Sk&auml;rmuppl&ouml;sning',
+	'UserSettings_ColumnTypeOfScreen' => 'Typ av sk&auml;rm',
 	'UserSettings_WidgetResolutions' => 'Sk&auml;rmuppl&ouml;sning',
 	'UserSettings_WidgetBrowsers' => 'Webbl&auml;sare',
 	'UserSettings_WidgetPlugins' => 'Lista med till&auml;gg',
@@ -552,17 +597,21 @@ $translations = array(
 	'VisitFrequency_SubmenuFrequency' => 'Frekvens',
 	'VisitTime_LocalTime' => 'Bes&ouml;k efter lokal tid',
 	'VisitTime_ServerTime' => 'Bes&ouml;k efter servertid',
+	'VisitTime_ColumnServerTime' => 'Servertid',
+	'VisitTime_ColumnLocalTime' => 'Lokal tid',
 	'VisitTime_WidgetLocalTime' => 'Bes&ouml;k efter lokal tid',
 	'VisitTime_WidgetServerTime' => 'Bes&ouml;k efter servertid',
 	'VisitTime_SubmenuTimes' => 'Tider',
 	'VisitTime_NHour' => '%sh',
 	'VisitorInterest_VisitsPerDuration' => 'Tid per bes&ouml;k',
 	'VisitorInterest_VisitsPerNbOfPages' => 'Sidvisningar per bes&ouml;k',
+	'VisitorInterest_ColumnVisitDuration' => 'Bes&ouml;ksl&auml;ngd',
+	'VisitorInterest_ColumnPagesPerVisit' => 'Sidvisningar per bes&ouml;k',
 	'VisitorInterest_WidgetLengths' => 'Bes&ouml;ksl&auml;ngd',
 	'VisitorInterest_WidgetPages' => 'Sidvisningar per bes&ouml;k',
 	'VisitorInterest_SubmenuFrequencyLoyalty' => 'Frekvens och lojalitet',
 	'VisitorInterest_PlusXMin' => '%s min',
-	'VisitorInterest_BetweenXYMinutes' => '%1s-%2s min',
+	'VisitorInterest_BetweenXYMinutes' => '%1s-%1s min',
 	'VisitorInterest_OnePage' => '1 sida',
 	'VisitorInterest_NPages' => '%s sidor',
 	'VisitorInterest_BetweenXYSeconds' => '%1s-%2ss',
@@ -603,7 +652,7 @@ $translations = array(
 	'UsersManager_DeleteConfirm_js' => '&Auml;r du s&auml;ker p&aring; att du vill radera \'%s\'?',
 	'UsersManager_ExceptionLoginExists' => 'Anv&auml;ndarnamnet \'%s\' finns redan.',
 	'UsersManager_ExceptionEmailExists' => 'En anv&auml;ndare med e-postadressen \'%s\' finns redan.',
-	'UsersManager_ExceptionInvalidLogin' => 'Anv&auml;ndarnamnet f&aring;r endast best&aring; av bokst&auml;ver, siffror eller tecknen \'_\' eller \'-\' eller \'.\'',
+	'UsersManager_ExceptionInvalidLoginFormat' => 'Anv&auml;ndarnamnet f&aring;r endast best&aring; av bokst&auml;ver, siffror eller tecknen \'_\' eller \'-\' eller \'.\'',
 	'UsersManager_ExceptionInvalidPassword' => 'L&ouml;senordet m&aring;ste ha en l&auml;ngd mellan 6 och 26 tecken.',
 	'UsersManager_ExceptionInvalidEmail' => 'E-postadressen har inget giltigt format.',
 	'UsersManager_ExceptionDeleteDoesNotExist' => 'Anv&auml;ndaren \'%s\' finns inte och kan d&auml;rf&ouml;r inte raderas.',
@@ -615,9 +664,9 @@ $translations = array(
 	'SitesManager_Sites' => 'Webbplatser',
 	'SitesManager_WebsitesManagement' => 'Webbplatser',
 	'SitesManager_MainDescription' => 'Dina analyser beh&ouml;ver webbplatser! L&auml;gg till, uppdatera, radera webbplatser och visa Javascript-kod att l&auml;gga till p&aring; dina sidor.',
-	'SitesManager_JsCode' => 'Javascript-kod',
-	'SitesManager_JsCodeHelp' => 'H&auml;r &auml;r javascript-koden som ska l&auml;ggas in p&aring; alla dina sidor',
-	'SitesManager_ShowJsCode' => 'Visa kod',
+	'SitesManager_JsTrackingTag' => 'Javascript-sp&aring;rningskod',
+	'SitesManager_JsTrackingTagHelp' => 'H&auml;r &auml;r sp&aring;rningskod som ska l&auml;ggas in p&aring; alla dina sidor',
+	'SitesManager_ShowTrackingTag' => 'Visa sp&aring;rningskod',
 	'SitesManager_NoWebsites' => 'Do har inga webbplatser att administrera',
 	'SitesManager_AddSite' => 'L&auml;gg till webbplats',
 	'SitesManager_Id' => 'Id',
@@ -683,7 +732,8 @@ $translations = array(
 	'Installation_Welcome' => 'V&auml;lkommen!',
 	'Installation_WelcomeHelp' => '<p>Piwik &auml;r en open source programvara f&ouml;r webbplatsanalys som g&ouml;r det enkelt att samla in information om dina bes&ouml;kare.</p><p>Den &auml;r processen &auml;r uppdelad i %s enkla steg och kommer ta ca 5 minuter.</p>',
 	'Installation_ErrorInvalidState' => 'Fel: det ser ut som att du f&ouml;rs&ouml;kt hoppa &ouml;ver ett steg i installationsprocessen, eller s&aring; har du inte cookies aktiverat, eller s&aring; &auml;r Piwik\'s konfigurationsfil redan skapad. %sKontrollera s&aring; att cookies &auml;r aktiverat%s och g&aring; tillbaka %s till f&ouml;rsta sidan av installationen %s.',
-	'Provider_WidgetProviders' => 'Operat&ouml;r',
+	'Provider_WidgetProviders' => 'Operat&ouml;rer',
+	'Provider_ColumnProvider' => 'Operat&ouml;r',
 	'Provider_SubmenuLocationsProvider' => 'Ursprung och operat&ouml;r',
 	'Goals_ColumnConversions' => 'Omvandlingar',
 	'Goals_ColumnConversionRate' => 'Omvandlingsfrekvens',
@@ -708,4 +758,4 @@ $translations = array(
 	'TranslationsAdmin_LanguageCode' => 'Spr&aring;kkod',
 	'TranslationsAdmin_Export' => 'Exportera spr&aring;k',
 	'TranslationsAdmin_Import' => 'Importera spr&aring;k',
-);
\ No newline at end of file
+);
