@@ -13,7 +13,7 @@ $translations = array(
 	'General_Settings' => 'ตั้งค่า',
 	'General_GiveUsYourFeedback' => 'แสดงความคิดเห็นกับเรา',
 	'General_Unknown' => 'ไม่ทราบ',
-	'General_Required' => '%sจำเป็นต้องมี',
+	'General_Required' => '%s จำเป็นต้องมี',
 	'General_Error' => 'ข้อผิดพลาด',
 	'General_Warning' => 'คำเตือน',
 	'General_BackToHomepage' => 'กลับไปยังหน้าหลักของ Piwik',
@@ -25,7 +25,7 @@ $translations = array(
 	'General_Close' => 'ปิด',
 	'General_Logout' => 'ลงชื่อออก',
 	'General_Done' => 'เสร็จสิ้น',
-	'General_LoadingData' => 'กำลังโหลด...',
+	'General_LoadingData' => 'กำลังโหลดข้อมูล...',
 	'General_ErrorRequest' => 'Oops&hellip; เกิดปัญหาระหว่างดึงข้อมูล กรุณาลองใหม่อีกครั้ง',
 	'General_Next' => 'ต่อไป',
 	'General_Previous' => 'ย้อนกลับ',
@@ -56,12 +56,66 @@ $translations = array(
 	'General_YouAreCurrentlyViewingDemoOfPiwik' => 'คุณกำลังดูตัวอย่างของ %s; %sดาวโหลด%s เวอร์ชั่นเต็ม! หรือไม่ %s',
 	'General_PiwikXIsAvailablePleaseUpdateNow' => 'Piwik %s ออกแล้ว %s กรุณาอัพเดทเดี๋ยวนี้ %s (ดู %s การเปลี่ยนแปลง %s)',
 	'General_BackToPiwik' => 'กลับไปยัง Piwik',
-	'API_QuickDocumentation' => '',
+	'General_Loading' => 'กำลังโหลด...',
+	'General_ExportAsImage' => 'ส่งออกเป็นภาพ',
+	'General_SaveImageOnYourComputer' => 'เพื่อบันทึกภาพลงบนคอมพิวเตอร์ของคุณ คลิกขวาที่ภาพแล้วเลือก " Save Image As..."',
+	'General_ColumnNbActions' => 'การดำเนินการ',
+	'General_ColumnMaxActions' => 'กาำรดำเนินการสูงสุด ต่อผู้เยี่ยมชมหนึ่งคน',
+	'General_ColumnSumVisitLength' => 'ระยะเวลาทั้งหมดที่ใช้โดยผู้เยี่ยมชม (วินาที)',
+	'General_ColumnValuePerVisit' => 'ค่าต่อผู้ชม',
+	'General_ColumnVisitsWithConversions' => 'ผู้เยี่ยมชมกับการเปลงข้อมูล',
+	'General_PiwikIsACollaborativeProjectYouCanContribute' => '%s Piwik %s เป็นโปรเจ็กทำด้วยความร่วมมือกัน %s หากคุณชอบ Piwik คุณสามารถช่วยเราได้!ลองดูว่า %s คุณสามารถสนับสนุน Piwik ได้อย่างไร ? %s',
+	'General_ShortMonth_1' => 'มค.',
+	'General_ShortMonth_2' => 'กพ.',
+	'General_ShortMonth_3' => 'มีค.',
+	'General_ShortMonth_4' => 'เมษ.',
+	'General_ShortMonth_5' => 'พค.',
+	'General_ShortMonth_6' => 'มิย.',
+	'General_ShortMonth_7' => 'กค.',
+	'General_ShortMonth_8' => 'สค.',
+	'General_ShortMonth_9' => 'กย.',
+	'General_ShortMonth_10' => 'ตค.',
+	'General_ShortMonth_11' => 'พย.',
+	'General_ShortMonth_12' => 'ธค.',
+	'General_LongMonth_1' => 'มกราคม',
+	'General_LongMonth_2' => 'กุมภาพันธ์',
+	'General_LongMonth_3' => 'มีนาคม',
+	'General_LongMonth_4' => 'เมษายน',
+	'General_LongMonth_5' => 'พฤษภาคม',
+	'General_LongMonth_6' => 'มิถุนายน',
+	'General_LongMonth_7' => 'กรกฎาคม',
+	'General_LongMonth_8' => 'สิงหาคม',
+	'General_LongMonth_9' => 'กันยายน',
+	'General_LongMonth_10' => 'ตุลาคม',
+	'General_LongMonth_11' => 'พฤศจิกายน',
+	'General_LongMonth_12' => 'ธันวาคม',
+	'General_ShortDay_1' => 'จ',
+	'General_ShortDay_2' => 'อ',
+	'General_ShortDay_3' => 'พ',
+	'General_ShortDay_4' => 'พฤ',
+	'General_ShortDay_5' => 'ศ',
+	'General_ShortDay_6' => 'ส',
+	'General_ShortDay_7' => 'อา',
+	'General_LongDay_1' => 'จันทร์',
+	'General_LongDay_2' => 'อังคาร',
+	'General_LongDay_3' => 'พุทธ',
+	'General_LongDay_4' => 'พฤหัสบดี',
+	'General_LongDay_5' => 'ศุกร์',
+	'General_LongDay_6' => 'เสาร์',
+	'General_LongDay_7' => 'อาทิตย์',
+	'API_QuickDocumentation' => '<h2>เอกสาร API แบบเร็ว</h2><p>If you don\'t have data for today you can first <a href=\'misc/generateVisits.php\' target=_blank>generate some data</a> using the Visits Generator script.</p><p>You can try the different formats available for every method. It is very easy to extract any data you want from Piwik!</p><p><b>For more information have a look at the <a href=\'http://dev.piwik.org/trac/wiki/API\'>official API Documentation</a> or the <a href=\'http://dev.piwik.org/trac/wiki/API/Reference\'>API Reference</a>.</b></P><h2>User authentication</h2><p>If you want to <b>request the data in your scripts, in a crontab, etc. </b> you need to add the parameter <code><u>&token_auth=%s</u></code> to the API calls URLs that require authentication.</p><p>This token_auth is as secret as your login and password, <b>do not share it!</p>',
 	'API_LoadedAPIs' => 'โหลด API สำเร็จแล้ว %s',
 	'Actions_Actions' => 'ดำเนินการ',
 	'Actions_SubmenuPages' => 'หน้าของเนื้อหา',
 	'Actions_SubmenuOutlinks' => 'ลิงค์ออก',
 	'Actions_SubmenuDownloads' => 'ดาวน์โหลด',
+	'Actions_ColumnClicks' => 'คลิก',
+	'Actions_ColumnUniqueClicks' => 'คลิก',
+	'Actions_ColumnDownloads' => 'ดาวน์โหลด',
+	'Actions_ColumnUniqueDownloads' => 'ดาวน์โหลด',
+	'Actions_ColumnPageName' => 'ชื่อหน้า',
+	'Actions_ColumnClickedURL' => 'คลิก URL',
+	'Actions_ColumnDownloadURL' => 'ดาวน์โหลด URL',
 	'CoreHome_NoPrivileges' => 'คุณกำลังเข้าสู่ระบบในฐานะ \'%s\' แต่ดูเหมือนว่าคุณไม่ได้รับสิทธิ์ใดๆที่กำหนดไว้ใน Piwik. <br />ถามผู้ดูแลระบบ Piwik ของคุณเพื่อให้คุณ \'view\' การเข้าถึงเว็บไซต์',
 	'CoreHome_JavascriptDisabled' => 'จาวาสคริปจะต้องเปิดไว้เพื่อใช้งาน Piwik ในมุมมองมาตรฐาน <br /> อย่างไรก็ตาม ดูเหมือนว่าจาวาสคริปจะถูกปิดอยู่ หรือบราวเซอร์ของคุณไม่รองรับ<br /> เพื่อใช้งานในมุมมองปกติ คุณต้องเปิดการใช้งานจาวาสคริปโดยเปลี่ยนออฟชั่นของบราวเซอร์ของคุณ หลังจากนั้น %1s ลองใหม่อีกครั้ง %2s <br />',
 	'CoreHome_TableNoData' => 'ไม่มีข้อมูลสำหรับตารางนี้',
@@ -83,6 +137,32 @@ $translations = array(
 	'CoreHome_DayTh_js' => 'พฤ.',
 	'CoreHome_DayFr_js' => 'ศ.',
 	'CoreHome_DaySa_js' => 'ส.',
+	'CoreHome_ShortDay_1_js' => 'อา.',
+	'CoreHome_ShortDay_2_js' => 'จ.',
+	'CoreHome_ShortDay_3_js' => 'อ.',
+	'CoreHome_ShortDay_4_js' => 'พ.',
+	'CoreHome_ShortDay_5_js' => 'พฤ.',
+	'CoreHome_ShortDay_6_js' => 'ศ.',
+	'CoreHome_ShortDay_7_js' => 'ส.',
+	'CoreHome_LongDay_1_js' => 'อาทิตย์',
+	'CoreHome_LongDay_2_js' => 'จันทร์',
+	'CoreHome_LongDay_3_js' => 'อังคาร',
+	'CoreHome_LongDay_4_js' => 'พุธ',
+	'CoreHome_LongDay_5_js' => 'พฤหัสบดี',
+	'CoreHome_LongDay_6_js' => 'ศุกร์',
+	'CoreHome_LongDay_7_js' => 'เสาร์',
+	'CoreHome_ShortMonth_1_js' => 'ม.ค.',
+	'CoreHome_ShortMonth_2_js' => 'ก.พ.',
+	'CoreHome_ShortMonth_3_js' => 'มี.ค.',
+	'CoreHome_ShortMonth_4_js' => 'เม.ย.',
+	'CoreHome_ShortMonth_5_js' => 'พ.ค.',
+	'CoreHome_ShortMonth_6_js' => 'มิ.ย.',
+	'CoreHome_ShortMonth_7_js' => 'ก.ค.',
+	'CoreHome_ShortMonth_8_js' => 'ส.ค.',
+	'CoreHome_ShortMonth_9_js' => 'ก.ย.',
+	'CoreHome_ShortMonth_10_js' => 'ต.ค.',
+	'CoreHome_ShortMonth_11_js' => 'พ.ย.',
+	'CoreHome_ShortMonth_12_js' => 'ธ.ค.',
 	'CoreHome_MonthJanuary_js' => 'มกราคม',
 	'CoreHome_MonthFebruary_js' => 'กุมภาพันธ์',
 	'CoreHome_MonthMarch_js' => 'มีนาคม',
@@ -95,6 +175,11 @@ $translations = array(
 	'CoreHome_MonthOctober_js' => 'ตุลาคม',
 	'CoreHome_MonthNovember_js' => 'พฤศจิกายน',
 	'CoreHome_MonthDecember_js' => 'ธันวาคม',
+	'CoreHome_DayFormat' => '%วันแบบเต็ม%วัน%เดือนแบบเต็ม%%ปีแบบเต็ม%',
+	'CoreHome_PeriodDays' => 'วัน',
+	'CoreHome_PeriodWeeks' => 'สัปดาห์',
+	'CoreHome_PeriodMonths' => 'เดือน',
+	'CoreHome_PeriodYears' => 'ปี',
 	'CorePluginsAdmin_Plugins' => 'ปลั้กอิน',
 	'CorePluginsAdmin_PluginsManagement' => 'การจัดการปลั้กอิน',
 	'CorePluginsAdmin_MainDescription' => 'อธิบายปลั้กอินและแสดงการทำงานของ Piwik เมื่อปลั๊กอินที่ติดตั้งอยู่คุณสามารถเปิดใช้งานหรือยกเลิกการใช้งานได้ ที่นี่',
@@ -137,6 +222,7 @@ $translations = array(
 	'CoreUpdater_CreatingBackupOfConfigurationFile' => 'สำรองไฟลล์ข้อมูลการตั้งค่าใน %s',
 	'CoreUpdater_InstallingTheLatestVersion' => 'กำลังติดตั้งเวอร์ชั่นล่าสุด',
 	'CoreUpdater_PiwikUpdatedSuccessfully' => 'Piwik อัพเดทสมบูรณ์แล้ว',
+	'CoreUpdater_UpdateHasBeenCancelledExplanation' => 'การอัพเดท Piwik ในคลิกเดียวถูกยกเลิกแล้ว หากคุณไม่สามารถแก้ไขข้อความข้อผิดพลาด แนะนำให้คุณอัพเดท Piwik แบบ Manual %s กรุณาตรวจสอบ %s เอกสารการอัพเดท %s เพื่อเริ่มดำเนินการ',
 	'DBStats_DatabaseUsage' => 'ปริมาณการใช้ฐานข้อมูล',
 	'DBStats_MainDescription' => 'Piwik กำลังเก็บข้อมูลการวิเคราห์เว็บไซต์ของคุณในฐานข้อมูล MySQL ขณะนี้ตารางของ Piwik กำลังใช้งาน %s',
 	'DBStats_Table' => 'ตาราง',
@@ -153,8 +239,14 @@ $translations = array(
 	'Dashboard_TitleWidgetInDashboard_js' => 'Widget นี้อยู่ในแผงควบคุมแล้ว',
 	'Dashboard_TitleClickToAdd_js' => 'คลิกเพื่อเพิ่มลงในแผงควบคุม',
 	'Dashboard_LoadingPreview_js' => 'กำลังโหลดพรีวิว กรุณารอ...',
-	'Dashboard_LoadingWidget_js' => 'กำลังโหลด wedget กรุณารอ...',
+	'Dashboard_LoadingWidget_js' => 'กำลังโหลด widget กรุณารอ...',
 	'Dashboard_WidgetNotFound_js' => 'ไม่พบ Widget',
+	'Dashboard_AddPreviewedWidget_js' => 'เพิ่ม widget ที่พรีวิวในแผงควบคุม',
+	'Dashboard_WidgetPreview_js' => 'พรีวิว widget',
+	'Dashboard_Close_js' => 'ปิด',
+	'Goals_ColumnConversions' => 'การแปลงข้อมูล',
+	'Goals_ColumnConversionRate' => 'อัตราการแปลงข้อมูล',
+	'Goals_ColumnRevenue' => 'รายได้',
 	'Installation_Installation' => 'การติดตั้ง',
 	'Installation_InstallationStatus' => 'สถานะการติดตั้ง',
 	'Installation_PercentDone' => 'สำเร็จแล้ว %s %% ',
@@ -201,15 +293,19 @@ $translations = array(
 	'Installation_Tables' => 'กำลังสร้างตาราง',
 	'Installation_TablesWarning' => '<span id="linkToggle">บางตัวในตาราง Piwik </span>ถูกติดตั้งใน DB แล้ว',
 	'Installation_TablesFound' => 'ตารางดังต่อไปนี้ไม่พบในฐานข้อมูล',
-	'Installation_TablesWarningHelp' => '',
-	'Installation_TablesReuse' => '',
-	'Installation_TablesDelete' => '',
-	'Installation_TablesDeletedSuccess' => '',
-	'Installation_TablesCreatedSuccess' => '',
-	'Installation_DatabaseCreatedSuccess' => '',
+	'Installation_TablesWarningHelp' => 'เลือกอันอื่นเพื่อใช้ฐานข้อมูลที่มีอยู่อีกครั้ง หรือเลือกติดตั้งใหม่ เพื่อลบข้อมูลที่มีอยู่ในฐานข้อมูล',
+	'Installation_TablesReuse' => 'ใช้ตารางที่มีอยู่',
+	'Installation_TablesDelete' => 'ลบตารางที่ค้นพบ',
+	'Installation_TablesDeletedSuccess' => 'ลบตาราง Piwik ที่มีอยู่สำเร็จ',
+	'Installation_TablesCreatedSuccess' => 'สร้างตารางสำเร็จ!',
+	'Installation_DatabaseCreatedSuccess' => 'สร้างฐานข้อมูล %s สำเร็จ',
 	'Installation_TablesDeleteConfirm' => '',
-	'Installation_Welcome' => '',
-	'Installation_WelcomeHelp' => '',
+	'Installation_Welcome' => 'ยินดีต้อนรับ!',
+	'Installation_WelcomeHelp' => '<p>Piwik เป็นโปรแกรมวิเคราห์เว็บไซต์โอเพ่นซอร์ส ซึ่งจะทำให้คุณได้รับข้อมูลจากผู้เยี่ยมชมของคุณอย่างง่ายดาย </p><p>กระบวนการจะแบ่งเป็น %s ขั้นตอนง่ายๆ และจะใช้เวลาประมาณ 5 นาที </p>',
+	'Installation_TablesWithSameNamesFound' => 'บางตาราง %s ในฐานข้อมูลของคุณ %s มีชื่อเดียวกันกับตารางที่ Piwik พยายามจะสร้าง',
+	'Installation_GoBackAndDefinePrefix' => 'กลับไปและตั้งชื่อ Prefix สำหรับตาราง Piwik',
+	'Installation_ConfirmDeleteExistingTables' => 'คุณแน่ใจหรือไม่ว่าต้องการลบตาราง: %s จากฐานข้อมูล? <b>คำเตือน:<b> ข้อมูลในตารางเหล่านี้ไม่สามารถกู้คืนได้',
+	'Installation_ErrorInvalidState' => 'ผิดพลาด: ดูเหมือนว่าคุณพยายามจะข้ามขั้นตอนหนึ่งในกระบวนการติดตั้ง หรือคุกกี้คุณถูกใช้งานไม่ได้ หรือ ไฟลล์การตั้งค่าของ Piwik ถูกสร้างขี้นแล้ว %s กรุณาแน่ใจว่าเปิดให้คุกกี้ทำงานแล้ว %s และกลับไปยังหน้าแรกของการติดตั้ง %s',
 	'Login_LoginPasswordNotCorrect' => 'ชื่อผู้ใช้และรหัสผ่านไม่ถูกต้อง',
 	'Login_Login' => 'ชื่อผู้ใช้',
 	'Login_Password' => 'รหัสผ่าน',
@@ -226,6 +322,7 @@ $translations = array(
 	'Login_ContactAdmin' => 'ปัญหาอาจเกิดจากโฮสของคุณปิดฟังก์ชั่น Mail()<br /> กรุณาติดต่อ Piwik Administrator ของคุณ',
 	'Provider_WidgetProviders' => 'ผู้ให้บริการ',
 	'Provider_SubmenuLocationsProvider' => 'ตำแหน่งที่อยู่ และ ผู้ให้บริการ',
+	'Provider_ColumnProvider' => 'ผู้ให้บริการ',
 	'Referers_Referers' => 'แหล่งที่มา',
 	'Referers_SearchEngines' => 'เครื่องมือค้นหา',
 	'Referers_Keywords' => 'คีย์เวิร์ด',
@@ -253,6 +350,20 @@ $translations = array(
 	'Referers_WidgetExternalWebsites' => 'รายการเว็บไซต์ภายนอก',
 	'Referers_WidgetSearchEngines' => 'เครื่องมือค้นหาที่ดีที่สุด',
 	'Referers_WidgetOverview' => 'ภาพรวม',
+	'Referers_MetricsFromRefererTypeGraphLegend' => '%1s(จาก %2s)',
+	'Referers_ColumnRefererType' => 'ชนิดของแหล่งที่มา',
+	'Referers_ColumnSearchEngine' => 'เครื่องมือค้นหา',
+	'Referers_ColumnWebsite' => 'เว็บไซต์',
+	'Referers_ColumnWebsitePage' => 'หน้าเว็บไซต์',
+	'Referers_ColumnKeyword' => 'คีย์เวิร์ด',
+	'Referers_ColumnCampaign' => 'แคมเปญ',
+	'Referers_DetailsByRefererType' => 'รายละเอียดตามชนิดแหล่งที่มา',
+	'Referers_Distinct' => 'ความแตกต่างระหว่างแหล่งที่มาอย่างชัดเจน',
+	'Referers_DistinctSearchEngines' => 'ความแตกต่างระหว่างเครื่องมือค้นหาอย่างชัดเจน',
+	'Referers_DistinctKeywords' => 'ความแตกต่างระหว่างคีย์เวิร์ดอย่างชัดเจน',
+	'Referers_DistinctCampaigns' => 'ความแตกต่างระหว่างแคมเปญอย่างชัดเจน',
+	'Referers_DistinctWebsites' => 'ความแตกต่างระหว่างเว็บไซต์อย่างชัดเจน',
+	'Referers_UsingNDistinctUrls' => '(การใช้ %2s ความแตกต่างระหว่าง url อย่างชัดเจน',
 	'SitesManager_Sites' => 'ไซต์',
 	'SitesManager_WebsitesManagement' => 'การบริหารเว็บไซต์',
 	'SitesManager_MainDescription' => 'รายงานการวิเคราะห์เว็บไซต์ของคุณ ที่ต้องการ! เพิ่ม, ปรับข้อมูล, ลบเว็บไซต์และแสดงการใช้ Javascript เพื่อแทรกในหน้าเว็บของท่าน',
@@ -270,6 +381,9 @@ $translations = array(
 	'SitesManager_ExceptionNoUrl' => 'คุณต้องระบุ URL เว็บไซต์อย่างน้อย 1 URL ',
 	'SitesManager_ExceptionEmptyName' => 'ชื่อของไซต์ไม่สามารถเว้นว่างไว้ได้',
 	'SitesManager_ExceptionInvalidUrl' => 'URL ดังกล่าว \'%s\' ไม่สามารถใช้ได้',
+	'SitesManager_JsTrackingTag' => 'JavaScript Tracking Tag',
+	'SitesManager_JsTrackingTagHelp' => 'นี่คือ JavaScript Tracking Tag ที่ต้องใส่ไว้ทุกหน้าในเว็บของคุณ',
+	'SitesManager_ShowTrackingTag' => 'แสดง Tracking Tag',
 	'TranslationsAdmin_MenuTranslations' => 'การแปลภาษา',
 	'TranslationsAdmin_MenuLanguages' => 'ภาษา',
 	'TranslationsAdmin_Plugin' => 'ปลั้กอิน',
@@ -289,280 +403,280 @@ $translations = array(
 	'UserCountry_SubmenuLocations' => 'ตำแหน่งที่อยู่',
 	'UserCountry_WidgetContinents' => 'ทวีปของผู้เข้าชม',
 	'UserCountry_WidgetCountries' => 'ประเทศของผู้เข้าชม',
-	'UserCountry_country_ac' => '',
-	'UserCountry_country_ad' => '',
-	'UserCountry_country_ae' => '',
-	'UserCountry_country_af' => '',
-	'UserCountry_country_ag' => '',
-	'UserCountry_country_ai' => '',
-	'UserCountry_country_al' => '',
-	'UserCountry_country_am' => '',
-	'UserCountry_country_an' => '',
-	'UserCountry_country_ao' => '',
-	'UserCountry_country_aq' => '',
-	'UserCountry_country_ar' => '',
-	'UserCountry_country_as' => '',
-	'UserCountry_country_at' => '',
-	'UserCountry_country_au' => '',
-	'UserCountry_country_aw' => '',
-	'UserCountry_country_ax' => '',
-	'UserCountry_country_az' => '',
-	'UserCountry_country_ba' => '',
-	'UserCountry_country_bb' => '',
-	'UserCountry_country_bd' => '',
-	'UserCountry_country_be' => '',
-	'UserCountry_country_bf' => '',
-	'UserCountry_country_bg' => '',
-	'UserCountry_country_bh' => '',
-	'UserCountry_country_bi' => '',
-	'UserCountry_country_bj' => '',
-	'UserCountry_country_bl' => '',
-	'UserCountry_country_bm' => '',
-	'UserCountry_country_bn' => '',
-	'UserCountry_country_bo' => '',
-	'UserCountry_country_br' => '',
-	'UserCountry_country_bs' => '',
-	'UserCountry_country_bt' => '',
-	'UserCountry_country_bu' => '',
-	'UserCountry_country_bv' => '',
-	'UserCountry_country_bw' => '',
-	'UserCountry_country_by' => '',
-	'UserCountry_country_bz' => '',
-	'UserCountry_country_ca' => '',
-	'UserCountry_country_cc' => '',
-	'UserCountry_country_cd' => '',
-	'UserCountry_country_cf' => '',
-	'UserCountry_country_cg' => '',
-	'UserCountry_country_ch' => '',
-	'UserCountry_country_ci' => '',
-	'UserCountry_country_ck' => '',
-	'UserCountry_country_cl' => '',
-	'UserCountry_country_cm' => '',
-	'UserCountry_country_cn' => '',
-	'UserCountry_country_co' => '',
-	'UserCountry_country_cp' => '',
-	'UserCountry_country_cr' => '',
-	'UserCountry_country_cs' => '',
-	'UserCountry_country_cu' => '',
-	'UserCountry_country_cv' => '',
-	'UserCountry_country_cx' => '',
-	'UserCountry_country_cy' => '',
-	'UserCountry_country_cz' => '',
-	'UserCountry_country_de' => '',
-	'UserCountry_country_dg' => '',
-	'UserCountry_country_dj' => '',
-	'UserCountry_country_dk' => '',
-	'UserCountry_country_dm' => '',
-	'UserCountry_country_do' => '',
-	'UserCountry_country_dz' => '',
-	'UserCountry_country_ea' => '',
-	'UserCountry_country_ec' => '',
-	'UserCountry_country_ee' => '',
-	'UserCountry_country_eg' => '',
-	'UserCountry_country_eh' => '',
-	'UserCountry_country_er' => '',
-	'UserCountry_country_es' => '',
-	'UserCountry_country_et' => '',
-	'UserCountry_country_eu' => '',
-	'UserCountry_country_fi' => '',
-	'UserCountry_country_fj' => '',
-	'UserCountry_country_fk' => '',
-	'UserCountry_country_fm' => '',
-	'UserCountry_country_fo' => '',
-	'UserCountry_country_fr' => '',
-	'UserCountry_country_fx' => '',
-	'UserCountry_country_ga' => '',
-	'UserCountry_country_gb' => '',
-	'UserCountry_country_gd' => '',
-	'UserCountry_country_ge' => '',
-	'UserCountry_country_gf' => '',
-	'UserCountry_country_gg' => '',
-	'UserCountry_country_gh' => '',
-	'UserCountry_country_gi' => '',
-	'UserCountry_country_gl' => '',
-	'UserCountry_country_gm' => '',
-	'UserCountry_country_gn' => '',
-	'UserCountry_country_gp' => '',
-	'UserCountry_country_gq' => '',
-	'UserCountry_country_gr' => '',
-	'UserCountry_country_gs' => '',
-	'UserCountry_country_gt' => '',
-	'UserCountry_country_gu' => '',
-	'UserCountry_country_gw' => '',
-	'UserCountry_country_gy' => '',
-	'UserCountry_country_hk' => '',
-	'UserCountry_country_hm' => '',
-	'UserCountry_country_hn' => '',
-	'UserCountry_country_hr' => '',
-	'UserCountry_country_ht' => '',
-	'UserCountry_country_hu' => '',
-	'UserCountry_country_ic' => '',
-	'UserCountry_country_id' => '',
-	'UserCountry_country_ie' => '',
-	'UserCountry_country_il' => '',
-	'UserCountry_country_im' => '',
-	'UserCountry_country_in' => '',
-	'UserCountry_country_io' => '',
-	'UserCountry_country_iq' => '',
-	'UserCountry_country_ir' => '',
-	'UserCountry_country_is' => '',
-	'UserCountry_country_it' => '',
-	'UserCountry_country_je' => '',
-	'UserCountry_country_jm' => '',
-	'UserCountry_country_jo' => '',
-	'UserCountry_country_jp' => '',
-	'UserCountry_country_ke' => '',
-	'UserCountry_country_kg' => '',
-	'UserCountry_country_kh' => '',
-	'UserCountry_country_ki' => '',
-	'UserCountry_country_km' => '',
-	'UserCountry_country_kn' => '',
-	'UserCountry_country_kp' => '',
-	'UserCountry_country_kr' => '',
-	'UserCountry_country_kw' => '',
-	'UserCountry_country_ky' => '',
-	'UserCountry_country_kz' => '',
-	'UserCountry_country_la' => '',
-	'UserCountry_country_lb' => '',
-	'UserCountry_country_lc' => '',
-	'UserCountry_country_li' => '',
-	'UserCountry_country_lk' => '',
-	'UserCountry_country_lr' => '',
-	'UserCountry_country_ls' => '',
-	'UserCountry_country_lt' => '',
-	'UserCountry_country_lu' => '',
-	'UserCountry_country_lv' => '',
-	'UserCountry_country_ly' => '',
-	'UserCountry_country_ma' => '',
-	'UserCountry_country_mc' => '',
-	'UserCountry_country_md' => '',
-	'UserCountry_country_me' => '',
-	'UserCountry_country_mf' => '',
-	'UserCountry_country_mg' => '',
-	'UserCountry_country_mh' => '',
-	'UserCountry_country_mk' => '',
-	'UserCountry_country_ml' => '',
-	'UserCountry_country_mm' => '',
-	'UserCountry_country_mn' => '',
-	'UserCountry_country_mo' => '',
-	'UserCountry_country_mp' => '',
-	'UserCountry_country_mq' => '',
-	'UserCountry_country_mr' => '',
-	'UserCountry_country_ms' => '',
-	'UserCountry_country_mt' => '',
-	'UserCountry_country_mu' => '',
-	'UserCountry_country_mv' => '',
-	'UserCountry_country_mw' => '',
-	'UserCountry_country_mx' => '',
-	'UserCountry_country_my' => '',
-	'UserCountry_country_mz' => '',
-	'UserCountry_country_na' => '',
-	'UserCountry_country_nc' => '',
-	'UserCountry_country_ne' => '',
-	'UserCountry_country_nf' => '',
-	'UserCountry_country_ng' => '',
-	'UserCountry_country_ni' => '',
-	'UserCountry_country_nl' => '',
-	'UserCountry_country_no' => '',
-	'UserCountry_country_np' => '',
-	'UserCountry_country_nr' => '',
-	'UserCountry_country_nt' => '',
-	'UserCountry_country_nu' => '',
-	'UserCountry_country_nz' => '',
-	'UserCountry_country_om' => '',
-	'UserCountry_country_pa' => '',
-	'UserCountry_country_pe' => '',
-	'UserCountry_country_pf' => '',
-	'UserCountry_country_pg' => '',
-	'UserCountry_country_ph' => '',
-	'UserCountry_country_pk' => '',
-	'UserCountry_country_pl' => '',
-	'UserCountry_country_pm' => '',
-	'UserCountry_country_pn' => '',
-	'UserCountry_country_pr' => '',
-	'UserCountry_country_ps' => '',
-	'UserCountry_country_pt' => '',
-	'UserCountry_country_pw' => '',
-	'UserCountry_country_py' => '',
-	'UserCountry_country_qa' => '',
-	'UserCountry_country_re' => '',
-	'UserCountry_country_ro' => '',
-	'UserCountry_country_ru' => '',
-	'UserCountry_country_rs' => '',
-	'UserCountry_country_rw' => '',
-	'UserCountry_country_sa' => '',
-	'UserCountry_country_sb' => '',
-	'UserCountry_country_sc' => '',
-	'UserCountry_country_sd' => '',
-	'UserCountry_country_se' => '',
-	'UserCountry_country_sf' => '',
-	'UserCountry_country_sg' => '',
-	'UserCountry_country_sh' => '',
-	'UserCountry_country_si' => '',
-	'UserCountry_country_sj' => '',
-	'UserCountry_country_sk' => '',
-	'UserCountry_country_sl' => '',
-	'UserCountry_country_sm' => '',
-	'UserCountry_country_sn' => '',
-	'UserCountry_country_so' => '',
-	'UserCountry_country_sr' => '',
-	'UserCountry_country_st' => '',
-	'UserCountry_country_su' => '',
-	'UserCountry_country_sv' => '',
-	'UserCountry_country_sy' => '',
-	'UserCountry_country_sz' => '',
-	'UserCountry_country_ta' => '',
-	'UserCountry_country_tc' => '',
-	'UserCountry_country_td' => '',
-	'UserCountry_country_tf' => '',
-	'UserCountry_country_tg' => '',
-	'UserCountry_country_th' => '',
-	'UserCountry_country_tj' => '',
-	'UserCountry_country_tk' => '',
-	'UserCountry_country_tl' => '',
-	'UserCountry_country_tm' => '',
-	'UserCountry_country_tn' => '',
-	'UserCountry_country_to' => '',
-	'UserCountry_country_tp' => '',
-	'UserCountry_country_tr' => '',
-	'UserCountry_country_tt' => '',
-	'UserCountry_country_tv' => '',
-	'UserCountry_country_tw' => '',
-	'UserCountry_country_tz' => '',
-	'UserCountry_country_ua' => '',
-	'UserCountry_country_ug' => '',
-	'UserCountry_country_uk' => '',
-	'UserCountry_country_um' => '',
-	'UserCountry_country_us' => '',
-	'UserCountry_country_uy' => '',
-	'UserCountry_country_uz' => '',
-	'UserCountry_country_va' => '',
-	'UserCountry_country_vc' => '',
-	'UserCountry_country_ve' => '',
-	'UserCountry_country_vg' => '',
-	'UserCountry_country_vi' => '',
-	'UserCountry_country_vn' => '',
-	'UserCountry_country_vu' => '',
-	'UserCountry_country_wf' => '',
-	'UserCountry_country_ws' => '',
-	'UserCountry_country_ye' => '',
-	'UserCountry_country_yt' => '',
-	'UserCountry_country_yu' => '',
-	'UserCountry_country_za' => '',
-	'UserCountry_country_zm' => '',
-	'UserCountry_country_zr' => '',
-	'UserCountry_country_zw' => '',
-	'UserCountry_continent_eur' => '',
-	'UserCountry_continent_afr' => '',
-	'UserCountry_continent_asi' => '',
-	'UserCountry_continent_ams' => '',
-	'UserCountry_continent_amn' => '',
-	'UserCountry_continent_oce' => '',
+	'UserCountry_country_ac' => 'Ascension Islands',
+	'UserCountry_country_ad' => 'Andorra',
+	'UserCountry_country_ae' => 'United Arab Emirates',
+	'UserCountry_country_af' => 'Afghanistan',
+	'UserCountry_country_ag' => 'Antigua and Barbuda',
+	'UserCountry_country_ai' => 'Anguilla',
+	'UserCountry_country_al' => 'Albania',
+	'UserCountry_country_am' => 'Armenia',
+	'UserCountry_country_an' => 'Netherlands Antilles',
+	'UserCountry_country_ao' => 'Angola',
+	'UserCountry_country_aq' => 'Antarctica',
+	'UserCountry_country_ar' => 'Argentina',
+	'UserCountry_country_as' => 'American Samoa',
+	'UserCountry_country_at' => 'Austria',
+	'UserCountry_country_au' => 'Australia',
+	'UserCountry_country_aw' => 'Aruba',
+	'UserCountry_country_ax' => 'Aland Islands',
+	'UserCountry_country_az' => 'Azerbaijan',
+	'UserCountry_country_ba' => 'Bosnia and Herzegovina',
+	'UserCountry_country_bb' => 'Barbados',
+	'UserCountry_country_bd' => 'Bangladesh',
+	'UserCountry_country_be' => 'Belgium',
+	'UserCountry_country_bf' => 'Burkina Faso',
+	'UserCountry_country_bg' => 'Bulgaria',
+	'UserCountry_country_bh' => 'Bahrain',
+	'UserCountry_country_bi' => 'Burundi',
+	'UserCountry_country_bj' => 'Benin',
+	'UserCountry_country_bl' => 'Saint Barthelemy',
+	'UserCountry_country_bm' => 'Bermuda',
+	'UserCountry_country_bn' => 'Bruneo',
+	'UserCountry_country_bo' => 'Bolivia',
+	'UserCountry_country_br' => 'Brazil',
+	'UserCountry_country_bs' => 'Bahamas',
+	'UserCountry_country_bt' => 'Bhutan',
+	'UserCountry_country_bu' => 'Burma',
+	'UserCountry_country_bv' => 'Bouvet Island',
+	'UserCountry_country_bw' => 'Botswana',
+	'UserCountry_country_by' => 'Belarus',
+	'UserCountry_country_bz' => 'Belize',
+	'UserCountry_country_ca' => 'Canada',
+	'UserCountry_country_cc' => 'Cocos (Keeling) Islands',
+	'UserCountry_country_cd' => 'Congo, The Democratic Republic of the',
+	'UserCountry_country_cf' => 'Central African Republic',
+	'UserCountry_country_cg' => 'Congo',
+	'UserCountry_country_ch' => 'Switzerland',
+	'UserCountry_country_ci' => 'Cote D\'Ivoire',
+	'UserCountry_country_ck' => 'Cook Islands',
+	'UserCountry_country_cl' => 'Chile',
+	'UserCountry_country_cm' => 'Cameroon',
+	'UserCountry_country_cn' => 'China',
+	'UserCountry_country_co' => 'Colombia',
+	'UserCountry_country_cp' => 'Clipperton Island',
+	'UserCountry_country_cr' => 'Costa Rica',
+	'UserCountry_country_cs' => 'Serbia Montenegro',
+	'UserCountry_country_cu' => 'Cuba',
+	'UserCountry_country_cv' => 'Cape Verde',
+	'UserCountry_country_cx' => 'Christmas Island',
+	'UserCountry_country_cy' => 'Cyprus',
+	'UserCountry_country_cz' => 'Czech Republic',
+	'UserCountry_country_de' => 'Germany',
+	'UserCountry_country_dg' => 'Diego Garcia',
+	'UserCountry_country_dj' => 'Djibouti',
+	'UserCountry_country_dk' => 'Denmark',
+	'UserCountry_country_dm' => 'Dominica',
+	'UserCountry_country_do' => 'Dominican Republic',
+	'UserCountry_country_dz' => 'Algeria',
+	'UserCountry_country_ea' => 'Ceuta, Melilla',
+	'UserCountry_country_ec' => 'Ecuador',
+	'UserCountry_country_ee' => 'Estonia',
+	'UserCountry_country_eg' => 'Egypt',
+	'UserCountry_country_eh' => 'Western Sahara',
+	'UserCountry_country_er' => 'Eritrea',
+	'UserCountry_country_es' => 'Spain',
+	'UserCountry_country_et' => 'Ethiopia',
+	'UserCountry_country_eu' => 'European Union',
+	'UserCountry_country_fi' => 'Finland',
+	'UserCountry_country_fj' => 'Fiji',
+	'UserCountry_country_fk' => 'Falkland Islands (Malvinas)',
+	'UserCountry_country_fm' => 'Micronesia, Federated States of',
+	'UserCountry_country_fo' => 'Faroe Islands',
+	'UserCountry_country_fr' => 'France',
+	'UserCountry_country_fx' => 'France, Metropolitan',
+	'UserCountry_country_ga' => 'Gabon',
+	'UserCountry_country_gb' => 'Great Britain',
+	'UserCountry_country_gd' => 'Grenada',
+	'UserCountry_country_ge' => 'Georgia',
+	'UserCountry_country_gf' => 'French Guyana',
+	'UserCountry_country_gg' => 'Guernsey',
+	'UserCountry_country_gh' => 'Ghana',
+	'UserCountry_country_gi' => 'Gibraltar',
+	'UserCountry_country_gl' => 'Greenland',
+	'UserCountry_country_gm' => 'Gambia',
+	'UserCountry_country_gn' => 'Guinea',
+	'UserCountry_country_gp' => 'Guadeloupe',
+	'UserCountry_country_gq' => 'Equatorial Guinea',
+	'UserCountry_country_gr' => 'Greece',
+	'UserCountry_country_gs' => 'South Georgia and the South Sandwich Islands',
+	'UserCountry_country_gt' => 'Guatemala',
+	'UserCountry_country_gu' => 'Guam',
+	'UserCountry_country_gw' => 'Guinea-Bissau',
+	'UserCountry_country_gy' => 'Guyana',
+	'UserCountry_country_hk' => 'Hong Kong',
+	'UserCountry_country_hm' => 'Heard Island and McDonald Islands',
+	'UserCountry_country_hn' => 'Honduras',
+	'UserCountry_country_hr' => 'Croatia',
+	'UserCountry_country_ht' => 'Haiti',
+	'UserCountry_country_hu' => 'Hungary',
+	'UserCountry_country_ic' => 'Canary Islands',
+	'UserCountry_country_id' => 'Indonesia',
+	'UserCountry_country_ie' => 'Ireland',
+	'UserCountry_country_il' => 'Israel',
+	'UserCountry_country_im' => 'Man Island',
+	'UserCountry_country_in' => 'India',
+	'UserCountry_country_io' => 'British Indian Ocean Territory',
+	'UserCountry_country_iq' => 'Iraq',
+	'UserCountry_country_ir' => 'Iran, Islamic Republic of',
+	'UserCountry_country_is' => 'Iceland',
+	'UserCountry_country_it' => 'Italy',
+	'UserCountry_country_je' => 'Jersey',
+	'UserCountry_country_jm' => 'Jamaica',
+	'UserCountry_country_jo' => 'Jordan',
+	'UserCountry_country_jp' => 'Japan',
+	'UserCountry_country_ke' => 'Kenya',
+	'UserCountry_country_kg' => 'Kyrgyzstan',
+	'UserCountry_country_kh' => 'Cambodia',
+	'UserCountry_country_ki' => 'Kiribati',
+	'UserCountry_country_km' => 'Comoros',
+	'UserCountry_country_kn' => 'Saint Kitts and Nevis',
+	'UserCountry_country_kp' => ' Korea, Democratic People\'s Republic of ',
+	'UserCountry_country_kr' => 'Korea, Republic of',
+	'UserCountry_country_kw' => 'Kuwait',
+	'UserCountry_country_ky' => 'Cayman Islands',
+	'UserCountry_country_kz' => 'Kazakhstan',
+	'UserCountry_country_la' => 'Laos',
+	'UserCountry_country_lb' => 'Lebanon',
+	'UserCountry_country_lc' => 'Saint Lucia',
+	'UserCountry_country_li' => 'Liechtenstein',
+	'UserCountry_country_lk' => 'Sri Lanka',
+	'UserCountry_country_lr' => 'Liberia',
+	'UserCountry_country_ls' => 'Lesotho',
+	'UserCountry_country_lt' => 'Lithuania',
+	'UserCountry_country_lu' => 'Luxembourg',
+	'UserCountry_country_lv' => 'Latvia',
+	'UserCountry_country_ly' => 'Libya',
+	'UserCountry_country_ma' => 'Morocco',
+	'UserCountry_country_mc' => 'Monaco',
+	'UserCountry_country_md' => 'Moldova, Republic of',
+	'UserCountry_country_me' => 'Montenegro',
+	'UserCountry_country_mf' => 'Saint Martin',
+	'UserCountry_country_mg' => 'Madagascar',
+	'UserCountry_country_mh' => 'Marshall Islands',
+	'UserCountry_country_mk' => 'Macedonia',
+	'UserCountry_country_ml' => 'Mali',
+	'UserCountry_country_mm' => 'Myanmar',
+	'UserCountry_country_mn' => 'Mongolia',
+	'UserCountry_country_mo' => 'Macau',
+	'UserCountry_country_mp' => 'Northern Mariana Islands',
+	'UserCountry_country_mq' => 'Martinique',
+	'UserCountry_country_mr' => 'Mauritania',
+	'UserCountry_country_ms' => 'Montserrat',
+	'UserCountry_country_mt' => 'Malta',
+	'UserCountry_country_mu' => 'Mauritius',
+	'UserCountry_country_mv' => 'Maldives',
+	'UserCountry_country_mw' => 'Malawi',
+	'UserCountry_country_mx' => 'Mexico',
+	'UserCountry_country_my' => 'Malaysia',
+	'UserCountry_country_mz' => 'Mozambique',
+	'UserCountry_country_na' => 'Namibia',
+	'UserCountry_country_nc' => 'New Caledonia',
+	'UserCountry_country_ne' => 'Niger',
+	'UserCountry_country_nf' => 'Norfolk Island',
+	'UserCountry_country_ng' => 'Nigeria',
+	'UserCountry_country_ni' => 'Nicaragua',
+	'UserCountry_country_nl' => 'Netherlands',
+	'UserCountry_country_no' => 'Norway',
+	'UserCountry_country_np' => 'Nepal',
+	'UserCountry_country_nr' => 'Nauru',
+	'UserCountry_country_nt' => 'Neutral Zone',
+	'UserCountry_country_nu' => 'Niue',
+	'UserCountry_country_nz' => 'New Zealand',
+	'UserCountry_country_om' => 'Oman',
+	'UserCountry_country_pa' => 'Panama',
+	'UserCountry_country_pe' => 'Peru',
+	'UserCountry_country_pf' => 'French Polynesia',
+	'UserCountry_country_pg' => 'Papua New Guinea',
+	'UserCountry_country_ph' => 'Philippines',
+	'UserCountry_country_pk' => 'Pakistan',
+	'UserCountry_country_pl' => 'Poland',
+	'UserCountry_country_pm' => 'Saint Pierre and Miquelon',
+	'UserCountry_country_pn' => 'Pitcairn',
+	'UserCountry_country_pr' => 'Puerto Rico',
+	'UserCountry_country_ps' => 'Palestinian Territory',
+	'UserCountry_country_pt' => 'Portugal',
+	'UserCountry_country_pw' => 'Palau',
+	'UserCountry_country_py' => 'Paraguay',
+	'UserCountry_country_qa' => 'Qatar',
+	'UserCountry_country_re' => 'Reunion Island',
+	'UserCountry_country_ro' => 'Romania',
+	'UserCountry_country_ru' => 'Russia',
+	'UserCountry_country_rs' => 'Serbia',
+	'UserCountry_country_rw' => 'Rwanda',
+	'UserCountry_country_sa' => 'Saudi Arabia',
+	'UserCountry_country_sb' => 'Solomon Islands',
+	'UserCountry_country_sc' => 'Seychelles',
+	'UserCountry_country_sd' => 'Sudan',
+	'UserCountry_country_se' => 'Sweden',
+	'UserCountry_country_sf' => 'Finland',
+	'UserCountry_country_sg' => 'Singapore',
+	'UserCountry_country_sh' => 'Saint Helena',
+	'UserCountry_country_si' => 'Slovenia',
+	'UserCountry_country_sj' => 'Svalbard',
+	'UserCountry_country_sk' => 'Slovakia',
+	'UserCountry_country_sl' => 'Sierra Leone',
+	'UserCountry_country_sm' => 'San Marino',
+	'UserCountry_country_sn' => 'Senegal',
+	'UserCountry_country_so' => 'Somalia',
+	'UserCountry_country_sr' => 'Suriname',
+	'UserCountry_country_st' => 'Sao Tome and Principe',
+	'UserCountry_country_su' => 'Old U.S.S.R',
+	'UserCountry_country_sv' => 'El Salvador',
+	'UserCountry_country_sy' => 'Syrian Arab Republic',
+	'UserCountry_country_sz' => 'Swaziland',
+	'UserCountry_country_ta' => 'Tristan da Cunha',
+	'UserCountry_country_tc' => 'Turks and Caicos Islands',
+	'UserCountry_country_td' => 'Chad',
+	'UserCountry_country_tf' => 'French Southern Territories',
+	'UserCountry_country_tg' => 'Togo',
+	'UserCountry_country_th' => 'ประเทศไทย',
+	'UserCountry_country_tj' => 'Tajikistan',
+	'UserCountry_country_tk' => 'Tokelau',
+	'UserCountry_country_tl' => 'East Timor',
+	'UserCountry_country_tm' => 'Turkmenistan',
+	'UserCountry_country_tn' => 'Tunisia',
+	'UserCountry_country_to' => 'Tonga',
+	'UserCountry_country_tp' => 'Tonga',
+	'UserCountry_country_tr' => 'Tonga',
+	'UserCountry_country_tt' => 'Trinidad and Tobago',
+	'UserCountry_country_tv' => 'Tuvalu',
+	'UserCountry_country_tw' => 'Taiwan',
+	'UserCountry_country_tz' => 'Tanzania, United Republic of',
+	'UserCountry_country_ua' => 'Ukraine',
+	'UserCountry_country_ug' => 'Uganda',
+	'UserCountry_country_uk' => 'United Kingdom',
+	'UserCountry_country_um' => '_um United States Minor Outlying Islands ',
+	'UserCountry_country_us' => 'United States',
+	'UserCountry_country_uy' => 'Uruguay',
+	'UserCountry_country_uz' => 'Uzbekistan',
+	'UserCountry_country_va' => 'Vatican City',
+	'UserCountry_country_vc' => 'Saint Vincent and the Grenadines',
+	'UserCountry_country_ve' => 'Venezuela',
+	'UserCountry_country_vg' => 'Virgin Islands, British',
+	'UserCountry_country_vi' => 'Virgin Islands, U.S.',
+	'UserCountry_country_vn' => 'Vietnam',
+	'UserCountry_country_vu' => 'Vanuatu',
+	'UserCountry_country_wf' => 'Wallis and Futuna',
+	'UserCountry_country_ws' => 'Samoa',
+	'UserCountry_country_ye' => 'Yemen',
+	'UserCountry_country_yt' => 'Mayotte',
+	'UserCountry_country_yu' => 'Yugoslavia',
+	'UserCountry_country_za' => 'South Africa',
+	'UserCountry_country_zm' => 'Zambia',
+	'UserCountry_country_zr' => 'Zaire',
+	'UserCountry_country_zw' => 'Zimbabwe',
+	'UserCountry_continent_eur' => 'ยุโรป',
+	'UserCountry_continent_afr' => 'อัฟริกา',
+	'UserCountry_continent_asi' => 'เอเชีย',
+	'UserCountry_continent_ams' => 'อเมริกาใต้และกลาง',
+	'UserCountry_continent_amn' => 'อเมริกาเหนือ',
+	'UserCountry_continent_oce' => 'โอเชียเนีย',
 	'UserSettings_BrowserFamilies' => 'ประเภทของบราวเซอร์',
 	'UserSettings_Browsers' => 'บราวเซอร์',
 	'UserSettings_Plugins' => 'ปลั้กอิน',
 	'UserSettings_Configurations' => 'ระบบของผู้เข้าชม',
-	'UserSettings_OperatinsSystems' => 'ระบบปฎิบัติการ',
+	'UserSettings_OperatingSystems' => 'ระบบปฎิบัติการ',
 	'UserSettings_Resolutions' => 'ความละเอียด',
 	'UserSettings_WideScreen' => 'จอภาพแบบกว้าง',
 	'UserSettings_WidgetResolutions' => 'ความละเอียดจอภาพ',
@@ -573,6 +687,14 @@ $translations = array(
 	'UserSettings_WidgetOperatingSystems' => 'ระบบปฎิบัติการ',
 	'UserSettings_WidgetGlobalVisitors' => 'การตั้งค่าผู้เข้าชมโดยรวม',
 	'UserSettings_SubmenuSettings' => 'ระบบของผู้เข้าชม',
+	'UserSettings_VisitorSettings' => 'การตั้งค่าของผู้เยี่ยมชม',
+	'UserSettings_ColumnBrowserFamily' => 'ตระกูลของบราวเซอร์',
+	'UserSettings_ColumnBrowser' => 'บราวเซอร์',
+	'UserSettings_ColumnPlugin' => 'ปลักอิน',
+	'UserSettings_ColumnConfiguration' => 'การตั้งค่า',
+	'UserSettings_ColumnOperatingSystem' => 'ระบบปฏิบัติการ',
+	'UserSettings_ColumnResolution' => 'ความละเอียด',
+	'UserSettings_ColumnTypeOfScreen' => 'ชนิดของจอภาพ',
 	'UsersManager_UsersManagement' => 'การจัดการ User',
 	'UsersManager_UsersManagementMainDescription' => 'สร้างผู้ใช้ใหม่หรืออัปเดทผู้ใช้ที่มีอยู่ จากนั้นคุณสามารถกำหนดสิทธิ์ของพวกเขาได้',
 	'UsersManager_ManageAccess' => 'จัดการการเข้าถึง',
@@ -604,6 +726,7 @@ $translations = array(
 	'UsersManager_ExceptionEditAnonymous' => 'ผู้ใช้งานที่ไม่ระบุชื่อไม่สามารถแก้ไขหรือลบได้ ,มันถูกใช้งานโดย Piwik เพื่อระบุผู้ใช้ที่ไม่ได้เข้าสู่ระบบยัง ตัวอย่างเช่นคุณสามารถอนุญาติให้ผู้ใช้งานทั่วไปสามารถดูสถิติของเว็บคุณได้',
 	'UsersManager_ExceptionUserDoesNotExist' => 'ผู้ใช้ \'%s\' ไม่มีในระบบ',
 	'UsersManager_ExceptionAccessValues' => 'พารามิเตอร์เข้าถึงต้องมีหนึ่งค่าต่อไปนี้:[%s]',
+	'UsersManager_ExceptionSuperUser' => 'การรีเควสผู้ใช้ในระดับ Super User ไม่สามารถเรียกดู แก้ไข หรือลบได้ด้วย API คุณสามารถแก้ไขรายละเอียดของ Super User ได้แบบแมนนวลในไฟลล์การตั้งค่า Piwik',
 	'VisitFrequency_Evolution' => 'วิวัฒนาการตามเวลา',
 	'VisitFrequency_ReturnVisits' => '%s ผู้เข้าชม',
 	'VisitFrequency_ReturnActions' => '%s หน้าโดยผู้เข้าชม',
@@ -613,29 +736,39 @@ $translations = array(
 	'VisitFrequency_WidgetOverview' => 'ภาพรวมความถี่ผู้เข้าชมที่กลับมา',
 	'VisitFrequency_WidgetGraphReturning' => 'กราฟของผู้เข้าชม',
 	'VisitFrequency_SubmenuFrequency' => 'ความถี่ของผู้เข้าชม',
+	'VisitFrequency_ColumnReturningVisits' => 'ผู้เยี่ยมชมที่กลับมา',
+	'VisitFrequency_ColumnActionsByReturningVisits' => 'การดำเนินการโดยผู้เยี่ยมชมที่กลับมา',
+	'VisitFrequency_ColumnMaximumActionsByAReturningVisit' => 'การดำเนินการสูงสุดโดยผู้เยี่ยมชมที่กลับมา',
+	'VisitFrequency_ColumnTotalTimeSpentByReturningVisits' => 'เวลารวมทั้งหมดที่ใช้ไปโดยผู้เยี่ยมที่กลับมา',
+	'VisitFrequency_ColumnBounceRateForReturningVisits' => 'อัตราการเด้งของผู้เยี่ยมชมที่กลับมา',
+	'VisitFrequency_ReturnBounceRate' => '%s ผู้เยี่ยมชมที่กลับมาแล้วเด้ง(ออกจากเว็บไซต์หลังจากเปิดหน้าเดียว)',
 	'VisitTime_LocalTime' => 'จำนวนผู้ชมต่อเวลาท้องถิ่น',
 	'VisitTime_ServerTime' => 'จำนวนผู้ชมต่อเวลาของเซิฟเวอร์',
 	'VisitTime_WidgetLocalTime' => 'จำนวนผู้ชมตามเวลาท้องถิ่น',
 	'VisitTime_WidgetServerTime' => 'จำนวนผู้ชมตามเวลาของเซิฟเวอร์',
 	'VisitTime_SubmenuTimes' => 'เวลา',
-	'VisitTime_NHour' => '%sh',
+	'VisitTime_NHour' => '%sชม.',
+	'VisitTime_ColumnServerTime' => 'เวลาของเซิฟเวอร์',
+	'VisitTime_ColumnLocalTime' => 'เวลาของท้องถิ่น',
 	'VisitorInterest_VisitsPerDuration' => 'เวลาเฉลี่ยของผู้เข้าชม',
 	'VisitorInterest_VisitsPerNbOfPages' => 'หน้าเฉลี่ยของผู้เข้าชม',
 	'VisitorInterest_WidgetLengths' => 'ระยะเวลาการเข้าชม',
 	'VisitorInterest_WidgetPages' => 'หน้าต่อผู้เข้าชม',
 	'VisitorInterest_SubmenuFrequencyLoyalty' => 'ความถี่และความภักดี',
 	'VisitorInterest_PlusXMin' => '%sนาที',
-	'VisitorInterest_BetweenXYMinutes' => '%1s-%2sนาที',
+	'VisitorInterest_BetweenXYMinutes' => '%1s-%1sนาที',
 	'VisitorInterest_OnePage' => '1 หน้า',
 	'VisitorInterest_NPages' => '%s หน้า',
 	'VisitorInterest_BetweenXYSeconds' => '%1s-%2sวิ',
+	'VisitorInterest_ColumnVisitDuration' => 'ระยะเวลาผู้เยี่ยมชม',
+	'VisitorInterest_ColumnPagesPerVisit' => 'หน้าต่อผู้เยี่ยมชม',
 	'VisitsSummary_NbVisits' => '%s ผู้เข้าชม',
 	'VisitsSummary_NbUniqueVisitors' => '%sผู้เข้าชมที่ไม่ซ้ำ',
 	'VisitsSummary_NbActions' => '%s หน้าที่เข้าชม',
 	'VisitsSummary_TotalTime' => '%s เวลาบนไซต์',
-	'VisitsSummary_MaxNbActions' => '%s หน้าสูงสุดที่เข้าชม',
+	'VisitsSummary_MaxNbActions' => '%s หน้าสูงสุดในหนึ่งเข้าชม',
 	'VisitsSummary_NbBounced' => '%s หน้าที่ออกจากไซต์',
-	'VisitsSummary_Evolution' => 'วิวัฒนาการใน 30วันล่าสุด %ss',
+	'VisitsSummary_Evolution' => 'วิวัฒนาการใน 30วันล่าสุด %s',
 	'VisitsSummary_Report' => 'รายงาน',
 	'VisitsSummary_GenerateTime' => '%s วินาทีที่ใช้',
 	'VisitsSummary_GenerateQueries' => '%s การค้นหา',
@@ -644,4 +777,6 @@ $translations = array(
 	'VisitsSummary_WidgetLastVisitors' => 'ผู้เข้าชมที่ไม่ซ้ำกราฟล่าสุด',
 	'VisitsSummary_WidgetOverviewGraph' => 'ภาพรวมและกราฟ',
 	'VisitsSummary_SubmenuOverview' => 'ภาพรวมผู้เข้าชม',
-);
\ No newline at end of file
+	'VisitsSummary_NbVisitsBounced' => '%s ผู้เยี่ยมชมที่เด้ง(ออกจากเว็บไซต์หลังจากเปิดเพียงหน้าเดียว)',
+	'VisitsSummary_EvolutionOverLastPeriods' => 'วิวัฒนาการในช่วงเวลาล่าสุด %s',
+);
