@@ -87,6 +87,32 @@ $translations = array(
 	'CoreHome_DayTh_js' => 'Чт',
 	'CoreHome_DayFr_js' => 'Пт',
 	'CoreHome_DaySa_js' => 'Сб',
+	'CoreHome_ShortDay_1_js' => 'нед',
+	'CoreHome_ShortDay_2_js' => 'пнд',
+	'CoreHome_ShortDay_3_js' => 'вів',
+	'CoreHome_ShortDay_4_js' => 'срд',
+	'CoreHome_ShortDay_5_js' => 'чтв',
+	'CoreHome_ShortDay_6_js' => 'птн',
+	'CoreHome_ShortDay_7_js' => 'сбт',
+	'CoreHome_LongDay_1_js' => 'неділя',
+	'CoreHome_LongDay_2_js' => 'понеділок',
+	'CoreHome_LongDay_3_js' => 'вівторок',
+	'CoreHome_LongDay_4_js' => 'середа',
+	'CoreHome_LongDay_5_js' => 'четвер',
+	'CoreHome_LongDay_6_js' => 'п’ятниця',
+	'CoreHome_LongDay_7_js' => 'субота',
+	'CoreHome_ShortMonth_1_js' => 'Січ',
+	'CoreHome_ShortMonth_2_js' => 'Лют',
+	'CoreHome_ShortMonth_3_js' => 'Бер',
+	'CoreHome_ShortMonth_4_js' => 'Кві',
+	'CoreHome_ShortMonth_5_js' => 'Тра',
+	'CoreHome_ShortMonth_6_js' => 'Чер',
+	'CoreHome_ShortMonth_7_js' => 'Лип',
+	'CoreHome_ShortMonth_8_js' => 'Сер',
+	'CoreHome_ShortMonth_9_js' => 'Вер',
+	'CoreHome_ShortMonth_10_js' => 'Жов',
+	'CoreHome_ShortMonth_11_js' => 'Лис',
+	'CoreHome_ShortMonth_12_js' => 'Гру',
 	'CoreHome_MonthJanuary_js' => 'Січень',
 	'CoreHome_MonthFebruary_js' => 'Лютий',
 	'CoreHome_MonthMarch_js' => 'Березень',
@@ -580,7 +606,7 @@ $translations = array(
 	'UserSettings_Browsers' => 'Браузери',
 	'UserSettings_Plugins' => 'Плагіни',
 	'UserSettings_Configurations' => 'Конфігурації',
-	'UserSettings_OperatinsSystems' => 'Операційні системи',
+	'UserSettings_OperatingSystems' => 'Операційні системи',
 	'UserSettings_Resolutions' => 'Роздільні здатності',
 	'UserSettings_WideScreen' => 'Широкоформатність',
 	'UserSettings_WidgetResolutions' => 'Роздільні здатності',
@@ -644,7 +670,7 @@ $translations = array(
 	'VisitorInterest_WidgetPages' => 'Кількість сторінок за відвідування',
 	'VisitorInterest_SubmenuFrequencyLoyalty' => 'Частота та Лояльність',
 	'VisitorInterest_PlusXMin' => '%s хв',
-	'VisitorInterest_BetweenXYMinutes' => '%1s-%2s хв',
+	'VisitorInterest_BetweenXYMinutes' => '%1s-%1s хв',
 	'VisitorInterest_OnePage' => 'одна сторінка',
 	'VisitorInterest_NPages' => '%s сторінок',
 	'VisitorInterest_BetweenXYSeconds' => '%1s-%2s сек.',
@@ -664,4 +690,4 @@ $translations = array(
 	'VisitsSummary_WidgetOverviewGraph' => 'Огляд з графіком',
 	'VisitsSummary_SubmenuOverview' => 'Огляд',
 	'VisitsSummary_EvolutionPeriods' => 'Динаміка протягом останніх 30 %s',
-);
\ No newline at end of file
+);
