@@ -78,6 +78,32 @@ $translations = array(
 	'CoreHome_DayTh_js' => '四',
 	'CoreHome_DayFr_js' => '五',
 	'CoreHome_DaySa_js' => '六',
+	'CoreHome_ShortDay_1_js' => '周日',
+	'CoreHome_ShortDay_2_js' => '周一',
+	'CoreHome_ShortDay_3_js' => '周二',
+	'CoreHome_ShortDay_4_js' => '周三',
+	'CoreHome_ShortDay_5_js' => '周四',
+	'CoreHome_ShortDay_6_js' => '周五',
+	'CoreHome_ShortDay_7_js' => '周六',
+	'CoreHome_LongDay_1_js' => '星期日',
+	'CoreHome_LongDay_2_js' => '星期一',
+	'CoreHome_LongDay_3_js' => '星期二',
+	'CoreHome_LongDay_4_js' => '星期三',
+	'CoreHome_LongDay_5_js' => '星期四',
+	'CoreHome_LongDay_6_js' => '星期五',
+	'CoreHome_LongDay_7_js' => '星期六',
+	'CoreHome_ShortMonth_1_js' => '一',
+	'CoreHome_ShortMonth_2_js' => '二',
+	'CoreHome_ShortMonth_3_js' => '三',
+	'CoreHome_ShortMonth_4_js' => '四',
+	'CoreHome_ShortMonth_5_js' => '五',
+	'CoreHome_ShortMonth_6_js' => '六',
+	'CoreHome_ShortMonth_7_js' => '七',
+	'CoreHome_ShortMonth_8_js' => '八',
+	'CoreHome_ShortMonth_9_js' => '九',
+	'CoreHome_ShortMonth_10_js' => '十',
+	'CoreHome_ShortMonth_11_js' => '十一',
+	'CoreHome_ShortMonth_12_js' => '十二',
 	'CoreHome_MonthJanuary_js' => '一月',
 	'CoreHome_MonthFebruary_js' => '二月',
 	'CoreHome_MonthMarch_js' => '三月',
@@ -155,7 +181,7 @@ $translations = array(
 	'UserSettings_Browsers' => '使用浏览器',
 	'UserSettings_Plugins' => '浏览器插件',
 	'UserSettings_Configurations' => '客户端配置',
-	'UserSettings_OperatinsSystems' => '操作系统',
+	'UserSettings_OperatingSystems' => '操作系统',
 	'UserSettings_Resolutions' => '分辨率',
 	'UserSettings_WideScreen' => '宽屏幕',
 	'UserSettings_WidgetResolutions' => '画面分辨率',
@@ -432,7 +458,7 @@ $translations = array(
 	'VisitsSummary_TotalTime' => '%s 访客总停留时间',
 	'VisitsSummary_MaxNbActions' => '%s 由单一次访问所产生的最大活动数',
 	'VisitsSummary_NbBounced' => '%s 个单页浏览访问数 (于浏览单一网页后离开网站)',
-	'VisitsSummary_Evolution' => '最近 30 %ss 的发展趋势',
+	'VisitsSummary_Evolution' => '最近 30 %s 的发展趋势',
 	'VisitsSummary_Report' => '报告',
 	'VisitsSummary_GenerateTime' => '页面生成时间： %s 秒',
 	'VisitsSummary_GenerateQueries' => '%s 个查询已执行',
@@ -462,7 +488,7 @@ $translations = array(
 	'VisitorInterest_WidgetPages' => '页/每访问',
 	'VisitorInterest_SubmenuFrequencyLoyalty' => '访问频率＆忠诚度',
 	'VisitorInterest_PlusXMin' => '%s 分',
-	'VisitorInterest_BetweenXYMinutes' => '%1s-%2s 分',
+	'VisitorInterest_BetweenXYMinutes' => '%1s-%1s 分',
 	'VisitorInterest_OnePage' => '1 页',
 	'VisitorInterest_NPages' => '%s 页',
 	'VisitorInterest_BetweenXYSeconds' => '%1s-%2s秒',
