@@ -145,6 +145,32 @@ $translations = array(
 	'CoreHome_DayTh_js' => '四',
 	'CoreHome_DayFr_js' => '五',
 	'CoreHome_DaySa_js' => '六',
+	'CoreHome_ShortDay_1_js' => '周日',
+	'CoreHome_ShortDay_2_js' => '周一',
+	'CoreHome_ShortDay_3_js' => '周二',
+	'CoreHome_ShortDay_4_js' => '周三',
+	'CoreHome_ShortDay_5_js' => '周四',
+	'CoreHome_ShortDay_6_js' => '周五',
+	'CoreHome_ShortDay_7_js' => '周六',
+	'CoreHome_LongDay_1_js' => '星期日',
+	'CoreHome_LongDay_2_js' => '星期一',
+	'CoreHome_LongDay_3_js' => '星期二',
+	'CoreHome_LongDay_4_js' => '星期三',
+	'CoreHome_LongDay_5_js' => '星期四',
+	'CoreHome_LongDay_6_js' => '星期五',
+	'CoreHome_LongDay_7_js' => '星期六',
+	'CoreHome_ShortMonth_1_js' => '一',
+	'CoreHome_ShortMonth_2_js' => '二',
+	'CoreHome_ShortMonth_3_js' => '三',
+	'CoreHome_ShortMonth_4_js' => '四',
+	'CoreHome_ShortMonth_5_js' => '五',
+	'CoreHome_ShortMonth_6_js' => '六',
+	'CoreHome_ShortMonth_7_js' => '七',
+	'CoreHome_ShortMonth_8_js' => '八',
+	'CoreHome_ShortMonth_9_js' => '九',
+	'CoreHome_ShortMonth_10_js' => '十',
+	'CoreHome_ShortMonth_11_js' => '十一',
+	'CoreHome_ShortMonth_12_js' => '十二',
 	'CoreHome_MonthJanuary_js' => '一月',
 	'CoreHome_MonthFebruary_js' => '二月',
 	'CoreHome_MonthMarch_js' => '三月',
@@ -247,14 +273,14 @@ $translations = array(
 	'UserSettings_Browsers' => '使用瀏覽器',
 	'UserSettings_Plugins' => '瀏覽器外掛',
 	'UserSettings_Configurations' => '客端配置',
-	'UserSettings_OperatinsSystems' => '作業系統',
+	'UserSettings_OperatingSystems' => '作業系統',
 	'UserSettings_Resolutions' => '解析度',
 	'UserSettings_WideScreen' => '寬螢幕',
 	'UserSettings_ColumnBrowserFamily' => '瀏覽器家族',
 	'UserSettings_ColumnBrowser' => '瀏覽器',
 	'UserSettings_ColumnPlugin' => '外掛',
 	'UserSettings_ColumnConfiguration' => '客端配置',
-	'UserSettings_ColumnOperatinsSystem' => '作業系統',
+	'UserSettings_ColumnOperatingSystem' => '作業系統',
 	'UserSettings_ColumnResolution' => '解析度',
 	'UserSettings_ColumnTypeOfScreen' => '螢幕類型',
 	'UserSettings_WidgetResolutions' => '畫面解析度',
@@ -585,7 +611,7 @@ $translations = array(
 	'VisitorInterest_WidgetPages' => '每個造訪瀏覽的頁面數',
 	'VisitorInterest_SubmenuFrequencyLoyalty' => '造訪頻率＆忠誠度',
 	'VisitorInterest_PlusXMin' => '%s 分',
-	'VisitorInterest_BetweenXYMinutes' => '%1s-%2s 分',
+	'VisitorInterest_BetweenXYMinutes' => '%1s-%1s 分',
 	'VisitorInterest_OnePage' => '1 頁',
 	'VisitorInterest_NPages' => '%s 頁',
 	'VisitorInterest_BetweenXYSeconds' => '%1s-%2s秒',
