@@ -18,9 +18,9 @@
  * @author      Alexey Borzov <avb@php.net>
  * @author      Bertrand Mansion <bmansion@mamasam.com>
  * @author      Thomas Schulz <ths@4bconsult.de>
- * @copyright   2001-2007 The PHP Group
+ * @copyright   2001-2009 The PHP Group
  * @license     http://www.php.net/license/3_01.txt PHP License 3.01
- * @version     CVS: $Id: ArraySmarty.php 870 2009-01-14 03:40:55Z matt $
+ * @version     CVS: $Id: ArraySmarty.php 1297 2009-07-08 04:58:45Z vipsoft $
  * @link        http://pear.php.net/package/HTML_QuickForm
  */
 
@@ -87,7 +87,7 @@ require_once 'HTML/QuickForm/Renderer/Array.php';
  * @author      Alexey Borzov <avb@php.net>
  * @author      Bertrand Mansion <bmansion@mamasam.com>
  * @author      Thomas Schulz <ths@4bconsult.de>
- * @version     Release: 3.2.9
+ * @version     Release: 3.2.11
  * @since       3.0
  */
 class HTML_QuickForm_Renderer_ArraySmarty extends HTML_QuickForm_Renderer_Array
@@ -133,11 +133,12 @@ class HTML_QuickForm_Renderer_ArraySmarty extends HTML_QuickForm_Renderer_Array
     *
     * @param  Smarty  reference to the Smarty template engine instance
     * @param  bool    true: render an array of labels to many labels, $key 0 to 'label' and the oterh to "label_$key"
+    * @param  bool    true: collect all hidden elements into string; false: process them as usual form elements
     * @access public
     */
-    function HTML_QuickForm_Renderer_ArraySmarty(&$tpl, $staticLabels = false)
+    function HTML_QuickForm_Renderer_ArraySmarty(&$tpl, $staticLabels = false, $collectHidden = true)
     {
-        $this->HTML_QuickForm_Renderer_Array(false, $staticLabels);
+        $this->HTML_QuickForm_Renderer_Array($collectHidden, $staticLabels);
         $this->_tpl =& $tpl;
     } // end constructor
 
@@ -399,4 +400,4 @@ class HTML_QuickForm_Renderer_ArraySmarty extends HTML_QuickForm_Renderer_Array
         $this->_error = $template;
     } // end func setErrorTemplate
 }
-?>
+?>
\ No newline at end of file
