@@ -15,25 +15,22 @@
  * @category   Zend
  * @package    Zend_Log
  * @subpackage Writer
- * @copyright  Copyright (c) 2005-2007 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: Abstract.php 870 2009-01-14 03:40:55Z matt $
+ * @version    $Id: Abstract.php 16219 2009-06-21 19:45:39Z thomas $
  */
 
 /** Zend_Log_Filter_Priority */
 require_once 'Zend/Log/Filter/Priority.php';
 
-/** Zend_Log_Exception */
-require_once 'Zend/Log/Exception.php';
-
 /**
  * @category   Zend
  * @package    Zend_Log
  * @subpackage Writer
- * @copyright  Copyright (c) 2005-2007 Zend Technologies USA Inc. (http://www.zend.com)
+ * @copyright  Copyright (c) 2005-2009 Zend Technologies USA Inc. (http://www.zend.com)
  * @license    http://framework.zend.com/license/new-bsd     New BSD License
- * @version    $Id: Abstract.php 870 2009-01-14 03:40:55Z matt $
- */ 
+ * @version    $Id: Abstract.php 16219 2009-06-21 19:45:39Z thomas $
+ */
 abstract class Zend_Log_Writer_Abstract
 {
     /**
@@ -49,7 +46,7 @@ abstract class Zend_Log_Writer_Abstract
 
     /**
      * Add a filter specific to this writer.
-     * 
+     *
      * @param  Zend_Log_Filter_Interface  $filter
      * @return void
      */
@@ -86,7 +83,8 @@ abstract class Zend_Log_Writer_Abstract
      * @param  Zend_Log_Formatter_Interface $formatter
      * @return void
      */
-    public function setFormatter($formatter) {
+    public function setFormatter($formatter)
+    {
         $this->_formatter = $formatter;
     }
 
