@@ -22,7 +22,7 @@ define('FONT_3', 3);
 define('FONT_4', 4);
 define('FONT_5', 5);
 
-require_once('Object.php');
+require_once dirname(__FILE__).'/Object.php';
 
 class Sparkline extends Object {
 
