@@ -4,14 +4,12 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: Controller.php 1085 2009-05-04 22:55:35Z matt $
+ * @version $Id: Controller.php 1420 2009-08-22 13:23:16Z vipsoft $
  * 
+ * @category Piwik_Plugins
  * @package Piwik_API
  */
 
-require_once "API/Request.php";
-require_once "API/DocumentationGenerator.php";
-
 /**
  * 
  * @package Piwik_API
@@ -37,7 +35,7 @@ class Piwik_API_Controller extends Piwik_Controller
 	
 	public function listAllAPI()
 	{
-		$view = new Piwik_View("API/templates/listAllAPI.tpl");
+		$view = Piwik_View::factory("listAllAPI");
 		$this->setGeneralVariablesView($view);
 		
 		$ApiDocumentation = new Piwik_API_DocumentationGenerator();
@@ -46,4 +44,3 @@ class Piwik_API_Controller extends Piwik_Controller
 		echo $view->render();
 	}
 }
-
