@@ -4,15 +4,15 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: API.php 1158 2009-05-31 11:31:14Z matt $
+ * @version $Id: API.php 1530 2009-10-22 22:40:18Z matt $
  * 
+ * @category Piwik_Plugins
  * @package Piwik_Actions
  */
 
-require_once "Actions.php";
-
 /**
- * 
+ * Actions API
+ *
  * @package Piwik_Actions
  */
 class Piwik_Actions_API
@@ -50,10 +50,25 @@ class Piwik_Actions_API
 		$dataTable->queueFilter('ReplaceSummaryRowLabel');
 		return $dataTable;
 	}
-	
+
+	/**
+	 * Backward compatibility. Fallsback to getPageTitles() instead.
+	 * @deprecated Deprecated since Piwik 0.5
+	 */
 	public function getActions( $idSite, $period, $date, $expanded = false, $idSubtable = false )
 	{
-		return $this->getDataTable('Actions_actions', $idSite, $period, $date, $expanded, $idSubtable );
+	    return $this->getPageTitles( $idSite, $period, $date, $expanded, $idSubtable );
+	}
+	
+	public function getPageUrls( $idSite, $period, $date, $expanded = false, $idSubtable = false )
+	{
+		return $this->getDataTable('Actions_actions_url', $idSite, $period, $date, $expanded, $idSubtable );
+	}
+
+	public function getPageTitles( $idSite, $period, $date, $expanded = false, $idSubtable = false)
+	{
+		$dataTable = $this->getDataTable('Actions_actions', $idSite, $period, $date, $expanded, $idSubtable);
+		return $dataTable;
 	}
 
 	public function getDownloads( $idSite, $period, $date, $expanded = false, $idSubtable = false )
