@@ -1,43 +1,68 @@
 <?php
-require_once "ViewDataTable.php";
+/**
+ * Piwik - Open source web analytics
+ * 
+ * @link http://piwik.org
+ * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
+ * @version $Id: Controller.php 1530 2009-10-22 22:40:18Z matt $
+ * 
+ * @category Piwik_Plugins
+ * @package Piwik_Actions
+ */
 
+/**
+ * Actions controller
+ *
+ * @package Piwik_Actions
+ */
 class Piwik_Actions_Controller extends Piwik_Controller 
 {
-	public function index()
-	{
-		$view = new Piwik_View('Actions/index.tpl');
-		
-		/* Actions, Downloads, Outlinks */
-		$view->dataTableActions = $this->getActions( true );
-		$view->dataTableDownloads = $this->getDownloads( true );
-		$view->dataTableOutlinks = $this->getOutlinks( true );
-		
-		echo $view->render();
-	}
-	
-	public function getActions($fetch = false)
+	public function getPageUrls($fetch = false)
 	{
 		$view = Piwik_ViewDataTable::factory();
 		$view->init(  	$this->pluginName, 
 						__FUNCTION__,
-						'Actions.getActions', 
-						'getActionsSubDataTable' );
+						'Actions.getPageUrls',
+						'getPageUrlsSubDataTable' );
+		$view->setColumnTranslation('label', Piwik_Translate('Actions_ColumnPageURL'));
 		$this->configureViewActions($view);
-		$view->setColumnTranslation('label', Piwik_Translate('Actions_ColumnPageName'));
 		return $this->renderView($view, $fetch);
 	}
 	
-	public function getActionsSubDataTable($fetch = false)
+	public function getPageUrlsSubDataTable($fetch = false)
 	{
 		$view = Piwik_ViewDataTable::factory();
 		$view->init(  	$this->pluginName, 
 						__FUNCTION__,
-						'Actions.getActions', 
+						'Actions.getPageUrls',
 						'getActionsSubDataTable'  );
 		$this->configureViewActions($view);
 		return $this->renderView($view, $fetch);
 	}
-	
+
+	public function getPageTitles($fetch = false)
+	{
+		$view = Piwik_ViewDataTable::factory();
+		$view->init(  	$this->pluginName,
+						__FUNCTION__,
+						'Actions.getPageTitles',
+						'getPageTitlesSubDataTable' );
+		$view->setColumnTranslation('label', Piwik_Translate('Actions_ColumnPageName'));
+		$this->configureViewActions($view);
+		return $this->renderView($view, $fetch);
+	}
+
+	public function getPageTitlesSubDataTable($fetch = false)
+	{
+		$view = Piwik_ViewDataTable::factory();
+		$view->init(  	$this->pluginName,
+						__FUNCTION__,
+						'Actions.getPageTitles',
+						'getPageTitlesSubDataTable'  );
+		$this->configureViewActions($view);
+		return $this->renderView($view, $fetch);
+	}
+
 	public function getDownloads($fetch = false)
 	{
 		$view = Piwik_ViewDataTable::factory();
@@ -62,7 +87,7 @@ class Piwik_Actions_Controller extends Piwik_Controller
 		$view->disableSearchBox();
 		return $this->renderView($view, $fetch);
 	}
-	
+
 	public function getOutlinks($fetch = false)
 	{
 		$view = Piwik_ViewDataTable::factory();
@@ -87,7 +112,7 @@ class Piwik_Actions_Controller extends Piwik_Controller
 		$view->disableSearchBox();
 		return $this->renderView($view, $fetch);
 	}
-	
+
 	protected function configureViewActions($view)
 	{
 		$view->setTemplate('CoreHome/templates/datatable_actions.tpl');
@@ -109,14 +134,12 @@ class Piwik_Actions_Controller extends Piwik_Controller
 		
 		$view->setLimit( 100 );
 		$view->setColumnsToDisplay( array('label','nb_hits','nb_visits') );
-		$view->setColumnTranslation('label', Piwik_Translate('Actions_ColumnPageName'));
 		$view->setColumnTranslation('nb_hits', Piwik_Translate('General_ColumnPageviews'));
 		$view->setColumnTranslation('nb_visits', Piwik_Translate('General_ColumnUniquePageviews'));
 
 		if(Piwik_Common::getRequestVar('enable_filter_excludelowpop', '0', 'string' ) != '0')
 		{
 			// computing minimum value to exclude
-			require_once "VisitsSummary/Controller.php";
 			$visitsInfo = Piwik_VisitsSummary_Controller::getVisitsSummary();
 			$visitsInfo = $visitsInfo->getFirstRow();
 			$nbActions = $visitsInfo->getColumn('nb_actions');
@@ -158,7 +181,7 @@ class Piwik_Actions_Controller extends Piwik_Controller
 		$view->disableExcludeLowPopulation();
 		$view->setLimit( 15 );
 	}
-	
+
 	protected function getArrayFromRecursiveDataTable( $dataTable, $depth = 0 )
 	{
 		$table = array();
