@@ -4,15 +4,14 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version 
+ * @version $Id: Controller.php 1420 2009-08-22 13:23:16Z vipsoft $
  * 
+ * @category Piwik_Plugins
  * @package Piwik_CoreAdminHome
- * 
  */
 
-require_once "API/Request.php";
-
 /**
+ *
  * @package Piwik_CoreAdminHome
  */
 class Piwik_CoreAdminHome_Controller extends Piwik_Controller
@@ -44,10 +43,10 @@ class Piwik_CoreAdminHome_Controller extends Piwik_Controller
 	
 	protected function getDefaultIndexView()
 	{
-		$view = new Piwik_View('CoreAdminHome/templates/index.tpl');
+		$view = Piwik_View::factory('index');
 		$view->content = '';
+		$this->setGeneralVariablesView($view);
 		$view->menu = Piwik_GetAdminMenu();
 		return $view;
 	}
 }
-
