@@ -4,14 +4,15 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: Controller.php 169 2008-01-14 05:41:15Z matt $
+ * @version $Id: Controller.php 1420 2009-08-22 13:23:16Z vipsoft $
  * 
- * @package Piwik_ExamplePlugin
+ * @category Piwik_Plugins
+ * @package Piwik_CorePluginsAdmin
  */
 
 /**
- * 
- * @package Piwik_ExamplePlugin
+ *
+ * @package Piwik_CorePluginsAdmin
  */
 class Piwik_CorePluginsAdmin_Controller extends Piwik_Controller
 {	
@@ -31,8 +32,9 @@ class Piwik_CorePluginsAdmin_Controller extends Piwik_Controller
 									);
 		}
 		
-		$view = new Piwik_View('CorePluginsAdmin/templates/manage.tpl');
+		$view = Piwik_View::factory('manage');
 		$view->pluginsName = $plugins;
+		$this->setGeneralVariablesView($view);
 		$view->menu = Piwik_GetAdminMenu();
 		echo $view->render();
 	}
