@@ -4,11 +4,16 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: ExamplePlugin.php 169 2008-01-14 05:41:15Z matt $
+ * @version $Id: CorePluginsAdmin.php 1665 2009-12-11 21:25:57Z vipsoft $
  * 
+ * @category Piwik_Plugins
  * @package Piwik_CorePluginsAdmin
  */
 
+/**
+ *
+ * @package Piwik_CorePluginsAdmin
+ */
 class Piwik_CorePluginsAdmin extends Piwik_Plugin
 {
 	public function getInformation()
@@ -17,8 +22,8 @@ class Piwik_CorePluginsAdmin extends Piwik_Plugin
 			'name' => 'Plugins Management',
 			'description' => 'Plugins Administration Interface.',
 			'author' => 'Piwik',
-			'homepage' => 'http://piwik.org/',
-			'version' => '0.1',
+			'author_homepage' => 'http://piwik.org/',
+			'version' => Piwik_Version::VERSION,
 		);
 	}
 	
@@ -29,8 +34,6 @@ class Piwik_CorePluginsAdmin extends Piwik_Plugin
 	
 	function addMenu()
 	{
-		Piwik_AddAdminMenu(Piwik_Translate('CorePluginsAdmin_MenuPlugins'), array('module' => 'CorePluginsAdmin', 'action' => 'index'));		
+		Piwik_AddAdminMenu('CorePluginsAdmin_MenuPlugins', array('module' => 'CorePluginsAdmin', 'action' => 'index'));		
 	}
 }
-
-
