@@ -4,24 +4,26 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: Controller.php 241 2008-01-26 01:30:37Z matt $
+ * @version $Id: DBStats.php 1665 2009-12-11 21:25:57Z vipsoft $
  * 
+ * @category Piwik_Plugins
  * @package Piwik_DBStats
- * 
  */
 
-require_once "DBStats/API.php" ;
-
+/**
+ *
+ * @package Piwik_DBStats
+ */
 class Piwik_DBStats extends Piwik_Plugin
 {
 	public function getInformation()
 	{
 		return array(
 			'name' => 'Database statistics',
-			'description' => 'This plugin reports the database usage by Piwik tables.',
+			'description' => 'This plugin reports the MySQL database usage by Piwik tables.',
 			'author' => 'Piwik',
-			'homepage' => 'http://piwik.org/',
-			'version' => '0.1',
+			'author_homepage' => 'http://piwik.org/',
+			'version' => Piwik_Version::VERSION,
 		);
 	}
 
@@ -32,7 +34,6 @@ class Piwik_DBStats extends Piwik_Plugin
 	
 	function addMenu()
 	{
-		Piwik_AddAdminMenu("Database usage", array('module' => 'DBStats', 'action' => 'index'));		
+		Piwik_AddAdminMenu('DBStats_DatabaseUsage', array('module' => 'DBStats', 'action' => 'index'));		
 	}
 }
-	
