@@ -4,11 +4,16 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: ExamplePlugin.php 169 2008-01-14 05:41:15Z matt $
+ * @version $Id: Dashboard.php 1665 2009-12-11 21:25:57Z vipsoft $
  * 
- * @package Piwik_ExamplePlugin
+ * @category Piwik_Plugins
+ * @package Piwik_Dashboard
  */
 
+/**
+ *
+ * @package Piwik_Dashboard
+ */
 class Piwik_Dashboard extends Piwik_Plugin
 {
 	public function getInformation()
@@ -17,8 +22,8 @@ class Piwik_Dashboard extends Piwik_Plugin
 			'name' => 'Dashboard',
 			'description' => 'Your Web Analytics Dashboard. You can customize Your Dashboard: add new widgets, change the order of your widgets. Each user can access his own custom Dashboard.',
 			'author' => 'Piwik',
-			'homepage' => 'http://piwik.org/',
-			'version' => '0.1',
+			'author_homepage' => 'http://piwik.org/',
+			'version' => Piwik_Version::VERSION,
 		);
 	}
 
@@ -41,7 +46,7 @@ class Piwik_Dashboard extends Piwik_Plugin
 
 	function css()
 	{
-		echo '<link rel="stylesheet" type="text/css" href="plugins/Dashboard/templates/dashboard.css" />';
+		echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"plugins/Dashboard/templates/dashboard.css\" />\n";
 	}
 	
 	public function install()
@@ -49,20 +54,16 @@ class Piwik_Dashboard extends Piwik_Plugin
 		// we catch the exception
 		try{
 			$sql = "CREATE TABLE ". Piwik::prefixTable('user_dashboard')." (
-					login VARCHAR( 20 ) NOT NULL ,
+					login VARCHAR( 100 ) NOT NULL ,
 					iddashboard INT NOT NULL ,
 					layout TEXT NOT NULL,
 					PRIMARY KEY ( login , iddashboard )
 					)  DEFAULT CHARSET=utf8 " ;
-			Piwik_Query($sql);
-		} catch(Zend_Db_Statement_Exception $e){
+			Piwik_Exec($sql);
+		} catch(Exception $e){
 			// mysql code error 1050:table already exists
 			// see bug #153 http://dev.piwik.org/trac/ticket/153
-			if(ereg('1050',$e->getMessage()))
-			{
-				return;
-			}
-			else
+			if(!Zend_Registry::get('db')->isErrNo($e, '1050'))
 			{
 				throw $e;
 			}
@@ -72,7 +73,7 @@ class Piwik_Dashboard extends Piwik_Plugin
 	public function uninstall()
 	{
 		$sql = "DROP TABLE ". Piwik::prefixTable('user_dashboard') ;
-		Piwik_Query($sql);		
+		Piwik_Exec($sql);		
 	}
 	
 }
