@@ -1,5 +1,19 @@
 <?php
+/**
+ * Piwik - Open source web analytics
+ * 
+ * @link http://piwik.org
+ * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
+ * @version $Id: ExampleFeedburner.php 1665 2009-12-11 21:25:57Z vipsoft $
+ * 
+ * @category Piwik_Plugins
+ * @package Piwik_ExampleFeedburner
+ */
 
+/**
+ *
+ * @package Piwik_ExampleFeedburner
+ */
 class Piwik_ExampleFeedburner extends Piwik_Plugin
 {
 	public function getInformation()
@@ -8,7 +22,7 @@ class Piwik_ExampleFeedburner extends Piwik_Plugin
 			'name' => 'Example Feedburner',
 			'description' => 'Example Plugin: How to display your Feedburner subscriber in a Widget in the Dashboard?',
 			'author' => 'Piwik',
-			'homepage' => 'http://piwik.org/',
+			'author_homepage' => 'http://piwik.org/',
 			'version' => '0.1',
 		);
 	}
@@ -16,11 +30,11 @@ class Piwik_ExampleFeedburner extends Piwik_Plugin
 	function install()
 	{
 		try{
-			Piwik_Query('ALTER TABLE '.Piwik::prefixTable('site'). " ADD `feedburnerName` VARCHAR( 100 ) DEFAULT NULL");
-		} catch(Zend_Db_Statement_Exception $e){
+			Piwik_Exec('ALTER TABLE '.Piwik::prefixTable('site'). " ADD `feedburnerName` VARCHAR( 100 ) DEFAULT NULL");
+		} catch(Exception $e){
 			// mysql code error 1060: column already exists
 			// if there is another error we throw the exception, otherwise it is OK as we are simply reinstalling the plugin
-			if(!ereg('1060',$e->getMessage()))
+			if(!Zend_Registry::get('db')->isErrNo($e, '1060'))
 			{
 				throw $e;
 			}
@@ -35,6 +49,10 @@ class Piwik_ExampleFeedburner extends Piwik_Plugin
 
 Piwik_AddWidget('Example Widgets', 'Feedburner statistics', 'ExampleFeedburner', 'feedburner');
 
+/**
+ *
+ * @package Piwik_ExampleFeedburner
+ */
 class Piwik_ExampleFeedburner_Controller extends Piwik_Controller
 {
 
@@ -44,7 +62,7 @@ class Piwik_ExampleFeedburner_Controller extends Piwik_Controller
 	 */
 	function feedburner()
 	{
-		$view = new Piwik_View('ExampleFeedburner/templates/feedburner.tpl');
+		$view = Piwik_View::factory('feedburner');
 		$idSite = Piwik_Common::getRequestVar('idSite',1,'int');
 		$feedburnerFeedName = Piwik_FetchOne('SELECT feedburnerName FROM '.Piwik::prefixTable('site').
 								' WHERE idsite = ?', $idSite );
