@@ -4,12 +4,12 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: ExampleUI.php 1100 2009-05-08 20:22:44Z matt $
+ * @version $Id: ExampleUI.php 1665 2009-12-11 21:25:57Z vipsoft $
  * 
+ * @category Piwik_Plugins
  * @package Piwik_ExampleUI
  */
 
-
 /*
 - prepare a page with all use cases
 - test the actions datatable in this page?
@@ -19,6 +19,11 @@
 - without all columns icon
 + update http://dev.piwik.org/trac/wiki/HowToTestUI
 */
+
+/**
+ *
+ * @package Piwik_ExampleUI
+ */
 class Piwik_ExampleUI extends Piwik_Plugin
 {
 	public function getInformation()
@@ -27,7 +32,7 @@ class Piwik_ExampleUI extends Piwik_Plugin
 			'name' => 'Example User Interface',
 			'description' => 'Example Plugin: This plugin shows how to work with the Piwik UI: create tables, graphs, etc.',
 			'author' => 'Piwik',
-			'homepage' => 'http://piwik.org/',
+			'author_homepage' => 'http://piwik.org/',
 			'version' => '0.1',
 		);
 	}
@@ -55,6 +60,5 @@ class Piwik_ExampleUI extends Piwik_Plugin
 		{
 			Piwik_AddMenu('UI Framework', $subMenu, array('module' => 'ExampleUI', 'action' => $action));
 		}
-	}
-	
-}
\ No newline at end of file
+	}	
+}
