@@ -4,11 +4,16 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: ExamplePlugin.php 169 2008-01-14 05:41:15Z matt $
+ * @version $Id: Feedback.php 1665 2009-12-11 21:25:57Z vipsoft $
  * 
+ * @category Piwik_Plugins
  * @package Piwik_Feedback
  */
 
+/**
+ *
+ * @package Piwik_Feedback
+ */
 class Piwik_Feedback extends Piwik_Plugin
 {
 	public function getInformation()
@@ -17,8 +22,20 @@ class Piwik_Feedback extends Piwik_Plugin
 			'name' => 'Feedback',
 			'description' => 'Send your Feedback to the Piwik Team in one click. Share your ideas and suggestions with us!',
 			'author' => 'Piwik',
-			'homepage' => 'http://piwik.org/',
-			'version' => '0.1',
+			'author_homepage' => 'http://piwik.org/',
+			'version' => Piwik_Version::VERSION,
 		);
 	}
+
+	function getListHooksRegistered()
+	{
+		return array(
+			'template_js_import' => 'js',
+		);
+	}
+	
+	function js()
+	{
+		echo "<script type=\"text/javascript\" src=\"plugins/Feedback/templates/feedback.js\"></script>\n";
+	}
 }
