@@ -4,19 +4,20 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: Goals.php 1150 2009-05-27 22:45:25Z vipsoft $
+ * @version $Id: Goals.php 1665 2009-12-11 21:25:57Z vipsoft $
  * 
- * @package Piwik_Referers
+ * @category Piwik_Plugins
+ * @package Piwik_Goals
  */
-	
-require_once "Tracker/GoalManager.php";
 
 /**
  * TODO Goals plugin
  * - clean API especially int methods
  */
+
 /**
- * @package Piwik_Referers
+ *
+ * @package Piwik_Goals
  */
 class Piwik_Goals extends Piwik_Plugin
 {	
@@ -28,8 +29,8 @@ class Piwik_Goals extends Piwik_Plugin
 			'name' => '(ALPHA) Goal Tracking',
 			'description' => 'Create Goals and see reports about your goal conversions: evolution over time, revenue per visit, conversions per referer, per keyword, etc.',
 			'author' => 'Piwik',
-			'homepage' => 'http://piwik.org/',
-			'version' => '0.1',
+			'author_homepage' => 'http://piwik.org/',
+			'version' => Piwik_Version::VERSION,
 			'TrackerPlugin' => true, // this plugin must be loaded during the stats logging
 		);
 		
@@ -50,7 +51,6 @@ class Piwik_Goals extends Piwik_Plugin
 
 	function fetchGoalsFromDb($notification)
 	{
-		require_once "Goals/API.php";
 		$idsite = $notification->getNotificationInfo();
 		
 		// add the 'goal' entry in the website array
