@@ -4,8 +4,9 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: View.php 586 2008-08-03 23:53:22Z matt $
+ * @version $Id: View.php 1420 2009-08-22 13:23:16Z vipsoft $
  * 
+ * @category Piwik_Plugins
  * @package Piwik_Installation
  */
 
@@ -13,15 +14,17 @@
  * 
  * @package Piwik_Installation
  */
-class Piwik_Install_View extends Piwik_View
+class Piwik_Installation_View extends Piwik_View
 {
 	protected $mainTemplate = 'Installation/templates/structure.tpl';
 	
 	function __construct($subtemplatePath, $installationSteps, $currentStepName)
 	{
 		parent::__construct($this->mainTemplate);
+
 		$this->subTemplateToLoad = $subtemplatePath;
-		$this->steps = $installationSteps;
+		$this->steps = array_keys($installationSteps);
+		$this->allStepsTitle = array_values($installationSteps);
 		$this->currentStepName = $currentStepName;
 		$this->showNextStep = false;
 	}
@@ -29,7 +32,6 @@ class Piwik_Install_View extends Piwik_View
 	function render()
 	{
 		// prepare the all steps templates
-		$this->allStepsTitle = $this->steps;
 		$this->currentStepId = array_search($this->currentStepName, $this->steps);
 		$this->totalNumberOfSteps = count($this->steps);
 		
@@ -41,8 +43,12 @@ class Piwik_Install_View extends Piwik_View
 		{
 			$this->nextModuleName = $this->steps[$this->currentStepId + 1];
 		}
-		
+		$this->previousModuleName = '';
+		if(isset($this->steps[$this->currentStepId - 1]))
+		{
+			$this->previousModuleName = $this->steps[$this->currentStepId - 1];
+		}
+
 		return parent::render();
-		
 	}
-}
\ No newline at end of file
+}
