@@ -4,16 +4,15 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: Controller.php 241 2008-01-26 01:30:37Z matt $
+ * @version $Id: Controller.php 1420 2009-08-22 13:23:16Z vipsoft $
  * 
- * @package Piwik_CoreHome
+ * @category Piwik_Plugins
+ * @package Piwik_LanguagesManager
  * 
  */
-require_once "API/Request.php";
-require_once "ViewDataTable.php";
 
 /**
- * @package Piwik_Dashboard
+ * @package Piwik_LanguagesManager
  */
 class Piwik_LanguagesManager_Controller extends Piwik_Controller
 {
@@ -24,13 +23,14 @@ class Piwik_LanguagesManager_Controller extends Piwik_Controller
 	public function saveLanguage()
 	{
 		$language = Piwik_Common::getRequestVar('language');
-		$currentUser = Piwik::getCurrentUserLogin();
-		$_SESSION['language'] = $language;
-		if($currentUser !== 'anonymous')
-		{
-			Piwik_LanguagesManager_API::setLanguageForUser($currentUser, $language);
+		Piwik_LanguagesManager_API::setLanguageForSession($language);
+		if(Zend_Registry::isRegistered('access')) {
+			$currentUser = Piwik::getCurrentUserLogin();
+			if($currentUser && $currentUser !== 'anonymous')
+			{
+				Piwik_LanguagesManager_API::setLanguageForUser($currentUser, $language);
+			}
 		}
 		Piwik_Url::redirectToReferer();
-	}
-	
+	}	
 }
