@@ -4,11 +4,17 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: ExamplePlugin.php 169 2008-01-14 05:41:15Z matt $
+ * @version $Id: LanguagesManager.php 1665 2009-12-11 21:25:57Z vipsoft $
+ * 
+ * @category Piwik_Plugins
+ * @package Piwik_LanguagesManager
  * 
- * @package Piwik_LanguageManager
  */
 
+/**
+ *
+ * @package Piwik_LanguagesManager
+ */
 class Piwik_LanguagesManager extends Piwik_Plugin
 {
 	public function getInformation()
@@ -17,8 +23,8 @@ class Piwik_LanguagesManager extends Piwik_Plugin
 			'name' => 'Languages Management',
 			'description' => 'This plugin will display a list of the available languages for the Piwik interface. The language selected will be saved in the preferences for each user.',
 			'author' => 'Piwik',
-			'homepage' => 'http://piwik.org/',
-			'version' => '0.1',
+			'author_homepage' => 'http://piwik.org/',
+			'version' => Piwik_Version::VERSION,
 		);
 	}
 
@@ -33,12 +39,17 @@ class Piwik_LanguagesManager extends Piwik_Plugin
 
 	function css()
 	{
-		echo '<link rel="stylesheet" type="text/css" href="plugins/LanguagesManager/templates/styles.css" />';
+		echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"themes/default/styles.css\" />\n";
 	}
-	
+
+	/**
+	 * Show styled language selection drop-down list
+	 *
+	 * @param string $url The form action.  Default is to save language.
+	 */
 	function showLanguagesSelector()
 	{
-		$view = new Piwik_View("LanguagesManager/templates/languages.tpl");
+		$view = Piwik_View::factory("languages");
 		$view->languages = Piwik_LanguagesManager_API::getAvailableLanguageNames();
 		$view->currentLanguageCode = self::getLanguageCodeForCurrentUser();
 		$view->currentLanguageName = self::getLanguageNameForCurrentUser();
@@ -47,32 +58,27 @@ class Piwik_LanguagesManager extends Piwik_Plugin
 	
 	function getLanguageToLoad($notification)
 	{
-		require_once "LanguagesManager/API.php";
 		$language =& $notification->getNotificationObject();
 		$language = self::getLanguageCodeForCurrentUser();
 	}
 	
 	/**
-	 * @return void|Exception
+	 * @throws Exception if non-recoverable error
 	 */
 	public function install()
 	{
 		// we catch the exception
 		try{
 			$sql = "CREATE TABLE ". Piwik::prefixTable('user_language')." (
-					login VARCHAR( 20 ) NOT NULL ,
+					login VARCHAR( 100 ) NOT NULL ,
 					language VARCHAR( 10 ) NOT NULL ,
 					PRIMARY KEY ( login )
 					)  DEFAULT CHARSET=utf8 " ;
-			Piwik_Query($sql);
-		} catch(Zend_Db_Statement_Exception $e){
+			Piwik_Exec($sql);
+		} catch(Exception $e){
 			// mysql code error 1050:table already exists
 			// see bug #153 http://dev.piwik.org/trac/ticket/153
-			if(ereg('1050',$e->getMessage()))
-			{
-				return;
-			}
-			else
+			if(!Zend_Registry::get('db')->isErrNo($e, '1050'))
 			{
 				throw $e;
 			}
@@ -80,12 +86,12 @@ class Piwik_LanguagesManager extends Piwik_Plugin
 	}
 	
 	/**
-	 * @return void|Exception
+	 * @throws Exception if non-recoverable error
 	 */
 	public function uninstall()
 	{
 		$sql = "DROP TABLE ". Piwik::prefixTable('user_language') ;
-		Piwik_Query($sql);		
+		Piwik_Exec($sql);		
 	}
 	
 	
@@ -127,9 +133,9 @@ class Piwik_LanguagesManager extends Piwik_Plugin
 	 */
 	static protected function getLanguageFromPreferences()
 	{
-		if(isset($_SESSION['language']))
+		if ($language = Piwik_LanguagesManager_API::getLanguageForSession())
 		{
-			return $_SESSION['language'];
+			return $language;
 		}
 		
 		try {
@@ -139,8 +145,4 @@ class Piwik_LanguagesManager extends Piwik_Plugin
 			return false;
 		}
 	}
-	
-	
-	
 }
-
