@@ -1,9 +1,34 @@
 <?php
-require_once "Referers/functions.php";
-require_once "UserCountry/functions.php";
-require_once "UserSettings/functions.php";
-require_once "Provider/functions.php";
+/**
+ * Piwik - Open source web analytics
+ * 
+ * @link http://piwik.org
+ * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
+ * @version $Id: Visitor.php 1621 2009-12-03 02:50:14Z vipsoft $
+ * 
+ * @category Piwik_Plugins
+ * @package Piwik_Live
+ */
 
+// no direct access
+defined('PIWIK_INCLUDE_PATH') or die;
+
+/**
+ * @see plugins/Referers/functions.php
+ * @see plugins/UserCountry/functions.php
+ * @see plugins/UserSettings/functions.php
+ * @see plugins/Provider/functions.php
+ */
+
+require_once PIWIK_INCLUDE_PATH . '/plugins/Referers/functions.php';
+require_once PIWIK_INCLUDE_PATH . '/plugins/UserCountry/functions.php';
+require_once PIWIK_INCLUDE_PATH . '/plugins/UserSettings/functions.php';
+require_once PIWIK_INCLUDE_PATH . '/plugins/Provider/functions.php';
+
+/**
+ *
+ * @package Piwik_Live
+ */
 class Piwik_Live_Visitor
 {
 	function __construct($visitorRawData)
@@ -49,6 +74,7 @@ class Piwik_Live_Visitor
 			'resolution' => $this->getResolution(),
 			'screenIcon' => $this->getScreenTypeIcon(),
 			'plugins' => $this->getPlugins(),
+			'lastActionDateTime' => $this->getDateTimeLastAction(),
 		);
 	}
 	
@@ -181,9 +207,13 @@ class Piwik_Live_Visitor
 		$plugins = array( 
 	 		'config_pdf',
 	 		'config_flash',
+	 		'config_java',
 	 		'config_director',
+	 		'config_quicktime',
 	 		'config_realplayer',
-	 		'config_windowsmedia'
+	 		'config_windowsmedia',
+	 		'config_gears',
+	 		'config_silverlight',
 		);
 		$return = array();
 		foreach($plugins as $plugin)
@@ -256,4 +286,9 @@ class Piwik_Live_Visitor
 	{
 		return Piwik_getHostnameUrl($this->details['location_provider']);
 	}
+	
+	function getDateTimeLastAction()
+	{
+		return date('Y-m-d H:i:s', strtotime($this->details['visit_last_action_time']));
+	}
 }
