@@ -1,34 +1,33 @@
 <?php
 /**
  * Piwik - Open source web analytics
- * 
+ *
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: Login.php 772 2008-11-27 16:01:49Z matt $
- * 
+ * @version $Id: Login.php 1665 2009-12-11 21:25:57Z vipsoft $
+ *
+ * @category Piwik_Plugins
  * @package Piwik_Login
  */
-require "Login/Auth.php";
-require "Cookie.php";
 
 /**
- * 
+ *
  * @package Piwik_Login
  */
 class Piwik_Login extends Piwik_Plugin
-{	
+{
 	public function getInformation()
 	{
 		$info = array(
 			'name' => 'Login',
 			'description' => 'Login Authentication plugin, reading the credentials from the config/config.inc.php file for the Super User, and from the Database for the other users. Can be easily replaced to introduce a new Authentication mechanism (OpenID, htaccess, custom Auth, etc.).',
 			'author' => 'Piwik',
-			'homepage' => 'http://piwik.org/',
-			'version' => '0.1',
+			'author_homepage' => 'http://piwik.org/',
+			'version' => Piwik_Version::VERSION,
 		);
 		return $info;
 	}
-	
+
 	function getListHooksRegistered()
 	{
 		$hooks = array(
@@ -38,37 +37,37 @@ class Piwik_Login extends Piwik_Plugin
 		);
 		return $hooks;
 	}
-	
+
 	function noAccess( $notification )
 	{
 		$exception  = $notification->getNotificationObject();
-		$exceptionMessage = $exception->getMessage(); 
+		$exceptionMessage = $exception->getMessage();
 
-		require "Login/Controller.php";
-		$controller = new Piwik_Login_Controller;
+		$controller = new Piwik_Login_Controller();
 		$controller->login($exceptionMessage);
 	}
-	
+
 	function ApiRequestAuthenticate($notification)
 	{
 		$tokenAuth = $notification->getNotificationObject();
+		Zend_Registry::get('auth')->setLogin($login = null);
 		Zend_Registry::get('auth')->setTokenAuth($tokenAuth);
 	}
-	
+
 	function initAuthenticationObject($notification)
 	{
 		$auth = new Piwik_Login_Auth();
-     	Zend_Registry::set('auth', $auth);
-		
-     	$action = Piwik::getAction();
-     	if(Piwik::getModule() === 'API' 
-     		&& (empty($action) || $action == 'index'))
-     	{
-     		return;
-     	}
-     		
-		$authCookieName = 'piwik-auth';
-		$authCookieExpiry = time() + 3600;
+		Zend_Registry::set('auth', $auth);
+
+		$action = Piwik::getAction();
+		if(Piwik::getModule() === 'API'
+			&& (empty($action) || $action == 'index'))
+		{
+			return;
+		}
+
+		$authCookieName = Zend_Registry::get('config')->General->login_cookie_name;
+		$authCookieExpiry = time() + Zend_Registry::get('config')->General->login_cookie_expire;
 		$authCookie = new Piwik_Cookie($authCookieName, $authCookieExpiry);
 		$defaultLogin = 'anonymous';
 		$defaultTokenAuth = 'anonymous';
