@@ -4,11 +4,19 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: API.php 1158 2009-05-31 11:31:14Z matt $
+ * @version $Id: API.php 1431 2009-08-23 14:27:44Z vipsoft $
  * 
+ * @category Piwik_Plugins
  * @package Piwik_Provider
  */
-require_once "Provider/functions.php";
+
+// no direct access
+defined('PIWIK_INCLUDE_PATH') or die;
+
+/**
+ * @see plugins/Provider/functions.php
+ */
+require_once PIWIK_INCLUDE_PATH . '/plugins/Provider/functions.php';
 
 /**
  * 
