@@ -4,13 +4,14 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: Provider.php 1138 2009-05-18 04:43:56Z matt $
+ * @version $Id: Provider.php 1665 2009-12-11 21:25:57Z vipsoft $
  * 
+ * @category Piwik_Plugins
  * @package Piwik_Provider
  */
-	
+
 /**
- * 
+ *
  * @package Piwik_Provider
  */
 class Piwik_Provider extends Piwik_Plugin
@@ -21,8 +22,8 @@ class Piwik_Provider extends Piwik_Plugin
 			'name' => 'Provider',
 			'description' => 'Reports the Provider of the visitors.',
 			'author' => 'Piwik',
-			'homepage' => 'http://piwik.org/',
-			'version' => '0.1',
+			'author_homepage' => 'http://piwik.org/',
+			'version' => Piwik_Version::VERSION,
 			'TrackerPlugin' => true, // this plugin must be loaded during the stats logging
 		);
 		
@@ -48,7 +49,7 @@ class Piwik_Provider extends Piwik_Plugin
 		
 		// if the column already exist do not throw error. Could be installed twice...
 		try {
-			Piwik_Query($query);
+			Piwik_Exec($query);
 		}
 		catch(Exception $e){}
 	}
@@ -57,7 +58,7 @@ class Piwik_Provider extends Piwik_Plugin
 	{
 		// add column hostname / hostname ext in the visit table
 		$query = "ALTER TABLE `".Piwik::prefixTable('log_visit')."` DROP `location_provider`";
-		Piwik_Query($query);
+		Piwik_Exec($query);
 	}
 	
 	function addWidget()
@@ -183,7 +184,7 @@ class Piwik_Provider extends Piwik_Plugin
 		$out =& $notification->getNotificationObject();
 		$out = '</div>
 			<div id="rightcolumn">
-			<h2>Providers</h2>';
+			<h2>'.Piwik_Translate('Provider_WidgetProviders').'</h2>';
 		$out .= Piwik_FrontController::getInstance()->fetchDispatch('Provider','getProvider');
 		$out .= '</div>';
 	}
