@@ -1,9 +1,24 @@
 <?php
+/**
+ * Piwik - Open source web analytics
+ * 
+ * @link http://piwik.org
+ * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
+ * @version $Id: Controller.php 1420 2009-08-22 13:23:16Z vipsoft $
+ * 
+ * @category Piwik_Plugins
+ * @package Piwik_Referers
+ */
+
+/**
+ *
+ * @package Piwik_Referers
+ */
 class Piwik_Referers_Controller extends Piwik_Controller 
 {
 	function index()
 	{
-		$view = new Piwik_View('Referers/templates/index.tpl');
+		$view = Piwik_View::factory('index');
 		
 		$view->graphEvolutionReferers = $this->getEvolutionGraph(true, Piwik_Common::REFERER_TYPE_DIRECT_ENTRY, array('nb_visits'));
 		$view->nameGraphEvolutionReferers = 'ReferersgetEvolutionGraph';
@@ -39,7 +54,7 @@ class Piwik_Referers_Controller extends Piwik_Controller
 	
 	function getSearchEnginesAndKeywords()
 	{
-		$view = new Piwik_View('Referers/templates/searchEngines_Keywords.tpl');
+		$view = Piwik_View::factory('searchEngines_Keywords');
 		$view->searchEngines = $this->getSearchEngines(true) ;
 		$view->keywords = $this->getKeywords(true);
 		echo $view->render();
