@@ -4,36 +4,41 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: Controller.php 586 2008-08-03 23:53:22Z matt $
+ * @version $Id: Controller.php 1557 2009-11-01 14:57:25Z vipsoft $
  * 
+ * @category Piwik_Plugins
  * @package Piwik_SitesManager
  */
 
-
 /**
+ *
  * @package Piwik_SitesManager
  */
 class Piwik_SitesManager_Controller extends Piwik_Controller
 {
 	function index()
 	{
-		$view = new Piwik_View('SitesManager/templates/SitesManager.tpl');
+		$view = Piwik_View::factory('SitesManager');
 		$sites = Piwik_SitesManager_API::getSitesWithAdminAccess();
 		foreach($sites as &$site)
 		{
 			$site['alias_urls'] = Piwik_SitesManager_API::getSiteUrlsFromId($site['idsite']);
 		}
 		$view->adminSites = $sites;
+		$this->setGeneralVariablesView($view);
 		$view->menu = Piwik_GetAdminMenu();
 		echo $view->render();
 	}
 	
 	function displayJavascriptCode()
 	{
-		$jsTag = Piwik::getJavascriptCode(Piwik_Common::getRequestVar('idsite',1), Piwik_Url::getCurrentUrlWithoutFileName());
-		$view = new Piwik_View('SitesManager/templates/DisplayJavascriptCode.tpl');
+		$idSite = Piwik_Common::getRequestVar('idsite', 1);
+		Piwik::checkUserHasViewAccess($idSite);
+		$jsTag = Piwik::getJavascriptCode($idSite, Piwik_Url::getCurrentUrlWithoutFileName());
+		$view = Piwik_View::factory('DisplayJavascriptCode');
+		$this->setGeneralVariablesView($view);
 		$view->menu = Piwik_GetAdminMenu();
 		$view->jsTag = $jsTag;
 		echo $view->render();
 	}
-}
\ No newline at end of file
+}
