@@ -4,12 +4,21 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: API.php 1158 2009-05-31 11:31:14Z matt $
+ * @version $Id: API.php 1431 2009-08-23 14:27:44Z vipsoft $
  * 
+ * @category Piwik_Plugins
  * @package Piwik_UserCountry
  */
-require_once "DataFiles/Countries.php";
-require_once "UserCountry/functions.php";
+
+// no direct access
+defined('PIWIK_INCLUDE_PATH') or die;
+
+/**
+ * @see core/DataFiles/Countries.php
+ * @see plugins/UserCountry/functions.php
+ */
+require_once PIWIK_INCLUDE_PATH . '/core/DataFiles/Countries.php';
+require_once PIWIK_INCLUDE_PATH . '/plugins/UserCountry/functions.php';
 
 /**
  * 
@@ -64,6 +73,4 @@ class Piwik_UserCountry_API
 		$archive = Piwik_Archive::build($idSite, $period, $date );
 		return $archive->getDataTableFromNumeric('UserCountry_distinctCountries');
 	}
-	
-	
 }
