@@ -4,13 +4,14 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: UserCountry.php 1072 2009-04-27 04:18:16Z matt $
+ * @version $Id: UserCountry.php 1665 2009-12-11 21:25:57Z vipsoft $
  * 
+ * @category Piwik_Plugins
  * @package Piwik_UserCountry
  */
-	
+
 /**
- * 
+ *
  * @package Piwik_UserCountry
  */
 class Piwik_UserCountry extends Piwik_Plugin
@@ -21,8 +22,8 @@ class Piwik_UserCountry extends Piwik_Plugin
 			'name' => 'Visitors Country',
 			'description' => 'Reports the Country of the visitors.',
 			'author' => 'Piwik',
-			'homepage' => 'http://piwik.org/',
-			'version' => '0.1',
+			'author_homepage' => 'http://piwik.org/',
+			'version' => Piwik_Version::VERSION,
 		);
 		return $info;
 	}
@@ -106,4 +107,3 @@ class Piwik_UserCountry extends Piwik_Plugin
 		destroy($tableContinent);
 	}
 }
-
