@@ -1,10 +1,24 @@
 <?php
-require_once "ViewDataTable.php";
+/**
+ * Piwik - Open source web analytics
+ * 
+ * @link http://piwik.org
+ * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
+ * @version $Id: Controller.php 1681 2009-12-13 19:19:07Z vipsoft $
+ * 
+ * @category Piwik_Plugins
+ * @package Piwik_UserSettings
+ */
+
+/**
+ *
+ * @package Piwik_UserSettings
+ */
 class Piwik_UserSettings_Controller extends Piwik_Controller 
 {
 	function index()
 	{
-		$view = new Piwik_View('UserSettings/templates/index.tpl');
+		$view = Piwik_View::factory('index');
 		
 		$view->dataTablePlugin = $this->getPlugin( true );
 		$view->dataTableResolution = $this->getResolution( true );
@@ -44,7 +58,7 @@ class Piwik_UserSettings_Controller extends Piwik_Controller
 										__FUNCTION__, 
 										'UserSettings.getOS'
 									);
-		$view->setColumnTranslation('label', Piwik_Translate('UserSettings_ColumnOperatinsSystem'));
+		$view->setColumnTranslation('label', Piwik_Translate('UserSettings_ColumnOperatingSystem'));
 		return $this->renderView($view, $fetch);
 	}
 	
