@@ -1,9 +1,26 @@
 <?php
-require_once "UserAgentParser/UserAgentParser.php";
+/**
+ * Piwik - Open source web analytics
+ * 
+ * @link http://piwik.org
+ * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
+ * @version $Id: functions.php 1586 2009-11-14 12:45:16Z vipsoft $
+ * 
+ * @category Piwik_Plugins
+ * @package Piwik_UserSettings
+ */
+
+// no direct access
+defined('PIWIK_INCLUDE_PATH') or die;
+
+/**
+ * @see libs/UserAgentParser/UserAgentParser.php
+ */
+require_once PIWIK_INCLUDE_PATH . '/libs/UserAgentParser/UserAgentParser.php';
 		
 function Piwik_getPluginsLogo( $oldLabel )
 {
-	return  "plugins/UserSettings/images/plugins/". $oldLabel . ".gif";
+	return  'plugins/UserSettings/images/plugins/'. $oldLabel . '.gif';
 }
 
 function Piwik_getOSLabel($osId)
@@ -15,7 +32,7 @@ function Piwik_getOSLabel($osId)
 	}
 	if( $osId == 'UNK')
 	{
-		return Piwik_Translate('General_Unknown');
+		return html_entity_decode(Piwik_Translate('General_Unknown'), ENT_COMPAT, 'UTF-8');
 	}
 	return $osId;
 }
@@ -29,7 +46,7 @@ function Piwik_getOSShortLabel($osId)
 	}
 	if( $osId == 'UNK')
 	{
-		return Piwik_Translate('General_Unknown');
+		return html_entity_decode(Piwik_Translate('General_Unknown'), ENT_COMPAT, 'UTF-8');
 	}
 	return $osId;
 }
@@ -42,7 +59,7 @@ function Piwik_getBrowserTypeLabel($oldLabel)
 	}
 	if($oldLabel == 'unknown')
 	{
-		return Piwik_Translate('General_Unknown');
+		return html_entity_decode(Piwik_Translate('General_Unknown'), ENT_COMPAT, 'UTF-8');
 	}
 	return $oldLabel;
 }
@@ -61,7 +78,7 @@ function Piwik_getConfigurationLabel($str)
 	$browser = UserAgentParser::getBrowserNameFromId($name);
 	if($browser === false)
 	{
-		$browser = Piwik_Translate('General_Unknown');
+		$browser = html_entity_decode(Piwik_Translate('General_Unknown'), ENT_COMPAT, 'UTF-8');
 	}
 	$resolution = $values[2];
 	return $os . " / " . $browser . " / " . $resolution;
@@ -78,7 +95,7 @@ function Piwik_getBrowserLabel($oldLabel)
 	}
 	if( $browserId == 'UNK')
 	{
-		return Piwik_Translate('General_Unknown');
+		return html_entity_decode(Piwik_Translate('General_Unknown'), ENT_COMPAT, 'UTF-8');
 	}
 	return $oldLabel;
 }
@@ -94,7 +111,7 @@ function Piwik_getBrowserShortLabel($oldLabel)
 	}
 	if( $browserId == 'UNK')
 	{
-		return Piwik_Translate('General_Unknown');
+		return html_entity_decode(Piwik_Translate('General_Unknown'), ENT_COMPAT, 'UTF-8');
 	}
 	return $oldLabel;
 }
@@ -112,18 +129,18 @@ function Piwik_getBrowserVersion($str)
 function Piwik_getBrowsersLogo($label)
 {
 	$id = Piwik_getBrowserId($label);
-	return  "plugins/UserSettings/images/browsers/". $id . ".gif";
+	return  'plugins/UserSettings/images/browsers/'. $id . '.gif';
 }
 
 function Piwik_getOSLogo($label)
 {
-	$path = "plugins/UserSettings/images/os/". $label . ".gif";
+	$path = 'plugins/UserSettings/images/os/'. $label . '.gif';
 	return $path;
 }
 
 function Piwik_getScreensLogo($label)
 {
-	return "plugins/UserSettings/images/screens/" . $label . ".gif";
+	return 'plugins/UserSettings/images/screens/' . $label . '.gif';
 }
 
 function Piwik_UserSettings_keepStrlenGreater($value)
