@@ -4,11 +4,12 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: UsersManager.php 622 2008-09-04 23:24:26Z matt $
+ * @version $Id: UsersManager.php 1665 2009-12-11 21:25:57Z vipsoft $
  * 
+ * @category Piwik_Plugins
  * @package Piwik_UsersManager
  */
-	
+
 /**
  * 
  * @package Piwik_UsersManager
@@ -21,8 +22,8 @@ class Piwik_UsersManager extends Piwik_Plugin
 			'name' => 'Users Management',
 			'description' => 'Users Management in Piwik: add a new User, edit an existing one, update the permissions. All the actions are also available through the API.',
 			'author' => 'Piwik',
-			'homepage' => 'http://piwik.org/',
-			'version' => '0.1',
+			'author_homepage' => 'http://piwik.org/',
+			'version' => Piwik_Version::VERSION,
 		);
 		
 		return $info;
@@ -35,7 +36,7 @@ class Piwik_UsersManager extends Piwik_Plugin
 	
 	function addMenu()
 	{
-		Piwik_AddAdminMenu(Piwik_Translate('UsersManager_MenuUsers'), array('module' => 'UsersManager', 'action' => 'index'));		
+		Piwik_AddAdminMenu('UsersManager_MenuUsers', array('module' => 'UsersManager', 'action' => 'index'));		
 	}
 }
 
