@@ -4,13 +4,14 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: VisitFrequency.php 1072 2009-04-27 04:18:16Z matt $
+ * @version $Id: VisitFrequency.php 1665 2009-12-11 21:25:57Z vipsoft $
  * 
+ * @category Piwik_Plugins
  * @package Piwik_VisitFrequency
  */
-	
+
 /**
- * 
+ *
  * @package Piwik_VisitFrequency
  */
 class Piwik_VisitFrequency extends Piwik_Plugin
@@ -21,8 +22,8 @@ class Piwik_VisitFrequency extends Piwik_Plugin
 			'name' => 'Visits Frequency',
 			'description' => 'Reports various statistics about the Returning Visitor versus the First time visitor.',
 			'author' => 'Piwik',
-			'homepage' => 'http://piwik.org/',
-			'version' => '0.1',
+			'author_homepage' => 'http://piwik.org/',
+			'version' => Piwik_Version::VERSION,
 		);
 		return $info;
 	}
@@ -82,7 +83,7 @@ class Piwik_VisitFrequency extends Piwik_Plugin
 				 	GROUP BY visitor_returning";
 		$row = $archiveProcessing->db->fetchRow($query, array( $archiveProcessing->strDateStart, $archiveProcessing->idsite ) );
 		
-		if($row==false)
+		if($row === false || $row === null)
 		{
 			$row['nb_visits_returning'] = 0;
 			$row['nb_actions_returning'] = 0;
