@@ -1,11 +1,24 @@
 <?php
+/**
+ * Piwik - Open source web analytics
+ * 
+ * @link http://piwik.org
+ * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
+ * @version $Id: Controller.php 1420 2009-08-22 13:23:16Z vipsoft $
+ * 
+ * @category Piwik_Plugins
+ * @package Piwik_VisitTime
+ */
 
-require_once "ViewDataTable.php";
+/**
+ *
+ * @package Piwik_VisitTime
+ */
 class Piwik_VisitTime_Controller extends Piwik_Controller 
 {
 	function index()
 	{
-		$view = new Piwik_View('VisitTime/templates/index.tpl');
+		$view = Piwik_View::factory('index');
 		$view->dataTableVisitInformationPerLocalTime = $this->getVisitInformationPerLocalTime(true);
 		$view->dataTableVisitInformationPerServerTime = $this->getVisitInformationPerServerTime(true);
 		echo $view->render();
