@@ -4,13 +4,14 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: API.php 1158 2009-05-31 11:31:14Z matt $
+ * @version $Id: API.php 1420 2009-08-22 13:23:16Z vipsoft $
  * 
+ * @category Piwik_Plugins
  * @package Piwik_VisitorInterest
  */
 
-
 /**
+ *
  * @package Piwik_VisitorInterest
  */
 class Piwik_VisitorInterest_API 
@@ -78,7 +79,7 @@ function Piwik_getDurationLabel($label)
 	}
 	$time = intval($label) / 60;
 	$plusXMin = Piwik_Translate('VisitorInterest_PlusXMin');
-	return sprintf($plusXMin, '+' . $time);
+	return sprintf($plusXMin, $time . urlencode('+'));
 }
 
 function Piwik_getPageGapLabel($label)
