@@ -1,11 +1,23 @@
 <?php
+/**
+ * Piwik - Open source web analytics
+ * 
+ * @link http://piwik.org
+ * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
+ * @version $Id: Controller.php 1420 2009-08-22 13:23:16Z vipsoft $
+ * 
+ * @category Piwik_Plugins
+ * @package Piwik_VisitorInterest
+ */
 
-require_once "ViewDataTable.php";
+/**
+ * @package Piwik_VisitorInterest
+ */
 class Piwik_VisitorInterest_Controller extends Piwik_Controller 
 {
 	function index()
 	{
-		$view = new Piwik_View('VisitorInterest/templates/index.tpl');
+		$view = Piwik_View::factory('index');
 		$view->dataTableNumberOfVisitsPerVisitDuration = $this->getNumberOfVisitsPerVisitDuration(true);
 		$view->dataTableNumberOfVisitsPerPage = $this->getNumberOfVisitsPerPage(true);
 		echo $view->render();
@@ -17,6 +29,7 @@ class Piwik_VisitorInterest_Controller extends Piwik_Controller
 		$view->init( $this->pluginName,  __FUNCTION__, "VisitorInterest.getNumberOfVisitsPerVisitDuration" );
 		
 		$view->setColumnsToDisplay( array('label','nb_visits') );
+		$view->setSortedColumn( 'label', 'asc' );
 		$view->setColumnTranslation('label', Piwik_Translate('VisitorInterest_ColumnVisitDuration'));
 		$view->disableSort();
 		$view->disableExcludeLowPopulation();
