@@ -4,13 +4,14 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: VisitorInterest.php 1072 2009-04-27 04:18:16Z matt $
+ * @version $Id: VisitorInterest.php 1665 2009-12-11 21:25:57Z vipsoft $
  * 
+ * @category Piwik_Plugins
  * @package Piwik_VisitorInterest
  */
-	
+
 /**
- * 
+ *
  * @package Piwik_VisitorInterest
  */
 class Piwik_VisitorInterest extends Piwik_Plugin
@@ -21,8 +22,8 @@ class Piwik_VisitorInterest extends Piwik_Plugin
 			'name' => 'Visitors Interest',
 			'description' => 'Reports about the Visitor Interest: number of pages viewed, time spent on the Website.',
 			'author' => 'Piwik',
-			'homepage' => 'http://piwik.org/',
-			'version' => '0.1',
+			'author_homepage' => 'http://piwik.org/',
+			'version' => Piwik_Version::VERSION,
 		);
 		
 		return $info;
