@@ -1,11 +1,24 @@
 <?php
-require_once "ViewDataTable.php";
+/**
+ * Piwik - Open source web analytics
+ * 
+ * @link http://piwik.org
+ * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
+ * @version $Id: Controller.php 1420 2009-08-22 13:23:16Z vipsoft $
+ * 
+ * @category Piwik_Plugins
+ * @package Piwik_VisitsSummary
+ */
 
+/**
+ *
+ * @package Piwik_VisitsSummary
+ */
 class Piwik_VisitsSummary_Controller extends Piwik_Controller 
 {
 	public function index()
 	{
-		$view = new Piwik_View('VisitsSummary/templates/index.tpl');
+		$view = Piwik_View::factory('index');
 		$this->setPeriodVariablesView($view);
 		$view->graphEvolutionVisitsSummary = $this->getEvolutionGraph( true, array('nb_visits') );
 		$this->setSparklinesAndNumbers($view);		
@@ -14,7 +27,7 @@ class Piwik_VisitsSummary_Controller extends Piwik_Controller
 	
 	public function getSparklines()
 	{
-		$view = new Piwik_View('VisitsSummary/templates/sparklines.tpl');
+		$view = Piwik_View::factory('sparklines');
 		$this->setSparklinesAndNumbers($view);		
 		echo $view->render();
 	}
@@ -60,7 +73,7 @@ class Piwik_VisitsSummary_Controller extends Piwik_Controller
 		
 		$dataTableVisit = self::getVisitsSummary();
 		$dataRow = $dataTableVisit->getFirstRow();
-		if($view->period == 'day')
+		if($view->period != 'year')
 		{
 			$view->urlSparklineNbUniqVisitors 	= $this->getUrlSparkline( 'getEvolutionGraph', array('columns' => array('nb_uniq_visitors')));
 			$view->nbUniqVisitors = $dataRow->getColumn('nb_uniq_visitors');
