@@ -4,11 +4,16 @@
  * 
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html Gpl v3 or later
- * @version $Id: ExamplePlugin.php 169 2008-01-14 05:41:15Z matt $
+ * @version $Id: Widgetize.php 1665 2009-12-11 21:25:57Z vipsoft $
  * 
+ * @category Piwik_Plugins
  * @package Piwik_Widgetize
  */
 
+/**
+ * 
+ * @package Piwik_Widgetize
+ */
 class Piwik_Widgetize extends Piwik_Plugin
 {
 	public function getInformation()
@@ -17,8 +22,8 @@ class Piwik_Widgetize extends Piwik_Plugin
 			'name' => 'Widgetize your data!',
 			'description' => 'The plugin makes it very easy to export any Piwik Widget in your Blog, Website or on Igoogle and Netvibes!',
 			'author' => 'Piwik',
-			'homepage' => 'http://piwik.org/',
-			'version' => '0.1',
+			'author_homepage' => 'http://piwik.org/',
+			'version' => Piwik_Version::VERSION,
 		);
 	}
 }
