@@ -73,7 +73,8 @@ function widgetize()
 			.each(function() {
 				var htmlEmbed = $(this).parent().html();
 
-				htmlEmbed = htmlEmbed.replace(/ (data|href|src)="(?!javascript:)/g, ' $1="' + piwik.piwik_url);
+				htmlEmbed = htmlEmbed.replace(/ (data=")/, ' $1' + unescape(piwik.piwik_url));
+				htmlEmbed = htmlEmbed.replace(/ (value=")x-(data-file=)/, ' $1$2' + piwik.piwik_url + 'index.php');
 
 				$(exportButtonsElement).append(
 					'<div id="embedThisWidgetFlash">'+
@@ -83,18 +84,28 @@ function widgetize()
 						'</span>'+
 					'</div>'
 				);
+		});
+				
+		// 0.5: Removing launchpad feature as it doesn't seem to work well despite us contacting Clearspring
+		if(false) {
+			$(exportButtonsElement).append(
+				'<div id="embedThisWidgetEverywhere">'+
+					'<div id="exportThisWidget">'+
+						'<label for="flashEmbed">&rsaquo; Export anywhere!</label>'+
+						'<img src="http://cdn.clearspring.com/launchpad/static/cs_button_share1.gif">'+
+					'</div>'+
+					'<div id="exportThisWidgetMenu"></div>'+
+				'</div>'
+			);
+			// Call clearspring
+			$Launchpad.ShowButton({
+									actionElement : "exportThisWidget",
+									targetElement : "exportThisWidgetMenu",
+									userId : "4797da88692e4fe9",
+									widgetName : widgetName + " - Piwik",
+									source : "iframeDivToExport"
 			});
-		
-		// Add the Clearspring Export 
-		$(exportButtonsElement).append(
-			'<div id="embedThisWidgetEverywhere">'+
-				'<div id="exportThisWidget">'+
-					'<label for="flashEmbed">&rsaquo; Export anywhere!</label>'+
-					'<img src="http://cdn.clearspring.com/launchpad/static/cs_button_share1.gif">'+
-				'</div>'+
-				'<div id="exportThisWidgetMenu"></div>'+
-			'</div>'
-		);
+		}
 
 		// We then replace the div iframeDivToExport with the actual Iframe html
 		// Clearspring will then build a widget that has the same html as this div
@@ -106,15 +117,6 @@ function widgetize()
 			.parent()
 			.append(exportButtonsElement);
 		
-		// Call clearspring
-		$Launchpad.ShowButton({
-								actionElement : "exportThisWidget",
-								targetElement : "exportThisWidgetMenu",
-								userId : "4797da88692e4fe9",
-								widgetName : widgetName + " - Piwik",
-								source : "iframeDivToExport"
-		});
-
 		// JS is buggy at least on IE
 		//var widgetJS = '<script type="text/javascript" src="'+ getEmbedUrl(pluginId, actionId, "js") +'"></scr'+'ipt>';
 		//divEmbedThisWidget.append('<br/>Embed JS: '+ getInputFormWithHtml('javascriptEmbed', widgetJS));
